""" Cisco_IOS_XR_ipv4_bgp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-bgp package operational data.

This module contains definitions
for the following management objects\:
  bgp\: BGP operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BgpAfi(Enum):
    """
    BgpAfi

    BGP Address family

    .. data:: ipv4 = 0

    	IP v4 unicast

    .. data:: ipv4_multicast = 1

    	IP v4 multicast

    .. data:: ipv4_labeled = 2

    	IP v4 label

    .. data:: ipv4_tunnel = 3

    	IP v4 Tunnel

    .. data:: vpnv4 = 4

    	IP v4 virtual private network

    .. data:: ipv6 = 5

    	IP v6 unicast

    .. data:: ipv6_multicast = 6

    	IP v6 multicast

    .. data:: ipv6_labeled = 7

    	IP v6 label

    .. data:: vpnv6 = 8

    	IP v6 virtual private network

    .. data:: ipv4_mdt = 9

    	IP v4 Multicast  Distribution Tree

    .. data:: l2vpn_vpls = 10

    	L2VPN VPLS

    .. data:: rt_constraint = 11

    	IP RT-Constraint

    .. data:: ipv4_mvpn = 12

    	IP v4 mvpn

    .. data:: ipv6_mvpn = 13

    	IP v6 mvpn

    .. data:: l2vpn_evpn = 14

    	L2VPN EVPN

    .. data:: ls_ls = 15

    	Link-state Link-state

    .. data:: vpnv4_multicast = 16

    	IP v4 virtual private network for multicast

    .. data:: vpnv6_multicast = 17

    	IP v6 virtual private network for multicast

    .. data:: ipv4_flowspec = 18

    	IP v4 flowspec

    .. data:: ipv6_flowspec = 19

    	IP v6 flowspec

    .. data:: vpnv4_flowspec = 20

    	IP v4 vpn flowspec

    .. data:: vpnv6_flowspec = 21

    	IP v6 vpn flowspec

    .. data:: l2vpn_mspw = 22

    	L2VPN Multi-segment pseudowire

    .. data:: ipv4_sr_policy = 23

    	IP v4 SR Policy

    .. data:: ipv6_sr_policy = 24

    	IP v6 SR Policy

    .. data:: no_address_family = 25

    	Address-family not applicable

    .. data:: all_address_families = 26

    	All address-families

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv4_multicast = Enum.YLeaf(1, "ipv4-multicast")

    ipv4_labeled = Enum.YLeaf(2, "ipv4-labeled")

    ipv4_tunnel = Enum.YLeaf(3, "ipv4-tunnel")

    vpnv4 = Enum.YLeaf(4, "vpnv4")

    ipv6 = Enum.YLeaf(5, "ipv6")

    ipv6_multicast = Enum.YLeaf(6, "ipv6-multicast")

    ipv6_labeled = Enum.YLeaf(7, "ipv6-labeled")

    vpnv6 = Enum.YLeaf(8, "vpnv6")

    ipv4_mdt = Enum.YLeaf(9, "ipv4-mdt")

    l2vpn_vpls = Enum.YLeaf(10, "l2vpn-vpls")

    rt_constraint = Enum.YLeaf(11, "rt-constraint")

    ipv4_mvpn = Enum.YLeaf(12, "ipv4-mvpn")

    ipv6_mvpn = Enum.YLeaf(13, "ipv6-mvpn")

    l2vpn_evpn = Enum.YLeaf(14, "l2vpn-evpn")

    ls_ls = Enum.YLeaf(15, "ls-ls")

    vpnv4_multicast = Enum.YLeaf(16, "vpnv4-multicast")

    vpnv6_multicast = Enum.YLeaf(17, "vpnv6-multicast")

    ipv4_flowspec = Enum.YLeaf(18, "ipv4-flowspec")

    ipv6_flowspec = Enum.YLeaf(19, "ipv6-flowspec")

    vpnv4_flowspec = Enum.YLeaf(20, "vpnv4-flowspec")

    vpnv6_flowspec = Enum.YLeaf(21, "vpnv6-flowspec")

    l2vpn_mspw = Enum.YLeaf(22, "l2vpn-mspw")

    ipv4_sr_policy = Enum.YLeaf(23, "ipv4-sr-policy")

    ipv6_sr_policy = Enum.YLeaf(24, "ipv6-sr-policy")

    no_address_family = Enum.YLeaf(25, "no-address-family")

    all_address_families = Enum.YLeaf(26, "all-address-families")


class BgpBagUpdErrAction(Enum):
    """
    BgpBagUpdErrAction

    Bgp bag upd err action

    .. data:: bgp_bag_upd_err_action_none = 0

    	No Action

    .. data:: bgp_bag_upd_err_action_discard_msg = 1

    	Discard Message

    .. data:: bgp_bag_upd_err_action_reset = 2

    	Session Reset

    .. data:: bgp_bag_upd_err_action_wdr_or_reset = 3

    	Withdraw NLRI or Reset

    .. data:: bgp_bag_upd_err_action_wdr = 4

    	Withdraw NLRI

    .. data:: bgp_bag_upd_err_action_discard_attr = 5

    	Discard Attribute

    .. data:: bgp_bag_upd_err_action_local_repair = 6

    	Local Repair

    .. data:: bgp_bag_upd_err_action_max = 7

    	Maximum number of actions

    """

    bgp_bag_upd_err_action_none = Enum.YLeaf(0, "bgp-bag-upd-err-action-none")

    bgp_bag_upd_err_action_discard_msg = Enum.YLeaf(1, "bgp-bag-upd-err-action-discard-msg")

    bgp_bag_upd_err_action_reset = Enum.YLeaf(2, "bgp-bag-upd-err-action-reset")

    bgp_bag_upd_err_action_wdr_or_reset = Enum.YLeaf(3, "bgp-bag-upd-err-action-wdr-or-reset")

    bgp_bag_upd_err_action_wdr = Enum.YLeaf(4, "bgp-bag-upd-err-action-wdr")

    bgp_bag_upd_err_action_discard_attr = Enum.YLeaf(5, "bgp-bag-upd-err-action-discard-attr")

    bgp_bag_upd_err_action_local_repair = Enum.YLeaf(6, "bgp-bag-upd-err-action-local-repair")

    bgp_bag_upd_err_action_max = Enum.YLeaf(7, "bgp-bag-upd-err-action-max")


class BgpBagUpdFilterAction(Enum):
    """
    BgpBagUpdFilterAction

    Bgp bag upd filter action

    .. data:: none = 0

    	No Action

    .. data:: withdraw = 1

    	Withdraw NLRI

    .. data:: attribute_discard = 2

    	Discard Attribute

    """

    none = Enum.YLeaf(0, "none")

    withdraw = Enum.YLeaf(1, "withdraw")

    attribute_discard = Enum.YLeaf(2, "attribute-discard")


class BgpBfdEnableMode(Enum):
    """
    BgpBfdEnableMode

    BFD enable mode

    .. data:: bgp_bfd_enable_mode_disable = 0

    	BFD fast detect disabled 

    .. data:: bgp_bfd_enable_mode_def = 1

    	BFD fast detect default mode 

    .. data:: bgp_bfd_enable_mode_strict = 2

    	BFD fast detect hold down aka strict mode

    """

    bgp_bfd_enable_mode_disable = Enum.YLeaf(0, "bgp-bfd-enable-mode-disable")

    bgp_bfd_enable_mode_def = Enum.YLeaf(1, "bgp-bfd-enable-mode-def")

    bgp_bfd_enable_mode_strict = Enum.YLeaf(2, "bgp-bfd-enable-mode-strict")


class BgpBfdState(Enum):
    """
    BgpBfdState

    BFD session state

    .. data:: bgp_bfd_state_not_configured = 0

    	BFD not configured

    .. data:: bgp_bfd_state_admin_down = 1

    	BFD session disabled (neighbor shutdown)

    .. data:: bgp_bfd_state_not_supported = 2

    	BFD session disabled (interface type not

    	supported)

    .. data:: bgp_bfd_state_not_created = 3

    	BFD session configured, not yet created

    .. data:: bgp_bfd_state_created = 4

    	BFD session created, state notification not

    	received

    .. data:: bgp_bfd_state_up = 5

    	BFD session up

    .. data:: bgp_bfd_state_down = 6

    	BFD session down

    .. data:: bgp_bfd_state_nbr_not_configured = 7

    	BFD session down (peer not configured)

    .. data:: bgp_bfd_state_none = 8

    	BFD session (yet ro rcv Notification)

    """

    bgp_bfd_state_not_configured = Enum.YLeaf(0, "bgp-bfd-state-not-configured")

    bgp_bfd_state_admin_down = Enum.YLeaf(1, "bgp-bfd-state-admin-down")

    bgp_bfd_state_not_supported = Enum.YLeaf(2, "bgp-bfd-state-not-supported")

    bgp_bfd_state_not_created = Enum.YLeaf(3, "bgp-bfd-state-not-created")

    bgp_bfd_state_created = Enum.YLeaf(4, "bgp-bfd-state-created")

    bgp_bfd_state_up = Enum.YLeaf(5, "bgp-bfd-state-up")

    bgp_bfd_state_down = Enum.YLeaf(6, "bgp-bfd-state-down")

    bgp_bfd_state_nbr_not_configured = Enum.YLeaf(7, "bgp-bfd-state-nbr-not-configured")

    bgp_bfd_state_none = Enum.YLeaf(8, "bgp-bfd-state-none")


class BgpBindingSid(Enum):
    """
    BgpBindingSid

    BGP Binding SID type

    .. data:: none = 0

    	None

    .. data:: label = 1

    	Binding SID type MPLS label

    .. data:: v6 = 2

    	Binding SID type ipv6

    """

    none = Enum.YLeaf(0, "none")

    label = Enum.YLeaf(1, "label")

    v6 = Enum.YLeaf(2, "v6")


class BgpBmpState(Enum):
    """
    BgpBmpState

    BMP Connection State

    .. data:: none = 0

    	BMP NOT Connected

    .. data:: connecting = 1

    	BMP Under Connection

    .. data:: established = 2

    	BMP Connection Established

    .. data:: closing = 3

    	BMP Connection Closing

    """

    none = Enum.YLeaf(0, "none")

    connecting = Enum.YLeaf(1, "connecting")

    established = Enum.YLeaf(2, "established")

    closing = Enum.YLeaf(3, "closing")


class BgpBmpUpdMode(Enum):
    """
    BgpBmpUpdMode

    Bgp bmp upd mode

    .. data:: bgp_bmp_upd_n_either = 0

    	Neither of the modes are enabled

    .. data:: bgp_bmp_upd_route_mon = 1

    	Route Monotoring mode enabled

    .. data:: bgp_bmp_upd_route_mirr = 2

    	Route Mirroring mode is enabled

    """

    bgp_bmp_upd_n_either = Enum.YLeaf(0, "bgp-bmp-upd-n-either")

    bgp_bmp_upd_route_mon = Enum.YLeaf(1, "bgp-bmp-upd-route-mon")

    bgp_bmp_upd_route_mirr = Enum.YLeaf(2, "bgp-bmp-upd-route-mirr")


class BgpBpStage(Enum):
    """
    BgpBpStage

    Bgp bp stage

    .. data:: bgp_bp_comp_not_compared = 0

    	Best path comparison not performed

    .. data:: bgp_bp_comp_imulti_path = 1

    	Path is an iBGP multipath

    .. data:: bgp_bp_comp_emulti_path = 2

    	Path is an eBGP multipath

    .. data:: bgp_bp_comp_eimulti_path = 3

    	Path is an eiBGP multipath

    .. data:: bgp_bp_invalid_path = 4

    	Invalid path

    .. data:: bgp_bp_comp_pre_cost_comm = 5

    	TODO

    .. data:: bgp_bp_comp_weight = 6

    	Path has a lower weight

    .. data:: bgp_bp_comp_locpref = 7

    	Path has a lower local preference

    .. data:: bgp_bp_comp_rpki = 8

    	Path has worse origin validation state

    .. data:: bgp_bp_comp_aigp = 9

    	TODO

    .. data:: bgp_bp_comp_local = 10

    	Path is not local

    .. data:: bgp_bp_comp_local_rib = 11

    	TODO

    .. data:: bgp_bp_comp_as_path_len = 12

    	Path has a longer AS path

    .. data:: bgp_bp_comp_origin = 13

    	Path has a less favorable origin

    .. data:: bgp_bp_comp_med = 14

    	Path has a lower MED

    .. data:: bgp_bp_comp_ebgp = 15

    	Path lost to an eBGP path

    .. data:: bgp_bp_comp_ao = 16

    	Path has Accept-Own community

    .. data:: bgp_bp_comp_igp_metric = 17

    	Path has a higher IGP metric

    .. data:: bgp_bp_comp_igp_cost_comm = 18

    	TODO

    .. data:: bgp_bp_comp_rtr_id = 19

    	Path has a higher router ID

    .. data:: bgp_bp_comp_clstr_len = 20

    	Path has a longer cluster length

    .. data:: bgp_bp_comp_nbr_addr = 21

    	Path has a higher neighbor address

    .. data:: bgp_bp_comp_suppressed = 22

    	Path is newer than best path

    .. data:: bgp_bp_comp_mismatch = 23

    	Best path comparison failed, perhaps due to

    	recent configuration changes

    .. data:: bgp_bp_comp_persistence = 24

    	Path is persistent

    """

    bgp_bp_comp_not_compared = Enum.YLeaf(0, "bgp-bp-comp-not-compared")

    bgp_bp_comp_imulti_path = Enum.YLeaf(1, "bgp-bp-comp-imulti-path")

    bgp_bp_comp_emulti_path = Enum.YLeaf(2, "bgp-bp-comp-emulti-path")

    bgp_bp_comp_eimulti_path = Enum.YLeaf(3, "bgp-bp-comp-eimulti-path")

    bgp_bp_invalid_path = Enum.YLeaf(4, "bgp-bp-invalid-path")

    bgp_bp_comp_pre_cost_comm = Enum.YLeaf(5, "bgp-bp-comp-pre-cost-comm")

    bgp_bp_comp_weight = Enum.YLeaf(6, "bgp-bp-comp-weight")

    bgp_bp_comp_locpref = Enum.YLeaf(7, "bgp-bp-comp-locpref")

    bgp_bp_comp_rpki = Enum.YLeaf(8, "bgp-bp-comp-rpki")

    bgp_bp_comp_aigp = Enum.YLeaf(9, "bgp-bp-comp-aigp")

    bgp_bp_comp_local = Enum.YLeaf(10, "bgp-bp-comp-local")

    bgp_bp_comp_local_rib = Enum.YLeaf(11, "bgp-bp-comp-local-rib")

    bgp_bp_comp_as_path_len = Enum.YLeaf(12, "bgp-bp-comp-as-path-len")

    bgp_bp_comp_origin = Enum.YLeaf(13, "bgp-bp-comp-origin")

    bgp_bp_comp_med = Enum.YLeaf(14, "bgp-bp-comp-med")

    bgp_bp_comp_ebgp = Enum.YLeaf(15, "bgp-bp-comp-ebgp")

    bgp_bp_comp_ao = Enum.YLeaf(16, "bgp-bp-comp-ao")

    bgp_bp_comp_igp_metric = Enum.YLeaf(17, "bgp-bp-comp-igp-metric")

    bgp_bp_comp_igp_cost_comm = Enum.YLeaf(18, "bgp-bp-comp-igp-cost-comm")

    bgp_bp_comp_rtr_id = Enum.YLeaf(19, "bgp-bp-comp-rtr-id")

    bgp_bp_comp_clstr_len = Enum.YLeaf(20, "bgp-bp-comp-clstr-len")

    bgp_bp_comp_nbr_addr = Enum.YLeaf(21, "bgp-bp-comp-nbr-addr")

    bgp_bp_comp_suppressed = Enum.YLeaf(22, "bgp-bp-comp-suppressed")

    bgp_bp_comp_mismatch = Enum.YLeaf(23, "bgp-bp-comp-mismatch")

    bgp_bp_comp_persistence = Enum.YLeaf(24, "bgp-bp-comp-persistence")


class BgpConnState(Enum):
    """
    BgpConnState

    Bgp conn state

    .. data:: bgp_st_dont_care = 0

    	DontCare

    .. data:: bgp_st_idle = 1

    	Idle

    .. data:: bgp_st_connect = 2

    	Connect

    .. data:: bgp_st_active = 3

    	Active

    .. data:: bgp_st_open_sent = 4

    	OpenSent

    .. data:: bgp_st_open_confirm = 5

    	OpenConfirm

    .. data:: bgp_st_estab = 6

    	Established

    .. data:: bgp_st_closing = 7

    	Closing

    .. data:: bgp_st_closing_sync = 8

    	ClosingSync

    """

    bgp_st_dont_care = Enum.YLeaf(0, "bgp-st-dont-care")

    bgp_st_idle = Enum.YLeaf(1, "bgp-st-idle")

    bgp_st_connect = Enum.YLeaf(2, "bgp-st-connect")

    bgp_st_active = Enum.YLeaf(3, "bgp-st-active")

    bgp_st_open_sent = Enum.YLeaf(4, "bgp-st-open-sent")

    bgp_st_open_confirm = Enum.YLeaf(5, "bgp-st-open-confirm")

    bgp_st_estab = Enum.YLeaf(6, "bgp-st-estab")

    bgp_st_closing = Enum.YLeaf(7, "bgp-st-closing")

    bgp_st_closing_sync = Enum.YLeaf(8, "bgp-st-closing-sync")


class BgpDsConnState(Enum):
    """
    BgpDsConnState

    Bgp ds conn state

    .. data:: none = 0

    	DS connection not initiated - ST 0

    .. data:: connect_init = 1

    	DS connection initiated - ST 1

    .. data:: connect_fail = 2

    	DS connection failed - ST 2

    .. data:: connect_estb = 3

    	DS connection established - ST 3

    .. data:: disconnect_init = 4

    	DS disconnect initiated - ST 4

    .. data:: disconnect_fail = 5

    	DS disconnect failed - ST 5

    .. data:: disconnect_done = 6

    	DS disconnect done - ST 6

    """

    none = Enum.YLeaf(0, "none")

    connect_init = Enum.YLeaf(1, "connect-init")

    connect_fail = Enum.YLeaf(2, "connect-fail")

    connect_estb = Enum.YLeaf(3, "connect-estb")

    disconnect_init = Enum.YLeaf(4, "disconnect-init")

    disconnect_fail = Enum.YLeaf(5, "disconnect-fail")

    disconnect_done = Enum.YLeaf(6, "disconnect-done")


class BgpEbgpSendDmzEnableMode(Enum):
    """
    BgpEbgpSendDmzEnableMode

    EBGP send extended community dmz link bandwidth

    enable mode

    .. data:: bgp_ebgp_send_dmz_disable = 0

    	EBGP send extended community dmz link bandwidth

    	disabled 

    .. data:: bgp_ebgp_send_dmz_dflt = 1

    	EBGP send extended community dmz link bandwidth

    	default mode 

    .. data:: bgp_ebgp_send_dmz_cumulative = 2

    	EBGP send extended community dmz link bandwidth

    	cumulative mode

    """

    bgp_ebgp_send_dmz_disable = Enum.YLeaf(0, "bgp-ebgp-send-dmz-disable")

    bgp_ebgp_send_dmz_dflt = Enum.YLeaf(1, "bgp-ebgp-send-dmz-dflt")

    bgp_ebgp_send_dmz_cumulative = Enum.YLeaf(2, "bgp-ebgp-send-dmz-cumulative")


class BgpEntities(Enum):
    """
    BgpEntities

    Entity type

    .. data:: af_group = 0

    	AF groups

    .. data:: session_group = 1

    	Session Groups

    .. data:: neighbor_group = 2

    	Neighbor Groups

    .. data:: neighbor = 3

    	Neighbors

    """

    af_group = Enum.YLeaf(0, "af-group")

    session_group = Enum.YLeaf(1, "session-group")

    neighbor_group = Enum.YLeaf(2, "neighbor-group")

    neighbor = Enum.YLeaf(3, "neighbor")


class BgpEntity(Enum):
    """
    BgpEntity

    Bgp entity

    .. data:: af_group = 0

    	Address family group

    .. data:: session_group = 1

    	Session group

    .. data:: neighbor_group = 2

    	Neighbor group

    .. data:: neighbor = 3

    	Neighbor

    """

    af_group = Enum.YLeaf(0, "af-group")

    session_group = Enum.YLeaf(1, "session-group")

    neighbor_group = Enum.YLeaf(2, "neighbor-group")

    neighbor = Enum.YLeaf(3, "neighbor")


class BgpIsmConnState(Enum):
    """
    BgpIsmConnState

    Bgp ism conn state

    .. data:: none = 0

    	None - ST 0

    .. data:: connect_done = 1

    	ISSUMgr connection done - ST 1

    """

    none = Enum.YLeaf(0, "none")

    connect_done = Enum.YLeaf(1, "connect-done")


class BgpLabelRpfInstall(Enum):
    """
    BgpLabelRpfInstall

    BGP Label RPF Install Path

    .. data:: bgp_label_rpf_install_rib = 0

    	Install via RIB

    .. data:: bgp_label_rpf_install_lsd = 1

    	Install via LSD

    """

    bgp_label_rpf_install_rib = Enum.YLeaf(0, "bgp-label-rpf-install-rib")

    bgp_label_rpf_install_lsd = Enum.YLeaf(1, "bgp-label-rpf-install-lsd")


class BgpNhEvent(Enum):
    """
    BgpNhEvent

    Bgp nh event

    .. data:: bgp_nh_event_crit_not_f = 0

    	Last event received is a crit notf

    .. data:: bgp_nh_event_non_crit_not_f = 1

    	Last event received is a non-crit notf

    .. data:: bgp_nh_event_registration = 2

    	Last event sent is a registration

    """

    bgp_nh_event_crit_not_f = Enum.YLeaf(0, "bgp-nh-event-crit-not-f")

    bgp_nh_event_non_crit_not_f = Enum.YLeaf(1, "bgp-nh-event-non-crit-not-f")

    bgp_nh_event_registration = Enum.YLeaf(2, "bgp-nh-event-registration")


class BgpNhUpdate(Enum):
    """
    BgpNhUpdate

    Bgp nh update

    .. data:: bgp_nh_update_none = 0

    	No nh update yet

    .. data:: bgp_nh_update_crit_not_f = 1

    	Last nh update is crit notf

    .. data:: bgp_nh_update_crit_sync = 2

    	Last nh update is crit sync update

    .. data:: bgp_nh_update_crit_rib_conv = 3

    	Last nh update is crit update caused by rib

    	converge

    .. data:: bgp_nh_update_crit_table_down = 4

    	Last nh update is crit update caused by table

    	down

    .. data:: bgp_nh_update_non_crit_not_f = 5

    	Last nh update is non-crit notf

    .. data:: bgp_nh_update_non_crit_sync = 6

    	Last nh update is non-crit sync update

    .. data:: bgp_nh_update_non_crit_rib_conv = 7

    	Last nh update is non-crit update caused by rib

    	converge

    .. data:: bgp_nh_update_non_crit_table_down = 8

    	Last nh update is non-crit update caused by

    	table down

    """

    bgp_nh_update_none = Enum.YLeaf(0, "bgp-nh-update-none")

    bgp_nh_update_crit_not_f = Enum.YLeaf(1, "bgp-nh-update-crit-not-f")

    bgp_nh_update_crit_sync = Enum.YLeaf(2, "bgp-nh-update-crit-sync")

    bgp_nh_update_crit_rib_conv = Enum.YLeaf(3, "bgp-nh-update-crit-rib-conv")

    bgp_nh_update_crit_table_down = Enum.YLeaf(4, "bgp-nh-update-crit-table-down")

    bgp_nh_update_non_crit_not_f = Enum.YLeaf(5, "bgp-nh-update-non-crit-not-f")

    bgp_nh_update_non_crit_sync = Enum.YLeaf(6, "bgp-nh-update-non-crit-sync")

    bgp_nh_update_non_crit_rib_conv = Enum.YLeaf(7, "bgp-nh-update-non-crit-rib-conv")

    bgp_nh_update_non_crit_table_down = Enum.YLeaf(8, "bgp-nh-update-non-crit-table-down")


class BgpNhValidate(Enum):
    """
    BgpNhValidate

    Bgp nh validate

    .. data:: bgp_nh_validate_sync = 0

    	bgp nh validate sync

    .. data:: bgp_nh_validate_async = 1

    	bgp nh validate async

    .. data:: bgp_nh_validate_none = 2

    	bgp nh validate none

    """

    bgp_nh_validate_sync = Enum.YLeaf(0, "bgp-nh-validate-sync")

    bgp_nh_validate_async = Enum.YLeaf(1, "bgp-nh-validate-async")

    bgp_nh_validate_none = Enum.YLeaf(2, "bgp-nh-validate-none")


class BgpOpenCheckErr(Enum):
    """
    BgpOpenCheckErr

    BGP open check error types

    .. data:: none = 0

    	No error

    .. data:: neighbor_down = 1

    	Neighbor down

    .. data:: no_update_group_set = 2

    	No update-group set

    .. data:: no_af_config = 3

    	No AF configured

    .. data:: update_group_pending = 4

    	Update-group pending

    .. data:: low_memory = 5

    	Low memory

    .. data:: neighbor_shutdown = 6

    	Neighbor shutdown

    .. data:: ebgp_neighbor_remote = 7

    	eBGP neighbor is remote

    .. data:: update_source_interface_null = 8

    	Update source invalid

    .. data:: no_ipv6_address = 9

    	No global IPv6 address found

    .. data:: first_hop_interface_null = 10

    	First-hop interface invalid

    .. data:: no_ipv6ll_address = 11

    	No LL IPv6 address found

    .. data:: no_update_source_config = 12

    	No update-source configured

    .. data:: no_router_id = 13

    	No router-identifier

    .. data:: update_source_interface_get_failed = 14

    	Update-source interface get failed

    .. data:: update_source_interface_state_get_failed = 15

    	Update-source interface state get failed

    .. data:: update_source_interface_down = 16

    	Update-source interface down

    .. data:: update_source_interface_ll_get_failed = 17

    	Update-source interface LL get failed

    .. data:: update_source_interface_address_get_failed = 18

    	Update-source interface address get failed

    .. data:: source_address_af_invalid = 19

    	Source-address AF invalid

    .. data:: no_update_source_ll_peering = 20

    	No update-source for LL peering

    .. data:: local_address_get_failed = 21

    	Local-address get failed

    .. data:: no_best_local_address = 22

    	No best local-address

    .. data:: neighbor_address_equals_local_address = 23

    	Neighbor address is local address

    .. data:: neighbor_closing = 24

    	Neighbor in closing state

    .. data:: neighbor_pending_reset = 25

    	Neighbor in pending reset state

    .. data:: out_interface_set_failed = 26

    	Out-interface set failed

    .. data:: local_address_mismatch = 27

    	Local-address mismatch

    .. data:: neighbor_active_only = 28

    	Neighbor in active only mode

    .. data:: socket_init_failed = 29

    	Socket init failed

    .. data:: socket_operation_failed = 30

    	Socket operation failed

    .. data:: local_neighbor = 31

    	Neighbor is local

    .. data:: multi_hop_neighbor = 32

    	No router to multi-hop neighbor

    """

    none = Enum.YLeaf(0, "none")

    neighbor_down = Enum.YLeaf(1, "neighbor-down")

    no_update_group_set = Enum.YLeaf(2, "no-update-group-set")

    no_af_config = Enum.YLeaf(3, "no-af-config")

    update_group_pending = Enum.YLeaf(4, "update-group-pending")

    low_memory = Enum.YLeaf(5, "low-memory")

    neighbor_shutdown = Enum.YLeaf(6, "neighbor-shutdown")

    ebgp_neighbor_remote = Enum.YLeaf(7, "ebgp-neighbor-remote")

    update_source_interface_null = Enum.YLeaf(8, "update-source-interface-null")

    no_ipv6_address = Enum.YLeaf(9, "no-ipv6-address")

    first_hop_interface_null = Enum.YLeaf(10, "first-hop-interface-null")

    no_ipv6ll_address = Enum.YLeaf(11, "no-ipv6ll-address")

    no_update_source_config = Enum.YLeaf(12, "no-update-source-config")

    no_router_id = Enum.YLeaf(13, "no-router-id")

    update_source_interface_get_failed = Enum.YLeaf(14, "update-source-interface-get-failed")

    update_source_interface_state_get_failed = Enum.YLeaf(15, "update-source-interface-state-get-failed")

    update_source_interface_down = Enum.YLeaf(16, "update-source-interface-down")

    update_source_interface_ll_get_failed = Enum.YLeaf(17, "update-source-interface-ll-get-failed")

    update_source_interface_address_get_failed = Enum.YLeaf(18, "update-source-interface-address-get-failed")

    source_address_af_invalid = Enum.YLeaf(19, "source-address-af-invalid")

    no_update_source_ll_peering = Enum.YLeaf(20, "no-update-source-ll-peering")

    local_address_get_failed = Enum.YLeaf(21, "local-address-get-failed")

    no_best_local_address = Enum.YLeaf(22, "no-best-local-address")

    neighbor_address_equals_local_address = Enum.YLeaf(23, "neighbor-address-equals-local-address")

    neighbor_closing = Enum.YLeaf(24, "neighbor-closing")

    neighbor_pending_reset = Enum.YLeaf(25, "neighbor-pending-reset")

    out_interface_set_failed = Enum.YLeaf(26, "out-interface-set-failed")

    local_address_mismatch = Enum.YLeaf(27, "local-address-mismatch")

    neighbor_active_only = Enum.YLeaf(28, "neighbor-active-only")

    socket_init_failed = Enum.YLeaf(29, "socket-init-failed")

    socket_operation_failed = Enum.YLeaf(30, "socket-operation-failed")

    local_neighbor = Enum.YLeaf(31, "local-neighbor")

    multi_hop_neighbor = Enum.YLeaf(32, "multi-hop-neighbor")


class BgpPeerResetReasonIndex(Enum):
    """
    BgpPeerResetReasonIndex

    Bgp peer reset reason index

    .. data:: bgp_read_remote_closed = 1

    	Remote closed the session

    .. data:: bgp_read_failed = 2

    	Read failed

    .. data:: bgp_write_failed = 3

    	Write failed

    .. data:: bgp_sock_disconnected = 4

    	Socket disconnected

    .. data:: bgp_sock_select_failed = 5

    	Socket select failed

    .. data:: bgp_peer_reset_reason_none = 6

    	None

    """

    bgp_read_remote_closed = Enum.YLeaf(1, "bgp-read-remote-closed")

    bgp_read_failed = Enum.YLeaf(2, "bgp-read-failed")

    bgp_write_failed = Enum.YLeaf(3, "bgp-write-failed")

    bgp_sock_disconnected = Enum.YLeaf(4, "bgp-sock-disconnected")

    bgp_sock_select_failed = Enum.YLeaf(5, "bgp-sock-select-failed")

    bgp_peer_reset_reason_none = Enum.YLeaf(6, "bgp-peer-reset-reason-none")


class BgpResetReasonIndex(Enum):
    """
    BgpResetReasonIndex

    Bgp reset reason index

    .. data:: bgp_none = 0

    	None

    .. data:: bgp_init = 1

    	BGP neighbor initialized

    .. data:: bgp_no_memory = 2

    	No memory

    .. data:: not_received = 3

    	BGP Notification received

    .. data:: not_sent = 4

    	BGP Notification sent

    .. data:: conn_collision = 5

    	Error during connection collision

    .. data:: peer_closed = 6

    	Peer closing down the session

    .. data:: max_prefix_exceeded = 7

    	Peer exceeding maximum prefix limit

    .. data:: interface_flap = 8

    	Interface flap

    .. data:: neighbor_deleted = 9

    	Neighbor deleted

    .. data:: admin_shutdown = 10

    	Admin. shutdown

    .. data:: af_activated = 11

    	Address family activated

    .. data:: af_deactivated = 12

    	Address family removed

    .. data:: protocol_error = 13

    	Protocol Error

    .. data:: listen_closed = 14

    	Listen socket was closed

    .. data:: rib_failed = 15

    	Routing Table process not responding

    .. data:: user_clear = 16

    	User clear requested

    .. data:: user_clear_gr = 17

    	User clear with graceful restart requested

    .. data:: router_id_changed = 18

    	Router ID changed

    .. data:: remote_as_changed = 19

    	Remote AS configuration changed

    .. data:: orf_changed = 20

    	Outbound route filter configuration changed

    .. data:: rr_client_changed = 21

    	RR client configuration changed

    .. data:: legacy_pe_rt_changed = 22

    	Legacy-pe-RT configuration changed

    .. data:: softre_config_changed = 23

    	Soft reconfiguration configuration changed

    .. data:: local_as_changed = 24

    	Local AS configuration changed

    .. data:: low_memory = 25

    	Shutdown during SEVERE low memory condition

    .. data:: bfd_down = 26

    	BFD (Bidirectional forwarding detection)

    	session down

    .. data:: allow_as_in_changed = 27

    	Allowas-in configuration has changed

    .. data:: recv_dmz_cfg = 28

    	Recv DMZ Config changed

    .. data:: cap_4byteas_changed = 29

    	Capablity 4-byte-as configuration has changed

    .. data:: tcp_oper_down = 30

    	Received tcp oper down

    .. data:: scoped_sync_retry = 31

    	Scoped sync is repeated due to strict          

    	prefix check failure

    .. data:: cluster_id_changed = 32

    	Neighbor moved to a new cluster

    .. data:: rr_disable_changed = 33

    	Client-to-client reflection disabled/enabled   

    	for cluster to which neighbor belongs

    .. data:: aigp_changed = 34

    	AIGP configuration has changed                 

    	for cluster to which neighbor belongs

    .. data:: signalling_changed = 35

    	L2VPN Signalling Changed

    .. data:: open_check_s_failed = 36

    	Session open checks failed

    .. data:: ao_changed = 37

    	Accept-own changed

    .. data:: llgr_staletime_changed = 38

    	Long-lived graceful-restart stale-time

    	configuration changed

    .. data:: llgr_capable_changed = 39

    	Long-lived graceful-restart capable

    	configuration changed

    .. data:: nbr_local_addr_changed = 40

    	Neighbor local address configuration changed

    .. data:: internal_vpn_client_changed = 41

    	Internal-vpn-client configuration changed

    .. data:: cap_suppress_all_changed = 42

    	All capabilities suppression changed

    """

    bgp_none = Enum.YLeaf(0, "bgp-none")

    bgp_init = Enum.YLeaf(1, "bgp-init")

    bgp_no_memory = Enum.YLeaf(2, "bgp-no-memory")

    not_received = Enum.YLeaf(3, "not-received")

    not_sent = Enum.YLeaf(4, "not-sent")

    conn_collision = Enum.YLeaf(5, "conn-collision")

    peer_closed = Enum.YLeaf(6, "peer-closed")

    max_prefix_exceeded = Enum.YLeaf(7, "max-prefix-exceeded")

    interface_flap = Enum.YLeaf(8, "interface-flap")

    neighbor_deleted = Enum.YLeaf(9, "neighbor-deleted")

    admin_shutdown = Enum.YLeaf(10, "admin-shutdown")

    af_activated = Enum.YLeaf(11, "af-activated")

    af_deactivated = Enum.YLeaf(12, "af-deactivated")

    protocol_error = Enum.YLeaf(13, "protocol-error")

    listen_closed = Enum.YLeaf(14, "listen-closed")

    rib_failed = Enum.YLeaf(15, "rib-failed")

    user_clear = Enum.YLeaf(16, "user-clear")

    user_clear_gr = Enum.YLeaf(17, "user-clear-gr")

    router_id_changed = Enum.YLeaf(18, "router-id-changed")

    remote_as_changed = Enum.YLeaf(19, "remote-as-changed")

    orf_changed = Enum.YLeaf(20, "orf-changed")

    rr_client_changed = Enum.YLeaf(21, "rr-client-changed")

    legacy_pe_rt_changed = Enum.YLeaf(22, "legacy-pe-rt-changed")

    softre_config_changed = Enum.YLeaf(23, "softre-config-changed")

    local_as_changed = Enum.YLeaf(24, "local-as-changed")

    low_memory = Enum.YLeaf(25, "low-memory")

    bfd_down = Enum.YLeaf(26, "bfd-down")

    allow_as_in_changed = Enum.YLeaf(27, "allow-as-in-changed")

    recv_dmz_cfg = Enum.YLeaf(28, "recv-dmz-cfg")

    cap_4byteas_changed = Enum.YLeaf(29, "cap-4byteas-changed")

    tcp_oper_down = Enum.YLeaf(30, "tcp-oper-down")

    scoped_sync_retry = Enum.YLeaf(31, "scoped-sync-retry")

    cluster_id_changed = Enum.YLeaf(32, "cluster-id-changed")

    rr_disable_changed = Enum.YLeaf(33, "rr-disable-changed")

    aigp_changed = Enum.YLeaf(34, "aigp-changed")

    signalling_changed = Enum.YLeaf(35, "signalling-changed")

    open_check_s_failed = Enum.YLeaf(36, "open-check-s-failed")

    ao_changed = Enum.YLeaf(37, "ao-changed")

    llgr_staletime_changed = Enum.YLeaf(38, "llgr-staletime-changed")

    llgr_capable_changed = Enum.YLeaf(39, "llgr-capable-changed")

    nbr_local_addr_changed = Enum.YLeaf(40, "nbr-local-addr-changed")

    internal_vpn_client_changed = Enum.YLeaf(41, "internal-vpn-client-changed")

    cap_suppress_all_changed = Enum.YLeaf(42, "cap-suppress-all-changed")


class BgpRnhAddrLen(Enum):
    """
    BgpRnhAddrLen

    BGP RNH Address Length

    .. data:: none = 0

    	NO address length

    .. data:: v4 = 4

    	IP v4 address length

    .. data:: mac = 6

    	MAC address length

    .. data:: v6 = 16

    	IP v6 address length

    """

    none = Enum.YLeaf(0, "none")

    v4 = Enum.YLeaf(4, "v4")

    mac = Enum.YLeaf(6, "mac")

    v6 = Enum.YLeaf(16, "v6")


class BgpRoute(Enum):
    """
    BgpRoute

    Bgp route

    .. data:: used = 0

    	Used path from neighbor

    .. data:: received_only = 1

    	Received only path from neighbor

    .. data:: safi_labeled_unicast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: safi_labeled_unicast_received_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: rib = 4

    	Redistributed from the RIB

    .. data:: aggregate = 5

    	Locally generated aggregate

    """

    used = Enum.YLeaf(0, "used")

    received_only = Enum.YLeaf(1, "received-only")

    safi_labeled_unicast_used = Enum.YLeaf(2, "safi-labeled-unicast-used")

    safi_labeled_unicast_received_only = Enum.YLeaf(3, "safi-labeled-unicast-received-only")

    rib = Enum.YLeaf(4, "rib")

    aggregate = Enum.YLeaf(5, "aggregate")


class BgpRoute1(Enum):
    """
    BgpRoute1

    Bgp route1

    .. data:: bgp_route_type_used = 0

    	Used path from neighbor

    .. data:: bgp_route_type_rcvd_only = 1

    	Received only path from neighbor

    .. data:: bgp_route_type_safi_label_ed_ucast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_safi_label_ed_ucast_rcvd_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_rib = 4

    	Redistributed from the RIB

    .. data:: bgp_route_type_aggregate = 5

    	Locally generated aggregate

    .. data:: bgp_route_type_max = 6

    	Number of route types

    """

    bgp_route_type_used = Enum.YLeaf(0, "bgp-route-type-used")

    bgp_route_type_rcvd_only = Enum.YLeaf(1, "bgp-route-type-rcvd-only")

    bgp_route_type_safi_label_ed_ucast_used = Enum.YLeaf(2, "bgp-route-type-safi-label-ed-ucast-used")

    bgp_route_type_safi_label_ed_ucast_rcvd_only = Enum.YLeaf(3, "bgp-route-type-safi-label-ed-ucast-rcvd-only")

    bgp_route_type_rib = Enum.YLeaf(4, "bgp-route-type-rib")

    bgp_route_type_aggregate = Enum.YLeaf(5, "bgp-route-type-aggregate")

    bgp_route_type_max = Enum.YLeaf(6, "bgp-route-type-max")


class BgpRpkiAf(Enum):
    """
    BgpRpkiAf

    Bgp rpki af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 26

    	IPv6

    """

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(26, "ipv6")


class BgpRpkiCreason(Enum):
    """
    BgpRpkiCreason

    Bgp rpki creason

    .. data:: no_close_reason = 0

    	No close reason

    .. data:: read_error = 1

    	Socket Read error

    .. data:: write_error = 2

    	Socket Write error

    .. data:: proto_error = 3

    	Protocol error

    .. data:: config_shutdown = 4

    	Shutdown by configuration

    .. data:: config_removed = 5

    	Configuration removed

    .. data:: config_changed = 6

    	Configuration changed

    .. data:: nsr_disabled = 7

    	NSR disabled

    .. data:: user_clear = 8

    	Explicity user clear

    .. data:: ssh_died = 9

    	SSH process died

    .. data:: tcp_died = 10

    	TCP process died

    """

    no_close_reason = Enum.YLeaf(0, "no-close-reason")

    read_error = Enum.YLeaf(1, "read-error")

    write_error = Enum.YLeaf(2, "write-error")

    proto_error = Enum.YLeaf(3, "proto-error")

    config_shutdown = Enum.YLeaf(4, "config-shutdown")

    config_removed = Enum.YLeaf(5, "config-removed")

    config_changed = Enum.YLeaf(6, "config-changed")

    nsr_disabled = Enum.YLeaf(7, "nsr-disabled")

    user_clear = Enum.YLeaf(8, "user-clear")

    ssh_died = Enum.YLeaf(9, "ssh-died")

    tcp_died = Enum.YLeaf(10, "tcp-died")


class BgpRpkiEdmAf(Enum):
    """
    BgpRpkiEdmAf

    Bgp rpki edm af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 10

    	IPv6

    """

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(10, "ipv6")


class BgpRpkiPerror(Enum):
    """
    BgpRpkiPerror

    Bgp rpki perror

    .. data:: none = 0

    	No protocol error

    .. data:: message_version = 1

    	Message version error

    .. data:: message_type = 2

    	Message type error

    .. data:: message_length = 3

    	Message length error

    .. data:: nonce_mismatch = 4

    	Server nonce mismatch

    .. data:: bad_prefix = 5

    	Bad ROA

    .. data:: fsm = 6

    	FSM error

    .. data:: no_response = 7

    	No response from server

    .. data:: error_report = 8

    	Server sent error-report

    """

    none = Enum.YLeaf(0, "none")

    message_version = Enum.YLeaf(1, "message-version")

    message_type = Enum.YLeaf(2, "message-type")

    message_length = Enum.YLeaf(3, "message-length")

    nonce_mismatch = Enum.YLeaf(4, "nonce-mismatch")

    bad_prefix = Enum.YLeaf(5, "bad-prefix")

    fsm = Enum.YLeaf(6, "fsm")

    no_response = Enum.YLeaf(7, "no-response")

    error_report = Enum.YLeaf(8, "error-report")


class BgpRpkiPstate(Enum):
    """
    BgpRpkiPstate

    Bgp rpki pstate

    .. data:: not_started = 0

    	Server protocol has not started

    .. data:: reset = 1

    	Server protocol reset

    .. data:: refresh = 2

    	Server protocol resumed

    .. data:: reset_query_sent = 3

    	Reset query sent to server

    .. data:: serial_query_sent = 4

    	Serial query sent to server

    .. data:: data_start = 5

    	Server started sending data

    .. data:: data_end = 6

    	Server ended sending data

    """

    not_started = Enum.YLeaf(0, "not-started")

    reset = Enum.YLeaf(1, "reset")

    refresh = Enum.YLeaf(2, "refresh")

    reset_query_sent = Enum.YLeaf(3, "reset-query-sent")

    serial_query_sent = Enum.YLeaf(4, "serial-query-sent")

    data_start = Enum.YLeaf(5, "data-start")

    data_end = Enum.YLeaf(6, "data-end")


class BgpRpkiState(Enum):
    """
    BgpRpkiState

    Bgp rpki state

    .. data:: idle = 0

    	Server is idle

    .. data:: attempt_connect = 1

    	Connect attempt made to server

    .. data:: connected = 2

    	Server is connected

    """

    idle = Enum.YLeaf(0, "idle")

    attempt_connect = Enum.YLeaf(1, "attempt-connect")

    connected = Enum.YLeaf(2, "connected")


class BgpRtrState(Enum):
    """
    BgpRtrState

    Bgp rtr state

    .. data:: bgp_router_read_only = 0

    	Read only mode

    .. data:: bgp_router_do_best_path = 1

    	Bestpath calculation mode

    .. data:: bgp_router_do_tunnel_update = 2

    	Tunnel update mode

    .. data:: bgp_router_do_import = 3

    	Import mode

    .. data:: bgp_router_do_label_alloc = 4

    	Label Allocation mode

    .. data:: bgp_router_do_ribupd = 5

    	RIB update mode

    .. data:: bgp_router_read_write = 6

    	Normal (read/write) mode

    .. data:: bgp_router_mode_count = 7

    	Number of router modes

    """

    bgp_router_read_only = Enum.YLeaf(0, "bgp-router-read-only")

    bgp_router_do_best_path = Enum.YLeaf(1, "bgp-router-do-best-path")

    bgp_router_do_tunnel_update = Enum.YLeaf(2, "bgp-router-do-tunnel-update")

    bgp_router_do_import = Enum.YLeaf(3, "bgp-router-do-import")

    bgp_router_do_label_alloc = Enum.YLeaf(4, "bgp-router-do-label-alloc")

    bgp_router_do_ribupd = Enum.YLeaf(5, "bgp-router-do-ribupd")

    bgp_router_read_write = Enum.YLeaf(6, "bgp-router-read-write")

    bgp_router_mode_count = Enum.YLeaf(7, "bgp-router-mode-count")


class BgpScopedSyncState(Enum):
    """
    BgpScopedSyncState

    Bgp scoped sync state

    .. data:: bgp_scope_sync_state_none = 0

    	State none

    .. data:: bgp_scope_sync_state_not_nsr_ready = 1

    	Oper Down when NSR not ready

    .. data:: bgp_scope_sync_state_timer_start = 2

    	Timer started for active batch

    .. data:: bgp_scope_sync_state_add_list = 3

    	Start adding neighbors to pending batch

    .. data:: bgp_scope_sync_state_batch_acitve = 4

    	Active batch

    """

    bgp_scope_sync_state_none = Enum.YLeaf(0, "bgp-scope-sync-state-none")

    bgp_scope_sync_state_not_nsr_ready = Enum.YLeaf(1, "bgp-scope-sync-state-not-nsr-ready")

    bgp_scope_sync_state_timer_start = Enum.YLeaf(2, "bgp-scope-sync-state-timer-start")

    bgp_scope_sync_state_add_list = Enum.YLeaf(3, "bgp-scope-sync-state-add-list")

    bgp_scope_sync_state_batch_acitve = Enum.YLeaf(4, "bgp-scope-sync-state-batch-acitve")


class BgpSrpolicyReqState(Enum):
    """
    BgpSrpolicyReqState

    BGP SR Policy Internal State

    .. data:: request_pending = 0

    	SR policy install in dataplane not requested

    	yet

    .. data:: requested = 1

    	Requested SR policy install  dataplane

    .. data:: notified_up = 2

    	SR policy is UP

    .. data:: notified_down = 4

    	SR policy is notified down by XTC

    .. data:: marked_stale = 8

    	SR policy is marked stale due to XTC agent down

    .. data:: marked_disable = 16

    	SR policy is marked disabled from the config in

    	XTC

    """

    request_pending = Enum.YLeaf(0, "request-pending")

    requested = Enum.YLeaf(1, "requested")

    notified_up = Enum.YLeaf(2, "notified-up")

    notified_down = Enum.YLeaf(4, "notified-down")

    marked_stale = Enum.YLeaf(8, "marked-stale")

    marked_disable = Enum.YLeaf(16, "marked-disable")


class BgpSyncNbrNsrState(Enum):
    """
    BgpSyncNbrNsrState

    Bgp sync nbr nsr state

    .. data:: bgp_nbr_nsr_st_none = 0

    	None - ST 0

    .. data:: bgp_nbr_nsr_st_oper_down = 1

    	TCP OPER_DOWN notfn received - ST 1

    .. data:: bgp_nbr_nsr_st_tcp_init_sync = 2

    	TCP initial sync in progress - ST 2

    .. data:: bgp_nbr_nsr_st_tcp_phase_two = 3

    	TCP initial sync phase two in progress - ST 3

    .. data:: bgp_nbr_nsr_st_bgp_init_sync = 4

    	BGP initial sync in progress - ST 4

    .. data:: bgp_nbr_nsr_st_nsr_ready = 5

    	Neighbor NSR ready - ST 5

    """

    bgp_nbr_nsr_st_none = Enum.YLeaf(0, "bgp-nbr-nsr-st-none")

    bgp_nbr_nsr_st_oper_down = Enum.YLeaf(1, "bgp-nbr-nsr-st-oper-down")

    bgp_nbr_nsr_st_tcp_init_sync = Enum.YLeaf(2, "bgp-nbr-nsr-st-tcp-init-sync")

    bgp_nbr_nsr_st_tcp_phase_two = Enum.YLeaf(3, "bgp-nbr-nsr-st-tcp-phase-two")

    bgp_nbr_nsr_st_bgp_init_sync = Enum.YLeaf(4, "bgp-nbr-nsr-st-bgp-init-sync")

    bgp_nbr_nsr_st_nsr_ready = Enum.YLeaf(5, "bgp-nbr-nsr-st-nsr-ready")


class BgpTcpMode(Enum):
    """
    BgpTcpMode

    Bgp tcp mode

    .. data:: bgp_tcp_mode_type_either = 0

    	Use either active or passive mode

    .. data:: bgp_tcp_mode_type_active_only = 1

    	Use active mode only

    .. data:: bgp_tcp_mode_type_passive_only = 2

    	Use passive mode only

    """

    bgp_tcp_mode_type_either = Enum.YLeaf(0, "bgp-tcp-mode-type-either")

    bgp_tcp_mode_type_active_only = Enum.YLeaf(1, "bgp-tcp-mode-type-active-only")

    bgp_tcp_mode_type_passive_only = Enum.YLeaf(2, "bgp-tcp-mode-type-passive-only")


class BgpTunnel(Enum):
    """
    BgpTunnel

    BGP tunnel type

    .. data:: tunnel_none = 0

    	Tunnel not applicable

    .. data:: attrset = 1

    	Attribute set TE tunnel

    .. data:: sr_policy = 2

    	SR Policy

    .. data:: odn_color = 3

    	ODN color

    """

    tunnel_none = Enum.YLeaf(0, "tunnel-none")

    attrset = Enum.YLeaf(1, "attrset")

    sr_policy = Enum.YLeaf(2, "sr-policy")

    odn_color = Enum.YLeaf(3, "odn-color")


class BgpV4V6Len(Enum):
    """
    BgpV4V6Len

    BGP GW Address Length

    .. data:: gwnone = 0

    	NO address length

    .. data:: gwipv4 = 4

    	IP v4 address length

    .. data:: gwipv6 = 16

    	IP v6 address length

    """

    gwnone = Enum.YLeaf(0, "gwnone")

    gwipv4 = Enum.YLeaf(4, "gwipv4")

    gwipv6 = Enum.YLeaf(16, "gwipv6")


class SrSid(Enum):
    """
    SrSid

    Segment id type

    .. data:: label = 1

    	MPLS Label sid

    .. data:: ipv4 = 2

    	IPv4 address

    .. data:: ipv6 = 3

    	IPv6 address

    """

    label = Enum.YLeaf(1, "label")

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(3, "ipv6")



class Bgp(Entity):
    """
    BGP operational data
    
    .. attribute:: bpm_instances_table
    
    	BGP instances information
    	**type**\:   :py:class:`BpmInstancesTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable>`
    
    .. attribute:: config_instances
    
    	Instance specific BGP data
    	**type**\:   :py:class:`ConfigInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances>`
    
    .. attribute:: instances
    
    	Instance specific BGP data
    	**type**\:   :py:class:`Instances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances>`
    
    

    """

    _prefix = 'ipv4-bgp-oper'
    _revision = '2017-06-26'

    def __init__(self):
        super(Bgp, self).__init__()
        self._top_entity = None

        self.yang_name = "bgp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"bpm-instances-table" : ("bpm_instances_table", Bgp.BpmInstancesTable), "config-instances" : ("config_instances", Bgp.ConfigInstances), "instances" : ("instances", Bgp.Instances)}
        self._child_list_classes = {}

        self.bpm_instances_table = Bgp.BpmInstancesTable()
        self.bpm_instances_table.parent = self
        self._children_name_map["bpm_instances_table"] = "bpm-instances-table"
        self._children_yang_names.add("bpm-instances-table")

        self.config_instances = Bgp.ConfigInstances()
        self.config_instances.parent = self
        self._children_name_map["config_instances"] = "config-instances"
        self._children_yang_names.add("config-instances")

        self.instances = Bgp.Instances()
        self.instances.parent = self
        self._children_name_map["instances"] = "instances"
        self._children_yang_names.add("instances")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp"


    class BpmInstancesTable(Entity):
        """
        BGP instances information
        
        .. attribute:: bpm_instances
        
        	BGP instances information
        	**type**\:   :py:class:`BpmInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Bgp.BpmInstancesTable, self).__init__()

            self.yang_name = "bpm-instances-table"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"bpm-instances" : ("bpm_instances", Bgp.BpmInstancesTable.BpmInstances)}
            self._child_list_classes = {}

            self.bpm_instances = Bgp.BpmInstancesTable.BpmInstances()
            self.bpm_instances.parent = self
            self._children_name_map["bpm_instances"] = "bpm-instances"
            self._children_yang_names.add("bpm-instances")
            self._segment_path = lambda: "bpm-instances-table"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()


        class BpmInstances(Entity):
            """
            BGP instances information
            
            .. attribute:: instance
            
            	Array of instance information
            	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Bgp.BpmInstancesTable.BpmInstances, self).__init__()

                self.yang_name = "bpm-instances"
                self.yang_parent_name = "bpm-instances-table"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"instance" : ("instance", Bgp.BpmInstancesTable.BpmInstances.Instance)}

                self.instance = YList(self)
                self._segment_path = lambda: "bpm-instances"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances, [], name, value)


            class Instance(Entity):
                """
                Array of instance information
                
                .. attribute:: af_array
                
                	Array of Address Families
                	**type**\: list of    :py:class:`AfArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray>`
                
                .. attribute:: as_number
                
                	AS Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: install_diversion_enabled
                
                	Install diversion is enabled
                	**type**\:  bool
                
                .. attribute:: instance_identifier
                
                	Instance Identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: instance_name_str
                
                	Instance Name
                	**type**\:  str
                
                .. attribute:: number_of_vrfs
                
                	Number of VRFs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: placed_group_id
                
                	Placed Group Identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: read_only_enabled
                
                	Read\-only is enabled
                	**type**\:  bool
                
                .. attribute:: srgb_end_configured
                
                	Configured end value of Segment\-routing global block
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srgb_start_configured
                
                	Configured start value of Segment\-routing global block
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.BpmInstancesTable.BpmInstances.Instance, self).__init__()

                    self.yang_name = "instance"
                    self.yang_parent_name = "bpm-instances"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"af-array" : ("af_array", Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray)}

                    self.as_number = YLeaf(YType.uint32, "as-number")

                    self.install_diversion_enabled = YLeaf(YType.boolean, "install-diversion-enabled")

                    self.instance_identifier = YLeaf(YType.uint16, "instance-identifier")

                    self.instance_name_str = YLeaf(YType.str, "instance-name-str")

                    self.number_of_vrfs = YLeaf(YType.uint32, "number-of-vrfs")

                    self.placed_group_id = YLeaf(YType.uint16, "placed-group-id")

                    self.read_only_enabled = YLeaf(YType.boolean, "read-only-enabled")

                    self.srgb_end_configured = YLeaf(YType.uint32, "srgb-end-configured")

                    self.srgb_start_configured = YLeaf(YType.uint32, "srgb-start-configured")

                    self.af_array = YList(self)
                    self._segment_path = lambda: "instance"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/bpm-instances/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances.Instance, ['as_number', 'install_diversion_enabled', 'instance_identifier', 'instance_name_str', 'number_of_vrfs', 'placed_group_id', 'read_only_enabled', 'srgb_end_configured', 'srgb_start_configured'], name, value)


                class AfArray(Entity):
                    """
                    Array of Address Families
                    
                    .. attribute:: entry
                    
                    	Array entry
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray, self).__init__()

                        self.yang_name = "af-array"
                        self.yang_parent_name = "instance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.entry = YLeaf(YType.boolean, "entry")
                        self._segment_path = lambda: "af-array"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/bpm-instances/instance/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray, ['entry'], name, value)


    class ConfigInstances(Entity):
        """
        Instance specific BGP data
        
        .. attribute:: config_instance
        
        	Instance specific BGP data
        	**type**\: list of    :py:class:`ConfigInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Bgp.ConfigInstances, self).__init__()

            self.yang_name = "config-instances"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"config-instance" : ("config_instance", Bgp.ConfigInstances.ConfigInstance)}

            self.config_instance = YList(self)
            self._segment_path = lambda: "config-instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.ConfigInstances, [], name, value)


        class ConfigInstance(Entity):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  <key>
            
            	Name of the BGP instance
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: config_instance_default_vrf
            
            	Default VRF related configuration data
            	**type**\:   :py:class:`ConfigInstanceDefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf>`
            
            .. attribute:: config_vrfs
            
            	VRF related configuration data
            	**type**\:   :py:class:`ConfigVrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Bgp.ConfigInstances.ConfigInstance, self).__init__()

                self.yang_name = "config-instance"
                self.yang_parent_name = "config-instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"config-instance-default-vrf" : ("config_instance_default_vrf", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf), "config-vrfs" : ("config_vrfs", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs)}
                self._child_list_classes = {}

                self.instance_name = YLeaf(YType.str, "instance-name")

                self.config_instance_default_vrf = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf()
                self.config_instance_default_vrf.parent = self
                self._children_name_map["config_instance_default_vrf"] = "config-instance-default-vrf"
                self._children_yang_names.add("config-instance-default-vrf")

                self.config_vrfs = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs()
                self.config_vrfs.parent = self
                self._children_name_map["config_vrfs"] = "config-vrfs"
                self._children_yang_names.add("config-vrfs")
                self._segment_path = lambda: "config-instance" + "[instance-name='" + self.instance_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/config-instances/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance, ['instance_name'], name, value)


            class ConfigInstanceDefaultVrf(Entity):
                """
                Default VRF related configuration data
                
                .. attribute:: configuration_inheritances
                
                	The BGP configurataion inheritance table
                	**type**\:   :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances>`
                
                .. attribute:: configuration_users
                
                	The BGP configuration users table
                	**type**\:   :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers>`
                
                .. attribute:: entity_configurations
                
                	The BGP Entity Configuration table
                	**type**\:   :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf, self).__init__()

                    self.yang_name = "config-instance-default-vrf"
                    self.yang_parent_name = "config-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"configuration-inheritances" : ("configuration_inheritances", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances), "configuration-users" : ("configuration_users", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers), "entity-configurations" : ("entity_configurations", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations)}
                    self._child_list_classes = {}

                    self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances()
                    self.configuration_inheritances.parent = self
                    self._children_name_map["configuration_inheritances"] = "configuration-inheritances"
                    self._children_yang_names.add("configuration-inheritances")

                    self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers()
                    self.configuration_users.parent = self
                    self._children_name_map["configuration_users"] = "configuration-users"
                    self._children_yang_names.add("configuration-users")

                    self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations()
                    self.entity_configurations.parent = self
                    self._children_name_map["entity_configurations"] = "entity-configurations"
                    self._children_yang_names.add("entity-configurations")
                    self._segment_path = lambda: "config-instance-default-vrf"


                class ConfigurationInheritances(Entity):
                    """
                    The BGP configurataion inheritance table
                    
                    .. attribute:: configuration_inheritance
                    
                    	A BGP configuration inheritance table entry
                    	**type**\: list of    :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances, self).__init__()

                        self.yang_name = "configuration-inheritances"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"configuration-inheritance" : ("configuration_inheritance", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance)}

                        self.configuration_inheritance = YList(self)
                        self._segment_path = lambda: "configuration-inheritances"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances, [], name, value)


                    class ConfigurationInheritance(Entity):
                        """
                        A BGP configuration inheritance table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance, self).__init__()

                            self.yang_name = "configuration-inheritance"
                            self.yang_parent_name = "configuration-inheritances"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"af-independent-relatives" : ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr)}
                            self._child_list_classes = {"af-dependent-relative" : ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative)}

                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                            self.entity_name = YLeaf(YType.str, "entity-name")

                            self.entity_type = YLeaf(YType.enumeration, "entity-type")

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self._children_name_map["af_independent_relatives"] = "af-independent-relatives"
                            self._children_yang_names.add("af-independent-relatives")

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                            self._children_yang_names.add("neighbor-address-xr")

                            self.af_dependent_relative = YList(self)
                            self._segment_path = lambda: "configuration-inheritance"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                        class AfDependentRelative(Entity):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, self).__init__()

                                self.yang_name = "af-dependent-relative"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid)}

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-dependent-relative"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-dependent-relative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress)}
                                    self._child_list_classes = {}

                                    self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                    self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                    self.group_name = YLeaf(YType.str, "group-name")

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")
                                    self._segment_path = lambda: "bgp-config-entid"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class AfIndependentRelatives(Entity):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, self).__init__()

                                self.yang_name = "af-independent-relatives"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid)}

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-independent-relatives"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-independent-relatives"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress)}
                                    self._child_list_classes = {}

                                    self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                    self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                    self.group_name = YLeaf(YType.str, "group-name")

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")
                                    self._segment_path = lambda: "bgp-config-entid"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                self._children_yang_names.add("ipv4-sr-policy-address")

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._children_yang_names.add("ipv6-sr-policy-address")

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                self._children_yang_names.add("l2vpn-mspw-address")

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                self._children_yang_names.add("l2vpn-vpls-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                            class L2VpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                            class L2VpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                class ConfigurationUsers(Entity):
                    """
                    The BGP configuration users table
                    
                    .. attribute:: configuration_user
                    
                    	A BGP configuration user table entry
                    	**type**\: list of    :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers, self).__init__()

                        self.yang_name = "configuration-users"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"configuration-user" : ("configuration_user", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser)}

                        self.configuration_user = YList(self)
                        self._segment_path = lambda: "configuration-users"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers, [], name, value)


                    class ConfigurationUser(Entity):
                        """
                        A BGP configuration user table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser, self).__init__()

                            self.yang_name = "configuration-user"
                            self.yang_parent_name = "configuration-users"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"af-independent-relatives" : ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr)}
                            self._child_list_classes = {"af-dependent-relative" : ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative)}

                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                            self.entity_name = YLeaf(YType.str, "entity-name")

                            self.entity_type = YLeaf(YType.enumeration, "entity-type")

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self._children_name_map["af_independent_relatives"] = "af-independent-relatives"
                            self._children_yang_names.add("af-independent-relatives")

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                            self._children_yang_names.add("neighbor-address-xr")

                            self.af_dependent_relative = YList(self)
                            self._segment_path = lambda: "configuration-user"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                        class AfDependentRelative(Entity):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, self).__init__()

                                self.yang_name = "af-dependent-relative"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid)}

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-dependent-relative"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-dependent-relative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress)}
                                    self._child_list_classes = {}

                                    self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                    self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                    self.group_name = YLeaf(YType.str, "group-name")

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")
                                    self._segment_path = lambda: "bgp-config-entid"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class AfIndependentRelatives(Entity):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, self).__init__()

                                self.yang_name = "af-independent-relatives"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid)}

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-independent-relatives"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-independent-relatives"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress)}
                                    self._child_list_classes = {}

                                    self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                    self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                    self.group_name = YLeaf(YType.str, "group-name")

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")
                                    self._segment_path = lambda: "bgp-config-entid"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                self._children_yang_names.add("ipv4-sr-policy-address")

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._children_yang_names.add("ipv6-sr-policy-address")

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                self._children_yang_names.add("l2vpn-mspw-address")

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                self._children_yang_names.add("l2vpn-vpls-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                            class L2VpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                            class L2VpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                class EntityConfigurations(Entity):
                    """
                    The BGP Entity Configuration table
                    
                    .. attribute:: entity_configuration
                    
                    	A BGP Entity Configuration table entry
                    	**type**\: list of    :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations, self).__init__()

                        self.yang_name = "entity-configurations"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"entity-configuration" : ("entity_configuration", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration)}

                        self.entity_configuration = YList(self)
                        self._segment_path = lambda: "entity-configurations"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations, [], name, value)


                    class EntityConfiguration(Entity):
                        """
                        A BGP Entity Configuration table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_config
                        
                        	Af\-dependent config
                        	**type**\: list of    :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                        
                        .. attribute:: af_independent_config
                        
                        	AF\-independent config
                        	**type**\:   :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration, self).__init__()

                            self.yang_name = "entity-configuration"
                            self.yang_parent_name = "entity-configurations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"af-independent-config" : ("af_independent_config", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr)}
                            self._child_list_classes = {"af-dependent-config" : ("af_dependent_config", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig)}

                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                            self.entity_name = YLeaf(YType.str, "entity-name")

                            self.entity_type = YLeaf(YType.enumeration, "entity-type")

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                            self.af_independent_config.parent = self
                            self._children_name_map["af_independent_config"] = "af-independent-config"
                            self._children_yang_names.add("af-independent-config")

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                            self._children_yang_names.add("neighbor-address-xr")

                            self.af_dependent_config = YList(self)
                            self._segment_path = lambda: "entity-configuration"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                        class AfDependentConfig(Entity):
                            """
                            Af\-dependent config
                            
                            .. attribute:: accept_own
                            
                            	Accept Own
                            	**type**\:  bool
                            
                            .. attribute:: accept_own_info
                            
                            	Accept\-Own info
                            	**type**\:   :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                            
                            .. attribute:: accept_route_legacy_pe_rt
                            
                            	accept\-legacy\-pe RT route
                            	**type**\:  bool
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_dis_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                            
                            .. attribute:: advertise_disable
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_l2vpn_evpn
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_l2vpn_evpn_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseL2VpnEvpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo>`
                            
                            .. attribute:: advertise_local_labeled_route
                            
                            	Advertise routes with local\-label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: advertise_local_labeled_route_info
                            
                            	Advertise routes with local\-label
                            	**type**\:   :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                            
                            .. attribute:: advertise_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_v4_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                            
                            .. attribute:: advertise_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_v6_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_enabled_info
                            
                            	Address family activate item info
                            	**type**\:   :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                            
                            .. attribute:: af_encapsulation_type_info
                            
                            	Encapsulation type Info 
                            	**type**\:   :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                            
                            .. attribute:: af_long_lived_graceful_restart_capable
                            
                            	Long\-lived graceful\-restart capable
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                            
                            	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_send
                            
                            	Stale time to be sent in long\-lived graceful\-restart capability
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_start_capable_info
                            
                            	Long\-lived\-time item info
                            	**type**\:   :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                            
                            .. attribute:: af_long_lived_graceful_start_stale_time_info
                            
                            	Long\-lived\-time item info
                            	**type**\:   :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                            
                            .. attribute:: aigp_cost_community_info
                            
                            	AIGP Cost Community info 
                            	**type**\:   :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                            
                            .. attribute:: aigp_cost_community_poi
                            
                            	Point of insertion for AIGP cost community
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aigp_info
                            
                            	AIGP info 
                            	**type**\:   :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                            
                            .. attribute:: aigp_med
                            
                            	AIGP MED info 
                            	**type**\:   :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                            
                            .. attribute:: allowas_in_info
                            
                            	Allowas\-in item info
                            	**type**\:   :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                            
                            .. attribute:: alway_use_soft_reconfig
                            
                            	Always use soft reconfig
                            	**type**\:  bool
                            
                            .. attribute:: as_override_info
                            
                            	As\-override info 
                            	**type**\:   :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                            
                            .. attribute:: client_route_reflector
                            
                            	Route\-reflector client
                            	**type**\:  bool
                            
                            .. attribute:: default_allowas
                            
                            	Default allowas\_in count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_originate_info
                            
                            	Default\-originate item info
                            	**type**\:   :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                            
                            .. attribute:: default_originate_route_policy
                            
                            	Default\-originate route policy name
                            	**type**\:  str
                            
                            .. attribute:: default_weight
                            
                            	Default weight
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: encapsulation_type
                            
                            	Encapsulation type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enforce_multiple_labels
                            
                            	Enforce multiple labels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enforce_multiple_labels_info
                            
                            	Enforce multiple labels
                            	**type**\:   :py:class:`EnforceMultipleLabelsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo>`
                            
                            .. attribute:: entire_aspath_in
                            
                            	Inbound private\-AS removal if the entire AS Path has private ASes
                            	**type**\:  bool
                            
                            .. attribute:: entire_aspath_out
                            
                            	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                            	**type**\:  bool
                            
                            .. attribute:: fspec_valid_info
                            
                            	FSPEC Valid info
                            	**type**\:   :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                            
                            .. attribute:: has_orf_capability
                            
                            	ORF capability
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: import_
                            
                            	Import
                            	**type**\:  bool
                            
                            .. attribute:: import_afi_info
                            
                            	Import Afi Info 
                            	**type**\:   :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                            
                            .. attribute:: import_reoriginate
                            
                            	Import reoriginate
                            	**type**\:  bool
                            
                            .. attribute:: import_reoriginate_stitching
                            
                            	Import reoriginate stitching RTs
                            	**type**\:  bool
                            
                            .. attribute:: import_stitching
                            
                            	Import stitching RTs
                            	**type**\:  bool
                            
                            .. attribute:: is_af_enabled
                            
                            	Entity is activated for this address family
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_cost_community_enabled
                            
                            	AIGP cost community enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_cost_community_id
                            
                            	AIGP cost community ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_cost_community_transitive
                            
                            	AIGP cost community ID is transitive
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_enabled
                            
                            	AIGP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_med_enabled
                            
                            	AIGP to MED enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_as_override_disabled
                            
                            	Disable as override
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_not_disabled
                            
                            	TRUE if default\-originate is not disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_fspec_valid_enabled
                            
                            	FSPEC VALID enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_max_prefix_discard_extra_paths
                            
                            	Discard extra paths
                            	**type**\:  bool
                            
                            .. attribute:: is_max_prefix_warn_only
                            
                            	Warning messages only
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_self_disabled
                            
                            	Disable next\-hop calc
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_unchanged
                            
                            	Don't change next\-hop
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_unchanged_mpath
                            
                            	Don't change mpath next\-hop
                            	**type**\:  bool
                            
                            .. attribute:: is_send_mcast_attr_enabled
                            
                            	Send mcast attr enabled
                            	**type**\:  bool
                            
                            .. attribute:: legacy_pe_rt_info
                            
                            	Accept\-legacy\-pe\-RT item info
                            	**type**\:   :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                            
                            .. attribute:: max_prefix_restart_time
                            
                            	Restart time Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_warn_threshold
                            
                            	Warning message threshhold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefixes
                            
                            	Maximum prefixes to accept
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefixes_info
                            
                            	Maximum prefixes to accept item info
                            	**type**\:   :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                            
                            .. attribute:: multipath
                            
                            	multipath
                            	**type**\:  bool
                            
                            .. attribute:: multipath_info
                            
                            	Multipath info
                            	**type**\:   :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                            
                            .. attribute:: next_hop_self_info
                            
                            	Next hop self item info
                            	**type**\:   :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                            
                            .. attribute:: next_hop_unchanged_info
                            
                            	Next hop unchanged info
                            	**type**\:   :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                            
                            .. attribute:: next_hop_unchanged_mpath_info
                            
                            	Next hop unchanged mpath info
                            	**type**\:   :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                            
                            .. attribute:: orf_capability_info
                            
                            	ORF capability item info
                            	**type**\:   :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                            
                            .. attribute:: orr_info
                            
                            	Orr item info
                            	**type**\:   :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                            
                            .. attribute:: orr_root_address
                            
                            	ORR Root Address
                            	**type**\:   :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                            
                            .. attribute:: permanent_network
                            
                            	Permanent Network
                            	**type**\:  bool
                            
                            .. attribute:: permanent_network_info
                            
                            	Permanent network Info 
                            	**type**\:   :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                            
                            .. attribute:: prefix_filter_info
                            
                            	Inbound prefix based filter item info
                            	**type**\:   :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                            
                            .. attribute:: prefix_orf_filter
                            
                            	Inbound prefix based filter
                            	**type**\:  str
                            
                            .. attribute:: remove_private_as_in_info
                            
                            	Inbound private\-AS removal item info
                            	**type**\:   :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                            
                            .. attribute:: remove_private_as_info
                            
                            	Outbound private\-AS removal item info
                            	**type**\:   :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                            
                            .. attribute:: remove_private_as_out
                            
                            	Outbound private\-AS removal
                            	**type**\:  bool
                            
                            .. attribute:: remove_private_asin
                            
                            	Inbound private\-AS removal
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_in
                            
                            	Inbound route policy name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_in_info
                            
                            	Inbound route policy item info
                            	**type**\:   :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                            
                            .. attribute:: route_policy_out
                            
                            	Outbound route policy name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out_info
                            
                            	Outbound route policy item info
                            	**type**\:   :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                            
                            .. attribute:: route_reflector_info
                            
                            	Route\-reflector client item info
                            	**type**\:   :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                            
                            .. attribute:: send_community_attribute
                            
                            	Send community attribute
                            	**type**\:  bool
                            
                            .. attribute:: send_community_info
                            
                            	Send community attribute item info
                            	**type**\:   :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                            
                            .. attribute:: send_extended_community_attribute
                            
                            	Send extended community attribute
                            	**type**\:  bool
                            
                            .. attribute:: send_extended_community_info
                            
                            	Send extended community  item info
                            	**type**\:   :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                            
                            .. attribute:: send_graceful_shut_community_attributes
                            
                            	Send Graceful shutdown related community attributes
                            	**type**\:  bool
                            
                            .. attribute:: send_graceful_shutdown_community_info
                            
                            	Send Graceful shutdown related community attribute item info
                            	**type**\:   :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                            
                            .. attribute:: send_mcast_attr_info
                            
                            	Send mcast attr info
                            	**type**\:   :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                            
                            .. attribute:: site_of_origin
                            
                            	Site of Origin
                            	**type**\:  str
                            
                            .. attribute:: so_o_info
                            
                            	BGP Site\-of\-Origin info
                            	**type**\:   :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                            
                            .. attribute:: soft_reconfig_info
                            
                            	Soft reconf item info
                            	**type**\:   :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                            
                            .. attribute:: soft_reconfig_not_disabled
                            
                            	TRUE if soft reconf is not disabled
                            	**type**\:  bool
                            
                            .. attribute:: weight_info
                            
                            	Default weight item info
                            	**type**\:   :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, self).__init__()

                                self.yang_name = "af-dependent-config"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"accept-own-info" : ("accept_own_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo), "advertise-def-vrf-imp-disable-afi-v4-info" : ("advertise_def_vrf_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info), "advertise-def-vrf-imp-disable-afi-v6-info" : ("advertise_def_vrf_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info), "advertise-dis-info" : ("advertise_dis_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo), "advertise-l2vpn-evpn-afi-info" : ("advertise_l2vpn_evpn_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo), "advertise-local-labeled-route-info" : ("advertise_local_labeled_route_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo), "advertise-v4-afi-info" : ("advertise_v4_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo), "advertise-v6-afi-info" : ("advertise_v6_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo), "advertise-vrf-re-imp-disable-afi-v4-info" : ("advertise_vrf_re_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info), "advertise-vrf-re-imp-disable-afi-v6-info" : ("advertise_vrf_re_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info), "af-enabled-info" : ("af_enabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo), "af-encapsulation-type-info" : ("af_encapsulation_type_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo), "af-long-lived-graceful-start-capable-info" : ("af_long_lived_graceful_start_capable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo), "af-long-lived-graceful-start-stale-time-info" : ("af_long_lived_graceful_start_stale_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo), "aigp-cost-community-info" : ("aigp_cost_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo), "aigp-info" : ("aigp_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo), "aigp-med" : ("aigp_med", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed), "allowas-in-info" : ("allowas_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo), "as-override-info" : ("as_override_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo), "default-originate-info" : ("default_originate_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo), "enforce-multiple-labels-info" : ("enforce_multiple_labels_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo), "fspec-valid-info" : ("fspec_valid_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo), "import-afi-info" : ("import_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo), "legacy-pe-rt-info" : ("legacy_pe_rt_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo), "max-prefixes-info" : ("max_prefixes_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo), "multipath-info" : ("multipath_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo), "next-hop-self-info" : ("next_hop_self_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo), "next-hop-unchanged-info" : ("next_hop_unchanged_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo), "next-hop-unchanged-mpath-info" : ("next_hop_unchanged_mpath_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo), "orf-capability-info" : ("orf_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo), "orr-info" : ("orr_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo), "orr-root-address" : ("orr_root_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress), "permanent-network-info" : ("permanent_network_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo), "prefix-filter-info" : ("prefix_filter_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo), "remove-private-as-in-info" : ("remove_private_as_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo), "remove-private-as-info" : ("remove_private_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo), "route-policy-in-info" : ("route_policy_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo), "route-policy-out-info" : ("route_policy_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo), "route-reflector-info" : ("route_reflector_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo), "send-community-info" : ("send_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo), "send-extended-community-info" : ("send_extended_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo), "send-graceful-shutdown-community-info" : ("send_graceful_shutdown_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo), "send-mcast-attr-info" : ("send_mcast_attr_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo), "so-o-info" : ("so_o_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo), "soft-reconfig-info" : ("soft_reconfig_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo), "weight-info" : ("weight_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo)}
                                self._child_list_classes = {}

                                self.accept_own = YLeaf(YType.boolean, "accept-own")

                                self.accept_route_legacy_pe_rt = YLeaf(YType.boolean, "accept-route-legacy-pe-rt")

                                self.advertise_def_vrf_imp_disable_v4 = YLeaf(YType.uint8, "advertise-def-vrf-imp-disable-v4")

                                self.advertise_def_vrf_imp_disable_v6 = YLeaf(YType.uint8, "advertise-def-vrf-imp-disable-v6")

                                self.advertise_disable = YLeaf(YType.uint8, "advertise-disable")

                                self.advertise_l2vpn_evpn = YLeaf(YType.uint8, "advertise-l2vpn-evpn")

                                self.advertise_local_labeled_route = YLeaf(YType.uint32, "advertise-local-labeled-route")

                                self.advertise_v4 = YLeaf(YType.uint8, "advertise-v4")

                                self.advertise_v6 = YLeaf(YType.uint8, "advertise-v6")

                                self.advertise_vrf_re_imp_disable_v4 = YLeaf(YType.uint8, "advertise-vrf-re-imp-disable-v4")

                                self.advertise_vrf_re_imp_disable_v6 = YLeaf(YType.uint8, "advertise-vrf-re-imp-disable-v6")

                                self.af_long_lived_graceful_restart_capable = YLeaf(YType.uint32, "af-long-lived-graceful-restart-capable")

                                self.af_long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "af-long-lived-graceful-restart-stale-time-accept")

                                self.af_long_lived_graceful_restart_stale_time_send = YLeaf(YType.uint32, "af-long-lived-graceful-restart-stale-time-send")

                                self.aigp_cost_community_poi = YLeaf(YType.uint32, "aigp-cost-community-poi")

                                self.alway_use_soft_reconfig = YLeaf(YType.boolean, "alway-use-soft-reconfig")

                                self.client_route_reflector = YLeaf(YType.boolean, "client-route-reflector")

                                self.default_allowas = YLeaf(YType.uint32, "default-allowas")

                                self.default_originate_route_policy = YLeaf(YType.str, "default-originate-route-policy")

                                self.default_weight = YLeaf(YType.uint32, "default-weight")

                                self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                self.enforce_multiple_labels = YLeaf(YType.uint32, "enforce-multiple-labels")

                                self.entire_aspath_in = YLeaf(YType.boolean, "entire-aspath-in")

                                self.entire_aspath_out = YLeaf(YType.boolean, "entire-aspath-out")

                                self.has_orf_capability = YLeaf(YType.uint32, "has-orf-capability")

                                self.import_ = YLeaf(YType.boolean, "import")

                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                self.is_af_enabled = YLeaf(YType.boolean, "is-af-enabled")

                                self.is_aigp_cost_community_enabled = YLeaf(YType.boolean, "is-aigp-cost-community-enabled")

                                self.is_aigp_cost_community_id = YLeaf(YType.uint32, "is-aigp-cost-community-id")

                                self.is_aigp_cost_community_transitive = YLeaf(YType.uint32, "is-aigp-cost-community-transitive")

                                self.is_aigp_enabled = YLeaf(YType.boolean, "is-aigp-enabled")

                                self.is_aigp_med_enabled = YLeaf(YType.boolean, "is-aigp-med-enabled")

                                self.is_as_override_disabled = YLeaf(YType.boolean, "is-as-override-disabled")

                                self.is_default_originate_not_disabled = YLeaf(YType.boolean, "is-default-originate-not-disabled")

                                self.is_fspec_valid_enabled = YLeaf(YType.boolean, "is-fspec-valid-enabled")

                                self.is_max_prefix_discard_extra_paths = YLeaf(YType.boolean, "is-max-prefix-discard-extra-paths")

                                self.is_max_prefix_warn_only = YLeaf(YType.boolean, "is-max-prefix-warn-only")

                                self.is_next_hop_self_disabled = YLeaf(YType.boolean, "is-next-hop-self-disabled")

                                self.is_next_hop_unchanged = YLeaf(YType.boolean, "is-next-hop-unchanged")

                                self.is_next_hop_unchanged_mpath = YLeaf(YType.boolean, "is-next-hop-unchanged-mpath")

                                self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                self.max_prefix_restart_time = YLeaf(YType.uint32, "max-prefix-restart-time")

                                self.max_prefix_warn_threshold = YLeaf(YType.uint32, "max-prefix-warn-threshold")

                                self.max_prefixes = YLeaf(YType.uint32, "max-prefixes")

                                self.multipath = YLeaf(YType.boolean, "multipath")

                                self.permanent_network = YLeaf(YType.boolean, "permanent-network")

                                self.prefix_orf_filter = YLeaf(YType.str, "prefix-orf-filter")

                                self.remove_private_as_out = YLeaf(YType.boolean, "remove-private-as-out")

                                self.remove_private_asin = YLeaf(YType.boolean, "remove-private-asin")

                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                self.send_community_attribute = YLeaf(YType.boolean, "send-community-attribute")

                                self.send_extended_community_attribute = YLeaf(YType.boolean, "send-extended-community-attribute")

                                self.send_graceful_shut_community_attributes = YLeaf(YType.boolean, "send-graceful-shut-community-attributes")

                                self.site_of_origin = YLeaf(YType.str, "site-of-origin")

                                self.soft_reconfig_not_disabled = YLeaf(YType.boolean, "soft-reconfig-not-disabled")

                                self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                self.accept_own_info.parent = self
                                self._children_name_map["accept_own_info"] = "accept-own-info"
                                self._children_yang_names.add("accept-own-info")

                                self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                self._children_name_map["advertise_def_vrf_imp_disable_afi_v4_info"] = "advertise-def-vrf-imp-disable-afi-v4-info"
                                self._children_yang_names.add("advertise-def-vrf-imp-disable-afi-v4-info")

                                self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                self._children_name_map["advertise_def_vrf_imp_disable_afi_v6_info"] = "advertise-def-vrf-imp-disable-afi-v6-info"
                                self._children_yang_names.add("advertise-def-vrf-imp-disable-afi-v6-info")

                                self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                self.advertise_dis_info.parent = self
                                self._children_name_map["advertise_dis_info"] = "advertise-dis-info"
                                self._children_yang_names.add("advertise-dis-info")

                                self.advertise_l2vpn_evpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo()
                                self.advertise_l2vpn_evpn_afi_info.parent = self
                                self._children_name_map["advertise_l2vpn_evpn_afi_info"] = "advertise-l2vpn-evpn-afi-info"
                                self._children_yang_names.add("advertise-l2vpn-evpn-afi-info")

                                self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                self.advertise_local_labeled_route_info.parent = self
                                self._children_name_map["advertise_local_labeled_route_info"] = "advertise-local-labeled-route-info"
                                self._children_yang_names.add("advertise-local-labeled-route-info")

                                self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                self.advertise_v4_afi_info.parent = self
                                self._children_name_map["advertise_v4_afi_info"] = "advertise-v4-afi-info"
                                self._children_yang_names.add("advertise-v4-afi-info")

                                self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                self.advertise_v6_afi_info.parent = self
                                self._children_name_map["advertise_v6_afi_info"] = "advertise-v6-afi-info"
                                self._children_yang_names.add("advertise-v6-afi-info")

                                self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                self._children_name_map["advertise_vrf_re_imp_disable_afi_v4_info"] = "advertise-vrf-re-imp-disable-afi-v4-info"
                                self._children_yang_names.add("advertise-vrf-re-imp-disable-afi-v4-info")

                                self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                self._children_name_map["advertise_vrf_re_imp_disable_afi_v6_info"] = "advertise-vrf-re-imp-disable-afi-v6-info"
                                self._children_yang_names.add("advertise-vrf-re-imp-disable-afi-v6-info")

                                self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                self.af_enabled_info.parent = self
                                self._children_name_map["af_enabled_info"] = "af-enabled-info"
                                self._children_yang_names.add("af-enabled-info")

                                self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                self.af_encapsulation_type_info.parent = self
                                self._children_name_map["af_encapsulation_type_info"] = "af-encapsulation-type-info"
                                self._children_yang_names.add("af-encapsulation-type-info")

                                self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                self.af_long_lived_graceful_start_capable_info.parent = self
                                self._children_name_map["af_long_lived_graceful_start_capable_info"] = "af-long-lived-graceful-start-capable-info"
                                self._children_yang_names.add("af-long-lived-graceful-start-capable-info")

                                self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                self.af_long_lived_graceful_start_stale_time_info.parent = self
                                self._children_name_map["af_long_lived_graceful_start_stale_time_info"] = "af-long-lived-graceful-start-stale-time-info"
                                self._children_yang_names.add("af-long-lived-graceful-start-stale-time-info")

                                self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                self.aigp_cost_community_info.parent = self
                                self._children_name_map["aigp_cost_community_info"] = "aigp-cost-community-info"
                                self._children_yang_names.add("aigp-cost-community-info")

                                self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                self.aigp_info.parent = self
                                self._children_name_map["aigp_info"] = "aigp-info"
                                self._children_yang_names.add("aigp-info")

                                self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                self.aigp_med.parent = self
                                self._children_name_map["aigp_med"] = "aigp-med"
                                self._children_yang_names.add("aigp-med")

                                self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                self.allowas_in_info.parent = self
                                self._children_name_map["allowas_in_info"] = "allowas-in-info"
                                self._children_yang_names.add("allowas-in-info")

                                self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                self.as_override_info.parent = self
                                self._children_name_map["as_override_info"] = "as-override-info"
                                self._children_yang_names.add("as-override-info")

                                self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                self.default_originate_info.parent = self
                                self._children_name_map["default_originate_info"] = "default-originate-info"
                                self._children_yang_names.add("default-originate-info")

                                self.enforce_multiple_labels_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo()
                                self.enforce_multiple_labels_info.parent = self
                                self._children_name_map["enforce_multiple_labels_info"] = "enforce-multiple-labels-info"
                                self._children_yang_names.add("enforce-multiple-labels-info")

                                self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                self.fspec_valid_info.parent = self
                                self._children_name_map["fspec_valid_info"] = "fspec-valid-info"
                                self._children_yang_names.add("fspec-valid-info")

                                self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                self.import_afi_info.parent = self
                                self._children_name_map["import_afi_info"] = "import-afi-info"
                                self._children_yang_names.add("import-afi-info")

                                self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                self.legacy_pe_rt_info.parent = self
                                self._children_name_map["legacy_pe_rt_info"] = "legacy-pe-rt-info"
                                self._children_yang_names.add("legacy-pe-rt-info")

                                self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                self.max_prefixes_info.parent = self
                                self._children_name_map["max_prefixes_info"] = "max-prefixes-info"
                                self._children_yang_names.add("max-prefixes-info")

                                self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                self.multipath_info.parent = self
                                self._children_name_map["multipath_info"] = "multipath-info"
                                self._children_yang_names.add("multipath-info")

                                self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                self.next_hop_self_info.parent = self
                                self._children_name_map["next_hop_self_info"] = "next-hop-self-info"
                                self._children_yang_names.add("next-hop-self-info")

                                self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                self.next_hop_unchanged_info.parent = self
                                self._children_name_map["next_hop_unchanged_info"] = "next-hop-unchanged-info"
                                self._children_yang_names.add("next-hop-unchanged-info")

                                self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                self.next_hop_unchanged_mpath_info.parent = self
                                self._children_name_map["next_hop_unchanged_mpath_info"] = "next-hop-unchanged-mpath-info"
                                self._children_yang_names.add("next-hop-unchanged-mpath-info")

                                self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                self.orf_capability_info.parent = self
                                self._children_name_map["orf_capability_info"] = "orf-capability-info"
                                self._children_yang_names.add("orf-capability-info")

                                self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                self.orr_info.parent = self
                                self._children_name_map["orr_info"] = "orr-info"
                                self._children_yang_names.add("orr-info")

                                self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                self.orr_root_address.parent = self
                                self._children_name_map["orr_root_address"] = "orr-root-address"
                                self._children_yang_names.add("orr-root-address")

                                self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                self.permanent_network_info.parent = self
                                self._children_name_map["permanent_network_info"] = "permanent-network-info"
                                self._children_yang_names.add("permanent-network-info")

                                self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                self.prefix_filter_info.parent = self
                                self._children_name_map["prefix_filter_info"] = "prefix-filter-info"
                                self._children_yang_names.add("prefix-filter-info")

                                self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                self.remove_private_as_in_info.parent = self
                                self._children_name_map["remove_private_as_in_info"] = "remove-private-as-in-info"
                                self._children_yang_names.add("remove-private-as-in-info")

                                self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                self.remove_private_as_info.parent = self
                                self._children_name_map["remove_private_as_info"] = "remove-private-as-info"
                                self._children_yang_names.add("remove-private-as-info")

                                self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                self.route_policy_in_info.parent = self
                                self._children_name_map["route_policy_in_info"] = "route-policy-in-info"
                                self._children_yang_names.add("route-policy-in-info")

                                self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                self.route_policy_out_info.parent = self
                                self._children_name_map["route_policy_out_info"] = "route-policy-out-info"
                                self._children_yang_names.add("route-policy-out-info")

                                self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                self.route_reflector_info.parent = self
                                self._children_name_map["route_reflector_info"] = "route-reflector-info"
                                self._children_yang_names.add("route-reflector-info")

                                self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                self.send_community_info.parent = self
                                self._children_name_map["send_community_info"] = "send-community-info"
                                self._children_yang_names.add("send-community-info")

                                self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                self.send_extended_community_info.parent = self
                                self._children_name_map["send_extended_community_info"] = "send-extended-community-info"
                                self._children_yang_names.add("send-extended-community-info")

                                self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                self.send_graceful_shutdown_community_info.parent = self
                                self._children_name_map["send_graceful_shutdown_community_info"] = "send-graceful-shutdown-community-info"
                                self._children_yang_names.add("send-graceful-shutdown-community-info")

                                self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                self.send_mcast_attr_info.parent = self
                                self._children_name_map["send_mcast_attr_info"] = "send-mcast-attr-info"
                                self._children_yang_names.add("send-mcast-attr-info")

                                self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                self.so_o_info.parent = self
                                self._children_name_map["so_o_info"] = "so-o-info"
                                self._children_yang_names.add("so-o-info")

                                self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                self.soft_reconfig_info.parent = self
                                self._children_name_map["soft_reconfig_info"] = "soft-reconfig-info"
                                self._children_yang_names.add("soft-reconfig-info")

                                self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                self.weight_info.parent = self
                                self._children_name_map["weight_info"] = "weight-info"
                                self._children_yang_names.add("weight-info")
                                self._segment_path = lambda: "af-dependent-config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, ['accept_own', 'accept_route_legacy_pe_rt', 'advertise_def_vrf_imp_disable_v4', 'advertise_def_vrf_imp_disable_v6', 'advertise_disable', 'advertise_l2vpn_evpn', 'advertise_local_labeled_route', 'advertise_v4', 'advertise_v6', 'advertise_vrf_re_imp_disable_v4', 'advertise_vrf_re_imp_disable_v6', 'af_long_lived_graceful_restart_capable', 'af_long_lived_graceful_restart_stale_time_accept', 'af_long_lived_graceful_restart_stale_time_send', 'aigp_cost_community_poi', 'alway_use_soft_reconfig', 'client_route_reflector', 'default_allowas', 'default_originate_route_policy', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'entire_aspath_in', 'entire_aspath_out', 'has_orf_capability', 'import_', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_af_enabled', 'is_aigp_cost_community_enabled', 'is_aigp_cost_community_id', 'is_aigp_cost_community_transitive', 'is_aigp_enabled', 'is_aigp_med_enabled', 'is_as_override_disabled', 'is_default_originate_not_disabled', 'is_fspec_valid_enabled', 'is_max_prefix_discard_extra_paths', 'is_max_prefix_warn_only', 'is_next_hop_self_disabled', 'is_next_hop_unchanged', 'is_next_hop_unchanged_mpath', 'is_send_mcast_attr_enabled', 'max_prefix_restart_time', 'max_prefix_warn_threshold', 'max_prefixes', 'multipath', 'permanent_network', 'prefix_orf_filter', 'remove_private_as_out', 'remove_private_asin', 'route_policy_in', 'route_policy_out', 'send_community_attribute', 'send_extended_community_attribute', 'send_graceful_shut_community_attributes', 'site_of_origin', 'soft_reconfig_not_disabled'], name, value)


                            class AcceptOwnInfo(Entity):
                                """
                                Accept\-Own info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, self).__init__()

                                    self.yang_name = "accept-own-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "accept-own-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "accept-own-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseDefVrfImpDisableAfiV4Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, self).__init__()

                                    self.yang_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v4-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseDefVrfImpDisableAfiV6Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, self).__init__()

                                    self.yang_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v6-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseDisInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, self).__init__()

                                    self.yang_name = "advertise-dis-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-dis-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-dis-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseL2VpnEvpnAfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo, self).__init__()

                                    self.yang_name = "advertise-l2vpn-evpn-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-l2vpn-evpn-afi-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-l2vpn-evpn-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseLocalLabeledRouteInfo(Entity):
                                """
                                Advertise routes with local\-label
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, self).__init__()

                                    self.yang_name = "advertise-local-labeled-route-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-local-labeled-route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-local-labeled-route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseV4AfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, self).__init__()

                                    self.yang_name = "advertise-v4-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-v4-afi-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-v4-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseV6AfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, self).__init__()

                                    self.yang_name = "advertise-v6-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-v6-afi-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-v6-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseVrfReImpDisableAfiV4Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, self).__init__()

                                    self.yang_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v4-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertiseVrfReImpDisableAfiV6Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, self).__init__()

                                    self.yang_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v6-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfEnabledInfo(Entity):
                                """
                                Address family activate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, self).__init__()

                                    self.yang_name = "af-enabled-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "af-enabled-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-enabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfEncapsulationTypeInfo(Entity):
                                """
                                Encapsulation type Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, self).__init__()

                                    self.yang_name = "af-encapsulation-type-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "af-encapsulation-type-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-encapsulation-type-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfLongLivedGracefulStartCapableInfo(Entity):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, self).__init__()

                                    self.yang_name = "af-long-lived-graceful-start-capable-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "af-long-lived-graceful-start-capable-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-long-lived-graceful-start-capable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfLongLivedGracefulStartStaleTimeInfo(Entity):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, self).__init__()

                                    self.yang_name = "af-long-lived-graceful-start-stale-time-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "af-long-lived-graceful-start-stale-time-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-long-lived-graceful-start-stale-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AigpCostCommunityInfo(Entity):
                                """
                                AIGP Cost Community info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, self).__init__()

                                    self.yang_name = "aigp-cost-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "aigp-cost-community-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-cost-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AigpInfo(Entity):
                                """
                                AIGP info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, self).__init__()

                                    self.yang_name = "aigp-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "aigp-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AigpMed(Entity):
                                """
                                AIGP MED info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, self).__init__()

                                    self.yang_name = "aigp-med"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "aigp-med"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-med"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AllowasInInfo(Entity):
                                """
                                Allowas\-in item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, self).__init__()

                                    self.yang_name = "allowas-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "allowas-in-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "allowas-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AsOverrideInfo(Entity):
                                """
                                As\-override info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, self).__init__()

                                    self.yang_name = "as-override-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "as-override-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "as-override-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class DefaultOriginateInfo(Entity):
                                """
                                Default\-originate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, self).__init__()

                                    self.yang_name = "default-originate-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "default-originate-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "default-originate-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class EnforceMultipleLabelsInfo(Entity):
                                """
                                Enforce multiple labels
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, self).__init__()

                                    self.yang_name = "enforce-multiple-labels-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "enforce-multiple-labels-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "enforce-multiple-labels-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class FspecValidInfo(Entity):
                                """
                                FSPEC Valid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, self).__init__()

                                    self.yang_name = "fspec-valid-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "fspec-valid-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "fspec-valid-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ImportAfiInfo(Entity):
                                """
                                Import Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, self).__init__()

                                    self.yang_name = "import-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "import-afi-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "import-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class LegacyPeRtInfo(Entity):
                                """
                                Accept\-legacy\-pe\-RT item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, self).__init__()

                                    self.yang_name = "legacy-pe-rt-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "legacy-pe-rt-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "legacy-pe-rt-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MaxPrefixesInfo(Entity):
                                """
                                Maximum prefixes to accept item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, self).__init__()

                                    self.yang_name = "max-prefixes-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "max-prefixes-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "max-prefixes-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MultipathInfo(Entity):
                                """
                                Multipath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, self).__init__()

                                    self.yang_name = "multipath-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "multipath-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "multipath-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NextHopSelfInfo(Entity):
                                """
                                Next hop self item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, self).__init__()

                                    self.yang_name = "next-hop-self-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "next-hop-self-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-self-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NextHopUnchangedInfo(Entity):
                                """
                                Next hop unchanged info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, self).__init__()

                                    self.yang_name = "next-hop-unchanged-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "next-hop-unchanged-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-unchanged-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NextHopUnchangedMpathInfo(Entity):
                                """
                                Next hop unchanged mpath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, self).__init__()

                                    self.yang_name = "next-hop-unchanged-mpath-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "next-hop-unchanged-mpath-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-unchanged-mpath-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class OrfCapabilityInfo(Entity):
                                """
                                ORF capability item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, self).__init__()

                                    self.yang_name = "orf-capability-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "orf-capability-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "orf-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class OrrInfo(Entity):
                                """
                                Orr item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, self).__init__()

                                    self.yang_name = "orr-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "orr-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "orr-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class OrrRootAddress(Entity):
                                """
                                ORR Root Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, self).__init__()

                                    self.yang_name = "orr-root-address"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "orr-root-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PermanentNetworkInfo(Entity):
                                """
                                Permanent network Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, self).__init__()

                                    self.yang_name = "permanent-network-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "permanent-network-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "permanent-network-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixFilterInfo(Entity):
                                """
                                Inbound prefix based filter item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, self).__init__()

                                    self.yang_name = "prefix-filter-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "prefix-filter-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-filter-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RemovePrivateAsInInfo(Entity):
                                """
                                Inbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, self).__init__()

                                    self.yang_name = "remove-private-as-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "remove-private-as-in-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remove-private-as-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RemovePrivateAsInfo(Entity):
                                """
                                Outbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, self).__init__()

                                    self.yang_name = "remove-private-as-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "remove-private-as-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remove-private-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RoutePolicyInInfo(Entity):
                                """
                                Inbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, self).__init__()

                                    self.yang_name = "route-policy-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "route-policy-in-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-policy-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RoutePolicyOutInfo(Entity):
                                """
                                Outbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, self).__init__()

                                    self.yang_name = "route-policy-out-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "route-policy-out-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-policy-out-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RouteReflectorInfo(Entity):
                                """
                                Route\-reflector client item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, self).__init__()

                                    self.yang_name = "route-reflector-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "route-reflector-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-reflector-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SendCommunityInfo(Entity):
                                """
                                Send community attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, self).__init__()

                                    self.yang_name = "send-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "send-community-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SendExtendedCommunityInfo(Entity):
                                """
                                Send extended community  item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, self).__init__()

                                    self.yang_name = "send-extended-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "send-extended-community-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-extended-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SendGracefulShutdownCommunityInfo(Entity):
                                """
                                Send Graceful shutdown related community
                                attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, self).__init__()

                                    self.yang_name = "send-graceful-shutdown-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "send-graceful-shutdown-community-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-graceful-shutdown-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SendMcastAttrInfo(Entity):
                                """
                                Send mcast attr info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, self).__init__()

                                    self.yang_name = "send-mcast-attr-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "send-mcast-attr-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-mcast-attr-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SoOInfo(Entity):
                                """
                                BGP Site\-of\-Origin info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, self).__init__()

                                    self.yang_name = "so-o-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "so-o-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "so-o-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SoftReconfigInfo(Entity):
                                """
                                Soft reconf item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, self).__init__()

                                    self.yang_name = "soft-reconfig-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "soft-reconfig-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "soft-reconfig-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class WeightInfo(Entity):
                                """
                                Default weight item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, self).__init__()

                                    self.yang_name = "weight-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "weight-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "weight-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class AfIndependentConfig(Entity):
                            """
                            AF\-independent config
                            
                            .. attribute:: addpath_receive_capability
                            
                            	Indicates if addpath receive capability is enabled or disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: addpath_receive_capability_info
                            
                            	Addpath receive capability info
                            	**type**\:   :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                            
                            .. attribute:: addpath_send_capability
                            
                            	Indicates if addpath send capability is enabled or disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: addpath_send_capability_info
                            
                            	Addpath send capability info
                            	**type**\:   :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                            
                            .. attribute:: adminstrative_shutdown
                            
                            	Administrative shutdown
                            	**type**\:  bool
                            
                            .. attribute:: bestpath_use_origin_as_validity
                            
                            	Bestpath Use Origin\-AS Va
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd
                            
                            	Fast failure detection using BFD
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_info
                            
                            	BFD item info
                            	**type**\:   :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                            
                            .. attribute:: bfd_mininterval
                            
                            	BFD Minimum Interval
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_mininterval_info
                            
                            	BFD Mininterval item info
                            	**type**\:   :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                            
                            .. attribute:: bfd_multiplier
                            
                            	BFD Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplier_info
                            
                            	BFD Multiplier item info
                            	**type**\:   :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                            
                            .. attribute:: bgp_buffer_receive_size
                            
                            	BGP receive buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bgp_buffer_send_size
                            
                            	BGP send buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_servers
                            
                            	BMP Servers activated
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_servers_info
                            
                            	BMP Servers Configuredinfo
                            	**type**\:   :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                            
                            .. attribute:: capability_negotiation_suppressed
                            
                            	Capability negotiation is suppressed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability_negotiation_suppressed_info
                            
                            	Capability negotiation suppressed info
                            	**type**\:   :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                            
                            .. attribute:: cluster_id_info
                            
                            	Cluster ID item info
                            	**type**\:   :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                            
                            .. attribute:: configured_speaker_id
                            
                            	Configured speaker ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: description_info
                            
                            	Description item info
                            	**type**\:   :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Propagate the DMZ link bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth_info
                            
                            	DMZ link bandwidth item 
                            	**type**\:   :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                            
                            .. attribute:: ebgp_hop_count
                            
                            	EBGP neighbors hop count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_hop_count_info
                            
                            	EBGP neighbors hop count item info
                            	**type**\:   :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz_info
                            
                            	EBGP receive DMZ link bandwidth item info
                            	**type**\:   :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                            
                            .. attribute:: ebgp_send_dmz_info
                            
                            	EBGP send DMZ link bandwidth item info
                            	**type**\:   :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Send DMZ link bandwidthto ebgp peer
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: egress_peer_engineering
                            
                            	Indicates egress peer engineering is enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_info
                            
                            	Egress Peer Engineering info
                            	**type**\:   :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                            
                            .. attribute:: graceful_restart_disabled
                            
                            	Support for graceful\-restart
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_disabled_info
                            
                            	Graceful\-restart item info
                            	**type**\:   :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                            
                            .. attribute:: graceful_shutdown_activate
                            
                            	Graceful Shutdown state is activated
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_activate_info
                            
                            	GracefulShutdownAcivate info
                            	**type**\:   :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                            
                            .. attribute:: graceful_shutdown_as_prepends
                            
                            	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_as_prepends_info
                            
                            	GracefulShutdownASPrepends info
                            	**type**\:   :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                            
                            .. attribute:: graceful_shutdown_exists
                            
                            	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_info
                            
                            	GracefulShutdown info
                            	**type**\:   :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                            
                            .. attribute:: graceful_shutdown_loc_pref
                            
                            	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_loc_pref_info
                            
                            	GracefulShutdownLocPref info
                            	**type**\:   :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                            
                            .. attribute:: hold_time_value
                            
                            	Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: idle_watch_time
                            
                            	Idle Watch time(in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: idle_watch_time_info
                            
                            	Idle Watch time item info
                            	**type**\:   :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                            
                            .. attribute:: ignore_connected_check
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: ignore_connected_info
                            
                            	Ignore Connected Info
                            	**type**\:   :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, the VPN client isan iBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client_info
                            
                            	Internal VPN Client Info
                            	**type**\:   :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: keepalive_interval
                            
                            	Keepalive interval
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keychain
                            
                            	Neighbor keychain Name
                            	**type**\:  str
                            
                            .. attribute:: keychain_info
                            
                            	Neighbor Keychain item info
                            	**type**\:   :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                            
                            .. attribute:: local_address_info
                            
                            	Local address item info
                            	**type**\:   :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_info
                            
                            	Local AS number item info
                            	**type**\:   :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Local AS no\-prepend option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_number_xx
                            
                            	First half of Local ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_number_yy
                            
                            	Second half of Local ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_ip_address
                            
                            	Local ipv4 or ipv6 address for neighbor connection
                            	**type**\:   :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                            
                            .. attribute:: max_peers
                            
                            	Maximum dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_peers_info
                            
                            	Max dynamic nbrs in range info
                            	**type**\:   :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                            
                            .. attribute:: min_acc_hold_time_value
                            
                            	Min acceptable holdtimefrom neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertisement_info
                            
                            	Minimum advertisement interval item info
                            	**type**\:   :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                            
                            .. attribute:: min_advertisement_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertisement_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: msg_log_in_buf_count
                            
                            	Message Log Inbound buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in_info
                            
                            	Message Log Inbound item info
                            	**type**\:   :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                            
                            .. attribute:: msg_log_out_buf_count
                            
                            	Message Log Outbound buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out_info
                            
                            	Message Log Outbound item info
                            	**type**\:   :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                            
                            .. attribute:: nbr_cluster_id_info
                            
                            	Cluster ID value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id_type_info
                            
                            	Cluster ID Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_enforce_first_as_info
                            
                            	Neighbor enforce first AS info
                            	**type**\:   :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                            
                            .. attribute:: nbr_enforce_first_as_status
                            
                            	Neighbor enforce first AS status
                            	**type**\:  bool
                            
                            .. attribute:: nbr_restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_restart_time_info
                            
                            	Restart time item info
                            	**type**\:   :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                            
                            .. attribute:: nbr_stale_path_time
                            
                            	Stale\-path time(in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_stale_path_time_info
                            
                            	Stale\-path time item info
                            	**type**\:   :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                            
                            .. attribute:: neighbor_remote_as_list_group_name
                            
                            	Neighbor Range remote\-as\-list group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_remote_as_list_info
                            
                            	Neighbor range  remote\-as\-list group info
                            	**type**\:   :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                            
                            .. attribute:: neighbor_update_filter_attribute_filter_group_name
                            
                            	Neighbor filter attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_update_filter_attribute_info
                            
                            	Neighbor update filter attribute\-filter group info
                            	**type**\:   :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                            
                            .. attribute:: neighbor_update_filter_exists
                            
                            	Indicates if neighbor filter configuration exists
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_exists_info
                            
                            	Neighbor update filter configuration info
                            	**type**\:   :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                            
                            .. attribute:: neighbor_update_filter_logging_disable
                            
                            	Indicates if neighbor filter logging is disabled
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count
                            
                            	Count of neighbor filter message buffers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count_info
                            
                            	Neighbor update filter message buffer count info
                            	**type**\:   :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                            
                            .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                            
                            	Indicates if neighbor update filter message buffer is circular or not
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_syslog_disable_info
                            
                            	Neighbor update filter syslog disable info
                            	**type**\:   :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                            
                            .. attribute:: nsr_disabled
                            
                            	Support for NSR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_disabled_info
                            
                            	NSR item info
                            	**type**\:   :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                            
                            .. attribute:: password
                            
                            	Neighbor password
                            	**type**\:  str
                            
                            .. attribute:: password_info
                            
                            	Neighbor password item info
                            	**type**\:   :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                            
                            .. attribute:: prefix_validation_allow_invalid
                            
                            	Prefix validation allow invalid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_allow_invalid_info
                            
                            	RPKI allow invalid info
                            	**type**\:   :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                            
                            .. attribute:: prefix_validation_disable
                            
                            	Prefix validation disable
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_disable_info
                            
                            	RPKI disable info
                            	**type**\:   :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                            
                            .. attribute:: prefix_validation_signal_ibgp
                            
                            	Prefix validation signal ibgp
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_signal_ibgp_info
                            
                            	RPKI signal ibgp info
                            	**type**\:   :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                            
                            .. attribute:: prefix_validation_use_validit_info
                            
                            	RPKI use validity
                            	**type**\:   :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                            
                            .. attribute:: receive_buffer_info
                            
                            	Receive buffer sizes item info
                            	**type**\:   :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                            
                            .. attribute:: remote_as_info
                            
                            	Remote AS number item info
                            	**type**\:   :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                            
                            .. attribute:: remote_as_number_xx
                            
                            	First half of Remote ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number_yy
                            
                            	Second half of Remote ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_updates_source
                            
                            	Source of routing updates
                            	**type**\:  str
                            
                            .. attribute:: send_buffer_info
                            
                            	Send buffer sizes item info
                            	**type**\:   :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                            
                            .. attribute:: session_open_mode
                            
                            	TCP open mode to be used 
                            	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: session_open_mode_info
                            
                            	TCP conn open mode info
                            	**type**\:   :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                            
                            .. attribute:: shutdown_info
                            
                            	Shutdown item info
                            	**type**\:   :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                            
                            .. attribute:: socket_buffer_receive_size
                            
                            	Socket receive buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: socket_buffer_send_size
                            
                            	Socket send buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id_info
                            
                            	Configured speaker ID item info
                            	**type**\:   :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                            
                            .. attribute:: suppress4_bbyte_as_info
                            
                            	BGP suppress 4byte\-as item info
                            	**type**\:   :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress BGP 4byteas Cap
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tcp_mss
                            
                            	Maximum Segment Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tcpmss_info
                            
                            	TCP Maximum Segment Size item info
                            	**type**\:   :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                            
                            .. attribute:: timers_info
                            
                            	Timers item info
                            	**type**\:   :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                            
                            .. attribute:: tos_info
                            
                            	TOS item info
                            	**type**\:   :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                            
                            .. attribute:: tos_type_info
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value_info
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security
                            
                            	Enable BGP TTL Security
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ttl_security_info
                            
                            	BGP TTL Security item info
                            	**type**\:   :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                            
                            .. attribute:: update_error_handling_no_reset
                            
                            	Indicates if avoid\-reset behavior is enabled during update error\-handling
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_no_reset_info
                            
                            	Error\-handling avoid\-reset config info
                            	**type**\:   :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                            
                            .. attribute:: update_source_info
                            
                            	Update source item info
                            	**type**\:   :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, self).__init__()

                                self.yang_name = "af-independent-config"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"addpath-receive-capability-info" : ("addpath_receive_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo), "addpath-send-capability-info" : ("addpath_send_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo), "bfd-info" : ("bfd_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo), "bfd-mininterval-info" : ("bfd_mininterval_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo), "bfd-multiplier-info" : ("bfd_multiplier_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo), "bmp-servers-info" : ("bmp_servers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo), "capability-negotiation-suppressed-info" : ("capability_negotiation_suppressed_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo), "cluster-id-info" : ("cluster_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo), "description-info" : ("description_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo), "dmz-link-bandwidth-info" : ("dmz_link_bandwidth_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo), "ebgp-hop-count-info" : ("ebgp_hop_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo), "ebgp-recv-dmz-info" : ("ebgp_recv_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo), "ebgp-send-dmz-info" : ("ebgp_send_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo), "egress-peer-engineering-info" : ("egress_peer_engineering_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo), "graceful-restart-disabled-info" : ("graceful_restart_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo), "graceful-shutdown-activate-info" : ("graceful_shutdown_activate_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo), "graceful-shutdown-as-prepends-info" : ("graceful_shutdown_as_prepends_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo), "graceful-shutdown-info" : ("graceful_shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo), "graceful-shutdown-loc-pref-info" : ("graceful_shutdown_loc_pref_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo), "idle-watch-time-info" : ("idle_watch_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo), "ignore-connected-info" : ("ignore_connected_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo), "internal-vpn-client-info" : ("internal_vpn_client_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo), "keychain-info" : ("keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo), "local-address-info" : ("local_address_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo), "local-as-info" : ("local_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo), "local-ip-address" : ("local_ip_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress), "max-peers-info" : ("max_peers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo), "min-advertisement-info" : ("min_advertisement_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo), "msg-log-in-info" : ("msg_log_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo), "msg-log-out-info" : ("msg_log_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo), "nbr-enforce-first-as-info" : ("nbr_enforce_first_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo), "nbr-restart-time-info" : ("nbr_restart_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo), "nbr-stale-path-time-info" : ("nbr_stale_path_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo), "neighbor-remote-as-list-info" : ("neighbor_remote_as_list_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo), "neighbor-update-filter-attribute-info" : ("neighbor_update_filter_attribute_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo), "neighbor-update-filter-exists-info" : ("neighbor_update_filter_exists_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo), "neighbor-update-filter-message-buffer-count-info" : ("neighbor_update_filter_message_buffer_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo), "neighbor-update-filter-syslog-disable-info" : ("neighbor_update_filter_syslog_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo), "nsr-disabled-info" : ("nsr_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo), "password-info" : ("password_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo), "prefix-validation-allow-invalid-info" : ("prefix_validation_allow_invalid_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo), "prefix-validation-disable-info" : ("prefix_validation_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo), "prefix-validation-signal-ibgp-info" : ("prefix_validation_signal_ibgp_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo), "prefix-validation-use-validit-info" : ("prefix_validation_use_validit_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo), "receive-buffer-info" : ("receive_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo), "remote-as-info" : ("remote_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo), "send-buffer-info" : ("send_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo), "session-open-mode-info" : ("session_open_mode_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo), "shutdown-info" : ("shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo), "speaker-id-info" : ("speaker_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo), "suppress4-bbyte-as-info" : ("suppress4_bbyte_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo), "tcpmss-info" : ("tcpmss_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo), "timers-info" : ("timers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo), "tos-info" : ("tos_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo), "ttl-security-info" : ("ttl_security_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo), "update-error-handling-no-reset-info" : ("update_error_handling_no_reset_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo), "update-source-info" : ("update_source_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo)}
                                self._child_list_classes = {}

                                self.addpath_receive_capability = YLeaf(YType.uint32, "addpath-receive-capability")

                                self.addpath_send_capability = YLeaf(YType.uint32, "addpath-send-capability")

                                self.adminstrative_shutdown = YLeaf(YType.boolean, "adminstrative-shutdown")

                                self.bestpath_use_origin_as_validity = YLeaf(YType.uint32, "bestpath-use-origin-as-validity")

                                self.bfd = YLeaf(YType.uint32, "bfd")

                                self.bfd_mininterval = YLeaf(YType.uint32, "bfd-mininterval")

                                self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                self.bgp_buffer_receive_size = YLeaf(YType.uint32, "bgp-buffer-receive-size")

                                self.bgp_buffer_send_size = YLeaf(YType.uint32, "bgp-buffer-send-size")

                                self.bmp_servers = YLeaf(YType.uint32, "bmp-servers")

                                self.capability_negotiation_suppressed = YLeaf(YType.uint32, "capability-negotiation-suppressed")

                                self.configured_speaker_id = YLeaf(YType.uint32, "configured-speaker-id")

                                self.description = YLeaf(YType.str, "description")

                                self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                self.ebgp_hop_count = YLeaf(YType.uint32, "ebgp-hop-count")

                                self.ebgp_recv_dmz = YLeaf(YType.uint32, "ebgp-recv-dmz")

                                self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                self.egress_peer_engineering = YLeaf(YType.uint32, "egress-peer-engineering")

                                self.graceful_restart_disabled = YLeaf(YType.uint32, "graceful-restart-disabled")

                                self.graceful_shutdown_activate = YLeaf(YType.uint32, "graceful-shutdown-activate")

                                self.graceful_shutdown_as_prepends = YLeaf(YType.uint32, "graceful-shutdown-as-prepends")

                                self.graceful_shutdown_exists = YLeaf(YType.uint32, "graceful-shutdown-exists")

                                self.graceful_shutdown_loc_pref = YLeaf(YType.uint32, "graceful-shutdown-loc-pref")

                                self.hold_time_value = YLeaf(YType.uint32, "hold-time-value")

                                self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                self.ignore_connected_check = YLeaf(YType.boolean, "ignore-connected-check")

                                self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                self.keychain = YLeaf(YType.str, "keychain")

                                self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                self.local_as_number_xx = YLeaf(YType.uint32, "local-as-number-xx")

                                self.local_as_number_yy = YLeaf(YType.uint32, "local-as-number-yy")

                                self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                self.max_peers = YLeaf(YType.uint32, "max-peers")

                                self.min_acc_hold_time_value = YLeaf(YType.uint32, "min-acc-hold-time-value")

                                self.min_advertisement_interval = YLeaf(YType.uint32, "min-advertisement-interval")

                                self.min_advertisement_interval_msecs = YLeaf(YType.uint32, "min-advertisement-interval-msecs")

                                self.msg_log_in_buf_count = YLeaf(YType.uint32, "msg-log-in-buf-count")

                                self.msg_log_out_buf_count = YLeaf(YType.uint32, "msg-log-out-buf-count")

                                self.nbr_cluster_id_info = YLeaf(YType.uint32, "nbr-cluster-id-info")

                                self.nbr_cluster_id_type_info = YLeaf(YType.uint8, "nbr-cluster-id-type-info")

                                self.nbr_enforce_first_as_status = YLeaf(YType.boolean, "nbr-enforce-first-as-status")

                                self.nbr_restart_time = YLeaf(YType.uint32, "nbr-restart-time")

                                self.nbr_stale_path_time = YLeaf(YType.uint32, "nbr-stale-path-time")

                                self.neighbor_remote_as_list_group_name = YLeaf(YType.str, "neighbor-remote-as-list-group-name")

                                self.neighbor_update_filter_attribute_filter_group_name = YLeaf(YType.str, "neighbor-update-filter-attribute-filter-group-name")

                                self.neighbor_update_filter_exists = YLeaf(YType.boolean, "neighbor-update-filter-exists")

                                self.neighbor_update_filter_logging_disable = YLeaf(YType.boolean, "neighbor-update-filter-logging-disable")

                                self.neighbor_update_filter_message_buffer_count = YLeaf(YType.uint32, "neighbor-update-filter-message-buffer-count")

                                self.neighbor_update_filter_message_buffer_is_non_circular = YLeaf(YType.boolean, "neighbor-update-filter-message-buffer-is-non-circular")

                                self.nsr_disabled = YLeaf(YType.uint32, "nsr-disabled")

                                self.password = YLeaf(YType.str, "password")

                                self.prefix_validation_allow_invalid = YLeaf(YType.uint32, "prefix-validation-allow-invalid")

                                self.prefix_validation_disable = YLeaf(YType.uint32, "prefix-validation-disable")

                                self.prefix_validation_signal_ibgp = YLeaf(YType.uint32, "prefix-validation-signal-ibgp")

                                self.remote_as_number_xx = YLeaf(YType.uint32, "remote-as-number-xx")

                                self.remote_as_number_yy = YLeaf(YType.uint32, "remote-as-number-yy")

                                self.route_updates_source = YLeaf(YType.str, "route-updates-source")

                                self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                self.socket_buffer_receive_size = YLeaf(YType.uint32, "socket-buffer-receive-size")

                                self.socket_buffer_send_size = YLeaf(YType.uint32, "socket-buffer-send-size")

                                self.suppress4_byte_as = YLeaf(YType.uint32, "suppress4-byte-as")

                                self.tcp_mss = YLeaf(YType.uint32, "tcp-mss")

                                self.tos_type_info = YLeaf(YType.uint8, "tos-type-info")

                                self.tos_value_info = YLeaf(YType.uint8, "tos-value-info")

                                self.ttl_security = YLeaf(YType.uint32, "ttl-security")

                                self.update_error_handling_no_reset = YLeaf(YType.uint32, "update-error-handling-no-reset")

                                self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                self.addpath_receive_capability_info.parent = self
                                self._children_name_map["addpath_receive_capability_info"] = "addpath-receive-capability-info"
                                self._children_yang_names.add("addpath-receive-capability-info")

                                self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                self.addpath_send_capability_info.parent = self
                                self._children_name_map["addpath_send_capability_info"] = "addpath-send-capability-info"
                                self._children_yang_names.add("addpath-send-capability-info")

                                self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                self.bfd_info.parent = self
                                self._children_name_map["bfd_info"] = "bfd-info"
                                self._children_yang_names.add("bfd-info")

                                self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                self.bfd_mininterval_info.parent = self
                                self._children_name_map["bfd_mininterval_info"] = "bfd-mininterval-info"
                                self._children_yang_names.add("bfd-mininterval-info")

                                self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                self.bfd_multiplier_info.parent = self
                                self._children_name_map["bfd_multiplier_info"] = "bfd-multiplier-info"
                                self._children_yang_names.add("bfd-multiplier-info")

                                self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                self.bmp_servers_info.parent = self
                                self._children_name_map["bmp_servers_info"] = "bmp-servers-info"
                                self._children_yang_names.add("bmp-servers-info")

                                self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                self.capability_negotiation_suppressed_info.parent = self
                                self._children_name_map["capability_negotiation_suppressed_info"] = "capability-negotiation-suppressed-info"
                                self._children_yang_names.add("capability-negotiation-suppressed-info")

                                self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                self.cluster_id_info.parent = self
                                self._children_name_map["cluster_id_info"] = "cluster-id-info"
                                self._children_yang_names.add("cluster-id-info")

                                self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                self.description_info.parent = self
                                self._children_name_map["description_info"] = "description-info"
                                self._children_yang_names.add("description-info")

                                self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                self.dmz_link_bandwidth_info.parent = self
                                self._children_name_map["dmz_link_bandwidth_info"] = "dmz-link-bandwidth-info"
                                self._children_yang_names.add("dmz-link-bandwidth-info")

                                self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                self.ebgp_hop_count_info.parent = self
                                self._children_name_map["ebgp_hop_count_info"] = "ebgp-hop-count-info"
                                self._children_yang_names.add("ebgp-hop-count-info")

                                self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                self.ebgp_recv_dmz_info.parent = self
                                self._children_name_map["ebgp_recv_dmz_info"] = "ebgp-recv-dmz-info"
                                self._children_yang_names.add("ebgp-recv-dmz-info")

                                self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                self.ebgp_send_dmz_info.parent = self
                                self._children_name_map["ebgp_send_dmz_info"] = "ebgp-send-dmz-info"
                                self._children_yang_names.add("ebgp-send-dmz-info")

                                self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                self.egress_peer_engineering_info.parent = self
                                self._children_name_map["egress_peer_engineering_info"] = "egress-peer-engineering-info"
                                self._children_yang_names.add("egress-peer-engineering-info")

                                self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                self.graceful_restart_disabled_info.parent = self
                                self._children_name_map["graceful_restart_disabled_info"] = "graceful-restart-disabled-info"
                                self._children_yang_names.add("graceful-restart-disabled-info")

                                self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                self.graceful_shutdown_activate_info.parent = self
                                self._children_name_map["graceful_shutdown_activate_info"] = "graceful-shutdown-activate-info"
                                self._children_yang_names.add("graceful-shutdown-activate-info")

                                self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                self.graceful_shutdown_as_prepends_info.parent = self
                                self._children_name_map["graceful_shutdown_as_prepends_info"] = "graceful-shutdown-as-prepends-info"
                                self._children_yang_names.add("graceful-shutdown-as-prepends-info")

                                self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                self.graceful_shutdown_info.parent = self
                                self._children_name_map["graceful_shutdown_info"] = "graceful-shutdown-info"
                                self._children_yang_names.add("graceful-shutdown-info")

                                self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                self.graceful_shutdown_loc_pref_info.parent = self
                                self._children_name_map["graceful_shutdown_loc_pref_info"] = "graceful-shutdown-loc-pref-info"
                                self._children_yang_names.add("graceful-shutdown-loc-pref-info")

                                self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                self.idle_watch_time_info.parent = self
                                self._children_name_map["idle_watch_time_info"] = "idle-watch-time-info"
                                self._children_yang_names.add("idle-watch-time-info")

                                self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                self.ignore_connected_info.parent = self
                                self._children_name_map["ignore_connected_info"] = "ignore-connected-info"
                                self._children_yang_names.add("ignore-connected-info")

                                self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                self.internal_vpn_client_info.parent = self
                                self._children_name_map["internal_vpn_client_info"] = "internal-vpn-client-info"
                                self._children_yang_names.add("internal-vpn-client-info")

                                self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                self.keychain_info.parent = self
                                self._children_name_map["keychain_info"] = "keychain-info"
                                self._children_yang_names.add("keychain-info")

                                self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                self.local_address_info.parent = self
                                self._children_name_map["local_address_info"] = "local-address-info"
                                self._children_yang_names.add("local-address-info")

                                self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                self.local_as_info.parent = self
                                self._children_name_map["local_as_info"] = "local-as-info"
                                self._children_yang_names.add("local-as-info")

                                self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                self.local_ip_address.parent = self
                                self._children_name_map["local_ip_address"] = "local-ip-address"
                                self._children_yang_names.add("local-ip-address")

                                self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                self.max_peers_info.parent = self
                                self._children_name_map["max_peers_info"] = "max-peers-info"
                                self._children_yang_names.add("max-peers-info")

                                self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                self.min_advertisement_info.parent = self
                                self._children_name_map["min_advertisement_info"] = "min-advertisement-info"
                                self._children_yang_names.add("min-advertisement-info")

                                self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                self.msg_log_in_info.parent = self
                                self._children_name_map["msg_log_in_info"] = "msg-log-in-info"
                                self._children_yang_names.add("msg-log-in-info")

                                self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                self.msg_log_out_info.parent = self
                                self._children_name_map["msg_log_out_info"] = "msg-log-out-info"
                                self._children_yang_names.add("msg-log-out-info")

                                self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                self.nbr_enforce_first_as_info.parent = self
                                self._children_name_map["nbr_enforce_first_as_info"] = "nbr-enforce-first-as-info"
                                self._children_yang_names.add("nbr-enforce-first-as-info")

                                self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                self.nbr_restart_time_info.parent = self
                                self._children_name_map["nbr_restart_time_info"] = "nbr-restart-time-info"
                                self._children_yang_names.add("nbr-restart-time-info")

                                self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                self.nbr_stale_path_time_info.parent = self
                                self._children_name_map["nbr_stale_path_time_info"] = "nbr-stale-path-time-info"
                                self._children_yang_names.add("nbr-stale-path-time-info")

                                self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                self.neighbor_remote_as_list_info.parent = self
                                self._children_name_map["neighbor_remote_as_list_info"] = "neighbor-remote-as-list-info"
                                self._children_yang_names.add("neighbor-remote-as-list-info")

                                self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                self.neighbor_update_filter_attribute_info.parent = self
                                self._children_name_map["neighbor_update_filter_attribute_info"] = "neighbor-update-filter-attribute-info"
                                self._children_yang_names.add("neighbor-update-filter-attribute-info")

                                self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                self.neighbor_update_filter_exists_info.parent = self
                                self._children_name_map["neighbor_update_filter_exists_info"] = "neighbor-update-filter-exists-info"
                                self._children_yang_names.add("neighbor-update-filter-exists-info")

                                self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                self.neighbor_update_filter_message_buffer_count_info.parent = self
                                self._children_name_map["neighbor_update_filter_message_buffer_count_info"] = "neighbor-update-filter-message-buffer-count-info"
                                self._children_yang_names.add("neighbor-update-filter-message-buffer-count-info")

                                self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                self.neighbor_update_filter_syslog_disable_info.parent = self
                                self._children_name_map["neighbor_update_filter_syslog_disable_info"] = "neighbor-update-filter-syslog-disable-info"
                                self._children_yang_names.add("neighbor-update-filter-syslog-disable-info")

                                self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                self.nsr_disabled_info.parent = self
                                self._children_name_map["nsr_disabled_info"] = "nsr-disabled-info"
                                self._children_yang_names.add("nsr-disabled-info")

                                self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                self.password_info.parent = self
                                self._children_name_map["password_info"] = "password-info"
                                self._children_yang_names.add("password-info")

                                self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                self.prefix_validation_allow_invalid_info.parent = self
                                self._children_name_map["prefix_validation_allow_invalid_info"] = "prefix-validation-allow-invalid-info"
                                self._children_yang_names.add("prefix-validation-allow-invalid-info")

                                self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                self.prefix_validation_disable_info.parent = self
                                self._children_name_map["prefix_validation_disable_info"] = "prefix-validation-disable-info"
                                self._children_yang_names.add("prefix-validation-disable-info")

                                self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                self.prefix_validation_signal_ibgp_info.parent = self
                                self._children_name_map["prefix_validation_signal_ibgp_info"] = "prefix-validation-signal-ibgp-info"
                                self._children_yang_names.add("prefix-validation-signal-ibgp-info")

                                self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                self.prefix_validation_use_validit_info.parent = self
                                self._children_name_map["prefix_validation_use_validit_info"] = "prefix-validation-use-validit-info"
                                self._children_yang_names.add("prefix-validation-use-validit-info")

                                self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                self.receive_buffer_info.parent = self
                                self._children_name_map["receive_buffer_info"] = "receive-buffer-info"
                                self._children_yang_names.add("receive-buffer-info")

                                self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                self.remote_as_info.parent = self
                                self._children_name_map["remote_as_info"] = "remote-as-info"
                                self._children_yang_names.add("remote-as-info")

                                self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                self.send_buffer_info.parent = self
                                self._children_name_map["send_buffer_info"] = "send-buffer-info"
                                self._children_yang_names.add("send-buffer-info")

                                self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                self.session_open_mode_info.parent = self
                                self._children_name_map["session_open_mode_info"] = "session-open-mode-info"
                                self._children_yang_names.add("session-open-mode-info")

                                self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                self.shutdown_info.parent = self
                                self._children_name_map["shutdown_info"] = "shutdown-info"
                                self._children_yang_names.add("shutdown-info")

                                self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                self.speaker_id_info.parent = self
                                self._children_name_map["speaker_id_info"] = "speaker-id-info"
                                self._children_yang_names.add("speaker-id-info")

                                self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                self.suppress4_bbyte_as_info.parent = self
                                self._children_name_map["suppress4_bbyte_as_info"] = "suppress4-bbyte-as-info"
                                self._children_yang_names.add("suppress4-bbyte-as-info")

                                self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                self.tcpmss_info.parent = self
                                self._children_name_map["tcpmss_info"] = "tcpmss-info"
                                self._children_yang_names.add("tcpmss-info")

                                self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                self.timers_info.parent = self
                                self._children_name_map["timers_info"] = "timers-info"
                                self._children_yang_names.add("timers-info")

                                self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                self.tos_info.parent = self
                                self._children_name_map["tos_info"] = "tos-info"
                                self._children_yang_names.add("tos-info")

                                self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                self.ttl_security_info.parent = self
                                self._children_name_map["ttl_security_info"] = "ttl-security-info"
                                self._children_yang_names.add("ttl-security-info")

                                self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                self.update_error_handling_no_reset_info.parent = self
                                self._children_name_map["update_error_handling_no_reset_info"] = "update-error-handling-no-reset-info"
                                self._children_yang_names.add("update-error-handling-no-reset-info")

                                self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                self.update_source_info.parent = self
                                self._children_name_map["update_source_info"] = "update-source-info"
                                self._children_yang_names.add("update-source-info")
                                self._segment_path = lambda: "af-independent-config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, ['addpath_receive_capability', 'addpath_send_capability', 'adminstrative_shutdown', 'bestpath_use_origin_as_validity', 'bfd', 'bfd_mininterval', 'bfd_multiplier', 'bgp_buffer_receive_size', 'bgp_buffer_send_size', 'bmp_servers', 'capability_negotiation_suppressed', 'configured_speaker_id', 'description', 'dmz_link_bandwidth', 'ebgp_hop_count', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'egress_peer_engineering', 'graceful_restart_disabled', 'graceful_shutdown_activate', 'graceful_shutdown_as_prepends', 'graceful_shutdown_exists', 'graceful_shutdown_loc_pref', 'hold_time_value', 'idle_watch_time', 'ignore_connected_check', 'internal_vpn_client', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'keepalive_interval', 'keychain', 'local_as_dual_as', 'local_as_no_prepend', 'local_as_number_xx', 'local_as_number_yy', 'local_as_replace_as', 'max_peers', 'min_acc_hold_time_value', 'min_advertisement_interval', 'min_advertisement_interval_msecs', 'msg_log_in_buf_count', 'msg_log_out_buf_count', 'nbr_cluster_id_info', 'nbr_cluster_id_type_info', 'nbr_enforce_first_as_status', 'nbr_restart_time', 'nbr_stale_path_time', 'neighbor_remote_as_list_group_name', 'neighbor_update_filter_attribute_filter_group_name', 'neighbor_update_filter_exists', 'neighbor_update_filter_logging_disable', 'neighbor_update_filter_message_buffer_count', 'neighbor_update_filter_message_buffer_is_non_circular', 'nsr_disabled', 'password', 'prefix_validation_allow_invalid', 'prefix_validation_disable', 'prefix_validation_signal_ibgp', 'remote_as_number_xx', 'remote_as_number_yy', 'route_updates_source', 'session_open_mode', 'socket_buffer_receive_size', 'socket_buffer_send_size', 'suppress4_byte_as', 'tcp_mss', 'tos_type_info', 'tos_value_info', 'ttl_security', 'update_error_handling_no_reset'], name, value)


                            class AddpathReceiveCapabilityInfo(Entity):
                                """
                                Addpath receive capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, self).__init__()

                                    self.yang_name = "addpath-receive-capability-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "addpath-receive-capability-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "addpath-receive-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AddpathSendCapabilityInfo(Entity):
                                """
                                Addpath send capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, self).__init__()

                                    self.yang_name = "addpath-send-capability-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "addpath-send-capability-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "addpath-send-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class BfdInfo(Entity):
                                """
                                BFD item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, self).__init__()

                                    self.yang_name = "bfd-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "bfd-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class BfdMinintervalInfo(Entity):
                                """
                                BFD Mininterval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, self).__init__()

                                    self.yang_name = "bfd-mininterval-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "bfd-mininterval-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-mininterval-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class BfdMultiplierInfo(Entity):
                                """
                                BFD Multiplier item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, self).__init__()

                                    self.yang_name = "bfd-multiplier-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "bfd-multiplier-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-multiplier-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class BmpServersInfo(Entity):
                                """
                                BMP Servers Configuredinfo
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, self).__init__()

                                    self.yang_name = "bmp-servers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "bmp-servers-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bmp-servers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class CapabilityNegotiationSuppressedInfo(Entity):
                                """
                                Capability negotiation suppressed info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, self).__init__()

                                    self.yang_name = "capability-negotiation-suppressed-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "capability-negotiation-suppressed-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "capability-negotiation-suppressed-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ClusterIdInfo(Entity):
                                """
                                Cluster ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, self).__init__()

                                    self.yang_name = "cluster-id-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "cluster-id-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "cluster-id-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class DescriptionInfo(Entity):
                                """
                                Description item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, self).__init__()

                                    self.yang_name = "description-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "description-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "description-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class DmzLinkBandwidthInfo(Entity):
                                """
                                DMZ link bandwidth item 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, self).__init__()

                                    self.yang_name = "dmz-link-bandwidth-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "dmz-link-bandwidth-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "dmz-link-bandwidth-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class EbgpHopCountInfo(Entity):
                                """
                                EBGP neighbors hop count item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, self).__init__()

                                    self.yang_name = "ebgp-hop-count-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "ebgp-hop-count-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-hop-count-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class EbgpRecvDmzInfo(Entity):
                                """
                                EBGP receive DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, self).__init__()

                                    self.yang_name = "ebgp-recv-dmz-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "ebgp-recv-dmz-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-recv-dmz-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class EbgpSendDmzInfo(Entity):
                                """
                                EBGP send DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, self).__init__()

                                    self.yang_name = "ebgp-send-dmz-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "ebgp-send-dmz-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-send-dmz-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class EgressPeerEngineeringInfo(Entity):
                                """
                                Egress Peer Engineering info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, self).__init__()

                                    self.yang_name = "egress-peer-engineering-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "egress-peer-engineering-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "egress-peer-engineering-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulRestartDisabledInfo(Entity):
                                """
                                Graceful\-restart item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, self).__init__()

                                    self.yang_name = "graceful-restart-disabled-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "graceful-restart-disabled-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-restart-disabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulShutdownActivateInfo(Entity):
                                """
                                GracefulShutdownAcivate info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-activate-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "graceful-shutdown-activate-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-activate-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulShutdownAsPrependsInfo(Entity):
                                """
                                GracefulShutdownASPrepends info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-as-prepends-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "graceful-shutdown-as-prepends-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-as-prepends-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulShutdownInfo(Entity):
                                """
                                GracefulShutdown info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "graceful-shutdown-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulShutdownLocPrefInfo(Entity):
                                """
                                GracefulShutdownLocPref info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-loc-pref-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "graceful-shutdown-loc-pref-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-loc-pref-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class IdleWatchTimeInfo(Entity):
                                """
                                Idle Watch time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, self).__init__()

                                    self.yang_name = "idle-watch-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "idle-watch-time-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "idle-watch-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class IgnoreConnectedInfo(Entity):
                                """
                                Ignore Connected Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, self).__init__()

                                    self.yang_name = "ignore-connected-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "ignore-connected-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ignore-connected-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class InternalVpnClientInfo(Entity):
                                """
                                Internal VPN Client Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, self).__init__()

                                    self.yang_name = "internal-vpn-client-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "internal-vpn-client-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "internal-vpn-client-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class KeychainInfo(Entity):
                                """
                                Neighbor Keychain item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, self).__init__()

                                    self.yang_name = "keychain-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "keychain-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "keychain-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class LocalAddressInfo(Entity):
                                """
                                Local address item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, self).__init__()

                                    self.yang_name = "local-address-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "local-address-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "local-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class LocalAsInfo(Entity):
                                """
                                Local AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, self).__init__()

                                    self.yang_name = "local-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "local-as-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "local-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class LocalIpAddress(Entity):
                                """
                                Local ipv4 or ipv6 address for neighbor
                                connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, self).__init__()

                                    self.yang_name = "local-ip-address"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "local-ip-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MaxPeersInfo(Entity):
                                """
                                Max dynamic nbrs in range info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, self).__init__()

                                    self.yang_name = "max-peers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "max-peers-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "max-peers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MinAdvertisementInfo(Entity):
                                """
                                Minimum advertisement interval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, self).__init__()

                                    self.yang_name = "min-advertisement-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "min-advertisement-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "min-advertisement-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MsgLogInInfo(Entity):
                                """
                                Message Log Inbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, self).__init__()

                                    self.yang_name = "msg-log-in-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "msg-log-in-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "msg-log-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class MsgLogOutInfo(Entity):
                                """
                                Message Log Outbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, self).__init__()

                                    self.yang_name = "msg-log-out-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "msg-log-out-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "msg-log-out-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NbrEnforceFirstAsInfo(Entity):
                                """
                                Neighbor enforce first AS info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, self).__init__()

                                    self.yang_name = "nbr-enforce-first-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "nbr-enforce-first-as-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-enforce-first-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NbrRestartTimeInfo(Entity):
                                """
                                Restart time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, self).__init__()

                                    self.yang_name = "nbr-restart-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "nbr-restart-time-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-restart-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NbrStalePathTimeInfo(Entity):
                                """
                                Stale\-path time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, self).__init__()

                                    self.yang_name = "nbr-stale-path-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "nbr-stale-path-time-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-stale-path-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborRemoteAsListInfo(Entity):
                                """
                                Neighbor range  remote\-as\-list group info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, self).__init__()

                                    self.yang_name = "neighbor-remote-as-list-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "neighbor-remote-as-list-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-remote-as-list-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborUpdateFilterAttributeInfo(Entity):
                                """
                                Neighbor update filter attribute\-filter group
                                info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-attribute-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "neighbor-update-filter-attribute-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-attribute-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborUpdateFilterExistsInfo(Entity):
                                """
                                Neighbor update filter configuration info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-exists-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "neighbor-update-filter-exists-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-exists-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborUpdateFilterMessageBufferCountInfo(Entity):
                                """
                                Neighbor update filter message buffer count info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-message-buffer-count-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "neighbor-update-filter-message-buffer-count-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-message-buffer-count-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborUpdateFilterSyslogDisableInfo(Entity):
                                """
                                Neighbor update filter syslog disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-syslog-disable-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "neighbor-update-filter-syslog-disable-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-syslog-disable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NsrDisabledInfo(Entity):
                                """
                                NSR item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, self).__init__()

                                    self.yang_name = "nsr-disabled-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "nsr-disabled-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nsr-disabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PasswordInfo(Entity):
                                """
                                Neighbor password item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, self).__init__()

                                    self.yang_name = "password-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "password-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "password-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixValidationAllowInvalidInfo(Entity):
                                """
                                RPKI allow invalid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, self).__init__()

                                    self.yang_name = "prefix-validation-allow-invalid-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "prefix-validation-allow-invalid-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-allow-invalid-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixValidationDisableInfo(Entity):
                                """
                                RPKI disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, self).__init__()

                                    self.yang_name = "prefix-validation-disable-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "prefix-validation-disable-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-disable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixValidationSignalIbgpInfo(Entity):
                                """
                                RPKI signal ibgp info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, self).__init__()

                                    self.yang_name = "prefix-validation-signal-ibgp-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "prefix-validation-signal-ibgp-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-signal-ibgp-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixValidationUseValiditInfo(Entity):
                                """
                                RPKI use validity
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, self).__init__()

                                    self.yang_name = "prefix-validation-use-validit-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "prefix-validation-use-validit-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-use-validit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ReceiveBufferInfo(Entity):
                                """
                                Receive buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, self).__init__()

                                    self.yang_name = "receive-buffer-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "receive-buffer-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "receive-buffer-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RemoteAsInfo(Entity):
                                """
                                Remote AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, self).__init__()

                                    self.yang_name = "remote-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "remote-as-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remote-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SendBufferInfo(Entity):
                                """
                                Send buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, self).__init__()

                                    self.yang_name = "send-buffer-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "send-buffer-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-buffer-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SessionOpenModeInfo(Entity):
                                """
                                TCP conn open mode info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, self).__init__()

                                    self.yang_name = "session-open-mode-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "session-open-mode-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "session-open-mode-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ShutdownInfo(Entity):
                                """
                                Shutdown item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, self).__init__()

                                    self.yang_name = "shutdown-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "shutdown-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "shutdown-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class SpeakerIdInfo(Entity):
                                """
                                Configured speaker ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, self).__init__()

                                    self.yang_name = "speaker-id-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "speaker-id-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "speaker-id-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class Suppress4BbyteAsInfo(Entity):
                                """
                                BGP suppress 4byte\-as item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, self).__init__()

                                    self.yang_name = "suppress4-bbyte-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "suppress4-bbyte-as-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "suppress4-bbyte-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class TcpmssInfo(Entity):
                                """
                                TCP Maximum Segment Size item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, self).__init__()

                                    self.yang_name = "tcpmss-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "tcpmss-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "tcpmss-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class TimersInfo(Entity):
                                """
                                Timers item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, self).__init__()

                                    self.yang_name = "timers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "timers-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "timers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class TosInfo(Entity):
                                """
                                TOS item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, self).__init__()

                                    self.yang_name = "tos-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "tos-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "tos-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class TtlSecurityInfo(Entity):
                                """
                                BGP TTL Security item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, self).__init__()

                                    self.yang_name = "ttl-security-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "ttl-security-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ttl-security-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class UpdateErrorHandlingNoResetInfo(Entity):
                                """
                                Error\-handling avoid\-reset config info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, self).__init__()

                                    self.yang_name = "update-error-handling-no-reset-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "update-error-handling-no-reset-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "update-error-handling-no-reset-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class UpdateSourceInfo(Entity):
                                """
                                Update source item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, self).__init__()

                                    self.yang_name = "update-source-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain)}
                                    self._child_list_classes = {}

                                    self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._children_yang_names.add("inheritance-chain")
                                    self._segment_path = lambda: "update-source-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, ['is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "update-source-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid)}

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                            self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                            self.group_name = YLeaf(YType.str, "group-name")

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bgp-config-entid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress)}
                                self._child_list_classes = {}

                                self.afi = YLeaf(YType.enumeration, "afi")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                self._children_yang_names.add("ipv4-sr-policy-address")

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._children_yang_names.add("ipv6-sr-policy-address")

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                self._children_yang_names.add("l2vpn-mspw-address")

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                self._children_yang_names.add("l2vpn-vpls-address")
                                self._segment_path = lambda: "neighbor-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                            class L2VpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                            class L2VpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


            class ConfigVrfs(Entity):
                """
                VRF related configuration data
                
                .. attribute:: config_vrf
                
                	Configuration data for a particular VRF
                	**type**\: list of    :py:class:`ConfigVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs, self).__init__()

                    self.yang_name = "config-vrfs"
                    self.yang_parent_name = "config-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"config-vrf" : ("config_vrf", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf)}

                    self.config_vrf = YList(self)
                    self._segment_path = lambda: "config-vrfs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs, [], name, value)


                class ConfigVrf(Entity):
                    """
                    Configuration data for a particular VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	Name of the VRF
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: configuration_inheritances
                    
                    	The BGP configurataion inheritance table
                    	**type**\:   :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances>`
                    
                    .. attribute:: configuration_users
                    
                    	The BGP configuration users table
                    	**type**\:   :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers>`
                    
                    .. attribute:: entity_configurations
                    
                    	The BGP Entity Configuration table
                    	**type**\:   :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf, self).__init__()

                        self.yang_name = "config-vrf"
                        self.yang_parent_name = "config-vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"configuration-inheritances" : ("configuration_inheritances", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances), "configuration-users" : ("configuration_users", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers), "entity-configurations" : ("entity_configurations", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances()
                        self.configuration_inheritances.parent = self
                        self._children_name_map["configuration_inheritances"] = "configuration-inheritances"
                        self._children_yang_names.add("configuration-inheritances")

                        self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers()
                        self.configuration_users.parent = self
                        self._children_name_map["configuration_users"] = "configuration-users"
                        self._children_yang_names.add("configuration-users")

                        self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations()
                        self.entity_configurations.parent = self
                        self._children_name_map["entity_configurations"] = "entity-configurations"
                        self._children_yang_names.add("entity-configurations")
                        self._segment_path = lambda: "config-vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf, ['vrf_name'], name, value)


                    class ConfigurationInheritances(Entity):
                        """
                        The BGP configurataion inheritance table
                        
                        .. attribute:: configuration_inheritance
                        
                        	A BGP configuration inheritance table entry
                        	**type**\: list of    :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances, self).__init__()

                            self.yang_name = "configuration-inheritances"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"configuration-inheritance" : ("configuration_inheritance", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance)}

                            self.configuration_inheritance = YList(self)
                            self._segment_path = lambda: "configuration-inheritances"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances, [], name, value)


                        class ConfigurationInheritance(Entity):
                            """
                            A BGP configuration inheritance table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance, self).__init__()

                                self.yang_name = "configuration-inheritance"
                                self.yang_parent_name = "configuration-inheritances"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"af-independent-relatives" : ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr)}
                                self._child_list_classes = {"af-dependent-relative" : ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative)}

                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                self.entity_name = YLeaf(YType.str, "entity-name")

                                self.entity_type = YLeaf(YType.enumeration, "entity-type")

                                self.group_name = YLeaf(YType.str, "group-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self._children_name_map["af_independent_relatives"] = "af-independent-relatives"
                                self._children_yang_names.add("af-independent-relatives")

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                self._children_yang_names.add("neighbor-address-xr")

                                self.af_dependent_relative = YList(self)
                                self._segment_path = lambda: "configuration-inheritance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                            class AfDependentRelative(Entity):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, self).__init__()

                                    self.yang_name = "af-dependent-relative"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid)}

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-dependent-relative"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-dependent-relative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                        self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                        self.group_name = YLeaf(YType.str, "group-name")

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "bgp-config-entid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfIndependentRelatives(Entity):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, self).__init__()

                                    self.yang_name = "af-independent-relatives"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid)}

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-independent-relatives"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-independent-relatives"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                        self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                        self.group_name = YLeaf(YType.str, "group-name")

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "bgp-config-entid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "neighbor-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class ConfigurationUsers(Entity):
                        """
                        The BGP configuration users table
                        
                        .. attribute:: configuration_user
                        
                        	A BGP configuration user table entry
                        	**type**\: list of    :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers, self).__init__()

                            self.yang_name = "configuration-users"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"configuration-user" : ("configuration_user", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser)}

                            self.configuration_user = YList(self)
                            self._segment_path = lambda: "configuration-users"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers, [], name, value)


                        class ConfigurationUser(Entity):
                            """
                            A BGP configuration user table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser, self).__init__()

                                self.yang_name = "configuration-user"
                                self.yang_parent_name = "configuration-users"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"af-independent-relatives" : ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr)}
                                self._child_list_classes = {"af-dependent-relative" : ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative)}

                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                self.entity_name = YLeaf(YType.str, "entity-name")

                                self.entity_type = YLeaf(YType.enumeration, "entity-type")

                                self.group_name = YLeaf(YType.str, "group-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self._children_name_map["af_independent_relatives"] = "af-independent-relatives"
                                self._children_yang_names.add("af-independent-relatives")

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                self._children_yang_names.add("neighbor-address-xr")

                                self.af_dependent_relative = YList(self)
                                self._segment_path = lambda: "configuration-user"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                            class AfDependentRelative(Entity):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, self).__init__()

                                    self.yang_name = "af-dependent-relative"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid)}

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-dependent-relative"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-dependent-relative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                        self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                        self.group_name = YLeaf(YType.str, "group-name")

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "bgp-config-entid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfIndependentRelatives(Entity):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, self).__init__()

                                    self.yang_name = "af-independent-relatives"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid)}

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-independent-relatives"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-independent-relatives"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                        self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                        self.group_name = YLeaf(YType.str, "group-name")

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "bgp-config-entid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "neighbor-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class EntityConfigurations(Entity):
                        """
                        The BGP Entity Configuration table
                        
                        .. attribute:: entity_configuration
                        
                        	A BGP Entity Configuration table entry
                        	**type**\: list of    :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations, self).__init__()

                            self.yang_name = "entity-configurations"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"entity-configuration" : ("entity_configuration", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration)}

                            self.entity_configuration = YList(self)
                            self._segment_path = lambda: "entity-configurations"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations, [], name, value)


                        class EntityConfiguration(Entity):
                            """
                            A BGP Entity Configuration table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_config
                            
                            	Af\-dependent config
                            	**type**\: list of    :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                            
                            .. attribute:: af_independent_config
                            
                            	AF\-independent config
                            	**type**\:   :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration, self).__init__()

                                self.yang_name = "entity-configuration"
                                self.yang_parent_name = "entity-configurations"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"af-independent-config" : ("af_independent_config", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr)}
                                self._child_list_classes = {"af-dependent-config" : ("af_dependent_config", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig)}

                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                self.entity_name = YLeaf(YType.str, "entity-name")

                                self.entity_type = YLeaf(YType.enumeration, "entity-type")

                                self.group_name = YLeaf(YType.str, "group-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                                self.af_independent_config.parent = self
                                self._children_name_map["af_independent_config"] = "af-independent-config"
                                self._children_yang_names.add("af-independent-config")

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                self._children_yang_names.add("neighbor-address-xr")

                                self.af_dependent_config = YList(self)
                                self._segment_path = lambda: "entity-configuration"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration, ['address_family_identifier', 'configuration_type', 'entity_name', 'entity_type', 'group_name', 'neighbor_address'], name, value)


                            class AfDependentConfig(Entity):
                                """
                                Af\-dependent config
                                
                                .. attribute:: accept_own
                                
                                	Accept Own
                                	**type**\:  bool
                                
                                .. attribute:: accept_own_info
                                
                                	Accept\-Own info
                                	**type**\:   :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                                
                                .. attribute:: accept_route_legacy_pe_rt
                                
                                	accept\-legacy\-pe RT route
                                	**type**\:  bool
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_dis_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                                
                                .. attribute:: advertise_disable
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_l2vpn_evpn
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_l2vpn_evpn_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseL2VpnEvpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo>`
                                
                                .. attribute:: advertise_local_labeled_route
                                
                                	Advertise routes with local\-label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_local_labeled_route_info
                                
                                	Advertise routes with local\-label
                                	**type**\:   :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                                
                                .. attribute:: advertise_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                                
                                .. attribute:: advertise_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v6_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: af_enabled_info
                                
                                	Address family activate item info
                                	**type**\:   :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                                
                                .. attribute:: af_encapsulation_type_info
                                
                                	Encapsulation type Info 
                                	**type**\:   :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                                
                                .. attribute:: af_long_lived_graceful_restart_capable
                                
                                	Long\-lived graceful\-restart capable
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                                
                                	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_send
                                
                                	Stale time to be sent in long\-lived graceful\-restart capability
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_start_capable_info
                                
                                	Long\-lived\-time item info
                                	**type**\:   :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                                
                                .. attribute:: af_long_lived_graceful_start_stale_time_info
                                
                                	Long\-lived\-time item info
                                	**type**\:   :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                                
                                .. attribute:: aigp_cost_community_info
                                
                                	AIGP Cost Community info 
                                	**type**\:   :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                                
                                .. attribute:: aigp_cost_community_poi
                                
                                	Point of insertion for AIGP cost community
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_info
                                
                                	AIGP info 
                                	**type**\:   :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                                
                                .. attribute:: aigp_med
                                
                                	AIGP MED info 
                                	**type**\:   :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                                
                                .. attribute:: allowas_in_info
                                
                                	Allowas\-in item info
                                	**type**\:   :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                                
                                .. attribute:: alway_use_soft_reconfig
                                
                                	Always use soft reconfig
                                	**type**\:  bool
                                
                                .. attribute:: as_override_info
                                
                                	As\-override info 
                                	**type**\:   :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                                
                                .. attribute:: client_route_reflector
                                
                                	Route\-reflector client
                                	**type**\:  bool
                                
                                .. attribute:: default_allowas
                                
                                	Default allowas\_in count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_originate_info
                                
                                	Default\-originate item info
                                	**type**\:   :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                                
                                .. attribute:: default_originate_route_policy
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: default_weight
                                
                                	Default weight
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enforce_multiple_labels
                                
                                	Enforce multiple labels
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enforce_multiple_labels_info
                                
                                	Enforce multiple labels
                                	**type**\:   :py:class:`EnforceMultipleLabelsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo>`
                                
                                .. attribute:: entire_aspath_in
                                
                                	Inbound private\-AS removal if the entire AS Path has private ASes
                                	**type**\:  bool
                                
                                .. attribute:: entire_aspath_out
                                
                                	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                                	**type**\:  bool
                                
                                .. attribute:: fspec_valid_info
                                
                                	FSPEC Valid info
                                	**type**\:   :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                                
                                .. attribute:: has_orf_capability
                                
                                	ORF capability
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: import_
                                
                                	Import
                                	**type**\:  bool
                                
                                .. attribute:: import_afi_info
                                
                                	Import Afi Info 
                                	**type**\:   :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                                
                                .. attribute:: import_reoriginate
                                
                                	Import reoriginate
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import reoriginate stitching RTs
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import stitching RTs
                                	**type**\:  bool
                                
                                .. attribute:: is_af_enabled
                                
                                	Entity is activated for this address family
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_cost_community_enabled
                                
                                	AIGP cost community enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_cost_community_id
                                
                                	AIGP cost community ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_cost_community_transitive
                                
                                	AIGP cost community ID is transitive
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_enabled
                                
                                	AIGP enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_med_enabled
                                
                                	AIGP to MED enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_disabled
                                
                                	Disable as override
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_not_disabled
                                
                                	TRUE if default\-originate is not disabled
                                	**type**\:  bool
                                
                                .. attribute:: is_fspec_valid_enabled
                                
                                	FSPEC VALID enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_max_prefix_discard_extra_paths
                                
                                	Discard extra paths
                                	**type**\:  bool
                                
                                .. attribute:: is_max_prefix_warn_only
                                
                                	Warning messages only
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_self_disabled
                                
                                	Disable next\-hop calc
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_unchanged
                                
                                	Don't change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_unchanged_mpath
                                
                                	Don't change mpath next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr_enabled
                                
                                	Send mcast attr enabled
                                	**type**\:  bool
                                
                                .. attribute:: legacy_pe_rt_info
                                
                                	Accept\-legacy\-pe\-RT item info
                                	**type**\:   :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Restart time Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_warn_threshold
                                
                                	Warning message threshhold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefixes
                                
                                	Maximum prefixes to accept
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefixes_info
                                
                                	Maximum prefixes to accept item info
                                	**type**\:   :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                                
                                .. attribute:: multipath
                                
                                	multipath
                                	**type**\:  bool
                                
                                .. attribute:: multipath_info
                                
                                	Multipath info
                                	**type**\:   :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                                
                                .. attribute:: next_hop_self_info
                                
                                	Next hop self item info
                                	**type**\:   :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                                
                                .. attribute:: next_hop_unchanged_info
                                
                                	Next hop unchanged info
                                	**type**\:   :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                                
                                .. attribute:: next_hop_unchanged_mpath_info
                                
                                	Next hop unchanged mpath info
                                	**type**\:   :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                                
                                .. attribute:: orf_capability_info
                                
                                	ORF capability item info
                                	**type**\:   :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                                
                                .. attribute:: orr_info
                                
                                	Orr item info
                                	**type**\:   :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                                
                                .. attribute:: orr_root_address
                                
                                	ORR Root Address
                                	**type**\:   :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                                
                                .. attribute:: permanent_network
                                
                                	Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: permanent_network_info
                                
                                	Permanent network Info 
                                	**type**\:   :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                                
                                .. attribute:: prefix_filter_info
                                
                                	Inbound prefix based filter item info
                                	**type**\:   :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                                
                                .. attribute:: prefix_orf_filter
                                
                                	Inbound prefix based filter
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_in_info
                                
                                	Inbound private\-AS removal item info
                                	**type**\:   :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                                
                                .. attribute:: remove_private_as_info
                                
                                	Outbound private\-AS removal item info
                                	**type**\:   :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                                
                                .. attribute:: remove_private_as_out
                                
                                	Outbound private\-AS removal
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_asin
                                
                                	Inbound private\-AS removal
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_in
                                
                                	Inbound route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in_info
                                
                                	Inbound route policy item info
                                	**type**\:   :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                                
                                .. attribute:: route_policy_out
                                
                                	Outbound route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out_info
                                
                                	Outbound route policy item info
                                	**type**\:   :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                                
                                .. attribute:: route_reflector_info
                                
                                	Route\-reflector client item info
                                	**type**\:   :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                                
                                .. attribute:: send_community_attribute
                                
                                	Send community attribute
                                	**type**\:  bool
                                
                                .. attribute:: send_community_info
                                
                                	Send community attribute item info
                                	**type**\:   :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                                
                                .. attribute:: send_extended_community_attribute
                                
                                	Send extended community attribute
                                	**type**\:  bool
                                
                                .. attribute:: send_extended_community_info
                                
                                	Send extended community  item info
                                	**type**\:   :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                                
                                .. attribute:: send_graceful_shut_community_attributes
                                
                                	Send Graceful shutdown related community attributes
                                	**type**\:  bool
                                
                                .. attribute:: send_graceful_shutdown_community_info
                                
                                	Send Graceful shutdown related community attribute item info
                                	**type**\:   :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                                
                                .. attribute:: send_mcast_attr_info
                                
                                	Send mcast attr info
                                	**type**\:   :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                                
                                .. attribute:: site_of_origin
                                
                                	Site of Origin
                                	**type**\:  str
                                
                                .. attribute:: so_o_info
                                
                                	BGP Site\-of\-Origin info
                                	**type**\:   :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                                
                                .. attribute:: soft_reconfig_info
                                
                                	Soft reconf item info
                                	**type**\:   :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                                
                                .. attribute:: soft_reconfig_not_disabled
                                
                                	TRUE if soft reconf is not disabled
                                	**type**\:  bool
                                
                                .. attribute:: weight_info
                                
                                	Default weight item info
                                	**type**\:   :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, self).__init__()

                                    self.yang_name = "af-dependent-config"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"accept-own-info" : ("accept_own_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo), "advertise-def-vrf-imp-disable-afi-v4-info" : ("advertise_def_vrf_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info), "advertise-def-vrf-imp-disable-afi-v6-info" : ("advertise_def_vrf_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info), "advertise-dis-info" : ("advertise_dis_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo), "advertise-l2vpn-evpn-afi-info" : ("advertise_l2vpn_evpn_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo), "advertise-local-labeled-route-info" : ("advertise_local_labeled_route_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo), "advertise-v4-afi-info" : ("advertise_v4_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo), "advertise-v6-afi-info" : ("advertise_v6_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo), "advertise-vrf-re-imp-disable-afi-v4-info" : ("advertise_vrf_re_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info), "advertise-vrf-re-imp-disable-afi-v6-info" : ("advertise_vrf_re_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info), "af-enabled-info" : ("af_enabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo), "af-encapsulation-type-info" : ("af_encapsulation_type_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo), "af-long-lived-graceful-start-capable-info" : ("af_long_lived_graceful_start_capable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo), "af-long-lived-graceful-start-stale-time-info" : ("af_long_lived_graceful_start_stale_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo), "aigp-cost-community-info" : ("aigp_cost_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo), "aigp-info" : ("aigp_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo), "aigp-med" : ("aigp_med", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed), "allowas-in-info" : ("allowas_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo), "as-override-info" : ("as_override_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo), "default-originate-info" : ("default_originate_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo), "enforce-multiple-labels-info" : ("enforce_multiple_labels_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo), "fspec-valid-info" : ("fspec_valid_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo), "import-afi-info" : ("import_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo), "legacy-pe-rt-info" : ("legacy_pe_rt_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo), "max-prefixes-info" : ("max_prefixes_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo), "multipath-info" : ("multipath_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo), "next-hop-self-info" : ("next_hop_self_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo), "next-hop-unchanged-info" : ("next_hop_unchanged_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo), "next-hop-unchanged-mpath-info" : ("next_hop_unchanged_mpath_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo), "orf-capability-info" : ("orf_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo), "orr-info" : ("orr_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo), "orr-root-address" : ("orr_root_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress), "permanent-network-info" : ("permanent_network_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo), "prefix-filter-info" : ("prefix_filter_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo), "remove-private-as-in-info" : ("remove_private_as_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo), "remove-private-as-info" : ("remove_private_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo), "route-policy-in-info" : ("route_policy_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo), "route-policy-out-info" : ("route_policy_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo), "route-reflector-info" : ("route_reflector_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo), "send-community-info" : ("send_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo), "send-extended-community-info" : ("send_extended_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo), "send-graceful-shutdown-community-info" : ("send_graceful_shutdown_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo), "send-mcast-attr-info" : ("send_mcast_attr_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo), "so-o-info" : ("so_o_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo), "soft-reconfig-info" : ("soft_reconfig_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo), "weight-info" : ("weight_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo)}
                                    self._child_list_classes = {}

                                    self.accept_own = YLeaf(YType.boolean, "accept-own")

                                    self.accept_route_legacy_pe_rt = YLeaf(YType.boolean, "accept-route-legacy-pe-rt")

                                    self.advertise_def_vrf_imp_disable_v4 = YLeaf(YType.uint8, "advertise-def-vrf-imp-disable-v4")

                                    self.advertise_def_vrf_imp_disable_v6 = YLeaf(YType.uint8, "advertise-def-vrf-imp-disable-v6")

                                    self.advertise_disable = YLeaf(YType.uint8, "advertise-disable")

                                    self.advertise_l2vpn_evpn = YLeaf(YType.uint8, "advertise-l2vpn-evpn")

                                    self.advertise_local_labeled_route = YLeaf(YType.uint32, "advertise-local-labeled-route")

                                    self.advertise_v4 = YLeaf(YType.uint8, "advertise-v4")

                                    self.advertise_v6 = YLeaf(YType.uint8, "advertise-v6")

                                    self.advertise_vrf_re_imp_disable_v4 = YLeaf(YType.uint8, "advertise-vrf-re-imp-disable-v4")

                                    self.advertise_vrf_re_imp_disable_v6 = YLeaf(YType.uint8, "advertise-vrf-re-imp-disable-v6")

                                    self.af_long_lived_graceful_restart_capable = YLeaf(YType.uint32, "af-long-lived-graceful-restart-capable")

                                    self.af_long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "af-long-lived-graceful-restart-stale-time-accept")

                                    self.af_long_lived_graceful_restart_stale_time_send = YLeaf(YType.uint32, "af-long-lived-graceful-restart-stale-time-send")

                                    self.aigp_cost_community_poi = YLeaf(YType.uint32, "aigp-cost-community-poi")

                                    self.alway_use_soft_reconfig = YLeaf(YType.boolean, "alway-use-soft-reconfig")

                                    self.client_route_reflector = YLeaf(YType.boolean, "client-route-reflector")

                                    self.default_allowas = YLeaf(YType.uint32, "default-allowas")

                                    self.default_originate_route_policy = YLeaf(YType.str, "default-originate-route-policy")

                                    self.default_weight = YLeaf(YType.uint32, "default-weight")

                                    self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                    self.enforce_multiple_labels = YLeaf(YType.uint32, "enforce-multiple-labels")

                                    self.entire_aspath_in = YLeaf(YType.boolean, "entire-aspath-in")

                                    self.entire_aspath_out = YLeaf(YType.boolean, "entire-aspath-out")

                                    self.has_orf_capability = YLeaf(YType.uint32, "has-orf-capability")

                                    self.import_ = YLeaf(YType.boolean, "import")

                                    self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                    self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                    self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                    self.is_af_enabled = YLeaf(YType.boolean, "is-af-enabled")

                                    self.is_aigp_cost_community_enabled = YLeaf(YType.boolean, "is-aigp-cost-community-enabled")

                                    self.is_aigp_cost_community_id = YLeaf(YType.uint32, "is-aigp-cost-community-id")

                                    self.is_aigp_cost_community_transitive = YLeaf(YType.uint32, "is-aigp-cost-community-transitive")

                                    self.is_aigp_enabled = YLeaf(YType.boolean, "is-aigp-enabled")

                                    self.is_aigp_med_enabled = YLeaf(YType.boolean, "is-aigp-med-enabled")

                                    self.is_as_override_disabled = YLeaf(YType.boolean, "is-as-override-disabled")

                                    self.is_default_originate_not_disabled = YLeaf(YType.boolean, "is-default-originate-not-disabled")

                                    self.is_fspec_valid_enabled = YLeaf(YType.boolean, "is-fspec-valid-enabled")

                                    self.is_max_prefix_discard_extra_paths = YLeaf(YType.boolean, "is-max-prefix-discard-extra-paths")

                                    self.is_max_prefix_warn_only = YLeaf(YType.boolean, "is-max-prefix-warn-only")

                                    self.is_next_hop_self_disabled = YLeaf(YType.boolean, "is-next-hop-self-disabled")

                                    self.is_next_hop_unchanged = YLeaf(YType.boolean, "is-next-hop-unchanged")

                                    self.is_next_hop_unchanged_mpath = YLeaf(YType.boolean, "is-next-hop-unchanged-mpath")

                                    self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                    self.max_prefix_restart_time = YLeaf(YType.uint32, "max-prefix-restart-time")

                                    self.max_prefix_warn_threshold = YLeaf(YType.uint32, "max-prefix-warn-threshold")

                                    self.max_prefixes = YLeaf(YType.uint32, "max-prefixes")

                                    self.multipath = YLeaf(YType.boolean, "multipath")

                                    self.permanent_network = YLeaf(YType.boolean, "permanent-network")

                                    self.prefix_orf_filter = YLeaf(YType.str, "prefix-orf-filter")

                                    self.remove_private_as_out = YLeaf(YType.boolean, "remove-private-as-out")

                                    self.remove_private_asin = YLeaf(YType.boolean, "remove-private-asin")

                                    self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                    self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                    self.send_community_attribute = YLeaf(YType.boolean, "send-community-attribute")

                                    self.send_extended_community_attribute = YLeaf(YType.boolean, "send-extended-community-attribute")

                                    self.send_graceful_shut_community_attributes = YLeaf(YType.boolean, "send-graceful-shut-community-attributes")

                                    self.site_of_origin = YLeaf(YType.str, "site-of-origin")

                                    self.soft_reconfig_not_disabled = YLeaf(YType.boolean, "soft-reconfig-not-disabled")

                                    self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                    self.accept_own_info.parent = self
                                    self._children_name_map["accept_own_info"] = "accept-own-info"
                                    self._children_yang_names.add("accept-own-info")

                                    self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                    self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                    self._children_name_map["advertise_def_vrf_imp_disable_afi_v4_info"] = "advertise-def-vrf-imp-disable-afi-v4-info"
                                    self._children_yang_names.add("advertise-def-vrf-imp-disable-afi-v4-info")

                                    self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                    self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                    self._children_name_map["advertise_def_vrf_imp_disable_afi_v6_info"] = "advertise-def-vrf-imp-disable-afi-v6-info"
                                    self._children_yang_names.add("advertise-def-vrf-imp-disable-afi-v6-info")

                                    self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                    self.advertise_dis_info.parent = self
                                    self._children_name_map["advertise_dis_info"] = "advertise-dis-info"
                                    self._children_yang_names.add("advertise-dis-info")

                                    self.advertise_l2vpn_evpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo()
                                    self.advertise_l2vpn_evpn_afi_info.parent = self
                                    self._children_name_map["advertise_l2vpn_evpn_afi_info"] = "advertise-l2vpn-evpn-afi-info"
                                    self._children_yang_names.add("advertise-l2vpn-evpn-afi-info")

                                    self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                    self.advertise_local_labeled_route_info.parent = self
                                    self._children_name_map["advertise_local_labeled_route_info"] = "advertise-local-labeled-route-info"
                                    self._children_yang_names.add("advertise-local-labeled-route-info")

                                    self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                    self.advertise_v4_afi_info.parent = self
                                    self._children_name_map["advertise_v4_afi_info"] = "advertise-v4-afi-info"
                                    self._children_yang_names.add("advertise-v4-afi-info")

                                    self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                    self.advertise_v6_afi_info.parent = self
                                    self._children_name_map["advertise_v6_afi_info"] = "advertise-v6-afi-info"
                                    self._children_yang_names.add("advertise-v6-afi-info")

                                    self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                    self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                    self._children_name_map["advertise_vrf_re_imp_disable_afi_v4_info"] = "advertise-vrf-re-imp-disable-afi-v4-info"
                                    self._children_yang_names.add("advertise-vrf-re-imp-disable-afi-v4-info")

                                    self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                    self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                    self._children_name_map["advertise_vrf_re_imp_disable_afi_v6_info"] = "advertise-vrf-re-imp-disable-afi-v6-info"
                                    self._children_yang_names.add("advertise-vrf-re-imp-disable-afi-v6-info")

                                    self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                    self.af_enabled_info.parent = self
                                    self._children_name_map["af_enabled_info"] = "af-enabled-info"
                                    self._children_yang_names.add("af-enabled-info")

                                    self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                    self.af_encapsulation_type_info.parent = self
                                    self._children_name_map["af_encapsulation_type_info"] = "af-encapsulation-type-info"
                                    self._children_yang_names.add("af-encapsulation-type-info")

                                    self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                    self.af_long_lived_graceful_start_capable_info.parent = self
                                    self._children_name_map["af_long_lived_graceful_start_capable_info"] = "af-long-lived-graceful-start-capable-info"
                                    self._children_yang_names.add("af-long-lived-graceful-start-capable-info")

                                    self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                    self.af_long_lived_graceful_start_stale_time_info.parent = self
                                    self._children_name_map["af_long_lived_graceful_start_stale_time_info"] = "af-long-lived-graceful-start-stale-time-info"
                                    self._children_yang_names.add("af-long-lived-graceful-start-stale-time-info")

                                    self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                    self.aigp_cost_community_info.parent = self
                                    self._children_name_map["aigp_cost_community_info"] = "aigp-cost-community-info"
                                    self._children_yang_names.add("aigp-cost-community-info")

                                    self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                    self.aigp_info.parent = self
                                    self._children_name_map["aigp_info"] = "aigp-info"
                                    self._children_yang_names.add("aigp-info")

                                    self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                    self.aigp_med.parent = self
                                    self._children_name_map["aigp_med"] = "aigp-med"
                                    self._children_yang_names.add("aigp-med")

                                    self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                    self.allowas_in_info.parent = self
                                    self._children_name_map["allowas_in_info"] = "allowas-in-info"
                                    self._children_yang_names.add("allowas-in-info")

                                    self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                    self.as_override_info.parent = self
                                    self._children_name_map["as_override_info"] = "as-override-info"
                                    self._children_yang_names.add("as-override-info")

                                    self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                    self.default_originate_info.parent = self
                                    self._children_name_map["default_originate_info"] = "default-originate-info"
                                    self._children_yang_names.add("default-originate-info")

                                    self.enforce_multiple_labels_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo()
                                    self.enforce_multiple_labels_info.parent = self
                                    self._children_name_map["enforce_multiple_labels_info"] = "enforce-multiple-labels-info"
                                    self._children_yang_names.add("enforce-multiple-labels-info")

                                    self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                    self.fspec_valid_info.parent = self
                                    self._children_name_map["fspec_valid_info"] = "fspec-valid-info"
                                    self._children_yang_names.add("fspec-valid-info")

                                    self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                    self.import_afi_info.parent = self
                                    self._children_name_map["import_afi_info"] = "import-afi-info"
                                    self._children_yang_names.add("import-afi-info")

                                    self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                    self.legacy_pe_rt_info.parent = self
                                    self._children_name_map["legacy_pe_rt_info"] = "legacy-pe-rt-info"
                                    self._children_yang_names.add("legacy-pe-rt-info")

                                    self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                    self.max_prefixes_info.parent = self
                                    self._children_name_map["max_prefixes_info"] = "max-prefixes-info"
                                    self._children_yang_names.add("max-prefixes-info")

                                    self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                    self.multipath_info.parent = self
                                    self._children_name_map["multipath_info"] = "multipath-info"
                                    self._children_yang_names.add("multipath-info")

                                    self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                    self.next_hop_self_info.parent = self
                                    self._children_name_map["next_hop_self_info"] = "next-hop-self-info"
                                    self._children_yang_names.add("next-hop-self-info")

                                    self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                    self.next_hop_unchanged_info.parent = self
                                    self._children_name_map["next_hop_unchanged_info"] = "next-hop-unchanged-info"
                                    self._children_yang_names.add("next-hop-unchanged-info")

                                    self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                    self.next_hop_unchanged_mpath_info.parent = self
                                    self._children_name_map["next_hop_unchanged_mpath_info"] = "next-hop-unchanged-mpath-info"
                                    self._children_yang_names.add("next-hop-unchanged-mpath-info")

                                    self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                    self.orf_capability_info.parent = self
                                    self._children_name_map["orf_capability_info"] = "orf-capability-info"
                                    self._children_yang_names.add("orf-capability-info")

                                    self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                    self.orr_info.parent = self
                                    self._children_name_map["orr_info"] = "orr-info"
                                    self._children_yang_names.add("orr-info")

                                    self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                    self.orr_root_address.parent = self
                                    self._children_name_map["orr_root_address"] = "orr-root-address"
                                    self._children_yang_names.add("orr-root-address")

                                    self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                    self.permanent_network_info.parent = self
                                    self._children_name_map["permanent_network_info"] = "permanent-network-info"
                                    self._children_yang_names.add("permanent-network-info")

                                    self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                    self.prefix_filter_info.parent = self
                                    self._children_name_map["prefix_filter_info"] = "prefix-filter-info"
                                    self._children_yang_names.add("prefix-filter-info")

                                    self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                    self.remove_private_as_in_info.parent = self
                                    self._children_name_map["remove_private_as_in_info"] = "remove-private-as-in-info"
                                    self._children_yang_names.add("remove-private-as-in-info")

                                    self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                    self.remove_private_as_info.parent = self
                                    self._children_name_map["remove_private_as_info"] = "remove-private-as-info"
                                    self._children_yang_names.add("remove-private-as-info")

                                    self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                    self.route_policy_in_info.parent = self
                                    self._children_name_map["route_policy_in_info"] = "route-policy-in-info"
                                    self._children_yang_names.add("route-policy-in-info")

                                    self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                    self.route_policy_out_info.parent = self
                                    self._children_name_map["route_policy_out_info"] = "route-policy-out-info"
                                    self._children_yang_names.add("route-policy-out-info")

                                    self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                    self.route_reflector_info.parent = self
                                    self._children_name_map["route_reflector_info"] = "route-reflector-info"
                                    self._children_yang_names.add("route-reflector-info")

                                    self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                    self.send_community_info.parent = self
                                    self._children_name_map["send_community_info"] = "send-community-info"
                                    self._children_yang_names.add("send-community-info")

                                    self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                    self.send_extended_community_info.parent = self
                                    self._children_name_map["send_extended_community_info"] = "send-extended-community-info"
                                    self._children_yang_names.add("send-extended-community-info")

                                    self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                    self.send_graceful_shutdown_community_info.parent = self
                                    self._children_name_map["send_graceful_shutdown_community_info"] = "send-graceful-shutdown-community-info"
                                    self._children_yang_names.add("send-graceful-shutdown-community-info")

                                    self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                    self.send_mcast_attr_info.parent = self
                                    self._children_name_map["send_mcast_attr_info"] = "send-mcast-attr-info"
                                    self._children_yang_names.add("send-mcast-attr-info")

                                    self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                    self.so_o_info.parent = self
                                    self._children_name_map["so_o_info"] = "so-o-info"
                                    self._children_yang_names.add("so-o-info")

                                    self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                    self.soft_reconfig_info.parent = self
                                    self._children_name_map["soft_reconfig_info"] = "soft-reconfig-info"
                                    self._children_yang_names.add("soft-reconfig-info")

                                    self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                    self.weight_info.parent = self
                                    self._children_name_map["weight_info"] = "weight-info"
                                    self._children_yang_names.add("weight-info")
                                    self._segment_path = lambda: "af-dependent-config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, ['accept_own', 'accept_route_legacy_pe_rt', 'advertise_def_vrf_imp_disable_v4', 'advertise_def_vrf_imp_disable_v6', 'advertise_disable', 'advertise_l2vpn_evpn', 'advertise_local_labeled_route', 'advertise_v4', 'advertise_v6', 'advertise_vrf_re_imp_disable_v4', 'advertise_vrf_re_imp_disable_v6', 'af_long_lived_graceful_restart_capable', 'af_long_lived_graceful_restart_stale_time_accept', 'af_long_lived_graceful_restart_stale_time_send', 'aigp_cost_community_poi', 'alway_use_soft_reconfig', 'client_route_reflector', 'default_allowas', 'default_originate_route_policy', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'entire_aspath_in', 'entire_aspath_out', 'has_orf_capability', 'import_', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_af_enabled', 'is_aigp_cost_community_enabled', 'is_aigp_cost_community_id', 'is_aigp_cost_community_transitive', 'is_aigp_enabled', 'is_aigp_med_enabled', 'is_as_override_disabled', 'is_default_originate_not_disabled', 'is_fspec_valid_enabled', 'is_max_prefix_discard_extra_paths', 'is_max_prefix_warn_only', 'is_next_hop_self_disabled', 'is_next_hop_unchanged', 'is_next_hop_unchanged_mpath', 'is_send_mcast_attr_enabled', 'max_prefix_restart_time', 'max_prefix_warn_threshold', 'max_prefixes', 'multipath', 'permanent_network', 'prefix_orf_filter', 'remove_private_as_out', 'remove_private_asin', 'route_policy_in', 'route_policy_out', 'send_community_attribute', 'send_extended_community_attribute', 'send_graceful_shut_community_attributes', 'site_of_origin', 'soft_reconfig_not_disabled'], name, value)


                                class AcceptOwnInfo(Entity):
                                    """
                                    Accept\-Own info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, self).__init__()

                                        self.yang_name = "accept-own-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "accept-own-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "accept-own-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseDefVrfImpDisableAfiV4Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, self).__init__()

                                        self.yang_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v4-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseDefVrfImpDisableAfiV6Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, self).__init__()

                                        self.yang_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v6-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseDisInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, self).__init__()

                                        self.yang_name = "advertise-dis-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-dis-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-dis-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseL2VpnEvpnAfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo, self).__init__()

                                        self.yang_name = "advertise-l2vpn-evpn-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-l2vpn-evpn-afi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-l2vpn-evpn-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseLocalLabeledRouteInfo(Entity):
                                    """
                                    Advertise routes with local\-label
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, self).__init__()

                                        self.yang_name = "advertise-local-labeled-route-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-local-labeled-route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-local-labeled-route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseV4AfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, self).__init__()

                                        self.yang_name = "advertise-v4-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-v4-afi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-v4-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseV6AfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, self).__init__()

                                        self.yang_name = "advertise-v6-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-v6-afi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-v6-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseVrfReImpDisableAfiV4Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, self).__init__()

                                        self.yang_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v4-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertiseVrfReImpDisableAfiV6Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, self).__init__()

                                        self.yang_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v6-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfEnabledInfo(Entity):
                                    """
                                    Address family activate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, self).__init__()

                                        self.yang_name = "af-enabled-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "af-enabled-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-enabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfEncapsulationTypeInfo(Entity):
                                    """
                                    Encapsulation type Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, self).__init__()

                                        self.yang_name = "af-encapsulation-type-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "af-encapsulation-type-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-encapsulation-type-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfLongLivedGracefulStartCapableInfo(Entity):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, self).__init__()

                                        self.yang_name = "af-long-lived-graceful-start-capable-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "af-long-lived-graceful-start-capable-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-long-lived-graceful-start-capable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfLongLivedGracefulStartStaleTimeInfo(Entity):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, self).__init__()

                                        self.yang_name = "af-long-lived-graceful-start-stale-time-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "af-long-lived-graceful-start-stale-time-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-long-lived-graceful-start-stale-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AigpCostCommunityInfo(Entity):
                                    """
                                    AIGP Cost Community info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, self).__init__()

                                        self.yang_name = "aigp-cost-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "aigp-cost-community-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-cost-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AigpInfo(Entity):
                                    """
                                    AIGP info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, self).__init__()

                                        self.yang_name = "aigp-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "aigp-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AigpMed(Entity):
                                    """
                                    AIGP MED info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, self).__init__()

                                        self.yang_name = "aigp-med"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "aigp-med"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-med"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AllowasInInfo(Entity):
                                    """
                                    Allowas\-in item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, self).__init__()

                                        self.yang_name = "allowas-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "allowas-in-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "allowas-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AsOverrideInfo(Entity):
                                    """
                                    As\-override info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, self).__init__()

                                        self.yang_name = "as-override-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "as-override-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "as-override-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class DefaultOriginateInfo(Entity):
                                    """
                                    Default\-originate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, self).__init__()

                                        self.yang_name = "default-originate-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "default-originate-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "default-originate-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class EnforceMultipleLabelsInfo(Entity):
                                    """
                                    Enforce multiple labels
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, self).__init__()

                                        self.yang_name = "enforce-multiple-labels-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "enforce-multiple-labels-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "enforce-multiple-labels-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class FspecValidInfo(Entity):
                                    """
                                    FSPEC Valid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, self).__init__()

                                        self.yang_name = "fspec-valid-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "fspec-valid-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "fspec-valid-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ImportAfiInfo(Entity):
                                    """
                                    Import Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, self).__init__()

                                        self.yang_name = "import-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "import-afi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "import-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class LegacyPeRtInfo(Entity):
                                    """
                                    Accept\-legacy\-pe\-RT item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, self).__init__()

                                        self.yang_name = "legacy-pe-rt-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "legacy-pe-rt-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "legacy-pe-rt-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MaxPrefixesInfo(Entity):
                                    """
                                    Maximum prefixes to accept item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, self).__init__()

                                        self.yang_name = "max-prefixes-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "max-prefixes-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "max-prefixes-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MultipathInfo(Entity):
                                    """
                                    Multipath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, self).__init__()

                                        self.yang_name = "multipath-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "multipath-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "multipath-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NextHopSelfInfo(Entity):
                                    """
                                    Next hop self item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, self).__init__()

                                        self.yang_name = "next-hop-self-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "next-hop-self-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-self-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NextHopUnchangedInfo(Entity):
                                    """
                                    Next hop unchanged info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, self).__init__()

                                        self.yang_name = "next-hop-unchanged-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "next-hop-unchanged-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-unchanged-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NextHopUnchangedMpathInfo(Entity):
                                    """
                                    Next hop unchanged mpath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, self).__init__()

                                        self.yang_name = "next-hop-unchanged-mpath-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "next-hop-unchanged-mpath-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-unchanged-mpath-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class OrfCapabilityInfo(Entity):
                                    """
                                    ORF capability item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, self).__init__()

                                        self.yang_name = "orf-capability-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "orf-capability-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "orf-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class OrrInfo(Entity):
                                    """
                                    Orr item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, self).__init__()

                                        self.yang_name = "orr-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "orr-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "orr-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class OrrRootAddress(Entity):
                                    """
                                    ORR Root Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, self).__init__()

                                        self.yang_name = "orr-root-address"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "orr-root-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PermanentNetworkInfo(Entity):
                                    """
                                    Permanent network Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, self).__init__()

                                        self.yang_name = "permanent-network-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "permanent-network-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "permanent-network-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixFilterInfo(Entity):
                                    """
                                    Inbound prefix based filter item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, self).__init__()

                                        self.yang_name = "prefix-filter-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "prefix-filter-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-filter-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RemovePrivateAsInInfo(Entity):
                                    """
                                    Inbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, self).__init__()

                                        self.yang_name = "remove-private-as-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "remove-private-as-in-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remove-private-as-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RemovePrivateAsInfo(Entity):
                                    """
                                    Outbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, self).__init__()

                                        self.yang_name = "remove-private-as-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "remove-private-as-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remove-private-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RoutePolicyInInfo(Entity):
                                    """
                                    Inbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, self).__init__()

                                        self.yang_name = "route-policy-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "route-policy-in-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-policy-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RoutePolicyOutInfo(Entity):
                                    """
                                    Outbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, self).__init__()

                                        self.yang_name = "route-policy-out-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "route-policy-out-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-policy-out-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RouteReflectorInfo(Entity):
                                    """
                                    Route\-reflector client item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, self).__init__()

                                        self.yang_name = "route-reflector-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "route-reflector-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-reflector-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SendCommunityInfo(Entity):
                                    """
                                    Send community attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, self).__init__()

                                        self.yang_name = "send-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "send-community-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SendExtendedCommunityInfo(Entity):
                                    """
                                    Send extended community  item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, self).__init__()

                                        self.yang_name = "send-extended-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "send-extended-community-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-extended-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SendGracefulShutdownCommunityInfo(Entity):
                                    """
                                    Send Graceful shutdown related community
                                    attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, self).__init__()

                                        self.yang_name = "send-graceful-shutdown-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "send-graceful-shutdown-community-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-graceful-shutdown-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SendMcastAttrInfo(Entity):
                                    """
                                    Send mcast attr info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, self).__init__()

                                        self.yang_name = "send-mcast-attr-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "send-mcast-attr-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-mcast-attr-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SoOInfo(Entity):
                                    """
                                    BGP Site\-of\-Origin info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, self).__init__()

                                        self.yang_name = "so-o-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "so-o-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "so-o-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SoftReconfigInfo(Entity):
                                    """
                                    Soft reconf item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, self).__init__()

                                        self.yang_name = "soft-reconfig-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "soft-reconfig-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "soft-reconfig-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class WeightInfo(Entity):
                                    """
                                    Default weight item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, self).__init__()

                                        self.yang_name = "weight-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "weight-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "weight-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfIndependentConfig(Entity):
                                """
                                AF\-independent config
                                
                                .. attribute:: addpath_receive_capability
                                
                                	Indicates if addpath receive capability is enabled or disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: addpath_receive_capability_info
                                
                                	Addpath receive capability info
                                	**type**\:   :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                                
                                .. attribute:: addpath_send_capability
                                
                                	Indicates if addpath send capability is enabled or disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: addpath_send_capability_info
                                
                                	Addpath send capability info
                                	**type**\:   :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                                
                                .. attribute:: adminstrative_shutdown
                                
                                	Administrative shutdown
                                	**type**\:  bool
                                
                                .. attribute:: bestpath_use_origin_as_validity
                                
                                	Bestpath Use Origin\-AS Va
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd
                                
                                	Fast failure detection using BFD
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_info
                                
                                	BFD item info
                                	**type**\:   :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                                
                                .. attribute:: bfd_mininterval
                                
                                	BFD Minimum Interval
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_mininterval_info
                                
                                	BFD Mininterval item info
                                	**type**\:   :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                                
                                .. attribute:: bfd_multiplier
                                
                                	BFD Multiplier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplier_info
                                
                                	BFD Multiplier item info
                                	**type**\:   :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                                
                                .. attribute:: bgp_buffer_receive_size
                                
                                	BGP receive buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_buffer_send_size
                                
                                	BGP send buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_servers
                                
                                	BMP Servers activated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_servers_info
                                
                                	BMP Servers Configuredinfo
                                	**type**\:   :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                                
                                .. attribute:: capability_negotiation_suppressed
                                
                                	Capability negotiation is suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: capability_negotiation_suppressed_info
                                
                                	Capability negotiation suppressed info
                                	**type**\:   :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                                
                                .. attribute:: cluster_id_info
                                
                                	Cluster ID item info
                                	**type**\:   :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                                
                                .. attribute:: configured_speaker_id
                                
                                	Configured speaker ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: description_info
                                
                                	Description item info
                                	**type**\:   :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth_info
                                
                                	DMZ link bandwidth item 
                                	**type**\:   :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                                
                                .. attribute:: ebgp_hop_count
                                
                                	EBGP neighbors hop count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_hop_count_info
                                
                                	EBGP neighbors hop count item info
                                	**type**\:   :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz_info
                                
                                	EBGP receive DMZ link bandwidth item info
                                	**type**\:   :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                                
                                .. attribute:: ebgp_send_dmz_info
                                
                                	EBGP send DMZ link bandwidth item info
                                	**type**\:   :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Send DMZ link bandwidthto ebgp peer
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	Indicates egress peer engineering is enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_info
                                
                                	Egress Peer Engineering info
                                	**type**\:   :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                                
                                .. attribute:: graceful_restart_disabled
                                
                                	Support for graceful\-restart
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_restart_disabled_info
                                
                                	Graceful\-restart item info
                                	**type**\:   :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                                
                                .. attribute:: graceful_shutdown_activate
                                
                                	Graceful Shutdown state is activated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_activate_info
                                
                                	GracefulShutdownAcivate info
                                	**type**\:   :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                                
                                .. attribute:: graceful_shutdown_as_prepends
                                
                                	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_as_prepends_info
                                
                                	GracefulShutdownASPrepends info
                                	**type**\:   :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                                
                                .. attribute:: graceful_shutdown_exists
                                
                                	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_info
                                
                                	GracefulShutdown info
                                	**type**\:   :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                                
                                .. attribute:: graceful_shutdown_loc_pref
                                
                                	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_loc_pref_info
                                
                                	GracefulShutdownLocPref info
                                	**type**\:   :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                                
                                .. attribute:: hold_time_value
                                
                                	Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: idle_watch_time
                                
                                	Idle Watch time(in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: idle_watch_time_info
                                
                                	Idle Watch time item info
                                	**type**\:   :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                                
                                .. attribute:: ignore_connected_check
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: ignore_connected_info
                                
                                	Ignore Connected Info
                                	**type**\:   :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, the VPN client isan iBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_info
                                
                                	Internal VPN Client Info
                                	**type**\:   :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: keepalive_interval
                                
                                	Keepalive interval
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keychain
                                
                                	Neighbor keychain Name
                                	**type**\:  str
                                
                                .. attribute:: keychain_info
                                
                                	Neighbor Keychain item info
                                	**type**\:   :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                                
                                .. attribute:: local_address_info
                                
                                	Local address item info
                                	**type**\:   :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_info
                                
                                	Local AS number item info
                                	**type**\:   :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Local AS no\-prepend option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_number_xx
                                
                                	First half of Local ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_number_yy
                                
                                	Second half of Local ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_ip_address
                                
                                	Local ipv4 or ipv6 address for neighbor connection
                                	**type**\:   :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                                
                                .. attribute:: max_peers
                                
                                	Maximum dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_peers_info
                                
                                	Max dynamic nbrs in range info
                                	**type**\:   :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                                
                                .. attribute:: min_acc_hold_time_value
                                
                                	Min acceptable holdtimefrom neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertisement_info
                                
                                	Minimum advertisement interval item info
                                	**type**\:   :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                                
                                .. attribute:: min_advertisement_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertisement_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: msg_log_in_buf_count
                                
                                	Message Log Inbound buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in_info
                                
                                	Message Log Inbound item info
                                	**type**\:   :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                                
                                .. attribute:: msg_log_out_buf_count
                                
                                	Message Log Outbound buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out_info
                                
                                	Message Log Outbound item info
                                	**type**\:   :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                                
                                .. attribute:: nbr_cluster_id_info
                                
                                	Cluster ID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id_type_info
                                
                                	Cluster ID Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_enforce_first_as_info
                                
                                	Neighbor enforce first AS info
                                	**type**\:   :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                                
                                .. attribute:: nbr_enforce_first_as_status
                                
                                	Neighbor enforce first AS status
                                	**type**\:  bool
                                
                                .. attribute:: nbr_restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_restart_time_info
                                
                                	Restart time item info
                                	**type**\:   :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                                
                                .. attribute:: nbr_stale_path_time
                                
                                	Stale\-path time(in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_stale_path_time_info
                                
                                	Stale\-path time item info
                                	**type**\:   :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                                
                                .. attribute:: neighbor_remote_as_list_group_name
                                
                                	Neighbor Range remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_remote_as_list_info
                                
                                	Neighbor range  remote\-as\-list group info
                                	**type**\:   :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                                
                                .. attribute:: neighbor_update_filter_attribute_filter_group_name
                                
                                	Neighbor filter attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_update_filter_attribute_info
                                
                                	Neighbor update filter attribute\-filter group info
                                	**type**\:   :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                                
                                .. attribute:: neighbor_update_filter_exists
                                
                                	Indicates if neighbor filter configuration exists
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_exists_info
                                
                                	Neighbor update filter configuration info
                                	**type**\:   :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                                
                                .. attribute:: neighbor_update_filter_logging_disable
                                
                                	Indicates if neighbor filter logging is disabled
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count
                                
                                	Count of neighbor filter message buffers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count_info
                                
                                	Neighbor update filter message buffer count info
                                	**type**\:   :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                                
                                .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                                
                                	Indicates if neighbor update filter message buffer is circular or not
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_syslog_disable_info
                                
                                	Neighbor update filter syslog disable info
                                	**type**\:   :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                                
                                .. attribute:: nsr_disabled
                                
                                	Support for NSR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_disabled_info
                                
                                	NSR item info
                                	**type**\:   :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                                
                                .. attribute:: password
                                
                                	Neighbor password
                                	**type**\:  str
                                
                                .. attribute:: password_info
                                
                                	Neighbor password item info
                                	**type**\:   :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                                
                                .. attribute:: prefix_validation_allow_invalid
                                
                                	Prefix validation allow invalid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_allow_invalid_info
                                
                                	RPKI allow invalid info
                                	**type**\:   :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                                
                                .. attribute:: prefix_validation_disable
                                
                                	Prefix validation disable
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_disable_info
                                
                                	RPKI disable info
                                	**type**\:   :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                                
                                .. attribute:: prefix_validation_signal_ibgp
                                
                                	Prefix validation signal ibgp
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_signal_ibgp_info
                                
                                	RPKI signal ibgp info
                                	**type**\:   :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                                
                                .. attribute:: prefix_validation_use_validit_info
                                
                                	RPKI use validity
                                	**type**\:   :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                                
                                .. attribute:: receive_buffer_info
                                
                                	Receive buffer sizes item info
                                	**type**\:   :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                                
                                .. attribute:: remote_as_info
                                
                                	Remote AS number item info
                                	**type**\:   :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                                
                                .. attribute:: remote_as_number_xx
                                
                                	First half of Remote ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number_yy
                                
                                	Second half of Remote ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_updates_source
                                
                                	Source of routing updates
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_info
                                
                                	Send buffer sizes item info
                                	**type**\:   :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                                
                                .. attribute:: session_open_mode
                                
                                	TCP open mode to be used 
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: session_open_mode_info
                                
                                	TCP conn open mode info
                                	**type**\:   :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                                
                                .. attribute:: shutdown_info
                                
                                	Shutdown item info
                                	**type**\:   :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                                
                                .. attribute:: socket_buffer_receive_size
                                
                                	Socket receive buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: socket_buffer_send_size
                                
                                	Socket send buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id_info
                                
                                	Configured speaker ID item info
                                	**type**\:   :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                                
                                .. attribute:: suppress4_bbyte_as_info
                                
                                	BGP suppress 4byte\-as item info
                                	**type**\:   :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress BGP 4byteas Cap
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_mss
                                
                                	Maximum Segment Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcpmss_info
                                
                                	TCP Maximum Segment Size item info
                                	**type**\:   :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                                
                                .. attribute:: timers_info
                                
                                	Timers item info
                                	**type**\:   :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                                
                                .. attribute:: tos_info
                                
                                	TOS item info
                                	**type**\:   :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                                
                                .. attribute:: tos_type_info
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value_info
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security
                                
                                	Enable BGP TTL Security
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ttl_security_info
                                
                                	BGP TTL Security item info
                                	**type**\:   :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                                
                                .. attribute:: update_error_handling_no_reset
                                
                                	Indicates if avoid\-reset behavior is enabled during update error\-handling
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_no_reset_info
                                
                                	Error\-handling avoid\-reset config info
                                	**type**\:   :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                                
                                .. attribute:: update_source_info
                                
                                	Update source item info
                                	**type**\:   :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, self).__init__()

                                    self.yang_name = "af-independent-config"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"addpath-receive-capability-info" : ("addpath_receive_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo), "addpath-send-capability-info" : ("addpath_send_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo), "bfd-info" : ("bfd_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo), "bfd-mininterval-info" : ("bfd_mininterval_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo), "bfd-multiplier-info" : ("bfd_multiplier_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo), "bmp-servers-info" : ("bmp_servers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo), "capability-negotiation-suppressed-info" : ("capability_negotiation_suppressed_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo), "cluster-id-info" : ("cluster_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo), "description-info" : ("description_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo), "dmz-link-bandwidth-info" : ("dmz_link_bandwidth_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo), "ebgp-hop-count-info" : ("ebgp_hop_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo), "ebgp-recv-dmz-info" : ("ebgp_recv_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo), "ebgp-send-dmz-info" : ("ebgp_send_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo), "egress-peer-engineering-info" : ("egress_peer_engineering_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo), "graceful-restart-disabled-info" : ("graceful_restart_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo), "graceful-shutdown-activate-info" : ("graceful_shutdown_activate_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo), "graceful-shutdown-as-prepends-info" : ("graceful_shutdown_as_prepends_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo), "graceful-shutdown-info" : ("graceful_shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo), "graceful-shutdown-loc-pref-info" : ("graceful_shutdown_loc_pref_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo), "idle-watch-time-info" : ("idle_watch_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo), "ignore-connected-info" : ("ignore_connected_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo), "internal-vpn-client-info" : ("internal_vpn_client_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo), "keychain-info" : ("keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo), "local-address-info" : ("local_address_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo), "local-as-info" : ("local_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo), "local-ip-address" : ("local_ip_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress), "max-peers-info" : ("max_peers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo), "min-advertisement-info" : ("min_advertisement_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo), "msg-log-in-info" : ("msg_log_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo), "msg-log-out-info" : ("msg_log_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo), "nbr-enforce-first-as-info" : ("nbr_enforce_first_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo), "nbr-restart-time-info" : ("nbr_restart_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo), "nbr-stale-path-time-info" : ("nbr_stale_path_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo), "neighbor-remote-as-list-info" : ("neighbor_remote_as_list_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo), "neighbor-update-filter-attribute-info" : ("neighbor_update_filter_attribute_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo), "neighbor-update-filter-exists-info" : ("neighbor_update_filter_exists_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo), "neighbor-update-filter-message-buffer-count-info" : ("neighbor_update_filter_message_buffer_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo), "neighbor-update-filter-syslog-disable-info" : ("neighbor_update_filter_syslog_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo), "nsr-disabled-info" : ("nsr_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo), "password-info" : ("password_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo), "prefix-validation-allow-invalid-info" : ("prefix_validation_allow_invalid_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo), "prefix-validation-disable-info" : ("prefix_validation_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo), "prefix-validation-signal-ibgp-info" : ("prefix_validation_signal_ibgp_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo), "prefix-validation-use-validit-info" : ("prefix_validation_use_validit_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo), "receive-buffer-info" : ("receive_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo), "remote-as-info" : ("remote_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo), "send-buffer-info" : ("send_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo), "session-open-mode-info" : ("session_open_mode_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo), "shutdown-info" : ("shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo), "speaker-id-info" : ("speaker_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo), "suppress4-bbyte-as-info" : ("suppress4_bbyte_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo), "tcpmss-info" : ("tcpmss_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo), "timers-info" : ("timers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo), "tos-info" : ("tos_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo), "ttl-security-info" : ("ttl_security_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo), "update-error-handling-no-reset-info" : ("update_error_handling_no_reset_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo), "update-source-info" : ("update_source_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo)}
                                    self._child_list_classes = {}

                                    self.addpath_receive_capability = YLeaf(YType.uint32, "addpath-receive-capability")

                                    self.addpath_send_capability = YLeaf(YType.uint32, "addpath-send-capability")

                                    self.adminstrative_shutdown = YLeaf(YType.boolean, "adminstrative-shutdown")

                                    self.bestpath_use_origin_as_validity = YLeaf(YType.uint32, "bestpath-use-origin-as-validity")

                                    self.bfd = YLeaf(YType.uint32, "bfd")

                                    self.bfd_mininterval = YLeaf(YType.uint32, "bfd-mininterval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.bgp_buffer_receive_size = YLeaf(YType.uint32, "bgp-buffer-receive-size")

                                    self.bgp_buffer_send_size = YLeaf(YType.uint32, "bgp-buffer-send-size")

                                    self.bmp_servers = YLeaf(YType.uint32, "bmp-servers")

                                    self.capability_negotiation_suppressed = YLeaf(YType.uint32, "capability-negotiation-suppressed")

                                    self.configured_speaker_id = YLeaf(YType.uint32, "configured-speaker-id")

                                    self.description = YLeaf(YType.str, "description")

                                    self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                    self.ebgp_hop_count = YLeaf(YType.uint32, "ebgp-hop-count")

                                    self.ebgp_recv_dmz = YLeaf(YType.uint32, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                    self.egress_peer_engineering = YLeaf(YType.uint32, "egress-peer-engineering")

                                    self.graceful_restart_disabled = YLeaf(YType.uint32, "graceful-restart-disabled")

                                    self.graceful_shutdown_activate = YLeaf(YType.uint32, "graceful-shutdown-activate")

                                    self.graceful_shutdown_as_prepends = YLeaf(YType.uint32, "graceful-shutdown-as-prepends")

                                    self.graceful_shutdown_exists = YLeaf(YType.uint32, "graceful-shutdown-exists")

                                    self.graceful_shutdown_loc_pref = YLeaf(YType.uint32, "graceful-shutdown-loc-pref")

                                    self.hold_time_value = YLeaf(YType.uint32, "hold-time-value")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check = YLeaf(YType.boolean, "ignore-connected-check")

                                    self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                    self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                    self.keychain = YLeaf(YType.str, "keychain")

                                    self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                    self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                    self.local_as_number_xx = YLeaf(YType.uint32, "local-as-number-xx")

                                    self.local_as_number_yy = YLeaf(YType.uint32, "local-as-number-yy")

                                    self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.min_acc_hold_time_value = YLeaf(YType.uint32, "min-acc-hold-time-value")

                                    self.min_advertisement_interval = YLeaf(YType.uint32, "min-advertisement-interval")

                                    self.min_advertisement_interval_msecs = YLeaf(YType.uint32, "min-advertisement-interval-msecs")

                                    self.msg_log_in_buf_count = YLeaf(YType.uint32, "msg-log-in-buf-count")

                                    self.msg_log_out_buf_count = YLeaf(YType.uint32, "msg-log-out-buf-count")

                                    self.nbr_cluster_id_info = YLeaf(YType.uint32, "nbr-cluster-id-info")

                                    self.nbr_cluster_id_type_info = YLeaf(YType.uint8, "nbr-cluster-id-type-info")

                                    self.nbr_enforce_first_as_status = YLeaf(YType.boolean, "nbr-enforce-first-as-status")

                                    self.nbr_restart_time = YLeaf(YType.uint32, "nbr-restart-time")

                                    self.nbr_stale_path_time = YLeaf(YType.uint32, "nbr-stale-path-time")

                                    self.neighbor_remote_as_list_group_name = YLeaf(YType.str, "neighbor-remote-as-list-group-name")

                                    self.neighbor_update_filter_attribute_filter_group_name = YLeaf(YType.str, "neighbor-update-filter-attribute-filter-group-name")

                                    self.neighbor_update_filter_exists = YLeaf(YType.boolean, "neighbor-update-filter-exists")

                                    self.neighbor_update_filter_logging_disable = YLeaf(YType.boolean, "neighbor-update-filter-logging-disable")

                                    self.neighbor_update_filter_message_buffer_count = YLeaf(YType.uint32, "neighbor-update-filter-message-buffer-count")

                                    self.neighbor_update_filter_message_buffer_is_non_circular = YLeaf(YType.boolean, "neighbor-update-filter-message-buffer-is-non-circular")

                                    self.nsr_disabled = YLeaf(YType.uint32, "nsr-disabled")

                                    self.password = YLeaf(YType.str, "password")

                                    self.prefix_validation_allow_invalid = YLeaf(YType.uint32, "prefix-validation-allow-invalid")

                                    self.prefix_validation_disable = YLeaf(YType.uint32, "prefix-validation-disable")

                                    self.prefix_validation_signal_ibgp = YLeaf(YType.uint32, "prefix-validation-signal-ibgp")

                                    self.remote_as_number_xx = YLeaf(YType.uint32, "remote-as-number-xx")

                                    self.remote_as_number_yy = YLeaf(YType.uint32, "remote-as-number-yy")

                                    self.route_updates_source = YLeaf(YType.str, "route-updates-source")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.socket_buffer_receive_size = YLeaf(YType.uint32, "socket-buffer-receive-size")

                                    self.socket_buffer_send_size = YLeaf(YType.uint32, "socket-buffer-send-size")

                                    self.suppress4_byte_as = YLeaf(YType.uint32, "suppress4-byte-as")

                                    self.tcp_mss = YLeaf(YType.uint32, "tcp-mss")

                                    self.tos_type_info = YLeaf(YType.uint8, "tos-type-info")

                                    self.tos_value_info = YLeaf(YType.uint8, "tos-value-info")

                                    self.ttl_security = YLeaf(YType.uint32, "ttl-security")

                                    self.update_error_handling_no_reset = YLeaf(YType.uint32, "update-error-handling-no-reset")

                                    self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                    self.addpath_receive_capability_info.parent = self
                                    self._children_name_map["addpath_receive_capability_info"] = "addpath-receive-capability-info"
                                    self._children_yang_names.add("addpath-receive-capability-info")

                                    self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                    self.addpath_send_capability_info.parent = self
                                    self._children_name_map["addpath_send_capability_info"] = "addpath-send-capability-info"
                                    self._children_yang_names.add("addpath-send-capability-info")

                                    self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                    self.bfd_info.parent = self
                                    self._children_name_map["bfd_info"] = "bfd-info"
                                    self._children_yang_names.add("bfd-info")

                                    self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                    self.bfd_mininterval_info.parent = self
                                    self._children_name_map["bfd_mininterval_info"] = "bfd-mininterval-info"
                                    self._children_yang_names.add("bfd-mininterval-info")

                                    self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                    self.bfd_multiplier_info.parent = self
                                    self._children_name_map["bfd_multiplier_info"] = "bfd-multiplier-info"
                                    self._children_yang_names.add("bfd-multiplier-info")

                                    self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                    self.bmp_servers_info.parent = self
                                    self._children_name_map["bmp_servers_info"] = "bmp-servers-info"
                                    self._children_yang_names.add("bmp-servers-info")

                                    self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                    self.capability_negotiation_suppressed_info.parent = self
                                    self._children_name_map["capability_negotiation_suppressed_info"] = "capability-negotiation-suppressed-info"
                                    self._children_yang_names.add("capability-negotiation-suppressed-info")

                                    self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                    self.cluster_id_info.parent = self
                                    self._children_name_map["cluster_id_info"] = "cluster-id-info"
                                    self._children_yang_names.add("cluster-id-info")

                                    self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                    self.description_info.parent = self
                                    self._children_name_map["description_info"] = "description-info"
                                    self._children_yang_names.add("description-info")

                                    self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                    self.dmz_link_bandwidth_info.parent = self
                                    self._children_name_map["dmz_link_bandwidth_info"] = "dmz-link-bandwidth-info"
                                    self._children_yang_names.add("dmz-link-bandwidth-info")

                                    self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                    self.ebgp_hop_count_info.parent = self
                                    self._children_name_map["ebgp_hop_count_info"] = "ebgp-hop-count-info"
                                    self._children_yang_names.add("ebgp-hop-count-info")

                                    self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                    self.ebgp_recv_dmz_info.parent = self
                                    self._children_name_map["ebgp_recv_dmz_info"] = "ebgp-recv-dmz-info"
                                    self._children_yang_names.add("ebgp-recv-dmz-info")

                                    self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                    self.ebgp_send_dmz_info.parent = self
                                    self._children_name_map["ebgp_send_dmz_info"] = "ebgp-send-dmz-info"
                                    self._children_yang_names.add("ebgp-send-dmz-info")

                                    self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                    self.egress_peer_engineering_info.parent = self
                                    self._children_name_map["egress_peer_engineering_info"] = "egress-peer-engineering-info"
                                    self._children_yang_names.add("egress-peer-engineering-info")

                                    self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                    self.graceful_restart_disabled_info.parent = self
                                    self._children_name_map["graceful_restart_disabled_info"] = "graceful-restart-disabled-info"
                                    self._children_yang_names.add("graceful-restart-disabled-info")

                                    self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                    self.graceful_shutdown_activate_info.parent = self
                                    self._children_name_map["graceful_shutdown_activate_info"] = "graceful-shutdown-activate-info"
                                    self._children_yang_names.add("graceful-shutdown-activate-info")

                                    self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                    self.graceful_shutdown_as_prepends_info.parent = self
                                    self._children_name_map["graceful_shutdown_as_prepends_info"] = "graceful-shutdown-as-prepends-info"
                                    self._children_yang_names.add("graceful-shutdown-as-prepends-info")

                                    self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                    self.graceful_shutdown_info.parent = self
                                    self._children_name_map["graceful_shutdown_info"] = "graceful-shutdown-info"
                                    self._children_yang_names.add("graceful-shutdown-info")

                                    self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                    self.graceful_shutdown_loc_pref_info.parent = self
                                    self._children_name_map["graceful_shutdown_loc_pref_info"] = "graceful-shutdown-loc-pref-info"
                                    self._children_yang_names.add("graceful-shutdown-loc-pref-info")

                                    self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                    self.idle_watch_time_info.parent = self
                                    self._children_name_map["idle_watch_time_info"] = "idle-watch-time-info"
                                    self._children_yang_names.add("idle-watch-time-info")

                                    self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                    self.ignore_connected_info.parent = self
                                    self._children_name_map["ignore_connected_info"] = "ignore-connected-info"
                                    self._children_yang_names.add("ignore-connected-info")

                                    self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                    self.internal_vpn_client_info.parent = self
                                    self._children_name_map["internal_vpn_client_info"] = "internal-vpn-client-info"
                                    self._children_yang_names.add("internal-vpn-client-info")

                                    self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                    self.keychain_info.parent = self
                                    self._children_name_map["keychain_info"] = "keychain-info"
                                    self._children_yang_names.add("keychain-info")

                                    self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                    self.local_address_info.parent = self
                                    self._children_name_map["local_address_info"] = "local-address-info"
                                    self._children_yang_names.add("local-address-info")

                                    self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                    self.local_as_info.parent = self
                                    self._children_name_map["local_as_info"] = "local-as-info"
                                    self._children_yang_names.add("local-as-info")

                                    self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                    self.local_ip_address.parent = self
                                    self._children_name_map["local_ip_address"] = "local-ip-address"
                                    self._children_yang_names.add("local-ip-address")

                                    self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                    self.max_peers_info.parent = self
                                    self._children_name_map["max_peers_info"] = "max-peers-info"
                                    self._children_yang_names.add("max-peers-info")

                                    self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                    self.min_advertisement_info.parent = self
                                    self._children_name_map["min_advertisement_info"] = "min-advertisement-info"
                                    self._children_yang_names.add("min-advertisement-info")

                                    self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                    self.msg_log_in_info.parent = self
                                    self._children_name_map["msg_log_in_info"] = "msg-log-in-info"
                                    self._children_yang_names.add("msg-log-in-info")

                                    self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                    self.msg_log_out_info.parent = self
                                    self._children_name_map["msg_log_out_info"] = "msg-log-out-info"
                                    self._children_yang_names.add("msg-log-out-info")

                                    self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                    self.nbr_enforce_first_as_info.parent = self
                                    self._children_name_map["nbr_enforce_first_as_info"] = "nbr-enforce-first-as-info"
                                    self._children_yang_names.add("nbr-enforce-first-as-info")

                                    self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                    self.nbr_restart_time_info.parent = self
                                    self._children_name_map["nbr_restart_time_info"] = "nbr-restart-time-info"
                                    self._children_yang_names.add("nbr-restart-time-info")

                                    self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                    self.nbr_stale_path_time_info.parent = self
                                    self._children_name_map["nbr_stale_path_time_info"] = "nbr-stale-path-time-info"
                                    self._children_yang_names.add("nbr-stale-path-time-info")

                                    self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                    self.neighbor_remote_as_list_info.parent = self
                                    self._children_name_map["neighbor_remote_as_list_info"] = "neighbor-remote-as-list-info"
                                    self._children_yang_names.add("neighbor-remote-as-list-info")

                                    self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                    self.neighbor_update_filter_attribute_info.parent = self
                                    self._children_name_map["neighbor_update_filter_attribute_info"] = "neighbor-update-filter-attribute-info"
                                    self._children_yang_names.add("neighbor-update-filter-attribute-info")

                                    self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                    self.neighbor_update_filter_exists_info.parent = self
                                    self._children_name_map["neighbor_update_filter_exists_info"] = "neighbor-update-filter-exists-info"
                                    self._children_yang_names.add("neighbor-update-filter-exists-info")

                                    self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                    self.neighbor_update_filter_message_buffer_count_info.parent = self
                                    self._children_name_map["neighbor_update_filter_message_buffer_count_info"] = "neighbor-update-filter-message-buffer-count-info"
                                    self._children_yang_names.add("neighbor-update-filter-message-buffer-count-info")

                                    self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                    self.neighbor_update_filter_syslog_disable_info.parent = self
                                    self._children_name_map["neighbor_update_filter_syslog_disable_info"] = "neighbor-update-filter-syslog-disable-info"
                                    self._children_yang_names.add("neighbor-update-filter-syslog-disable-info")

                                    self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                    self.nsr_disabled_info.parent = self
                                    self._children_name_map["nsr_disabled_info"] = "nsr-disabled-info"
                                    self._children_yang_names.add("nsr-disabled-info")

                                    self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                    self.password_info.parent = self
                                    self._children_name_map["password_info"] = "password-info"
                                    self._children_yang_names.add("password-info")

                                    self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                    self.prefix_validation_allow_invalid_info.parent = self
                                    self._children_name_map["prefix_validation_allow_invalid_info"] = "prefix-validation-allow-invalid-info"
                                    self._children_yang_names.add("prefix-validation-allow-invalid-info")

                                    self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                    self.prefix_validation_disable_info.parent = self
                                    self._children_name_map["prefix_validation_disable_info"] = "prefix-validation-disable-info"
                                    self._children_yang_names.add("prefix-validation-disable-info")

                                    self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                    self.prefix_validation_signal_ibgp_info.parent = self
                                    self._children_name_map["prefix_validation_signal_ibgp_info"] = "prefix-validation-signal-ibgp-info"
                                    self._children_yang_names.add("prefix-validation-signal-ibgp-info")

                                    self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                    self.prefix_validation_use_validit_info.parent = self
                                    self._children_name_map["prefix_validation_use_validit_info"] = "prefix-validation-use-validit-info"
                                    self._children_yang_names.add("prefix-validation-use-validit-info")

                                    self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                    self.receive_buffer_info.parent = self
                                    self._children_name_map["receive_buffer_info"] = "receive-buffer-info"
                                    self._children_yang_names.add("receive-buffer-info")

                                    self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                    self.remote_as_info.parent = self
                                    self._children_name_map["remote_as_info"] = "remote-as-info"
                                    self._children_yang_names.add("remote-as-info")

                                    self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                    self.send_buffer_info.parent = self
                                    self._children_name_map["send_buffer_info"] = "send-buffer-info"
                                    self._children_yang_names.add("send-buffer-info")

                                    self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                    self.session_open_mode_info.parent = self
                                    self._children_name_map["session_open_mode_info"] = "session-open-mode-info"
                                    self._children_yang_names.add("session-open-mode-info")

                                    self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                    self.shutdown_info.parent = self
                                    self._children_name_map["shutdown_info"] = "shutdown-info"
                                    self._children_yang_names.add("shutdown-info")

                                    self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                    self.speaker_id_info.parent = self
                                    self._children_name_map["speaker_id_info"] = "speaker-id-info"
                                    self._children_yang_names.add("speaker-id-info")

                                    self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                    self.suppress4_bbyte_as_info.parent = self
                                    self._children_name_map["suppress4_bbyte_as_info"] = "suppress4-bbyte-as-info"
                                    self._children_yang_names.add("suppress4-bbyte-as-info")

                                    self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                    self.tcpmss_info.parent = self
                                    self._children_name_map["tcpmss_info"] = "tcpmss-info"
                                    self._children_yang_names.add("tcpmss-info")

                                    self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                    self.timers_info.parent = self
                                    self._children_name_map["timers_info"] = "timers-info"
                                    self._children_yang_names.add("timers-info")

                                    self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                    self.tos_info.parent = self
                                    self._children_name_map["tos_info"] = "tos-info"
                                    self._children_yang_names.add("tos-info")

                                    self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                    self.ttl_security_info.parent = self
                                    self._children_name_map["ttl_security_info"] = "ttl-security-info"
                                    self._children_yang_names.add("ttl-security-info")

                                    self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                    self.update_error_handling_no_reset_info.parent = self
                                    self._children_name_map["update_error_handling_no_reset_info"] = "update-error-handling-no-reset-info"
                                    self._children_yang_names.add("update-error-handling-no-reset-info")

                                    self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                    self.update_source_info.parent = self
                                    self._children_name_map["update_source_info"] = "update-source-info"
                                    self._children_yang_names.add("update-source-info")
                                    self._segment_path = lambda: "af-independent-config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, ['addpath_receive_capability', 'addpath_send_capability', 'adminstrative_shutdown', 'bestpath_use_origin_as_validity', 'bfd', 'bfd_mininterval', 'bfd_multiplier', 'bgp_buffer_receive_size', 'bgp_buffer_send_size', 'bmp_servers', 'capability_negotiation_suppressed', 'configured_speaker_id', 'description', 'dmz_link_bandwidth', 'ebgp_hop_count', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'egress_peer_engineering', 'graceful_restart_disabled', 'graceful_shutdown_activate', 'graceful_shutdown_as_prepends', 'graceful_shutdown_exists', 'graceful_shutdown_loc_pref', 'hold_time_value', 'idle_watch_time', 'ignore_connected_check', 'internal_vpn_client', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'keepalive_interval', 'keychain', 'local_as_dual_as', 'local_as_no_prepend', 'local_as_number_xx', 'local_as_number_yy', 'local_as_replace_as', 'max_peers', 'min_acc_hold_time_value', 'min_advertisement_interval', 'min_advertisement_interval_msecs', 'msg_log_in_buf_count', 'msg_log_out_buf_count', 'nbr_cluster_id_info', 'nbr_cluster_id_type_info', 'nbr_enforce_first_as_status', 'nbr_restart_time', 'nbr_stale_path_time', 'neighbor_remote_as_list_group_name', 'neighbor_update_filter_attribute_filter_group_name', 'neighbor_update_filter_exists', 'neighbor_update_filter_logging_disable', 'neighbor_update_filter_message_buffer_count', 'neighbor_update_filter_message_buffer_is_non_circular', 'nsr_disabled', 'password', 'prefix_validation_allow_invalid', 'prefix_validation_disable', 'prefix_validation_signal_ibgp', 'remote_as_number_xx', 'remote_as_number_yy', 'route_updates_source', 'session_open_mode', 'socket_buffer_receive_size', 'socket_buffer_send_size', 'suppress4_byte_as', 'tcp_mss', 'tos_type_info', 'tos_value_info', 'ttl_security', 'update_error_handling_no_reset'], name, value)


                                class AddpathReceiveCapabilityInfo(Entity):
                                    """
                                    Addpath receive capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, self).__init__()

                                        self.yang_name = "addpath-receive-capability-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "addpath-receive-capability-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "addpath-receive-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AddpathSendCapabilityInfo(Entity):
                                    """
                                    Addpath send capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, self).__init__()

                                        self.yang_name = "addpath-send-capability-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "addpath-send-capability-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "addpath-send-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class BfdInfo(Entity):
                                    """
                                    BFD item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, self).__init__()

                                        self.yang_name = "bfd-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "bfd-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class BfdMinintervalInfo(Entity):
                                    """
                                    BFD Mininterval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, self).__init__()

                                        self.yang_name = "bfd-mininterval-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "bfd-mininterval-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-mininterval-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class BfdMultiplierInfo(Entity):
                                    """
                                    BFD Multiplier item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, self).__init__()

                                        self.yang_name = "bfd-multiplier-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "bfd-multiplier-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-multiplier-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class BmpServersInfo(Entity):
                                    """
                                    BMP Servers Configuredinfo
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, self).__init__()

                                        self.yang_name = "bmp-servers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "bmp-servers-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bmp-servers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class CapabilityNegotiationSuppressedInfo(Entity):
                                    """
                                    Capability negotiation suppressed info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, self).__init__()

                                        self.yang_name = "capability-negotiation-suppressed-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "capability-negotiation-suppressed-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "capability-negotiation-suppressed-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ClusterIdInfo(Entity):
                                    """
                                    Cluster ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, self).__init__()

                                        self.yang_name = "cluster-id-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "cluster-id-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "cluster-id-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class DescriptionInfo(Entity):
                                    """
                                    Description item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, self).__init__()

                                        self.yang_name = "description-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "description-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "description-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class DmzLinkBandwidthInfo(Entity):
                                    """
                                    DMZ link bandwidth item 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, self).__init__()

                                        self.yang_name = "dmz-link-bandwidth-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "dmz-link-bandwidth-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "dmz-link-bandwidth-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class EbgpHopCountInfo(Entity):
                                    """
                                    EBGP neighbors hop count item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, self).__init__()

                                        self.yang_name = "ebgp-hop-count-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "ebgp-hop-count-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-hop-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class EbgpRecvDmzInfo(Entity):
                                    """
                                    EBGP receive DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, self).__init__()

                                        self.yang_name = "ebgp-recv-dmz-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "ebgp-recv-dmz-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-recv-dmz-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class EbgpSendDmzInfo(Entity):
                                    """
                                    EBGP send DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, self).__init__()

                                        self.yang_name = "ebgp-send-dmz-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "ebgp-send-dmz-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-send-dmz-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class EgressPeerEngineeringInfo(Entity):
                                    """
                                    Egress Peer Engineering info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, self).__init__()

                                        self.yang_name = "egress-peer-engineering-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "egress-peer-engineering-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "egress-peer-engineering-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulRestartDisabledInfo(Entity):
                                    """
                                    Graceful\-restart item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, self).__init__()

                                        self.yang_name = "graceful-restart-disabled-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "graceful-restart-disabled-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-restart-disabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulShutdownActivateInfo(Entity):
                                    """
                                    GracefulShutdownAcivate info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-activate-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "graceful-shutdown-activate-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-activate-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulShutdownAsPrependsInfo(Entity):
                                    """
                                    GracefulShutdownASPrepends info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-as-prepends-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "graceful-shutdown-as-prepends-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-as-prepends-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulShutdownInfo(Entity):
                                    """
                                    GracefulShutdown info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "graceful-shutdown-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulShutdownLocPrefInfo(Entity):
                                    """
                                    GracefulShutdownLocPref info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-loc-pref-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "graceful-shutdown-loc-pref-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-loc-pref-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class IdleWatchTimeInfo(Entity):
                                    """
                                    Idle Watch time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, self).__init__()

                                        self.yang_name = "idle-watch-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "idle-watch-time-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "idle-watch-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class IgnoreConnectedInfo(Entity):
                                    """
                                    Ignore Connected Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, self).__init__()

                                        self.yang_name = "ignore-connected-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "ignore-connected-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ignore-connected-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class InternalVpnClientInfo(Entity):
                                    """
                                    Internal VPN Client Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, self).__init__()

                                        self.yang_name = "internal-vpn-client-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "internal-vpn-client-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "internal-vpn-client-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class KeychainInfo(Entity):
                                    """
                                    Neighbor Keychain item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, self).__init__()

                                        self.yang_name = "keychain-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "keychain-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "keychain-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class LocalAddressInfo(Entity):
                                    """
                                    Local address item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, self).__init__()

                                        self.yang_name = "local-address-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "local-address-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "local-address-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class LocalAsInfo(Entity):
                                    """
                                    Local AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, self).__init__()

                                        self.yang_name = "local-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "local-as-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "local-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class LocalIpAddress(Entity):
                                    """
                                    Local ipv4 or ipv6 address for neighbor
                                    connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, self).__init__()

                                        self.yang_name = "local-ip-address"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "local-ip-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MaxPeersInfo(Entity):
                                    """
                                    Max dynamic nbrs in range info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, self).__init__()

                                        self.yang_name = "max-peers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "max-peers-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "max-peers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MinAdvertisementInfo(Entity):
                                    """
                                    Minimum advertisement interval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, self).__init__()

                                        self.yang_name = "min-advertisement-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "min-advertisement-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "min-advertisement-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MsgLogInInfo(Entity):
                                    """
                                    Message Log Inbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, self).__init__()

                                        self.yang_name = "msg-log-in-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "msg-log-in-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "msg-log-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class MsgLogOutInfo(Entity):
                                    """
                                    Message Log Outbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, self).__init__()

                                        self.yang_name = "msg-log-out-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "msg-log-out-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "msg-log-out-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NbrEnforceFirstAsInfo(Entity):
                                    """
                                    Neighbor enforce first AS info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, self).__init__()

                                        self.yang_name = "nbr-enforce-first-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "nbr-enforce-first-as-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-enforce-first-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NbrRestartTimeInfo(Entity):
                                    """
                                    Restart time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, self).__init__()

                                        self.yang_name = "nbr-restart-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "nbr-restart-time-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-restart-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NbrStalePathTimeInfo(Entity):
                                    """
                                    Stale\-path time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, self).__init__()

                                        self.yang_name = "nbr-stale-path-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "nbr-stale-path-time-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-stale-path-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborRemoteAsListInfo(Entity):
                                    """
                                    Neighbor range  remote\-as\-list group info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, self).__init__()

                                        self.yang_name = "neighbor-remote-as-list-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "neighbor-remote-as-list-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-remote-as-list-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborUpdateFilterAttributeInfo(Entity):
                                    """
                                    Neighbor update filter attribute\-filter group
                                    info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-attribute-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "neighbor-update-filter-attribute-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-attribute-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborUpdateFilterExistsInfo(Entity):
                                    """
                                    Neighbor update filter configuration info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-exists-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "neighbor-update-filter-exists-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-exists-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborUpdateFilterMessageBufferCountInfo(Entity):
                                    """
                                    Neighbor update filter message buffer count info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-message-buffer-count-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "neighbor-update-filter-message-buffer-count-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-message-buffer-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborUpdateFilterSyslogDisableInfo(Entity):
                                    """
                                    Neighbor update filter syslog disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-syslog-disable-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "neighbor-update-filter-syslog-disable-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-syslog-disable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NsrDisabledInfo(Entity):
                                    """
                                    NSR item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, self).__init__()

                                        self.yang_name = "nsr-disabled-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "nsr-disabled-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nsr-disabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PasswordInfo(Entity):
                                    """
                                    Neighbor password item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, self).__init__()

                                        self.yang_name = "password-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "password-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "password-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixValidationAllowInvalidInfo(Entity):
                                    """
                                    RPKI allow invalid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, self).__init__()

                                        self.yang_name = "prefix-validation-allow-invalid-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "prefix-validation-allow-invalid-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-allow-invalid-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixValidationDisableInfo(Entity):
                                    """
                                    RPKI disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, self).__init__()

                                        self.yang_name = "prefix-validation-disable-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "prefix-validation-disable-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-disable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixValidationSignalIbgpInfo(Entity):
                                    """
                                    RPKI signal ibgp info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, self).__init__()

                                        self.yang_name = "prefix-validation-signal-ibgp-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "prefix-validation-signal-ibgp-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-signal-ibgp-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixValidationUseValiditInfo(Entity):
                                    """
                                    RPKI use validity
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, self).__init__()

                                        self.yang_name = "prefix-validation-use-validit-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "prefix-validation-use-validit-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-use-validit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ReceiveBufferInfo(Entity):
                                    """
                                    Receive buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, self).__init__()

                                        self.yang_name = "receive-buffer-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "receive-buffer-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "receive-buffer-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RemoteAsInfo(Entity):
                                    """
                                    Remote AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, self).__init__()

                                        self.yang_name = "remote-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "remote-as-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remote-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SendBufferInfo(Entity):
                                    """
                                    Send buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, self).__init__()

                                        self.yang_name = "send-buffer-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "send-buffer-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-buffer-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SessionOpenModeInfo(Entity):
                                    """
                                    TCP conn open mode info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, self).__init__()

                                        self.yang_name = "session-open-mode-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "session-open-mode-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "session-open-mode-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ShutdownInfo(Entity):
                                    """
                                    Shutdown item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, self).__init__()

                                        self.yang_name = "shutdown-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "shutdown-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "shutdown-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class SpeakerIdInfo(Entity):
                                    """
                                    Configured speaker ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, self).__init__()

                                        self.yang_name = "speaker-id-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "speaker-id-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "speaker-id-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class Suppress4BbyteAsInfo(Entity):
                                    """
                                    BGP suppress 4byte\-as item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, self).__init__()

                                        self.yang_name = "suppress4-bbyte-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "suppress4-bbyte-as-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "suppress4-bbyte-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class TcpmssInfo(Entity):
                                    """
                                    TCP Maximum Segment Size item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, self).__init__()

                                        self.yang_name = "tcpmss-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "tcpmss-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "tcpmss-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class TimersInfo(Entity):
                                    """
                                    Timers item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, self).__init__()

                                        self.yang_name = "timers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "timers-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "timers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class TosInfo(Entity):
                                    """
                                    TOS item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, self).__init__()

                                        self.yang_name = "tos-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "tos-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "tos-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class TtlSecurityInfo(Entity):
                                    """
                                    BGP TTL Security item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, self).__init__()

                                        self.yang_name = "ttl-security-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "ttl-security-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ttl-security-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateErrorHandlingNoResetInfo(Entity):
                                    """
                                    Error\-handling avoid\-reset config info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, self).__init__()

                                        self.yang_name = "update-error-handling-no-reset-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "update-error-handling-no-reset-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "update-error-handling-no-reset-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateSourceInfo(Entity):
                                    """
                                    Update source item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, self).__init__()

                                        self.yang_name = "update-source-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"inheritance-chain" : ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain)}
                                        self._child_list_classes = {}

                                        self.is_item_configured = YLeaf(YType.boolean, "is-item-configured")

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._children_yang_names.add("inheritance-chain")
                                        self._segment_path = lambda: "update-source-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, ['is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "update-source-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-config-entid" : ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid)}

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.address_family_identifier = YLeaf(YType.uint8, "address-family-identifier")

                                                self.configuration_type = YLeaf(YType.enumeration, "configuration-type")

                                                self.group_name = YLeaf(YType.str, "group-name")

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bgp-config-entid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, ['address_family_identifier', 'configuration_type', 'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "neighbor-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


    class Instances(Entity):
        """
        Instance specific BGP data
        
        .. attribute:: instance
        
        	Instance specific BGP data
        	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-06-26'

        def __init__(self):
            super(Bgp.Instances, self).__init__()

            self.yang_name = "instances"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"instance" : ("instance", Bgp.Instances.Instance)}

            self.instance = YList(self)
            self._segment_path = lambda: "instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.Instances, [], name, value)


        class Instance(Entity):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  <key>
            
            	Name of the BGP instance
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: instance_active
            
            	Active BGP operational data
            	**type**\:   :py:class:`InstanceActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive>`
            
            .. attribute:: instance_standby
            
            	Standby BGP operational data
            	**type**\:   :py:class:`InstanceStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-06-26'

            def __init__(self):
                super(Bgp.Instances.Instance, self).__init__()

                self.yang_name = "instance"
                self.yang_parent_name = "instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"instance-active" : ("instance_active", Bgp.Instances.Instance.InstanceActive), "instance-standby" : ("instance_standby", Bgp.Instances.Instance.InstanceStandby)}
                self._child_list_classes = {}

                self.instance_name = YLeaf(YType.str, "instance-name")

                self.instance_active = Bgp.Instances.Instance.InstanceActive()
                self.instance_active.parent = self
                self._children_name_map["instance_active"] = "instance-active"
                self._children_yang_names.add("instance-active")

                self.instance_standby = Bgp.Instances.Instance.InstanceStandby()
                self.instance_standby.parent = self
                self._children_name_map["instance_standby"] = "instance-standby"
                self._children_yang_names.add("instance-standby")
                self._segment_path = lambda: "instance" + "[instance-name='" + self.instance_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/instances/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.Instances.Instance, ['instance_name'], name, value)


            class InstanceActive(Entity):
                """
                Active BGP operational data
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf>`
                
                .. attribute:: label_entries
                
                	BGP Label Table
                	**type**\:   :py:class:`LabelEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries>`
                
                .. attribute:: label_rpf_entries
                
                	BGP Label RPF Table
                	**type**\:   :py:class:`LabelRpfEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries>`
                
                .. attribute:: label_summary
                
                	BGP Label Summary
                	**type**\:   :py:class:`LabelSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary>`
                
                .. attribute:: rpki_refresh_afs
                
                	RPKI Refresh Table (per AF)
                	**type**\:   :py:class:`RpkiRefreshAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:   :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:   :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:   :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiSummary>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:   :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries>`
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:   :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:   :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:   :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.Instances.Instance.InstanceActive, self).__init__()

                    self.yang_name = "instance-active"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"attribute-filter-groups" : ("attribute_filter_groups", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceActive.Attributes), "default-vrf" : ("default_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf), "label-entries" : ("label_entries", Bgp.Instances.Instance.InstanceActive.LabelEntries), "label-rpf-entries" : ("label_rpf_entries", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries), "label-summary" : ("label_summary", Bgp.Instances.Instance.InstanceActive.LabelSummary), "rpki-refresh-afs" : ("rpki_refresh_afs", Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs), "rpki-routes" : ("rpki_routes", Bgp.Instances.Instance.InstanceActive.RpkiRoutes), "rpki-server-list" : ("rpki_server_list", Bgp.Instances.Instance.InstanceActive.RpkiServerList), "rpki-summary" : ("rpki_summary", Bgp.Instances.Instance.InstanceActive.RpkiSummary), "rt-entries" : ("rt_entries", Bgp.Instances.Instance.InstanceActive.RtEntries), "update-generation-process" : ("update_generation_process", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess), "update-inbound-error-process" : ("update_inbound_error_process", Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess), "update-inbound-filter-process" : ("update_inbound_filter_process", Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess), "vrfs" : ("vrfs", Bgp.Instances.Instance.InstanceActive.Vrfs)}
                    self._child_list_classes = {}

                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"
                    self._children_yang_names.add("attribute-filter-groups")

                    self.attributes = Bgp.Instances.Instance.InstanceActive.Attributes()
                    self.attributes.parent = self
                    self._children_name_map["attributes"] = "attributes"
                    self._children_yang_names.add("attributes")

                    self.default_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"
                    self._children_yang_names.add("default-vrf")

                    self.label_entries = Bgp.Instances.Instance.InstanceActive.LabelEntries()
                    self.label_entries.parent = self
                    self._children_name_map["label_entries"] = "label-entries"
                    self._children_yang_names.add("label-entries")

                    self.label_rpf_entries = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries()
                    self.label_rpf_entries.parent = self
                    self._children_name_map["label_rpf_entries"] = "label-rpf-entries"
                    self._children_yang_names.add("label-rpf-entries")

                    self.label_summary = Bgp.Instances.Instance.InstanceActive.LabelSummary()
                    self.label_summary.parent = self
                    self._children_name_map["label_summary"] = "label-summary"
                    self._children_yang_names.add("label-summary")

                    self.rpki_refresh_afs = Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs()
                    self.rpki_refresh_afs.parent = self
                    self._children_name_map["rpki_refresh_afs"] = "rpki-refresh-afs"
                    self._children_yang_names.add("rpki-refresh-afs")

                    self.rpki_routes = Bgp.Instances.Instance.InstanceActive.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self._children_name_map["rpki_routes"] = "rpki-routes"
                    self._children_yang_names.add("rpki-routes")

                    self.rpki_server_list = Bgp.Instances.Instance.InstanceActive.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self._children_name_map["rpki_server_list"] = "rpki-server-list"
                    self._children_yang_names.add("rpki-server-list")

                    self.rpki_summary = Bgp.Instances.Instance.InstanceActive.RpkiSummary()
                    self.rpki_summary.parent = self
                    self._children_name_map["rpki_summary"] = "rpki-summary"
                    self._children_yang_names.add("rpki-summary")

                    self.rt_entries = Bgp.Instances.Instance.InstanceActive.RtEntries()
                    self.rt_entries.parent = self
                    self._children_name_map["rt_entries"] = "rt-entries"
                    self._children_yang_names.add("rt-entries")

                    self.update_generation_process = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self._children_name_map["update_generation_process"] = "update-generation-process"
                    self._children_yang_names.add("update-generation-process")

                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self._children_name_map["update_inbound_error_process"] = "update-inbound-error-process"
                    self._children_yang_names.add("update-inbound-error-process")

                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self._children_name_map["update_inbound_filter_process"] = "update-inbound-filter-process"
                    self._children_yang_names.add("update-inbound-filter-process")

                    self.vrfs = Bgp.Instances.Instance.InstanceActive.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                    self._children_yang_names.add("vrfs")
                    self._segment_path = lambda: "instance-active"


                class AttributeFilterGroups(Entity):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups, self).__init__()

                        self.yang_name = "attribute-filter-groups"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"attribute-filter-group" : ("attribute_filter_group", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup)}

                        self.attribute_filter_group = YList(self)
                        self._segment_path = lambda: "attribute-filter-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups, [], name, value)


                    class AttributeFilterGroup(Entity):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  <key>
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of    :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                            self.yang_name = "attribute-filter-group"
                            self.yang_parent_name = "attribute-filter-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"attribute-filter-entry" : ("attribute_filter_entry", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry)}

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.attribute_filter_group_name = YLeaf(YType.str, "attribute-filter-group-name")

                            self.attribute_filter_total_group_count = YLeaf(YType.uint32, "attribute-filter-total-group-count")

                            self.attribute_filter_entry = YList(self)
                            self._segment_path = lambda: "attribute-filter-group" + "[group-name='" + self.group_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup, ['group_name', 'attribute_filter_group_name', 'attribute_filter_total_group_count'], name, value)


                        class AttributeFilterEntry(Entity):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, self).__init__()

                                self.yang_name = "attribute-filter-entry"
                                self.yang_parent_name = "attribute-filter-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.attribute_filter_entry_range_end = YLeaf(YType.uint32, "attribute-filter-entry-range-end")

                                self.attribute_filter_entry_range_start = YLeaf(YType.uint32, "attribute-filter-entry-range-start")

                                self.attribute_filter_entry_requested_action = YLeaf(YType.enumeration, "attribute-filter-entry-requested-action")
                                self._segment_path = lambda: "attribute-filter-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, ['attribute_filter_entry_range_end', 'attribute_filter_entry_range_start', 'attribute_filter_entry_requested_action'], name, value)


                class Attributes(Entity):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.Attributes, self).__init__()

                        self.yang_name = "attributes"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute)}

                        self.attribute = YList(self)
                        self._segment_path = lambda: "attributes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes, [], name, value)


                    class Attribute(Entity):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo)}
                            self._child_list_classes = {}

                            self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                            self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                            self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                            self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                            self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                            self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                            self.reference_count = YLeaf(YType.uint32, "reference-count")

                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self._children_name_map["attribute_info"] = "attribute-info"
                            self._children_yang_names.add("attribute-info")
                            self._segment_path = lambda: "attribute"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                        class AttributeInfo(Entity):
                            """
                            Attributes
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\:  bool
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\:  bool
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\:  bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\:  bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\:  bool
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo, self).__init__()

                                self.yang_name = "attribute-info"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                self._child_list_classes = {}

                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self._children_name_map["attr_set"] = "attr-set"
                                self._children_yang_names.add("attr-set")

                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self._children_name_map["common_attributes"] = "common-attributes"
                                self._children_yang_names.add("common-attributes")

                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                self._children_yang_names.add("ribrnh-ip")

                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                self._children_yang_names.add("rnh-addr")
                                self._segment_path = lambda: "attribute-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                            class AttrSet(Entity):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                    self.yang_name = "attr-set"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                    self.as_path = YLeaf(YType.str, "as-path")

                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                    self.origin = YLeaf(YType.uint16, "origin")

                                    self.originator = YLeaf(YType.str, "originator")

                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                    self._children_yang_names.add("tunnel-encap")

                                    self.cluster = YList(self)
                                    self.community = YList(self)
                                    self.connector_value = YList(self)
                                    self.extended_community = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.label_index_attr = YList(self)
                                    self.large_community = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self._segment_path = lambda: "attr-set"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "cluster"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "connector-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                class L2Tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "l2tpv3-cookie"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                class LabelIndexAttr(Entity):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                        self.yang_name = "label-index-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "label-index-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                        self._segment_path = lambda: "large-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "ls-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                        self._segment_path = lambda: "pe-distinguisher-label"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "pmsi-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                        self._child_list_classes = {}

                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._children_yang_names.add("sr-policy")
                                        self._segment_path = lambda: "tunnel-encap"


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\:  bool
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                            self.preference = YLeaf(YType.uint32, "preference")

                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                            self.state = YLeaf(YType.boolean, "state")

                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                            self._children_yang_names.add("allocated-binding-sid")

                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"
                                            self._children_yang_names.add("binding-sid")

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "allocated-binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                self.weight = YLeaf(YType.uint8, "weight")

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.type = YLeaf(YType.enumeration, "type")
                                                    self._segment_path = lambda: "segment"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "unknown-attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                            class CommonAttributes(Entity):
                                """
                                Common attributes
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                    self.yang_name = "common-attributes"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                    self.as_path = YLeaf(YType.str, "as-path")

                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                    self.origin = YLeaf(YType.uint16, "origin")

                                    self.originator = YLeaf(YType.str, "originator")

                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                    self._children_yang_names.add("tunnel-encap")

                                    self.cluster = YList(self)
                                    self.community = YList(self)
                                    self.connector_value = YList(self)
                                    self.extended_community = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.label_index_attr = YList(self)
                                    self.large_community = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self._segment_path = lambda: "common-attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "cluster"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "connector-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                class L2Tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "l2tpv3-cookie"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                class LabelIndexAttr(Entity):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                        self.yang_name = "label-index-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "label-index-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                        self._segment_path = lambda: "large-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "ls-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                        self._segment_path = lambda: "pe-distinguisher-label"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "pmsi-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                        self._child_list_classes = {}

                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._children_yang_names.add("sr-policy")
                                        self._segment_path = lambda: "tunnel-encap"


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\:  bool
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                            self.preference = YLeaf(YType.uint32, "preference")

                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                            self.state = YLeaf(YType.boolean, "state")

                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                            self._children_yang_names.add("allocated-binding-sid")

                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"
                                            self._children_yang_names.add("binding-sid")

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "allocated-binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                self.weight = YLeaf(YType.uint8, "weight")

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.type = YLeaf(YType.enumeration, "type")
                                                    self._segment_path = lambda: "segment"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "unknown-attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                            class RibrnhIp(Entity):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                    self.yang_name = "ribrnh-ip"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "ribrnh-ip"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RnhAddr(Entity):
                                """
                                RNH Address
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                    self.yang_name = "rnh-addr"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.len = YLeaf(YType.enumeration, "len")

                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                    self._segment_path = lambda: "rnh-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                class DefaultVrf(Entity):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"afs" : ("afs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs), "bmp" : ("bmp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp), "global-process-info" : ("global_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo), "information" : ("information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information), "message-logs" : ("message_logs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs), "neighbor-ranges" : ("neighbor_ranges", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges), "neighbors" : ("neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors), "next-hop-vrf" : ("next_hop_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf), "postits" : ("postits", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits), "process-info" : ("process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo), "sessions" : ("sessions", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions), "update-inbound-error-neighbors" : ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors), "update-inbound-error-vrf" : ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf), "update-inbound-filter-neighbors" : ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors), "update-inbound-filter-vrf" : ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf)}
                        self._child_list_classes = {}

                        self.afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                        self._children_yang_names.add("afs")

                        self.bmp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self._children_name_map["bmp"] = "bmp"
                        self._children_yang_names.add("bmp")

                        self.global_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self._children_name_map["global_process_info"] = "global-process-info"
                        self._children_yang_names.add("global-process-info")

                        self.information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information()
                        self.information.parent = self
                        self._children_name_map["information"] = "information"
                        self._children_yang_names.add("information")

                        self.message_logs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self._children_name_map["message_logs"] = "message-logs"
                        self._children_yang_names.add("message-logs")

                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self._children_name_map["neighbor_ranges"] = "neighbor-ranges"
                        self._children_yang_names.add("neighbor-ranges")

                        self.neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self._children_name_map["next_hop_vrf"] = "next-hop-vrf"
                        self._children_yang_names.add("next-hop-vrf")

                        self.postits = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits()
                        self.postits.parent = self
                        self._children_name_map["postits"] = "postits"
                        self._children_yang_names.add("postits")

                        self.process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self._children_name_map["process_info"] = "process-info"
                        self._children_yang_names.add("process-info")

                        self.sessions = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self._children_name_map["sessions"] = "sessions"
                        self._children_yang_names.add("sessions")

                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"
                        self._children_yang_names.add("update-inbound-error-neighbors")

                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"
                        self._children_yang_names.add("update-inbound-error-vrf")

                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"
                        self._children_yang_names.add("update-inbound-filter-neighbors")

                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self
                        self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"
                        self._children_yang_names.add("update-inbound-filter-vrf")
                        self._segment_path = lambda: "default-vrf"


                    class Afs(Entity):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"af" : ("af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af)}

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address family
                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes>`
                            
                            .. attribute:: bmp_path_table_generic
                            
                            	Summary Info about BMP Table
                            	**type**\:   :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: network_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds>`
                            
                            .. attribute:: network_lookup_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds>`
                            
                            .. attribute:: network_prefixes
                            
                            	The BGP Network Lookup table
                            	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"advertised-path-counts" : ("advertised_path_counts", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts), "advertised-path-xr" : ("advertised_path_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr), "advertised-paths" : ("advertised_paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths), "af-process-info" : ("af_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes), "bmp-path-table-generic" : ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric), "bmp-paths" : ("bmp_paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths), "convergence" : ("convergence", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence), "dampenings" : ("dampenings", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings), "epes" : ("epes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes), "global-af-process-info" : ("global_af_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo), "neighbor-af-table" : ("neighbor_af_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable), "network-all-rds" : ("network_all_rds", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds), "network-lookup-all-rds" : ("network_lookup_all_rds", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds), "network-prefixes" : ("network_prefixes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes), "networks" : ("networks", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks), "next-hop-address-families" : ("next_hop_address_families", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies), "path-labeled-table" : ("path_labeled_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable), "path-table" : ("path_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable), "path-used-table" : ("path_used_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable), "policies" : ("policies", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies), "prefix-filters" : ("prefix_filters", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters), "rpc-sets" : ("rpc_sets", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets), "rt-set-counters" : ("rt_set_counters", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters), "sourced-networks" : ("sourced_networks", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks), "update-generation-address-family" : ("update_generation_address_family", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily), "update-generation-filter-groups" : ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups), "update-generation-neighbors" : ("update_generation_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors), "update-generation-sub-groups" : ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups), "update-generation-update-groups" : ("update_generation_update_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups), "update-groups" : ("update_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups)}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self._children_name_map["advertised_path_counts"] = "advertised-path-counts"
                                self._children_yang_names.add("advertised-path-counts")

                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self._children_name_map["advertised_path_xr"] = "advertised-path-xr"
                                self._children_yang_names.add("advertised-path-xr")

                                self.advertised_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self._children_name_map["advertised_paths"] = "advertised-paths"
                                self._children_yang_names.add("advertised-paths")

                                self.af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self._children_name_map["af_process_info"] = "af-process-info"
                                self._children_yang_names.add("af-process-info")

                                self.attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self._children_name_map["attributes"] = "attributes"
                                self._children_yang_names.add("attributes")

                                self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric()
                                self.bmp_path_table_generic.parent = self
                                self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"
                                self._children_yang_names.add("bmp-path-table-generic")

                                self.bmp_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self._children_name_map["bmp_paths"] = "bmp-paths"
                                self._children_yang_names.add("bmp-paths")

                                self.convergence = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self._children_name_map["convergence"] = "convergence"
                                self._children_yang_names.add("convergence")

                                self.dampenings = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self._children_name_map["dampenings"] = "dampenings"
                                self._children_yang_names.add("dampenings")

                                self.epes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self._children_name_map["epes"] = "epes"
                                self._children_yang_names.add("epes")

                                self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self._children_name_map["global_af_process_info"] = "global-af-process-info"
                                self._children_yang_names.add("global-af-process-info")

                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self._children_name_map["neighbor_af_table"] = "neighbor-af-table"
                                self._children_yang_names.add("neighbor-af-table")

                                self.network_all_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds()
                                self.network_all_rds.parent = self
                                self._children_name_map["network_all_rds"] = "network-all-rds"
                                self._children_yang_names.add("network-all-rds")

                                self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds()
                                self.network_lookup_all_rds.parent = self
                                self._children_name_map["network_lookup_all_rds"] = "network-lookup-all-rds"
                                self._children_yang_names.add("network-lookup-all-rds")

                                self.network_prefixes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes()
                                self.network_prefixes.parent = self
                                self._children_name_map["network_prefixes"] = "network-prefixes"
                                self._children_yang_names.add("network-prefixes")

                                self.networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self._children_name_map["networks"] = "networks"
                                self._children_yang_names.add("networks")

                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self._children_name_map["next_hop_address_families"] = "next-hop-address-families"
                                self._children_yang_names.add("next-hop-address-families")

                                self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self._children_name_map["path_labeled_table"] = "path-labeled-table"
                                self._children_yang_names.add("path-labeled-table")

                                self.path_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self._children_name_map["path_table"] = "path-table"
                                self._children_yang_names.add("path-table")

                                self.path_used_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self._children_name_map["path_used_table"] = "path-used-table"
                                self._children_yang_names.add("path-used-table")

                                self.policies = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self._children_name_map["policies"] = "policies"
                                self._children_yang_names.add("policies")

                                self.prefix_filters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self._children_name_map["prefix_filters"] = "prefix-filters"
                                self._children_yang_names.add("prefix-filters")

                                self.rpc_sets = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self._children_name_map["rpc_sets"] = "rpc-sets"
                                self._children_yang_names.add("rpc-sets")

                                self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self._children_name_map["rt_set_counters"] = "rt-set-counters"
                                self._children_yang_names.add("rt-set-counters")

                                self.sourced_networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self._children_name_map["sourced_networks"] = "sourced-networks"
                                self._children_yang_names.add("sourced-networks")

                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self._children_name_map["update_generation_address_family"] = "update-generation-address-family"
                                self._children_yang_names.add("update-generation-address-family")

                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"
                                self._children_yang_names.add("update-generation-filter-groups")

                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"
                                self._children_yang_names.add("update-generation-neighbors")

                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"
                                self._children_yang_names.add("update-generation-sub-groups")

                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"
                                self._children_yang_names.add("update-generation-update-groups")

                                self.update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self
                                self._children_name_map["update_groups"] = "update-groups"
                                self._children_yang_names.add("update-groups")
                                self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af, ['af_name'], name, value)


                            class AdvertisedPathCounts(Entity):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                    self.yang_name = "advertised-path-counts"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path-count" : ("advertised_path_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount)}

                                    self.advertised_path_count = YList(self)
                                    self._segment_path = lambda: "advertised-path-counts"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                class AdvertisedPathCount(Entity):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                        self.yang_name = "advertised-path-count"
                                        self.yang_parent_name = "advertised-path-counts"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.max_prefix_advertisedcount = YLeaf(YType.uint32, "max-prefix-advertisedcount")
                                        self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', 'max_prefix_advertisedcount'], name, value)


                            class AdvertisedPathXr(Entity):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                    self.yang_name = "advertised-path-xr"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath)}

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-path-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-path-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "advertised-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertisedPaths(Entity):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths, self).__init__()

                                    self.yang_name = "advertised-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath)}

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-paths"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"adv-path-info" : ("adv_path_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo), "paths" : ("paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.adv_path_info = YList(self)
                                        self.paths = YList(self)
                                        self._segment_path = lambda: "advertised-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['neighbor_address', 'network', 'prefix_length', 'rd'], name, value)


                                    class AdvPathInfo(Entity):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                            self.yang_name = "adv-path-info"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._children_yang_names.add("attributes-after-policy-out")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                            self._children_yang_names.add("path-info-after-policy-in")

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                            self._children_yang_names.add("path-info-after-policy-out")
                                            self._segment_path = lambda: "adv-path-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, ['af_name', 'no_path', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class Paths(Entity):
                                        """
                                        paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "paths"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfProcessInfo(Entity):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo, self).__init__()

                                    self.yang_name = "af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.process_instance = YLeaf(YType.uint8, "process-instance")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._children_yang_names.add("performance-statistics")

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "af-process-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo, ['af_name', 'process_instance', 'vrf_name', 'vrf_totals'], name, value)


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v4_next_hop
                                    
                                    	Max supported label stack depth for IPv4 Nexthop
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v6_next_hop
                                    
                                    	Max supported label stack depth for IPv6 Nexthop
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_bgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:   :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall), "trigger-import" : ("trigger_import", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport), "trigger-label" : ("trigger_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel), "trigger-rib" : ("trigger_rib", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib), "trigger-update" : ("trigger_update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate), "version-wrap-done-time-spec" : ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec), "version-wrap-start-time-spec" : ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec), "version-wrap-time-spec" : ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec)}
                                        self._child_list_classes = {}

                                        self.freed_rd_count = YLeaf(YType.uint32, "freed-rd-count")

                                        self.import_bgp_version = YLeaf(YType.uint32, "import-bgp-version")

                                        self.import_last_trigger = YLeaf(YType.uint64, "import-last-trigger")

                                        self.import_triggers = YLeaf(YType.uint32, "import-triggers")

                                        self.import_version = YLeaf(YType.uint32, "import-version")

                                        self.imported_paths_memory = YLeaf(YType.uint32, "imported-paths-memory")

                                        self.imported_paths_num = YLeaf(YType.uint32, "imported-paths-num")

                                        self.label_bgp_version = YLeaf(YType.uint32, "label-bgp-version")

                                        self.label_last_trigger = YLeaf(YType.uint64, "label-last-trigger")

                                        self.label_triggers = YLeaf(YType.uint32, "label-triggers")

                                        self.label_version = YLeaf(YType.uint32, "label-version")

                                        self.last_import_version = YLeaf(YType.uint32, "last-import-version")

                                        self.last_label_version = YLeaf(YType.uint32, "last-label-version")

                                        self.last_rib_version = YLeaf(YType.uint32, "last-rib-version")

                                        self.local_networks_freed_num = YLeaf(YType.uint32, "local-networks-freed-num")

                                        self.local_networks_malloced_num = YLeaf(YType.uint32, "local-networks-malloced-num")

                                        self.local_networks_memory = YLeaf(YType.uint32, "local-networks-memory")

                                        self.local_networks_num = YLeaf(YType.uint32, "local-networks-num")

                                        self.local_paths_freed_num = YLeaf(YType.uint32, "local-paths-freed-num")

                                        self.local_paths_malloced_num = YLeaf(YType.uint32, "local-paths-malloced-num")

                                        self.local_paths_memory = YLeaf(YType.uint32, "local-paths-memory")

                                        self.local_paths_num = YLeaf(YType.uint32, "local-paths-num")

                                        self.malloced_rd_count = YLeaf(YType.uint32, "malloced-rd-count")

                                        self.max_active_pelem_version = YLeaf(YType.uint32, "max-active-pelem-version")

                                        self.max_label_stack_depth_v4_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v4-next-hop")

                                        self.max_label_stack_depth_v6_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v6-next-hop")

                                        self.merged_table_version = YLeaf(YType.uint32, "merged-table-version")

                                        self.multipath_network_entry_count = YLeaf(YType.uint32, "multipath-network-entry-count")

                                        self.multipath_network_entry_memory = YLeaf(YType.uint32, "multipath-network-entry-memory")

                                        self.multipath_paths_count = YLeaf(YType.uint32, "multipath-paths-count")

                                        self.multipath_paths_memory = YLeaf(YType.uint32, "multipath-paths-memory")

                                        self.networks_freed_num = YLeaf(YType.uint32, "networks-freed-num")

                                        self.networks_malloced_num = YLeaf(YType.uint32, "networks-malloced-num")

                                        self.networks_memory = YLeaf(YType.uint32, "networks-memory")

                                        self.networks_num = YLeaf(YType.uint32, "networks-num")

                                        self.num_init_sync_pfx = YLeaf(YType.uint32, "num-init-sync-pfx")

                                        self.path_elems_freed_num = YLeaf(YType.uint32, "path-elems-freed-num")

                                        self.path_elems_malloced_num = YLeaf(YType.uint32, "path-elems-malloced-num")

                                        self.path_elems_memory = YLeaf(YType.uint32, "path-elems-memory")

                                        self.path_elems_num = YLeaf(YType.uint32, "path-elems-num")

                                        self.paths_freed_num = YLeaf(YType.uint32, "paths-freed-num")

                                        self.paths_malloced_num = YLeaf(YType.uint32, "paths-malloced-num")

                                        self.paths_memory = YLeaf(YType.uint32, "paths-memory")

                                        self.paths_num = YLeaf(YType.uint32, "paths-num")

                                        self.rd_memory = YLeaf(YType.uint32, "rd-memory")

                                        self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                        self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                        self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                        self.rib_bgp_version = YLeaf(YType.uint32, "rib-bgp-version")

                                        self.rib_brib_received_version = YLeaf(YType.uint32, "rib-brib-received-version")

                                        self.rib_last_trigger = YLeaf(YType.uint64, "rib-last-trigger")

                                        self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                        self.rib_triggers = YLeaf(YType.uint32, "rib-triggers")

                                        self.route_download_go_active_done_pending = YLeaf(YType.uint32, "route-download-go-active-done-pending")

                                        self.router_state = YLeaf(YType.enumeration, "router-state")

                                        self.send_version = YLeaf(YType.uint32, "send-version")

                                        self.standby_version = YLeaf(YType.uint32, "standby-version")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.total_r_ds_num = YLeaf(YType.uint32, "total-r-ds-num")

                                        self.total_remote_r_ds_num = YLeaf(YType.uint32, "total-remote-r-ds-num")

                                        self.total_same_r_ds_num = YLeaf(YType.uint32, "total-same-r-ds-num")

                                        self.update_gen_bgp_version = YLeaf(YType.uint32, "update-gen-bgp-version")

                                        self.update_gen_last_trigger = YLeaf(YType.uint64, "update-gen-last-trigger")

                                        self.update_triggers = YLeaf(YType.uint32, "update-triggers")

                                        self.update_wait_install_enabled = YLeaf(YType.uint32, "update-wait-install-enabled")

                                        self.version_wrapped = YLeaf(YType.uint32, "version-wrapped")

                                        self.version_wrapped_tid = YLeaf(YType.uint32, "version-wrapped-tid")

                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._children_yang_names.add("rib-install")

                                        self.trigger_import = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                        self.trigger_import.parent = self
                                        self._children_name_map["trigger_import"] = "trigger-import"
                                        self._children_yang_names.add("trigger-import")

                                        self.trigger_label = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self._children_name_map["trigger_label"] = "trigger-label"
                                        self._children_yang_names.add("trigger-label")

                                        self.trigger_rib = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self._children_name_map["trigger_rib"] = "trigger-rib"
                                        self._children_yang_names.add("trigger-rib")

                                        self.trigger_update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self._children_name_map["trigger_update"] = "trigger-update"
                                        self._children_yang_names.add("trigger-update")

                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"
                                        self._children_yang_names.add("version-wrap-done-time-spec")

                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"
                                        self._children_yang_names.add("version-wrap-start-time-spec")

                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"
                                        self._children_yang_names.add("version-wrap-time-spec")
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_, ['freed_rd_count', 'import_bgp_version', 'import_last_trigger', 'import_triggers', 'import_version', 'imported_paths_memory', 'imported_paths_num', 'label_bgp_version', 'label_last_trigger', 'label_triggers', 'label_version', 'last_import_version', 'last_label_version', 'last_rib_version', 'local_networks_freed_num', 'local_networks_malloced_num', 'local_networks_memory', 'local_networks_num', 'local_paths_freed_num', 'local_paths_malloced_num', 'local_paths_memory', 'local_paths_num', 'malloced_rd_count', 'max_active_pelem_version', 'max_label_stack_depth_v4_next_hop', 'max_label_stack_depth_v6_next_hop', 'merged_table_version', 'multipath_network_entry_count', 'multipath_network_entry_memory', 'multipath_paths_count', 'multipath_paths_memory', 'networks_freed_num', 'networks_malloced_num', 'networks_memory', 'networks_num', 'num_init_sync_pfx', 'path_elems_freed_num', 'path_elems_malloced_num', 'path_elems_memory', 'path_elems_num', 'paths_freed_num', 'paths_malloced_num', 'paths_memory', 'paths_num', 'rd_memory', 'rib_ack_requests', 'rib_acked_table_version', 'rib_acks_received', 'rib_bgp_version', 'rib_brib_received_version', 'rib_last_trigger', 'rib_slow_acks', 'rib_triggers', 'route_download_go_active_done_pending', 'router_state', 'send_version', 'standby_version', 'table_brib_version', 'table_version', 'total_r_ds_num', 'total_remote_r_ds_num', 'total_same_r_ds_num', 'update_gen_bgp_version', 'update_gen_last_trigger', 'update_triggers', 'update_wait_install_enabled', 'version_wrapped', 'version_wrapped_tid'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime)}
                                            self._child_list_classes = {}

                                            self.installed_count = YLeaf(YType.uint32, "installed-count")

                                            self.modified_count = YLeaf(YType.uint32, "modified-count")

                                            self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                            self.start_version = YLeaf(YType.uint32, "start-version")

                                            self.target_version = YLeaf(YType.uint32, "target-version")

                                            self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._children_yang_names.add("install-time")

                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"
                                            self._children_yang_names.add("update-time")
                                            self._segment_path = lambda: "rib-install"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "install-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerImport(Entity):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, self).__init__()

                                            self.yang_name = "trigger-import"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerLabel(Entity):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, self).__init__()

                                            self.yang_name = "trigger-label"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-label"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-label"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerRib(Entity):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, self).__init__()

                                            self.yang_name = "trigger-rib"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-rib"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-rib"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerUpdate(Entity):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, self).__init__()

                                            self.yang_name = "trigger-update"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-update"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-done-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-start-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-start-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf)}
                                        self._child_list_classes = {}

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "performance-statistics"


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mode-enter-time" : ("mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime), "total-pim-callback-add" : ("total_pim_callback_add", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd), "total-pim-callback-add-local" : ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal), "total-pim-callback-del" : ("total_pim_callback_del", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel), "total-pim-callback-del-local" : ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal), "total-pim-install-add" : ("total_pim_install_add", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd), "total-pim-install-del" : ("total_pim_install_del", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel)}

                                            self.first_nbr_up_time = YLeaf(YType.uint32, "first-nbr-up-time")

                                            self.has_converged = YLeaf(YType.boolean, "has-converged")

                                            self.total_pim_callback_batch = YLeaf(YType.uint32, "total-pim-callback-batch")

                                            self.total_pim_callbacks = YLeaf(YType.uint32, "total-pim-callbacks")

                                            self.total_pim_install = YLeaf(YType.uint32, "total-pim-install")

                                            self.mode_enter_time = YList(self)
                                            self.total_pim_callback_add = YList(self)
                                            self.total_pim_callback_add_local = YList(self)
                                            self.total_pim_callback_del = YList(self)
                                            self.total_pim_callback_del_local = YList(self)
                                            self.total_pim_install_add = YList(self)
                                            self.total_pim_install_del = YList(self)
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, ['first_nbr_up_time', 'has_converged', 'total_pim_callback_batch', 'total_pim_callbacks', 'total_pim_install'], name, value)


                                        class ModeEnterTime(Entity):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, self).__init__()

                                                self.yang_name = "mode-enter-time"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "mode-enter-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, ['entry'], name, value)


                                        class TotalPimCallbackAdd(Entity):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, self).__init__()

                                                self.yang_name = "total-pim-callback-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-add"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, ['entry'], name, value)


                                        class TotalPimCallbackAddLocal(Entity):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-add-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-add-local"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, ['entry'], name, value)


                                        class TotalPimCallbackDel(Entity):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, self).__init__()

                                                self.yang_name = "total-pim-callback-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-del"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, ['entry'], name, value)


                                        class TotalPimCallbackDelLocal(Entity):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-del-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-del-local"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, ['entry'], name, value)


                                        class TotalPimInstallAdd(Entity):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, self).__init__()

                                                self.yang_name = "total-pim-install-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-install-add"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, ['entry'], name, value)


                                        class TotalPimInstallDel(Entity):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, self).__init__()

                                                self.yang_name = "total-pim-install-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-install-del"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, ['entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_not_sent_to_rib
                                        
                                        	No. of prefixes not sent to RIB due to unsupported label stack size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-table-full-timestamp" : ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp), "first-rib-table-has-space-timestamp" : ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp), "last-rib-table-full-timestamp" : ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp), "last-rib-table-has-space-timestamp" : ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp), "time-label-retain" : ("time_label_retain", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain), "time-rib-coverged" : ("time_rib_coverged", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged), "time-rib-down" : ("time_rib_down", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)}
                                            self._child_list_classes = {}

                                            self.attributes_recover_from_rib = YLeaf(YType.uint32, "attributes-recover-from-rib")

                                            self.attributes_removed_from_rib = YLeaf(YType.uint32, "attributes-removed-from-rib")

                                            self.attributes_sent_to_rib = YLeaf(YType.uint32, "attributes-sent-to-rib")

                                            self.first_rib_table_full_version = YLeaf(YType.uint32, "first-rib-table-full-version")

                                            self.first_rib_table_has_space_version = YLeaf(YType.uint32, "first-rib-table-has-space-version")

                                            self.import_added_path_count = YLeaf(YType.uint32, "import-added-path-count")

                                            self.import_calls = YLeaf(YType.uint32, "import-calls")

                                            self.import_dest_net_processed_count = YLeaf(YType.uint32, "import-dest-net-processed-count")

                                            self.import_removed_path_count = YLeaf(YType.uint32, "import-removed-path-count")

                                            self.import_replaced_path_count = YLeaf(YType.uint32, "import-replaced-path-count")

                                            self.import_src_net_processed_count = YLeaf(YType.uint32, "import-src-net-processed-count")

                                            self.import_time = YLeaf(YType.uint32, "import-time")

                                            self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                            self.label_added_count = YLeaf(YType.uint32, "label-added-count")

                                            self.label_calls = YLeaf(YType.uint32, "label-calls")

                                            self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                            self.label_rewrite_count = YLeaf(YType.uint32, "label-rewrite-count")

                                            self.label_time = YLeaf(YType.uint32, "label-time")

                                            self.last_rib_table_full_age = YLeaf(YType.uint32, "last-rib-table-full-age")

                                            self.last_rib_table_full_version = YLeaf(YType.uint32, "last-rib-table-full-version")

                                            self.last_rib_table_has_space_age = YLeaf(YType.uint32, "last-rib-table-has-space-age")

                                            self.last_rib_table_has_space_version = YLeaf(YType.uint32, "last-rib-table-has-space-version")

                                            self.prefixes_not_sent_to_rib = YLeaf(YType.uint32, "prefixes-not-sent-to-rib")

                                            self.prefixes_removed_from_rib = YLeaf(YType.uint32, "prefixes-removed-from-rib")

                                            self.prefixes_resent_to_rib = YLeaf(YType.uint32, "prefixes-resent-to-rib")

                                            self.prefixes_sent_to_rib = YLeaf(YType.uint32, "prefixes-sent-to-rib")

                                            self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                            self.rib_tbl_del_calls = YLeaf(YType.uint32, "rib-tbl-del-calls")

                                            self.rib_tbl_invalid_calls = YLeaf(YType.uint32, "rib-tbl-invalid-calls")

                                            self.rib_tbl_local_label = YLeaf(YType.uint32, "rib-tbl-local-label")

                                            self.rib_tbl_retry = YLeaf(YType.uint32, "rib-tbl-retry")

                                            self.rib_tbl_skip_calls = YLeaf(YType.uint32, "rib-tbl-skip-calls")

                                            self.rib_trigger = YLeaf(YType.boolean, "rib-trigger")

                                            self.rib_update_calls = YLeaf(YType.uint32, "rib-update-calls")

                                            self.rib_update_time = YLeaf(YType.uint32, "rib-update-time")

                                            self.scanner_runs = YLeaf(YType.uint32, "scanner-runs")

                                            self.scanner_time = YLeaf(YType.uint32, "scanner-time")

                                            self.subgroup_count = YLeaf(YType.uint32, "subgroup-count")

                                            self.time_last_update_sent = YLeaf(YType.uint32, "time-last-update-sent")

                                            self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                            self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                            self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                            self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                            self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                            self.update_group_count = YLeaf(YType.uint32, "update-group-count")

                                            self.vrf_flags = YLeaf(YType.uint32, "vrf-flags")

                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"
                                            self._children_yang_names.add("first-rib-table-full-timestamp")

                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"
                                            self._children_yang_names.add("first-rib-table-has-space-timestamp")

                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"
                                            self._children_yang_names.add("last-rib-table-full-timestamp")

                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"
                                            self._children_yang_names.add("last-rib-table-has-space-timestamp")

                                            self.time_label_retain = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self._children_name_map["time_label_retain"] = "time-label-retain"
                                            self._children_yang_names.add("time-label-retain")

                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self._children_name_map["time_rib_coverged"] = "time-rib-coverged"
                                            self._children_yang_names.add("time-rib-coverged")

                                            self.time_rib_down = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self._children_name_map["time_rib_down"] = "time-rib-down"
                                            self._children_yang_names.add("time-rib-down")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, ['attributes_recover_from_rib', 'attributes_removed_from_rib', 'attributes_sent_to_rib', 'first_rib_table_full_version', 'first_rib_table_has_space_version', 'import_added_path_count', 'import_calls', 'import_dest_net_processed_count', 'import_removed_path_count', 'import_replaced_path_count', 'import_src_net_processed_count', 'import_time', 'is_rib_table_full', 'label_added_count', 'label_calls', 'label_release_count', 'label_rewrite_count', 'label_time', 'last_rib_table_full_age', 'last_rib_table_full_version', 'last_rib_table_has_space_age', 'last_rib_table_has_space_version', 'prefixes_not_sent_to_rib', 'prefixes_removed_from_rib', 'prefixes_resent_to_rib', 'prefixes_sent_to_rib', 'rib_table_full_version', 'rib_tbl_del_calls', 'rib_tbl_invalid_calls', 'rib_tbl_local_label', 'rib_tbl_retry', 'rib_tbl_skip_calls', 'rib_trigger', 'rib_update_calls', 'rib_update_time', 'scanner_runs', 'scanner_time', 'subgroup_count', 'time_last_update_sent', 'update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'update_group_count', 'vrf_flags'], name, value)


                                        class FirstRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-table-full-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-table-has-space-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-table-full-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-table-has-space-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class TimeLabelRetain(Entity):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                self.yang_name = "time-label-retain"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-label-retain"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, ['nanoseconds', 'seconds'], name, value)


                                        class TimeRibCoverged(Entity):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                self.yang_name = "time-rib-coverged"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-rib-coverged"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, ['nanoseconds', 'seconds'], name, value)


                                        class TimeRibDown(Entity):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                self.yang_name = "time-rib-down"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-rib-down"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, ['nanoseconds', 'seconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\:  bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.add_path_install_disable = YLeaf(YType.boolean, "add-path-install-disable")

                                        self.add_path_install_enable = YLeaf(YType.boolean, "add-path-install-enable")

                                        self.any_ebgp_neighbor_missing_policy = YLeaf(YType.boolean, "any-ebgp-neighbor-missing-policy")

                                        self.asbr = YLeaf(YType.boolean, "asbr")

                                        self.attribute_download = YLeaf(YType.boolean, "attribute-download")

                                        self.best_external = YLeaf(YType.boolean, "best-external")

                                        self.best_external_disable = YLeaf(YType.boolean, "best-external-disable")

                                        self.bmp_network_entry_count = YLeaf(YType.uint32, "bmp-network-entry-count")

                                        self.bmp_path_memory = YLeaf(YType.uint32, "bmp-path-memory")

                                        self.bmp_paths_count = YLeaf(YType.uint32, "bmp-paths-count")

                                        self.bmp_prefix_memory = YLeaf(YType.uint32, "bmp-prefix-memory")

                                        self.damped_path_count = YLeaf(YType.uint32, "damped-path-count")

                                        self.freed_path_count = YLeaf(YType.uint32, "freed-path-count")

                                        self.freed_path_elem_count = YLeaf(YType.uint32, "freed-path-elem-count")

                                        self.freed_prefix_count = YLeaf(YType.uint32, "freed-prefix-count")

                                        self.history_path_count = YLeaf(YType.uint32, "history-path-count")

                                        self.ibgp_nexthop_self_count = YLeaf(YType.uint32, "ibgp-nexthop-self-count")

                                        self.imported_path_memory = YLeaf(YType.uint32, "imported-path-memory")

                                        self.imported_paths = YLeaf(YType.uint32, "imported-paths")

                                        self.is_route_reflector = YLeaf(YType.boolean, "is-route-reflector")

                                        self.label_retain = YLeaf(YType.boolean, "label-retain")

                                        self.label_retainvalue = YLeaf(YType.uint32, "label-retainvalue")

                                        self.local_path_memory = YLeaf(YType.uint32, "local-path-memory")

                                        self.local_paths = YLeaf(YType.uint32, "local-paths")

                                        self.malloced_path_count = YLeaf(YType.uint32, "malloced-path-count")

                                        self.malloced_path_elem_count = YLeaf(YType.uint32, "malloced-path-elem-count")

                                        self.malloced_prefix_count = YLeaf(YType.uint32, "malloced-prefix-count")

                                        self.network_entry_count = YLeaf(YType.uint32, "network-entry-count")

                                        self.path_elem_memory = YLeaf(YType.uint32, "path-elem-memory")

                                        self.path_elems_count = YLeaf(YType.uint32, "path-elems-count")

                                        self.path_memory = YLeaf(YType.uint32, "path-memory")

                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                        self.prefix_memory = YLeaf(YType.uint32, "prefix-memory")

                                        self.received_path_count = YLeaf(YType.uint32, "received-path-count")

                                        self.retain_rt_all = YLeaf(YType.boolean, "retain-rt-all")

                                        self.route_target_download = YLeaf(YType.boolean, "route-target-download")

                                        self.tbl_bitf_size = YLeaf(YType.uint16, "tbl-bitf-size")

                                        self.tbl_chunk_bitf_size = YLeaf(YType.uint16, "tbl-chunk-bitf-size")

                                        self.use_igpsr_label = YLeaf(YType.boolean, "use-igpsr-label")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, ['add_path_install_disable', 'add_path_install_enable', 'any_ebgp_neighbor_missing_policy', 'asbr', 'attribute_download', 'best_external', 'best_external_disable', 'bmp_network_entry_count', 'bmp_path_memory', 'bmp_paths_count', 'bmp_prefix_memory', 'damped_path_count', 'freed_path_count', 'freed_path_elem_count', 'freed_prefix_count', 'history_path_count', 'ibgp_nexthop_self_count', 'imported_path_memory', 'imported_paths', 'is_route_reflector', 'label_retain', 'label_retainvalue', 'local_path_memory', 'local_paths', 'malloced_path_count', 'malloced_path_elem_count', 'malloced_prefix_count', 'network_entry_count', 'path_elem_memory', 'path_elems_count', 'path_memory', 'paths_count', 'prefix_memory', 'received_path_count', 'retain_rt_all', 'route_target_download', 'tbl_bitf_size', 'tbl_chunk_bitf_size', 'use_igpsr_label'], name, value)


                            class Attributes(Entity):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes, self).__init__()

                                    self.yang_name = "attributes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute)}

                                    self.attribute = YList(self)
                                    self._segment_path = lambda: "attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes, [], name, value)


                                class Attribute(Entity):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo)}
                                        self._child_list_classes = {}

                                        self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                                        self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                                        self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                                        self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                                        self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                                        self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.reference_count = YLeaf(YType.uint32, "reference-count")

                                        self.attribute_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self._children_name_map["attribute_info"] = "attribute-info"
                                        self._children_yang_names.add("attribute-info")
                                        self._segment_path = lambda: "attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                                    class AttributeInfo(Entity):
                                        """
                                        Attributes
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                            self.yang_name = "attribute-info"
                                            self.yang_parent_name = "attribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attribute-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                            class BmpPathTableGeneric(Entity):
                                """
                                Summary Info about BMP Table
                                
                                .. attribute:: bmp_route_monitoringe_enabled
                                
                                	Is Route Monitoring mode enabled
                                	**type**\:  bool
                                
                                .. attribute:: bmp_table_version
                                
                                	Table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_incremented
                                
                                	Is Version being incremented
                                	**type**\:  bool
                                
                                .. attribute:: bmp_version_inprogress
                                
                                	Is Version wrap in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_version_wrap_done_time_spec
                                
                                	Version Wrap handle Done timestamp
                                	**type**\:   :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_start_time_spec
                                
                                	Version Wrap handle start timestamp
                                	**type**\:   :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_time_spec
                                
                                	Version Wrap timestamp
                                	**type**\:   :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                
                                .. attribute:: bmp_version_wrapped
                                
                                	Number of times Table Version Wrapped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped_tid
                                
                                	Version Wrapped trigger thread id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of nets in the table
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths in the table
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                    self.yang_name = "bmp-path-table-generic"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"bmp-version-wrap-done-time-spec" : ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec), "bmp-version-wrap-start-time-spec" : ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec), "bmp-version-wrap-time-spec" : ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)}
                                    self._child_list_classes = {}

                                    self.bmp_route_monitoringe_enabled = YLeaf(YType.boolean, "bmp-route-monitoringe-enabled")

                                    self.bmp_table_version = YLeaf(YType.uint32, "bmp-table-version")

                                    self.bmp_version_incremented = YLeaf(YType.boolean, "bmp-version-incremented")

                                    self.bmp_version_inprogress = YLeaf(YType.boolean, "bmp-version-inprogress")

                                    self.bmp_version_wrapped = YLeaf(YType.uint32, "bmp-version-wrapped")

                                    self.bmp_version_wrapped_tid = YLeaf(YType.uint32, "bmp-version-wrapped-tid")

                                    self.network_count = YLeaf(YType.uint32, "network-count")

                                    self.path_count = YLeaf(YType.uint32, "path-count")

                                    self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                    self.bmp_version_wrap_done_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-done-time-spec")

                                    self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                    self.bmp_version_wrap_start_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-start-time-spec")

                                    self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                    self.bmp_version_wrap_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-time-spec")
                                    self._segment_path = lambda: "bmp-path-table-generic"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric, ['bmp_route_monitoringe_enabled', 'bmp_table_version', 'bmp_version_incremented', 'bmp_version_inprogress', 'bmp_version_wrapped', 'bmp_version_wrapped_tid', 'network_count', 'path_count'], name, value)


                                class BmpVersionWrapDoneTimeSpec(Entity):
                                    """
                                    Version Wrap handle Done timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-done-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-done-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpVersionWrapStartTimeSpec(Entity):
                                    """
                                    Version Wrap handle start timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-start-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-start-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpVersionWrapTimeSpec(Entity):
                                    """
                                    Version Wrap timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class BmpPaths(Entity):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths, self).__init__()

                                    self.yang_name = "bmp-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath)}

                                    self.bmp_path = YList(self)
                                    self._segment_path = lambda: "bmp-paths"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths, [], name, value)


                                class BmpPath(Entity):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath>`
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                        self.yang_name = "bmp-path"
                                        self.yang_parent_name = "bmp-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)}
                                        self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath)}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bmp_net_flags = YLeaf(YType.uint32, "bmp-net-flags")

                                        self.bmp_net_version = YLeaf(YType.uint32, "bmp-net-version")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.network = YLeaf(YType.str, "network")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath, ['af_name', 'bmp_net_flags', 'bmp_net_version', 'has_local_label', 'net_local_label', 'network', 'num_of_path', 'prefix_length'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BmpPath(Entity):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress>`
                                        
                                        .. attribute:: received_label
                                        
                                        	Label received from peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.bmp_nbr_bit_map = YLeaf(YType.uint32, "bmp-nbr-bit-map")

                                            self.bmp_path_adv_bit_map = YLeaf(YType.uint16, "bmp-path-adv-bit-map")

                                            self.bmp_path_flags = YLeaf(YType.uint32, "bmp-path-flags")

                                            self.bmp_path_snd_bit_map = YLeaf(YType.uint16, "bmp-path-snd-bit-map")

                                            self.bpath_pointer = YLeaf(YType.uint64, "bpath-pointer")

                                            self.local_path = YLeaf(YType.boolean, "local-path")

                                            self.received_label = YLeaf(YType.uint32, "received-label")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bmp-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath, ['bmp_nbr_bit_map', 'bmp_path_adv_bit_map', 'bmp_path_flags', 'bmp_path_snd_bit_map', 'bpath_pointer', 'local_path', 'received_label'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Convergence(Entity):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\:  bool
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence, self).__init__()

                                    self.yang_name = "convergence"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.are_write_queues_empty = YLeaf(YType.boolean, "are-write-queues-empty")

                                    self.has_converged = YLeaf(YType.boolean, "has-converged")
                                    self._segment_path = lambda: "convergence"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence, ['af_name', 'are_write_queues_empty', 'has_converged'], name, value)


                            class Dampenings(Entity):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings, self).__init__()

                                    self.yang_name = "dampenings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"dampening" : ("dampening", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening)}

                                    self.dampening = YList(self)
                                    self._segment_path = lambda: "dampenings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings, [], name, value)


                                class Dampening(Entity):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "dampenings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.length = YLeaf(YType.int32, "length")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.reuse = YLeaf(YType.int32, "reuse")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.version = YLeaf(YType.int32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "dampening"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'length', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_version', 'process_instance_id', 'rd', 'reuse', 'route_distinguisher', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'version', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class Epes(Entity):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes, self).__init__()

                                    self.yang_name = "epes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"epe" : ("epe", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe)}

                                    self.epe = YList(self)
                                    self._segment_path = lambda: "epes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes, [], name, value)


                                class Epe(Entity):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe, self).__init__()

                                        self.yang_name = "epe"
                                        self.yang_parent_name = "epes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"epe-local-address" : ("epe_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress), "epe-next-hop" : ("epe_next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop)}
                                        self._child_list_classes = {"epe-key" : ("epe_key", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey), "first-hop" : ("first_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop), "ifhandle" : ("ifhandle", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle), "nexthop-id" : ("nexthop_id", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId)}

                                        self.epe_flags = YLeaf(YType.uint8, "epe-flags")

                                        self.epe_key_length = YLeaf(YType.int32, "epe-key-length")

                                        self.epe_key_length_xr = YLeaf(YType.uint8, "epe-key-length-xr")

                                        self.epe_local_asn = YLeaf(YType.uint32, "epe-local-asn")

                                        self.epe_local_router_id = YLeaf(YType.uint32, "epe-local-router-id")

                                        self.epe_remote_asn = YLeaf(YType.uint32, "epe-remote-asn")

                                        self.epe_remote_router_id = YLeaf(YType.uint32, "epe-remote-router-id")

                                        self.epe_set_key = YLeaf(YType.str, "epe-set-key")

                                        self.epe_version = YLeaf(YType.uint32, "epe-version")

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.ref_count = YLeaf(YType.uint32, "ref-count")

                                        self.epe_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self._children_name_map["epe_local_address"] = "epe-local-address"
                                        self._children_yang_names.add("epe-local-address")

                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self._children_name_map["epe_next_hop"] = "epe-next-hop"
                                        self._children_yang_names.add("epe-next-hop")

                                        self.epe_key = YList(self)
                                        self.first_hop = YList(self)
                                        self.ifhandle = YList(self)
                                        self.nexthop_id = YList(self)
                                        self._segment_path = lambda: "epe"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe, ['epe_flags', 'epe_key_length', 'epe_key_length_xr', 'epe_local_asn', 'epe_local_router_id', 'epe_remote_asn', 'epe_remote_router_id', 'epe_set_key', 'epe_version', 'label', 'ref_count'], name, value)


                                    class EpeKey(Entity):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                            self.yang_name = "epe-key"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "epe-key"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, ['entry'], name, value)


                                    class EpeLocalAddress(Entity):
                                        """
                                        Local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                            self.yang_name = "epe-local-address"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "epe-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class EpeNextHop(Entity):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                            self.yang_name = "epe-next-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "epe-next-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class FirstHop(Entity):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                            self.yang_name = "first-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "first-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class Ifhandle(Entity):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                            self.yang_name = "ifhandle"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "ifhandle"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, ['entry'], name, value)


                                    class NexthopId(Entity):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                            self.yang_name = "nexthop-id"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "nexthop-id"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, ['entry'], name, value)


                            class GlobalAfProcessInfo(Entity):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                    self.yang_name = "global-af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "global-af-process-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo, ['af_name', 'is_nsr_enabled', 'vrf_name'], name, value)


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall)}
                                        self._child_list_classes = {"syncgrp-version" : ("syncgrp_version", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion)}

                                        self.gblafrpki_allow_invalid = YLeaf(YType.boolean, "gblafrpki-allow-invalid")

                                        self.gblafrpki_disable = YLeaf(YType.boolean, "gblafrpki-disable")

                                        self.gblafrpki_signal_ibgp = YLeaf(YType.boolean, "gblafrpki-signal-ibgp")

                                        self.gblafrpki_use_validity = YLeaf(YType.boolean, "gblafrpki-use-validity")

                                        self.global_mcast_enabled = YLeaf(YType.boolean, "global-mcast-enabled")

                                        self.inter_as_install_enabled = YLeaf(YType.boolean, "inter-as-install-enabled")

                                        self.is_perm_net_cfg = YLeaf(YType.boolean, "is-perm-net-cfg")

                                        self.nh_tunnel_version = YLeaf(YType.uint32, "nh-tunnel-version")

                                        self.perm_nbr_count = YLeaf(YType.uint16, "perm-nbr-count")

                                        self.perm_net_del_count = YLeaf(YType.uint16, "perm-net-del-count")

                                        self.perm_net_existing_count = YLeaf(YType.uint16, "perm-net-existing-count")

                                        self.perm_net_insert_count = YLeaf(YType.uint16, "perm-net-insert-count")

                                        self.perm_net_rpl_process_count = YLeaf(YType.uint16, "perm-net-rpl-process-count")

                                        self.perm_net_rpl_query_count = YLeaf(YType.uint16, "perm-net-rpl-query-count")

                                        self.perm_net_stale_del_count = YLeaf(YType.uint16, "perm-net-stale-del-count")

                                        self.perm_net_stale_mark_count = YLeaf(YType.uint16, "perm-net-stale-mark-count")

                                        self.perm_path_refresh_count = YLeaf(YType.uint16, "perm-path-refresh-count")

                                        self.perm_pelem_all_bump_count = YLeaf(YType.uint16, "perm-pelem-all-bump-count")

                                        self.perm_pelem_bump_count = YLeaf(YType.uint16, "perm-pelem-bump-count")

                                        self.perm_pelem_free_count = YLeaf(YType.uint16, "perm-pelem-free-count")

                                        self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                        self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                        self.rib_perm_path_found_count = YLeaf(YType.uint16, "rib-perm-path-found-count")

                                        self.rib_perm_path_not_found_count = YLeaf(YType.uint16, "rib-perm-path-not-found-count")

                                        self.rib_perm_pelem_found_count = YLeaf(YType.uint16, "rib-perm-pelem-found-count")

                                        self.rib_perm_pelem_not_found_count = YLeaf(YType.uint16, "rib-perm-pelem-not-found-count")

                                        self.rib_reg_path_found_count = YLeaf(YType.uint16, "rib-reg-path-found-count")

                                        self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                        self.scan_prefixes = YLeaf(YType.uint32, "scan-prefixes")

                                        self.scan_segment_prefixes = YLeaf(YType.uint32, "scan-segment-prefixes")

                                        self.scan_segments = YLeaf(YType.uint8, "scan-segments")

                                        self.scanner_period = YLeaf(YType.uint16, "scanner-period")

                                        self.segmented_mcast_enabled = YLeaf(YType.boolean, "segmented-mcast-enabled")

                                        self.update_wait_install_enabled = YLeaf(YType.boolean, "update-wait-install-enabled")

                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._children_yang_names.add("rib-install")

                                        self.syncgrp_version = YList(self)
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_, ['gblafrpki_allow_invalid', 'gblafrpki_disable', 'gblafrpki_signal_ibgp', 'gblafrpki_use_validity', 'global_mcast_enabled', 'inter_as_install_enabled', 'is_perm_net_cfg', 'nh_tunnel_version', 'perm_nbr_count', 'perm_net_del_count', 'perm_net_existing_count', 'perm_net_insert_count', 'perm_net_rpl_process_count', 'perm_net_rpl_query_count', 'perm_net_stale_del_count', 'perm_net_stale_mark_count', 'perm_path_refresh_count', 'perm_pelem_all_bump_count', 'perm_pelem_bump_count', 'perm_pelem_free_count', 'rib_ack_requests', 'rib_acks_received', 'rib_perm_path_found_count', 'rib_perm_path_not_found_count', 'rib_perm_pelem_found_count', 'rib_perm_pelem_not_found_count', 'rib_reg_path_found_count', 'rib_slow_acks', 'scan_prefixes', 'scan_segment_prefixes', 'scan_segments', 'scanner_period', 'segmented_mcast_enabled', 'update_wait_install_enabled'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime)}
                                            self._child_list_classes = {}

                                            self.installed_count = YLeaf(YType.uint32, "installed-count")

                                            self.modified_count = YLeaf(YType.uint32, "modified-count")

                                            self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                            self.start_version = YLeaf(YType.uint32, "start-version")

                                            self.target_version = YLeaf(YType.uint32, "target-version")

                                            self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._children_yang_names.add("install-time")

                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"
                                            self._children_yang_names.add("update-time")
                                            self._segment_path = lambda: "rib-install"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "install-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                    class SyncgrpVersion(Entity):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, self).__init__()

                                            self.yang_name = "syncgrp-version"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "syncgrp-version"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, ['entry'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\:  bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\:  bool
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\:  bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.aggregates_distance = YLeaf(YType.uint16, "aggregates-distance")

                                        self.client_reflection_enabled = YLeaf(YType.boolean, "client-reflection-enabled")

                                        self.dampening_enabled = YLeaf(YType.boolean, "dampening-enabled")

                                        self.dynamic_med_enabled = YLeaf(YType.boolean, "dynamic-med-enabled")

                                        self.dynamic_med_interval = YLeaf(YType.uint16, "dynamic-med-interval")

                                        self.dynamic_med_periodic_timer_running = YLeaf(YType.boolean, "dynamic-med-periodic-timer-running")

                                        self.dynamic_med_periodic_timer_value = YLeaf(YType.uint16, "dynamic-med-periodic-timer-value")

                                        self.dynamic_med_timer_running = YLeaf(YType.boolean, "dynamic-med-timer-running")

                                        self.dynamic_med_timer_value = YLeaf(YType.uint16, "dynamic-med-timer-value")

                                        self.ebgp_distance = YLeaf(YType.uint16, "ebgp-distance")

                                        self.ibgp_distance = YLeaf(YType.uint16, "ibgp-distance")

                                        self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                        self.nexthop_resolution_minimum_prefix_length = YLeaf(YType.uint32, "nexthop-resolution-minimum-prefix-length")

                                        self.nexthop_resolution_minimum_prefix_length_configured = YLeaf(YType.boolean, "nexthop-resolution-minimum-prefix-length-configured")

                                        self.nsr_conv_version = YLeaf(YType.uint32, "nsr-conv-version")

                                        self.nsr_is_conv = YLeaf(YType.boolean, "nsr-is-conv")

                                        self.rd_version = YLeaf(YType.uint32, "rd-version")

                                        self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                        self.rib_convergence_version = YLeaf(YType.uint32, "rib-convergence-version")

                                        self.rib_has_converged = YLeaf(YType.boolean, "rib-has-converged")

                                        self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                        self.rib_version = YLeaf(YType.uint32, "rib-version")

                                        self.selective_ebgp_multipath_enabled = YLeaf(YType.boolean, "selective-ebgp-multipath-enabled")

                                        self.selective_eibgp_multipath_enabled = YLeaf(YType.boolean, "selective-eibgp-multipath-enabled")

                                        self.selective_ibgp_multipath_enabled = YLeaf(YType.boolean, "selective-ibgp-multipath-enabled")

                                        self.table_id = YLeaf(YType.uint32, "table-id")

                                        self.table_is_active = YLeaf(YType.boolean, "table-is-active")

                                        self.table_version = YLeaf(YType.uint32, "table-version")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, ['aggregates_distance', 'client_reflection_enabled', 'dampening_enabled', 'dynamic_med_enabled', 'dynamic_med_interval', 'dynamic_med_periodic_timer_running', 'dynamic_med_periodic_timer_value', 'dynamic_med_timer_running', 'dynamic_med_timer_value', 'ebgp_distance', 'ibgp_distance', 'is_rib_table_full', 'nexthop_resolution_minimum_prefix_length', 'nexthop_resolution_minimum_prefix_length_configured', 'nsr_conv_version', 'nsr_is_conv', 'rd_version', 'rib_acked_table_version', 'rib_convergence_version', 'rib_has_converged', 'rib_table_full_version', 'rib_version', 'selective_ebgp_multipath_enabled', 'selective_eibgp_multipath_enabled', 'selective_ibgp_multipath_enabled', 'table_id', 'table_is_active', 'table_version'], name, value)


                            class NeighborAfTable(Entity):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable, self).__init__()

                                    self.yang_name = "neighbor-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor)}

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-af-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\:  str
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\:  bool
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\:  bool
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)}
                                        self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData)}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                        self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                        self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                        self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                        self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                        self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                        self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                        self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                        self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                        self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                        self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                        self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                        self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                        self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                        self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                        self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                        self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                        self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                        self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                        self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                        self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                        self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                        self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                        self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                        self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                        self.description = YLeaf(YType.str, "description")

                                        self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                        self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                        self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                        self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                        self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                        self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                        self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                        self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                        self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                        self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                        self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                        self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                        self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                        self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                        self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                        self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                        self.hold_time = YLeaf(YType.uint16, "hold-time")

                                        self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                        self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                        self.io_armed = YLeaf(YType.boolean, "io-armed")

                                        self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                        self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                        self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                        self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                        self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                        self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                        self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                        self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                        self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                        self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                        self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                        self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                        self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                        self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                        self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                        self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                        self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                        self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                        self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                        self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                        self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                        self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                        self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                        self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                        self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                        self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                        self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                        self.local_as = YLeaf(YType.uint32, "local-as")

                                        self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                        self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                        self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                        self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                        self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                        self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                        self.messages_received = YLeaf(YType.uint32, "messages-received")

                                        self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                        self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                        self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                        self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                        self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                        self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                        self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                        self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                        self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                        self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                        self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                        self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                        self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                        self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                        self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                        self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                        self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                        self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                        self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                        self.read_armed = YLeaf(YType.boolean, "read-armed")

                                        self.remote_as = YLeaf(YType.uint32, "remote-as")

                                        self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                        self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                        self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                        self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                        self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                        self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                        self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                        self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                        self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                        self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                        self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                        self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                        self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                        self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                        self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                        self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                        self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                        self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                        self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                        self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                        self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                        self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                        self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                        self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                        self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                        self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                        self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                        self.tos_type = YLeaf(YType.uint8, "tos-type")

                                        self.tos_value = YLeaf(YType.uint8, "tos-value")

                                        self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                        self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                        self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                        self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.write_armed = YLeaf(YType.boolean, "write-armed")

                                        self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self._children_name_map["connection_local_address"] = "connection-local-address"
                                        self._children_yang_names.add("connection-local-address")

                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                        self._children_yang_names.add("connection-remote-address")

                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        self._children_yang_names.add("graceful-maintenance")

                                        self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self._children_name_map["message_statistics"] = "message-statistics"
                                        self._children_yang_names.add("message-statistics")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self._children_name_map["received_notification_info"] = "received-notification-info"
                                        self._children_yang_names.add("received-notification-info")

                                        self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self._children_name_map["send_notification_info"] = "send-notification-info"
                                        self._children_yang_names.add("send-notification-info")

                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-time-spec")

                                        self.af_data = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                    class AfData(Entity):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with 
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\:  bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                            self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby)}

                                            self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                            self.acked_version = YLeaf(YType.uint32, "acked-version")

                                            self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                            self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                            self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                            self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                            self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                            self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                            self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                            self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                            self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                            self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                            self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                            self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                            self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                            self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                            self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                            self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                            self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                            self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                            self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                            self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                            self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                            self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                            self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                            self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                            self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                            self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                            self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                            self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                            self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                            self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                            self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                            self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                            self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                            self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                            self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                            self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                            self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                            self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                            self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                            self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                            self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                            self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                            self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                            self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                            self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                            self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                            self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                            self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                            self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                            self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                            self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                            self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                            self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                            self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                            self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                            self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                            self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                            self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                            self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                            self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                            self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                            self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                            self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                            self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                            self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                            self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                            self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                            self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                            self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                            self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                            self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                            self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                            self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                            self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                            self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                            self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                            self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                            self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                            self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                            self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                            self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                            self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                            self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                            self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                            self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                            self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                            self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                            self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                            self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                            self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                            self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                            self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                            self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                            self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                            self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                            self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                            self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                            self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                            self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                            self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                            self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                            self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                            self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                            self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                            self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                            self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                            self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                            self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                            self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                            self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                            self.restart_time = YLeaf(YType.uint32, "restart-time")

                                            self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                            self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                            self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                            self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                            self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                            self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                            self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                            self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                            self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                            self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                            self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                            self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                            self.weight = YLeaf(YType.uint32, "weight")

                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                            self._children_yang_names.add("neighbor-af-performance-statistics")

                                            self.extended_community = YList(self)
                                            self.extended_community_standby = YList(self)
                                            self._segment_path = lambda: "af-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                        class ExtendedCommunityStandby(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                self.yang_name = "extended-community-standby"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community-standby"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                        class NeighborAfPerformanceStatistics(Entity):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                self.yang_name = "neighbor-af-performance-statistics"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                                self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                                self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                                self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                                self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                                self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                                self._segment_path = lambda: "neighbor-af-performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                    class ConnectionLocalAddress(Entity):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                            self.yang_name = "connection-local-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "connection-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ConnectionRemoteAddress(Entity):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                            self.yang_name = "connection-remote-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "connection-remote-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class GracefulMaintenance(Entity):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                            self.yang_name = "graceful-maintenance"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                            self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                            self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                            self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                            self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                            self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                            self._segment_path = lambda: "graceful-maintenance"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                    class MessageStatistics(Entity):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                            self.yang_name = "message-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)}
                                            self._child_list_classes = {}

                                            self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self._children_name_map["keepalive"] = "keepalive"
                                            self._children_yang_names.add("keepalive")

                                            self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self._children_name_map["notification"] = "notification"
                                            self._children_yang_names.add("notification")

                                            self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self._children_name_map["open"] = "open"
                                            self._children_yang_names.add("open")

                                            self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self._children_name_map["route_refresh"] = "route-refresh"
                                            self._children_yang_names.add("route-refresh")

                                            self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self._children_name_map["total"] = "total"
                                            self._children_yang_names.add("total")

                                            self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self
                                            self._children_name_map["update"] = "update"
                                            self._children_yang_names.add("update")
                                            self._segment_path = lambda: "message-statistics"


                                        class Keepalive(Entity):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                self.yang_name = "keepalive"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "keepalive"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Notification(Entity):
                                            """
                                            Notification
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                self.yang_name = "notification"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "notification"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Open(Entity):
                                            """
                                            Open
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                self.yang_name = "open"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "open"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class RouteRefresh(Entity):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                self.yang_name = "route-refresh"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "route-refresh"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Total(Entity):
                                            """
                                            Total
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                self.yang_name = "total"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "total"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Update(Entity):
                                            """
                                            Update
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                self.yang_name = "update"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "update"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.active_collision = YLeaf(YType.uint32, "active-collision")

                                            self.actives = YLeaf(YType.uint32, "actives")

                                            self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                            self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                            self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                            self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                            self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                            self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                            self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                            self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                            self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                            self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                            self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                            self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                            self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                            self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                            self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                            self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                            self.network_status = YLeaf(YType.uint32, "network-status")

                                            self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                            self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                            self.passives = YLeaf(YType.uint32, "passives")

                                            self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                            self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                            self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                            self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                            self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                            self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                            self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                            self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                            self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                            self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                            self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                            self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                            self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                            self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                            self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                            self._segment_path = lambda: "performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                    class ReceivedNotificationInfo(Entity):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                            self.yang_name = "received-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "received-notification-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "received-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                    class SendNotificationInfo(Entity):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                            self.yang_name = "send-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "send-notification-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "send-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                    class TcpInitSyncDoneTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-done-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TcpInitSyncTimeSpec(Entity):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class NetworkAllRds(Entity):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds, self).__init__()

                                    self.yang_name = "network-all-rds"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-all-rd" : ("network_all_rd", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd)}

                                    self.network_all_rd = YList(self)
                                    self._segment_path = lambda: "network-all-rds"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds, [], name, value)


                                class NetworkAllRd(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: network_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd, self).__init__()

                                        self.yang_name = "network-all-rd"
                                        self.yang_parent_name = "network-all-rds"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"network-rds" : ("network_rds", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds)}
                                        self._child_list_classes = {}

                                        self.network = YLeaf(YType.str, "network")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.network_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                        self.network_rds.parent = self
                                        self._children_name_map["network_rds"] = "network-rds"
                                        self._children_yang_names.add("network-rds")
                                        self._segment_path = lambda: "network-all-rd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd, ['network', 'prefix_length'], name, value)


                                    class NetworkRds(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, self).__init__()

                                            self.yang_name = "network-rds"
                                            self.yang_parent_name = "network-all-rd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"network-rd" : ("network_rd", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd)}

                                            self.network_rd = YList(self)
                                            self._segment_path = lambda: "network-rds"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, [], name, value)


                                        class NetworkRd(Entity):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, self).__init__()

                                                self.yang_name = "network-rd"
                                                self.yang_parent_name = "network-rds"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp)}
                                                self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo)}

                                                self.rd = YLeaf(YType.str, "rd")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.bit = YLeaf(YType.uint16, "bit")

                                                self.flags = YLeaf(YType.uint8, "flags")

                                                self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                self.table_version = YLeaf(YType.uint32, "table-version")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                self.version_age.parent = self
                                                self._children_name_map["version_age"] = "version-age"
                                                self._children_yang_names.add("version-age")

                                                self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self._children_name_map["version_timestamp"] = "version-timestamp"
                                                self._children_yang_names.add("version-timestamp")

                                                self.active_path_element = YList(self)
                                                self.active_process_instance_path = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.local_path_element = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.local_process_instance_path = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self._segment_path = lambda: "network-rd" + "[rd='" + self.rd.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                            class ActivePathElement(Entity):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, self).__init__()

                                                    self.yang_name = "active-path-element"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "active-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ActiveProcessInstancePath(Entity):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, self).__init__()

                                                    self.yang_name = "active-process-instance-path"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "active-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPathElement(Entity):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, self).__init__()

                                                    self.yang_name = "local-path-element"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "local-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalProcessInstancePath(Entity):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, self).__init__()

                                                    self.yang_name = "local-process-instance-path"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "local-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class VersionAge(Entity):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, self).__init__()

                                                    self.yang_name = "version-age"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-age"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                            class VersionTimestamp(Entity):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, self).__init__()

                                                    self.yang_name = "version-timestamp"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NetworkLookupAllRds(Entity):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_lookup_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds, self).__init__()

                                    self.yang_name = "network-lookup-all-rds"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-lookup-all-rd" : ("network_lookup_all_rd", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd)}

                                    self.network_lookup_all_rd = YList(self)
                                    self._segment_path = lambda: "network-lookup-all-rds"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds, [], name, value)


                                class NetworkLookupAllRd(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_lookup_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, self).__init__()

                                        self.yang_name = "network-lookup-all-rd"
                                        self.yang_parent_name = "network-lookup-all-rds"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"network-lookup-rds" : ("network_lookup_rds", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds)}
                                        self._child_list_classes = {}

                                        self.network_prefix = YLeaf(YType.str, "network-prefix")

                                        self.network_lookup_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                        self.network_lookup_rds.parent = self
                                        self._children_name_map["network_lookup_rds"] = "network-lookup-rds"
                                        self._children_yang_names.add("network-lookup-rds")
                                        self._segment_path = lambda: "network-lookup-all-rd" + "[network-prefix='" + self.network_prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, ['network_prefix'], name, value)


                                    class NetworkLookupRds(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_lookup_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, self).__init__()

                                            self.yang_name = "network-lookup-rds"
                                            self.yang_parent_name = "network-lookup-all-rd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"network-lookup-rd" : ("network_lookup_rd", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd)}

                                            self.network_lookup_rd = YList(self)
                                            self._segment_path = lambda: "network-lookup-rds"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, [], name, value)


                                        class NetworkLookupRd(Entity):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, self).__init__()

                                                self.yang_name = "network-lookup-rd"
                                                self.yang_parent_name = "network-lookup-rds"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp)}
                                                self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo)}

                                                self.rd = YLeaf(YType.str, "rd")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.bit = YLeaf(YType.uint16, "bit")

                                                self.flags = YLeaf(YType.uint8, "flags")

                                                self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                self.table_version = YLeaf(YType.uint32, "table-version")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                self.version_age.parent = self
                                                self._children_name_map["version_age"] = "version-age"
                                                self._children_yang_names.add("version-age")

                                                self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self._children_name_map["version_timestamp"] = "version-timestamp"
                                                self._children_yang_names.add("version-timestamp")

                                                self.active_path_element = YList(self)
                                                self.active_process_instance_path = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.local_path_element = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.local_process_instance_path = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self._segment_path = lambda: "network-lookup-rd" + "[rd='" + self.rd.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                            class ActivePathElement(Entity):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, self).__init__()

                                                    self.yang_name = "active-path-element"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "active-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ActiveProcessInstancePath(Entity):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, self).__init__()

                                                    self.yang_name = "active-process-instance-path"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "active-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPathElement(Entity):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, self).__init__()

                                                    self.yang_name = "local-path-element"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "local-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalProcessInstancePath(Entity):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, self).__init__()

                                                    self.yang_name = "local-process-instance-path"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "local-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class VersionAge(Entity):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, self).__init__()

                                                    self.yang_name = "version-age"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-age"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                            class VersionTimestamp(Entity):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, self).__init__()

                                                    self.yang_name = "version-timestamp"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NetworkPrefixes(Entity):
                                """
                                The BGP Network Lookup table
                                
                                .. attribute:: network_prefix
                                
                                	A BGP Network Lookup prefix entry
                                	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes, self).__init__()

                                    self.yang_name = "network-prefixes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-prefix" : ("network_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix)}

                                    self.network_prefix = YList(self)
                                    self._segment_path = lambda: "network-prefixes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes, [], name, value)


                                class NetworkPrefix(Entity):
                                    """
                                    A BGP Network Lookup prefix entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_prefix
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix, self).__init__()

                                        self.yang_name = "network-prefix"
                                        self.yang_parent_name = "network-prefixes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp)}
                                        self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo)}

                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bit = YLeaf(YType.uint16, "bit")

                                        self.flags = YLeaf(YType.uint8, "flags")

                                        self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                        self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                        self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                        self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                        self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                        self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                        self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                        self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                        self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                        self.net_flags = YLeaf(YType.uint32, "net-flags")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                        self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                        self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                        self.network_prefix = YLeaf(YType.str, "network-prefix")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.active_path_element = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.local_path_element = YList(self)
                                        self.local_peers_advertised_to = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self._segment_path = lambda: "network-prefix"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network_prefix', 'num_of_path', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "active-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "active-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "local-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "local-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "local-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Networks(Entity):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks, self).__init__()

                                    self.yang_name = "networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network" : ("network", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network)}

                                    self.network = YList(self)
                                    self._segment_path = lambda: "networks"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks, [], name, value)


                                class Network(Entity):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp)}
                                        self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)}

                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bit = YLeaf(YType.uint16, "bit")

                                        self.flags = YLeaf(YType.uint8, "flags")

                                        self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                        self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                        self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                        self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                        self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                        self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                        self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                        self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                        self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                        self.net_flags = YLeaf(YType.uint32, "net-flags")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                        self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                        self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                        self.network = YLeaf(YType.str, "network")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.active_path_element = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.local_path_element = YList(self)
                                        self.local_peers_advertised_to = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self._segment_path = lambda: "network"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network', 'num_of_path', 'prefix_length', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "active-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "active-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "local-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "local-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "local-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NextHopAddressFamilies(Entity):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                    self.yang_name = "next-hop-address-families"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"next-hop-address-family" : ("next_hop_address_family", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily)}

                                    self.next_hop_address_family = YList(self)
                                    self._segment_path = lambda: "next-hop-address-families"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                class NextHopAddressFamily(Entity):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                        self.yang_name = "next-hop-address-family"
                                        self.yang_parent_name = "next-hop-address-families"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"next-hop-af-vrf-af" : ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf), "next-hop-afs" : ("next_hop_afs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs)}
                                        self._child_list_classes = {}

                                        self.next_hop_af_name = YLeaf(YType.enumeration, "next-hop-af-name")

                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"
                                        self._children_yang_names.add("next-hop-af-vrf-af")

                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self
                                        self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                        self._children_yang_names.add("next-hop-afs")
                                        self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + self.next_hop_af_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                    class NextHopAfVrfAf(Entity):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                            self.yang_name = "next-hop-af-vrf-af"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.critical_trigger_delay = YLeaf(YType.uint32, "critical-trigger-delay")

                                            self.epe_downloaded_version = YLeaf(YType.uint32, "epe-downloaded-version")

                                            self.epe_label_version = YLeaf(YType.uint32, "epe-label-version")

                                            self.epe_standby_version = YLeaf(YType.uint32, "epe-standby-version")

                                            self.epe_table_version = YLeaf(YType.uint32, "epe-table-version")

                                            self.gwaf_name = YLeaf(YType.enumeration, "gwaf-name")

                                            self.nh_nexthop_version = YLeaf(YType.uint32, "nh-nexthop-version")

                                            self.nh_rib_up = YLeaf(YType.boolean, "nh-rib-up")

                                            self.nh_rib_version = YLeaf(YType.uint32, "nh-rib-version")

                                            self.nh_table_id = YLeaf(YType.uint32, "nh-table-id")

                                            self.non_critical_trigger_delay = YLeaf(YType.uint32, "non-critical-trigger-delay")

                                            self.table_active = YLeaf(YType.boolean, "table-active")

                                            self.total_nexthops = YLeaf(YType.uint32, "total-nexthops")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")
                                            self._segment_path = lambda: "next-hop-af-vrf-af"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, ['af_name', 'critical_trigger_delay', 'epe_downloaded_version', 'epe_label_version', 'epe_standby_version', 'epe_table_version', 'gwaf_name', 'nh_nexthop_version', 'nh_rib_up', 'nh_rib_version', 'nh_table_id', 'non_critical_trigger_delay', 'table_active', 'total_nexthops'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "next-hop-af-vrf-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.critical_notf_count = YLeaf(YType.uint32, "critical-notf-count")

                                                self.last_notf_bestpath_changes = YLeaf(YType.uint32, "last-notf-bestpath-changes")

                                                self.last_notf_bestpath_deletes = YLeaf(YType.uint32, "last-notf-bestpath-deletes")

                                                self.nexthops_removed_from_rib = YLeaf(YType.uint32, "nexthops-removed-from-rib")

                                                self.nexthops_resent_to_rib = YLeaf(YType.uint32, "nexthops-resent-to-rib")

                                                self.nexthops_sent_to_rib = YLeaf(YType.uint32, "nexthops-sent-to-rib")

                                                self.nh_batch_finish_calls = YLeaf(YType.uint32, "nh-batch-finish-calls")

                                                self.nh_flush_timer_calls = YLeaf(YType.uint32, "nh-flush-timer-calls")

                                                self.nh_last_a_sync_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-reg-ts")

                                                self.nh_last_a_sync_un_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-un-reg-ts")

                                                self.nh_last_batch_finish_ts = YLeaf(YType.uint32, "nh-last-batch-finish-ts")

                                                self.nh_last_flush_timer_ts = YLeaf(YType.uint32, "nh-last-flush-timer-ts")

                                                self.nh_last_sync_reg_ts = YLeaf(YType.uint32, "nh-last-sync-reg-ts")

                                                self.nh_peak_registrations = YLeaf(YType.uint32, "nh-peak-registrations")

                                                self.nh_pending_registrations = YLeaf(YType.uint32, "nh-pending-registrations")

                                                self.nh_sync_reg_calls = YLeaf(YType.uint32, "nh-sync-reg-calls")

                                                self.nha_sync_reg_calls = YLeaf(YType.uint32, "nha-sync-reg-calls")

                                                self.nha_sync_un_reg_calls = YLeaf(YType.uint32, "nha-sync-un-reg-calls")

                                                self.nhrib_update_calls = YLeaf(YType.uint32, "nhrib-update-calls")

                                                self.nhrib_update_time = YLeaf(YType.uint32, "nhrib-update-time")

                                                self.noncritical_notf_count = YLeaf(YType.uint32, "noncritical-notf-count")

                                                self.rib_sync_registers_failed = YLeaf(YType.uint32, "rib-sync-registers-failed")

                                                self.riba_sync_registers_failed = YLeaf(YType.uint32, "riba-sync-registers-failed")

                                                self.ribnh_reg_failed_for_no_rib_conn = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-rib-conn")

                                                self.ribnh_reg_failed_for_no_tbl_id = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-tbl-id")

                                                self.tunnel_walk_backup_creates = YLeaf(YType.uint32, "tunnel-walk-backup-creates")

                                                self.tunnel_walk_gw_not_found = YLeaf(YType.uint32, "tunnel-walk-gw-not-found")

                                                self.tunnel_walk_nh_not_found = YLeaf(YType.uint32, "tunnel-walk-nh-not-found")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, ['critical_notf_count', 'last_notf_bestpath_changes', 'last_notf_bestpath_deletes', 'nexthops_removed_from_rib', 'nexthops_resent_to_rib', 'nexthops_sent_to_rib', 'nh_batch_finish_calls', 'nh_flush_timer_calls', 'nh_last_a_sync_reg_ts', 'nh_last_a_sync_un_reg_ts', 'nh_last_batch_finish_ts', 'nh_last_flush_timer_ts', 'nh_last_sync_reg_ts', 'nh_peak_registrations', 'nh_pending_registrations', 'nh_sync_reg_calls', 'nha_sync_reg_calls', 'nha_sync_un_reg_calls', 'nhrib_update_calls', 'nhrib_update_time', 'noncritical_notf_count', 'rib_sync_registers_failed', 'riba_sync_registers_failed', 'ribnh_reg_failed_for_no_rib_conn', 'ribnh_reg_failed_for_no_tbl_id', 'tunnel_walk_backup_creates', 'tunnel_walk_gw_not_found', 'tunnel_walk_nh_not_found'], name, value)


                                    class NextHopAfs(Entity):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                            self.yang_name = "next-hop-afs"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"next-hop-af" : ("next_hop_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf)}

                                            self.next_hop_af = YList(self)
                                            self._segment_path = lambda: "next-hop-afs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                        class NextHopAf(Entity):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                self.yang_name = "next-hop-af"
                                                self.yang_parent_name = "next-hop-afs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress), "nexthop-internal-info" : ("nexthop_internal_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)}
                                                self._child_list_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress), "nexthop-gateway-info" : ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.attribute_set = YLeaf(YType.str, "attribute-set")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.nexthop_aigp_metric = YLeaf(YType.uint32, "nexthop-aigp-metric")

                                                self.nexthop_gateway_prefix_connected = YLeaf(YType.boolean, "nexthop-gateway-prefix-connected")

                                                self.nexthop_gateway_prefix_length = YLeaf(YType.uint32, "nexthop-gateway-prefix-length")

                                                self.nexthop_gateway_reachable = YLeaf(YType.boolean, "nexthop-gateway-reachable")

                                                self.nexthop_pending_registration = YLeaf(YType.uint8, "nexthop-pending-registration")

                                                self.nexthop_reference_count = YLeaf(YType.uint32, "nexthop-reference-count")

                                                self.nh_first_hop_if_handle = YLeaf(YType.str, "nh-first-hop-if-handle")

                                                self.nh_reference_count_total = YLeaf(YType.uint32, "nh-reference-count-total")

                                                self.rib_nexthop_id = YLeaf(YType.uint32, "rib-nexthop-id")

                                                self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self._children_name_map["nexthop_address"] = "nexthop-address"
                                                self._children_yang_names.add("nexthop-address")

                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"
                                                self._children_yang_names.add("nexthop-internal-info")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.neighbor_address = YList(self)
                                                self.nexthop_gateway_info = YList(self)
                                                self._segment_path = lambda: "next-hop-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['af_name', 'attribute_set', 'next_hop_address', 'nexthop_aigp_metric', 'nexthop_gateway_prefix_connected', 'nexthop_gateway_prefix_length', 'nexthop_gateway_reachable', 'nexthop_pending_registration', 'nexthop_reference_count', 'nh_first_hop_if_handle', 'nh_reference_count_total', 'rib_nexthop_id'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopAddress(Entity):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                    self.yang_name = "nexthop-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "nexthop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopGatewayInfo(Entity):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:   :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:   :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\:  str
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                    self.yang_name = "nexthop-gateway-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-route" : ("nexthop_route", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)}
                                                    self._child_list_classes = {"nexthop-route-path" : ("nexthop_route_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath)}

                                                    self.critical_events = YLeaf(YType.uint32, "critical-events")

                                                    self.last_event_since = YLeaf(YType.uint32, "last-event-since")

                                                    self.last_event_type = YLeaf(YType.enumeration, "last-event-type")

                                                    self.last_rib_update = YLeaf(YType.uint32, "last-rib-update")

                                                    self.last_update_type = YLeaf(YType.enumeration, "last-update-type")

                                                    self.nexthop_af_invalid_bits = YLeaf(YType.uint16, "nexthop-af-invalid-bits")

                                                    self.nexthop_metric = YLeaf(YType.uint32, "nexthop-metric")

                                                    self.nexthop_mpls_enabled = YLeaf(YType.boolean, "nexthop-mpls-enabled")

                                                    self.nexthop_mpls_interfaces = YLeaf(YType.uint32, "nexthop-mpls-interfaces")

                                                    self.nexthop_mpls_label = YLeaf(YType.uint32, "nexthop-mpls-label")

                                                    self.nexthop_route_path_count = YLeaf(YType.uint32, "nexthop-route-path-count")

                                                    self.nexthop_route_prefix_length = YLeaf(YType.uint8, "nexthop-route-prefix-length")

                                                    self.nexthop_route_protocol = YLeaf(YType.str, "nexthop-route-protocol")

                                                    self.nexthop_status = YLeaf(YType.uint8, "nexthop-status")

                                                    self.nexthop_tableid = YLeaf(YType.uint64, "nexthop-tableid")

                                                    self.non_critical_events = YLeaf(YType.uint32, "non-critical-events")

                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self._children_name_map["nexthop_route"] = "nexthop-route"
                                                    self._children_yang_names.add("nexthop-route")

                                                    self.nexthop_route_path = YList(self)
                                                    self._segment_path = lambda: "nexthop-gateway-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, ['critical_events', 'last_event_since', 'last_event_type', 'last_rib_update', 'last_update_type', 'nexthop_af_invalid_bits', 'nexthop_metric', 'nexthop_mpls_enabled', 'nexthop_mpls_interfaces', 'nexthop_mpls_label', 'nexthop_route_path_count', 'nexthop_route_prefix_length', 'nexthop_route_protocol', 'nexthop_status', 'nexthop_tableid', 'non_critical_events'], name, value)


                                                class NexthopRoute(Entity):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                        self.yang_name = "nexthop-route"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-route"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopRoutePath(Entity):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                        self.yang_name = "nexthop-route-path"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopInternalInfo(Entity):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                    self.yang_name = "nexthop-internal-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)}
                                                    self._child_list_classes = {"nexthop-gateway-internal-info" : ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo), "nexthop-metrice" : ("nexthop_metrice", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice), "nexthop-refcount" : ("nexthop_refcount", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)}

                                                    self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                    self.nexthop_af_user_bits = YLeaf(YType.uint32, "nexthop-af-user-bits")

                                                    self.nexthop_flags = YLeaf(YType.uint32, "nexthop-flags")

                                                    self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                    self.nexthop_if_handle = YLeaf(YType.uint32, "nexthop-if-handle")

                                                    self.nexthop_label = YLeaf(YType.uint32, "nexthop-label")

                                                    self.nexthop_version = YLeaf(YType.uint32, "nexthop-version")

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"
                                                    self._children_yang_names.add("nexthop-address")

                                                    self.nexthop_gateway_internal_info = YList(self)
                                                    self.nexthop_metrice = YList(self)
                                                    self.nexthop_refcount = YList(self)
                                                    self._segment_path = lambda: "nexthop-internal-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, ['gateway_flags', 'nexthop_af_user_bits', 'nexthop_flags', 'nexthop_id', 'nexthop_if_handle', 'nexthop_label', 'nexthop_version'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopGatewayInternalInfo(Entity):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:   :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-internal-info"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                        self.registration_since = YLeaf(YType.uint32, "registration-since")

                                                        self.registration_type = YLeaf(YType.enumeration, "registration-type")
                                                        self._segment_path = lambda: "nexthop-gateway-internal-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, ['gateway_flags', 'registration_since', 'registration_type'], name, value)


                                                class NexthopMetrice(Entity):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                        self.yang_name = "nexthop-metrice"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nexthop-metrice"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, ['entry'], name, value)


                                                class NexthopRefcount(Entity):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                        self.yang_name = "nexthop-refcount"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nexthop-refcount"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, ['entry'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                            class PathLabeledTable(Entity):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable, self).__init__()

                                    self.yang_name = "path-labeled-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-labeled-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-labeled-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PathTable(Entity):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable, self).__init__()

                                    self.yang_name = "path-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PathUsedTable(Entity):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable, self).__init__()

                                    self.yang_name = "path-used-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-used-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-used-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class Policies(Entity):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies, self).__init__()

                                    self.yang_name = "policies"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"policy" : ("policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy)}

                                    self.policy = YList(self)
                                    self._segment_path = lambda: "policies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies, [], name, value)


                                class Policy(Entity):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy, self).__init__()

                                        self.yang_name = "policy"
                                        self.yang_parent_name = "policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                        self._children_yang_names.add("attributes-after-policy-out")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                        self._children_yang_names.add("path-info-after-policy-in")

                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                        self._children_yang_names.add("path-info-after-policy-out")
                                        self._segment_path = lambda: "policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy, ['af_name', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class AttributesAfterPolicyOut(Entity):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                            self.yang_name = "attributes-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-out"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInfoAfterPolicyIn(Entity):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                            self.yang_name = "path-info-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInfoAfterPolicyOut(Entity):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                            self.yang_name = "path-info-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-out"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixFilters(Entity):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters, self).__init__()

                                    self.yang_name = "prefix-filters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"prefix-filter" : ("prefix_filter", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter)}

                                    self.prefix_filter = YList(self)
                                    self._segment_path = lambda: "prefix-filters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters, [], name, value)


                                class PrefixFilter(Entity):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                        self.yang_name = "prefix-filter"
                                        self.yang_parent_name = "prefix-filters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr), "prefix-list-info" : ("prefix_list_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo)}
                                        self._child_list_classes = {}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self
                                        self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                        self._children_yang_names.add("prefix-list-info")
                                        self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', 'af_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PrefixListInfo(Entity):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                            self.yang_name = "prefix-list-info"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-pfxlst" : ("bgp_pfxlst", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst)}

                                            self.bgp_pfxlst = YList(self)
                                            self._segment_path = lambda: "prefix-list-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                        class BgpPfxlst(Entity):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                self.yang_name = "bgp-pfxlst"
                                                self.yang_parent_name = "prefix-list-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix)}
                                                self._child_list_classes = {}

                                                self.is_prefix_grant = YLeaf(YType.boolean, "is-prefix-grant")

                                                self.max_prefix_length = YLeaf(YType.uint8, "max-prefix-length")

                                                self.min_prefix_length = YLeaf(YType.uint8, "min-prefix-length")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")
                                                self._segment_path = lambda: "bgp-pfxlst"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, ['is_prefix_grant', 'max_prefix_length', 'min_prefix_length', 'sequence_number'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "bgp-pfxlst"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RpcSets(Entity):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets, self).__init__()

                                    self.yang_name = "rpc-sets"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"rpc-set" : ("rpc_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet)}

                                    self.rpc_set = YList(self)
                                    self._segment_path = lambda: "rpc-sets"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets, [], name, value)


                                class RpcSet(Entity):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  <key>
                                    
                                    	Nexthop set index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                        self.yang_name = "rpc-set"
                                        self.yang_parent_name = "rpc-sets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop)}

                                        self.rpc_set_index = YLeaf(YType.int32, "rpc-set-index")

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.next_hop_xr = YLeaf(YType.uint32, "next-hop-xr")

                                        self.ref_count = YLeaf(YType.uint32, "ref-count")

                                        self.next_hop = YList(self)
                                        self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + self.rpc_set_index.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', 'label', 'next_hop_xr', 'ref_count'], name, value)


                                    class NextHop(Entity):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                            self.yang_name = "next-hop"
                                            self.yang_parent_name = "rpc-set"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "next-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RtSetCounters(Entity):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters, self).__init__()

                                    self.yang_name = "rt-set-counters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"rt-set-counter" : ("rt_set_counter", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter)}

                                    self.rt_set_counter = YList(self)
                                    self._segment_path = lambda: "rt-set-counters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters, [], name, value)


                                class RtSetCounter(Entity):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  <key>
                                    
                                    	RTSet ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                        self.yang_name = "rt-set-counter"
                                        self.yang_parent_name = "rt-set-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-target-set" : ("route_target_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet)}
                                        self._child_list_classes = {}

                                        self.rt_set_id = YLeaf(YType.int32, "rt-set-id")

                                        self.route_target_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self
                                        self._children_name_map["route_target_set"] = "route-target-set"
                                        self._children_yang_names.add("route-target-set")
                                        self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + self.rt_set_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                    class RouteTargetSet(Entity):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                            self.yang_name = "route-target-set"
                                            self.yang_parent_name = "rt-set-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"rt-set" : ("rt_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet)}

                                            self.rt_set_id = YLeaf(YType.uint32, "rt-set-id")

                                            self.rt_set_len = YLeaf(YType.uint8, "rt-set-len")

                                            self.rt_set_net_count = YLeaf(YType.uint32, "rt-set-net-count")

                                            self.rt_set = YList(self)
                                            self._segment_path = lambda: "route-target-set"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, ['rt_set_id', 'rt_set_len', 'rt_set_net_count'], name, value)


                                        class RtSet(Entity):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                self.yang_name = "rt-set"
                                                self.yang_parent_name = "route-target-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "rt-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, ['entry'], name, value)


                            class SourcedNetworks(Entity):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks, self).__init__()

                                    self.yang_name = "sourced-networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork)}

                                    self.sourced_network = YList(self)
                                    self._segment_path = lambda: "sourced-networks"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks, [], name, value)


                                class SourcedNetwork(Entity):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  <key>
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\:  bool
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                        self.yang_name = "sourced-network"
                                        self.yang_parent_name = "sourced-networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sourced-prefix" : ("sourced_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix)}
                                        self._child_list_classes = {}

                                        self.network = YLeaf(YType.str, "network")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.is_backdoor = YLeaf(YType.boolean, "is-backdoor")

                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self
                                        self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                        self._children_yang_names.add("sourced-prefix")
                                        self._segment_path = lambda: "sourced-network" + "[network='" + self.network.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', 'af_name', 'is_backdoor'], name, value)


                                    class SourcedPrefix(Entity):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                            self.yang_name = "sourced-prefix"
                                            self.yang_parent_name = "sourced-network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "sourced-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "sourced-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class UpdateGenerationAddressFamily(Entity):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\:  bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                    self.yang_name = "update-generation-address-family"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics)}
                                    self._child_list_classes = {}

                                    self.configured_update_limit_af = YLeaf(YType.uint32, "configured-update-limit-af")

                                    self.configured_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "configured-update-limit-sub-group-ibgp")

                                    self.configured_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "configured-update-limit-subgrp-ebgp")

                                    self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                                    self.current_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "current-update-limit-sub-group-ibgp")

                                    self.current_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "current-update-limit-subgrp-ebgp")

                                    self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                    self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                    self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                    self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                    self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                    self.table_neighbor_count = YLeaf(YType.uint32, "table-neighbor-count")

                                    self.table_refresh_sub_group_count = YLeaf(YType.uint32, "table-refresh-sub-group-count")

                                    self.table_refresh_sub_group_throttled_count = YLeaf(YType.uint32, "table-refresh-sub-group-throttled-count")

                                    self.table_sub_group_throttled_count = YLeaf(YType.uint32, "table-sub-group-throttled-count")

                                    self.table_update_group_count = YLeaf(YType.uint32, "table-update-group-count")

                                    self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                    self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                    self.update_min_neighbor_version = YLeaf(YType.uint32, "update-min-neighbor-version")

                                    self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                    self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                    self.update_rib_version = YLeaf(YType.uint32, "update-rib-version")

                                    self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                    self.update_table_filter_group_count = YLeaf(YType.uint32, "update-table-filter-group-count")

                                    self.update_table_sub_group_count = YLeaf(YType.uint32, "update-table-sub-group-count")

                                    self.update_table_vrf_name = YLeaf(YType.str, "update-table-vrf-name")

                                    self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                    self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")

                                    self.update_vrf_rd_version = YLeaf(YType.uint32, "update-vrf-rd-version")

                                    self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                    self.update_vrfaf_name = YLeaf(YType.uint32, "update-vrfaf-name")

                                    self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self._children_name_map["update_statistics"] = "update-statistics"
                                    self._children_yang_names.add("update-statistics")
                                    self._segment_path = lambda: "update-generation-address-family"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, ['configured_update_limit_af', 'configured_update_limit_sub_group_ibgp', 'configured_update_limit_subgrp_ebgp', 'current_update_limit_af', 'current_update_limit_sub_group_ibgp', 'current_update_limit_subgrp_ebgp', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'table_neighbor_count', 'table_refresh_sub_group_count', 'table_refresh_sub_group_throttled_count', 'table_sub_group_throttled_count', 'table_update_group_count', 'update_group_af_name', 'update_main_table_version', 'update_min_neighbor_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_rib_version', 'update_sub_group_count', 'update_table_filter_group_count', 'update_table_sub_group_count', 'update_table_vrf_name', 'update_throttled', 'update_update_group_count', 'update_vrf_rd_version', 'update_vrf_table_rib_version', 'update_vrfaf_name'], name, value)


                                class UpdateStatistics(Entity):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                        self.yang_name = "update-statistics"
                                        self.yang_parent_name = "update-generation-address-family"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                        self._child_list_classes = {}

                                        self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                        self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                        self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                        self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                        self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                        self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                        self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                        self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                        self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                        self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                        self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                        self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                        self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                        self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                        self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                        self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                        self._children_yang_names.add("last-update-cleared-timestamp")

                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                        self._children_yang_names.add("last-update-discard-timestamp")

                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                        self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                        self._children_yang_names.add("last-update-recovery-timestamp")

                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                        self._children_yang_names.add("last-update-throttle-timestamp")
                                        self._segment_path = lambda: "update-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                    class LastUpdateClearedTimestamp(Entity):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                            self.yang_name = "last-update-cleared-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-cleared-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateDiscardTimestamp(Entity):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                            self.yang_name = "last-update-discard-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-discard-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                            self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateRecoveryTimestamp(Entity):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                            self.yang_name = "last-update-recovery-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-recovery-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateThrottleTimestamp(Entity):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                            self.yang_name = "last-update-throttle-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-throttle-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationFilterGroups(Entity):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                    self.yang_name = "update-generation-filter-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-filter-group" : ("update_generation_filter_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup)}

                                    self.update_generation_filter_group = YList(self)
                                    self._segment_path = lambda: "update-generation-filter-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                class UpdateGenerationFilterGroup(Entity):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                        self.yang_name = "update-generation-filter-group"
                                        self.yang_parent_name = "update-generation-filter-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.parent_filter_group_index = YLeaf(YType.uint32, "parent-filter-group-index")

                                        self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                        self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")
                                        self._segment_path = lambda: "update-generation-filter-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['filter_group_index', 'neighbor_count', 'parent_filter_group_index', 'parent_sub_group_id', 'parent_sub_group_index', 'process_id', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_filter_group_index', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_vrf_name'], name, value)


                            class UpdateGenerationNeighbors(Entity):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                    self.yang_name = "update-generation-neighbors"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-neighbor" : ("update_generation_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor)}

                                    self.update_generation_neighbor = YList(self)
                                    self._segment_path = lambda: "update-generation-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                class UpdateGenerationNeighbor(Entity):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                        self.yang_name = "update-generation-neighbor"
                                        self.yang_parent_name = "update-generation-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-default-originate-timestamp" : ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp), "first-update-queued-timestamp" : ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp), "first-update-write-timestamp" : ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp), "last-default-originate-timestamp" : ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp), "last-filter-group-add-timestamp" : ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp), "last-filter-group-remove-timestamp" : ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp), "last-refresh-update-queued-timestamp" : ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp), "last-refresh-update-write-timestamp" : ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp), "last-sub-group-add-timestamp" : ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp), "last-sub-group-remove-timestamp" : ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp), "last-update-group-expiry-timestamp" : ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp), "last-update-group-start-timestamp" : ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp), "last-update-write-timestamp" : ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.ack_version = YLeaf(YType.uint32, "ack-version")

                                        self.current_update_group_af_name = YLeaf(YType.enumeration, "current-update-group-af-name")

                                        self.default_originate_internal_context = YLeaf(YType.int32, "default-originate-internal-context")

                                        self.default_originate_state = YLeaf(YType.int32, "default-originate-state")

                                        self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                        self.inbound_refresh_count = YLeaf(YType.uint32, "inbound-refresh-count")

                                        self.is_eor_outstanding = YLeaf(YType.boolean, "is-eor-outstanding")

                                        self.is_update_group_timer_running = YLeaf(YType.boolean, "is-update-group-timer-running")

                                        self.last_default_originate_age = YLeaf(YType.uint32, "last-default-originate-age")

                                        self.last_refresh_update_queued_age = YLeaf(YType.uint32, "last-refresh-update-queued-age")

                                        self.last_refresh_update_write_age = YLeaf(YType.uint32, "last-refresh-update-write-age")

                                        self.last_update_group_af_name = YLeaf(YType.enumeration, "last-update-group-af-name")

                                        self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                        self.last_update_write_age = YLeaf(YType.uint32, "last-update-write-age")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                        self.outbound_refresh_count = YLeaf(YType.uint32, "outbound-refresh-count")

                                        self.outstanding_version_count = YLeaf(YType.uint32, "outstanding-version-count")

                                        self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_ack_version = YLeaf(YType.uint32, "refresh-ack-version")

                                        self.refresh_filter_group_index = YLeaf(YType.uint32, "refresh-filter-group-index")

                                        self.refresh_next_resume_version = YLeaf(YType.uint32, "refresh-next-resume-version")

                                        self.refresh_pending_target_version = YLeaf(YType.uint32, "refresh-pending-target-version")

                                        self.refresh_requested_target_version = YLeaf(YType.uint32, "refresh-requested-target-version")

                                        self.refresh_sub_group_id = YLeaf(YType.uint32, "refresh-sub-group-id")

                                        self.refresh_sub_group_index = YLeaf(YType.uint32, "refresh-sub-group-index")

                                        self.refresh_update_out_queue_messages = YLeaf(YType.uint32, "refresh-update-out-queue-messages")

                                        self.refresh_update_out_queue_size = YLeaf(YType.uint32, "refresh-update-out-queue-size")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.synced_ack_version = YLeaf(YType.uint32, "synced-ack-version")

                                        self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                        self.update_filter_group_messages = YLeaf(YType.uint32, "update-filter-group-messages")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                        self.update_refresh_version = YLeaf(YType.uint32, "update-refresh-version")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"
                                        self._children_yang_names.add("first-default-originate-timestamp")

                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"
                                        self._children_yang_names.add("first-update-queued-timestamp")

                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"
                                        self._children_yang_names.add("first-update-write-timestamp")

                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"
                                        self._children_yang_names.add("last-default-originate-timestamp")

                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"
                                        self._children_yang_names.add("last-filter-group-add-timestamp")

                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"
                                        self._children_yang_names.add("last-filter-group-remove-timestamp")

                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"
                                        self._children_yang_names.add("last-refresh-update-queued-timestamp")

                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"
                                        self._children_yang_names.add("last-refresh-update-write-timestamp")

                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"
                                        self._children_yang_names.add("last-sub-group-add-timestamp")

                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"
                                        self._children_yang_names.add("last-sub-group-remove-timestamp")

                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"
                                        self._children_yang_names.add("last-update-group-expiry-timestamp")

                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"
                                        self._children_yang_names.add("last-update-group-start-timestamp")

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                        self._children_yang_names.add("last-update-queued-timestamp")

                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"
                                        self._children_yang_names.add("last-update-write-timestamp")

                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                        self._children_yang_names.add("update-neighbor-address")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['ack_version', 'current_update_group_af_name', 'default_originate_internal_context', 'default_originate_state', 'filter_group_index', 'inbound_refresh_count', 'is_eor_outstanding', 'is_update_group_timer_running', 'last_default_originate_age', 'last_refresh_update_queued_age', 'last_refresh_update_write_age', 'last_update_group_af_name', 'last_update_queued_age', 'last_update_write_age', 'neighbor_address', 'next_resume_version', 'outbound_refresh_count', 'outstanding_version_count', 'pending_target_version', 'process_id', 'refresh_ack_version', 'refresh_filter_group_index', 'refresh_next_resume_version', 'refresh_pending_target_version', 'refresh_requested_target_version', 'refresh_sub_group_id', 'refresh_sub_group_index', 'refresh_update_out_queue_messages', 'refresh_update_out_queue_size', 'sub_group_id', 'sub_group_index', 'sub_group_index_xr', 'synced_ack_version', 'update_filter_group_index', 'update_filter_group_messages', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_refresh_version', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                    class FirstDefaultOriginateTimestamp(Entity):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "first-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-default-originate-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateQueuedTimestamp(Entity):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "first-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWriteTimestamp(Entity):
                                        """
                                        First update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "first-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastDefaultOriginateTimestamp(Entity):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "last-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-default-originate-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastFilterGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-filter-group-add-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastFilterGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-filter-group-remove-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRefreshUpdateQueuedTimestamp(Entity):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-refresh-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRefreshUpdateWriteTimestamp(Entity):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-refresh-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastSubGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-sub-group-add-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastSubGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-sub-group-remove-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateGroupExpiryTimestamp(Entity):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-group-expiry-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateGroupStartTimestamp(Entity):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-start-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-group-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWriteTimestamp(Entity):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateNeighborAddress(Entity):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                            self.yang_name = "update-neighbor-address"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "update-neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationSubGroups(Entity):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                    self.yang_name = "update-generation-sub-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-sub-group" : ("update_generation_sub_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup)}

                                    self.update_generation_sub_group = YList(self)
                                    self._segment_path = lambda: "update-generation-sub-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                class UpdateGenerationSubGroup(Entity):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                        self.yang_name = "update-generation-sub-group"
                                        self.yang_parent_name = "update-generation-sub-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"creation-timestamp" : ("creation_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp), "first-update-walk-end-timestamp" : ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp), "first-update-walk-start-timestamp" : ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp), "last-merge-timestamp" : ("last_merge_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp), "last-update-walk-end-timestamp" : ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp), "last-update-walk-start-timestamp" : ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.configured_update_limit_sub_group = YLeaf(YType.uint32, "configured-update-limit-sub-group")

                                        self.current_update_limit_sub_group = YLeaf(YType.uint32, "current-update-limit-sub-group")

                                        self.eo_r_attempted = YLeaf(YType.boolean, "eo-r-attempted")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.io_write_event_pending = YLeaf(YType.boolean, "io-write-event-pending")

                                        self.last_merged_sub_group_index = YLeaf(YType.uint32, "last-merged-sub-group-index")

                                        self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                        self.last_update_walk_end_age = YLeaf(YType.uint32, "last-update-walk-end-age")

                                        self.merge_count = YLeaf(YType.uint32, "merge-count")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                        self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                        self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                        self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                        self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.update_default_route_sent = YLeaf(YType.boolean, "update-default-route-sent")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self._children_name_map["creation_timestamp"] = "creation-timestamp"
                                        self._children_yang_names.add("creation-timestamp")

                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"
                                        self._children_yang_names.add("first-update-walk-end-timestamp")

                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"
                                        self._children_yang_names.add("first-update-walk-start-timestamp")

                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"
                                        self._children_yang_names.add("last-merge-timestamp")

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                        self._children_yang_names.add("last-update-queued-timestamp")

                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"
                                        self._children_yang_names.add("last-update-walk-end-timestamp")

                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"
                                        self._children_yang_names.add("last-update-walk-start-timestamp")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-sub-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['configured_update_limit_sub_group', 'current_update_limit_sub_group', 'eo_r_attempted', 'filter_group_count', 'io_write_event_pending', 'last_merged_sub_group_index', 'last_update_queued_age', 'last_update_walk_end_age', 'merge_count', 'neighbor_count', 'next_resume_version', 'nsr_version', 'parent_sub_group_id', 'parent_sub_group_index', 'pending_target_version', 'process_id', 'refresh_sub_group_count', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_default_route_sent', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_throttled', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                    class CreationTimestamp(Entity):
                                        """
                                        Creation time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                            self.yang_name = "creation-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "creation-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWalkEndTimestamp(Entity):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-walk-end-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWalkStartTimestamp(Entity):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-walk-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastMergeTimestamp(Entity):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                            self.yang_name = "last-merge-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-merge-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWalkEndTimestamp(Entity):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-walk-end-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWalkStartTimestamp(Entity):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-walk-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationUpdateGroups(Entity):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                    self.yang_name = "update-generation-update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-update-group" : ("update_generation_update_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup)}

                                    self.update_generation_update_group = YList(self)
                                    self._segment_path = lambda: "update-generation-update-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                class UpdateGenerationUpdateGroup(Entity):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  <key>
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                        self.yang_name = "update-generation-update-group"
                                        self.yang_parent_name = "update-generation-update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-timer-delay-value" : ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue), "last-update-timer-expiry-timestamp" : ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp), "last-update-timer-remaining-value" : ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue), "last-update-timer-start-timestamp" : ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp), "last-update-timer-stop-timestamp" : ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.is_permanent = YLeaf(YType.boolean, "is-permanent")

                                        self.is_update_timer_running = YLeaf(YType.boolean, "is-update-timer-running")

                                        self.last_update_timer_expiry_age = YLeaf(YType.uint32, "last-update-timer-expiry-age")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.neighbor_leaving_count = YLeaf(YType.uint32, "neighbor-leaving-count")

                                        self.neighbor_session_af_name = YLeaf(YType.uint8, "neighbor-session-af-name")

                                        self.perm_pelem_allowed = YLeaf(YType.uint32, "perm-pelem-allowed")

                                        self.perm_pelem_encountered = YLeaf(YType.uint32, "perm-pelem-encountered")

                                        self.perm_pelem_exp_wdr = YLeaf(YType.uint32, "perm-pelem-exp-wdr")

                                        self.perm_pelem_not_allowed = YLeaf(YType.uint32, "perm-pelem-not-allowed")

                                        self.perm_pelem_spur_wdr = YLeaf(YType.uint32, "perm-pelem-spur-wdr")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                        self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                        self.update_generation_recovery_pending = YLeaf(YType.boolean, "update-generation-recovery-pending")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_flags2 = YLeaf(YType.uint32, "update-group-flags2")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"
                                        self._children_yang_names.add("last-update-timer-delay-value")

                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"
                                        self._children_yang_names.add("last-update-timer-expiry-timestamp")

                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"
                                        self._children_yang_names.add("last-update-timer-remaining-value")

                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"
                                        self._children_yang_names.add("last-update-timer-start-timestamp")

                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"
                                        self._children_yang_names.add("last-update-timer-stop-timestamp")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + self.update_group_index.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', 'filter_group_count', 'is_permanent', 'is_update_timer_running', 'last_update_timer_expiry_age', 'neighbor_count', 'neighbor_leaving_count', 'neighbor_session_af_name', 'perm_pelem_allowed', 'perm_pelem_encountered', 'perm_pelem_exp_wdr', 'perm_pelem_not_allowed', 'perm_pelem_spur_wdr', 'process_id', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_generation_recovery_pending', 'update_group_af_name', 'update_group_flags2', 'update_group_index_xr', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_vrf_name'], name, value)


                                    class LastUpdateTimerDelayValue(Entity):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                            self.yang_name = "last-update-timer-delay-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-delay-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerExpiryTimestamp(Entity):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-expiry-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerRemainingValue(Entity):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                            self.yang_name = "last-update-timer-remaining-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-remaining-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerStartTimestamp(Entity):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-start-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerStopTimestamp(Entity):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-stop-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-stop-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGroups(Entity):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups, self).__init__()

                                    self.yang_name = "update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-group" : ("update_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup)}

                                    self.update_group = YList(self)
                                    self._segment_path = lambda: "update-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups, [], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\:  bool
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\:  str
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\:  bool
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\:  bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor), "update-sub-group" : ("update_sub_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup)}

                                        self.accepts_legacy_pe_rt_route = YLeaf(YType.boolean, "accepts-legacy-pe-rt-route")

                                        self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                        self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                        self.as_override = YLeaf(YType.boolean, "as-override")

                                        self.desync_count = YLeaf(YType.uint32, "desync-count")

                                        self.disable_def_vrf_imp_advertisement = YLeaf(YType.boolean, "disable-def-vrf-imp-advertisement")

                                        self.disable_native_advertisement = YLeaf(YType.boolean, "disable-native-advertisement")

                                        self.disable_vrf_re_imp_advertisement = YLeaf(YType.boolean, "disable-vrf-re-imp-advertisement")

                                        self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                        self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                        self.ext_nh_encoding = YLeaf(YType.boolean, "ext-nh-encoding")

                                        self.filter_group_id = YLeaf(YType.int32, "filter-group-id")

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")

                                        self.has_orf_receive_capability = YLeaf(YType.boolean, "has-orf-receive-capability")

                                        self.is4_byte_as_peer = YLeaf(YType.boolean, "is4-byte-as-peer")

                                        self.is_addpath_capable = YLeaf(YType.boolean, "is-addpath-capable")

                                        self.is_adv_capable = YLeaf(YType.boolean, "is-adv-capable")

                                        self.is_adv_perm_net_capable = YLeaf(YType.boolean, "is-adv-perm-net-capable")

                                        self.is_adv_reorg_capable = YLeaf(YType.boolean, "is-adv-reorg-capable")

                                        self.is_aigp_capable = YLeaf(YType.boolean, "is-aigp-capable")

                                        self.is_aigp_cost_community_capable = YLeaf(YType.boolean, "is-aigp-cost-community-capable")

                                        self.is_aigp_med_capable = YLeaf(YType.boolean, "is-aigp-med-capable")

                                        self.is_client_reflection_disabled = YLeaf(YType.boolean, "is-client-reflection-disabled")

                                        self.is_common_admin_peers = YLeaf(YType.boolean, "is-common-admin-peers")

                                        self.is_directly_connected_ebgp_v6_peers = YLeaf(YType.boolean, "is-directly-connected-ebgp-v6-peers")

                                        self.is_internal_peers = YLeaf(YType.boolean, "is-internal-peers")

                                        self.is_labeled_afi_enabled = YLeaf(YType.boolean, "is-labeled-afi-enabled")

                                        self.is_llgr_capable = YLeaf(YType.boolean, "is-llgr-capable")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_route_reflector_client = YLeaf(YType.boolean, "is-route-reflector-client")

                                        self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                        self.is_unlabeled_afi_enabled = YLeaf(YType.boolean, "is-unlabeled-afi-enabled")

                                        self.local_as = YLeaf(YType.uint32, "local-as")

                                        self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                        self.minimum_advertisement_interval = YLeaf(YType.uint32, "minimum-advertisement-interval")

                                        self.minimum_advertisement_interval_msecs = YLeaf(YType.uint32, "minimum-advertisement-interval-msecs")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.refresh_subgrp_count = YLeaf(YType.uint32, "refresh-subgrp-count")

                                        self.remote_as = YLeaf(YType.uint32, "remote-as")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.session_af_name = YLeaf(YType.uint8, "session-af-name")

                                        self.should_remove_private_a_ss = YLeaf(YType.boolean, "should-remove-private-a-ss")

                                        self.should_remove_private_as_ent_path = YLeaf(YType.boolean, "should-remove-private-as-ent-path")

                                        self.should_send_communities = YLeaf(YType.boolean, "should-send-communities")

                                        self.should_send_ext_communities = YLeaf(YType.boolean, "should-send-ext-communities")

                                        self.should_send_gshut_community = YLeaf(YType.boolean, "should-send-gshut-community")

                                        self.should_send_stitching_rt = YLeaf(YType.boolean, "should-send-stitching-rt")

                                        self.soo_value = YLeaf(YType.str, "soo-value")

                                        self.split_horizon = YLeaf(YType.boolean, "split-horizon")

                                        self.subgrp_merge_count = YLeaf(YType.uint32, "subgrp-merge-count")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_id = YLeaf(YType.int32, "update-group-id")

                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                        self.updates_formatted = YLeaf(YType.uint32, "updates-formatted")

                                        self.updates_replicated = YLeaf(YType.uint32, "updates-replicated")

                                        self.updgrp_cluster_id = YLeaf(YType.uint32, "updgrp-cluster-id")

                                        self.updgrp_cluster_type = YLeaf(YType.uint8, "updgrp-cluster-type")

                                        self.use_next_hop_self = YLeaf(YType.boolean, "use-next-hop-self")

                                        self.use_next_hop_unchanged_mpath = YLeaf(YType.boolean, "use-next-hop-unchanged-mpath")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.neighbor = YList(self)
                                        self.update_sub_group = YList(self)
                                        self._segment_path = lambda: "update-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, ['accepts_legacy_pe_rt_route', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'as_override', 'desync_count', 'disable_def_vrf_imp_advertisement', 'disable_native_advertisement', 'disable_vrf_re_imp_advertisement', 'enable_label_stack', 'encapsulation_type', 'ext_nh_encoding', 'filter_group_id', 'gshut_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends', 'has_orf_receive_capability', 'is4_byte_as_peer', 'is_addpath_capable', 'is_adv_capable', 'is_adv_perm_net_capable', 'is_adv_reorg_capable', 'is_aigp_capable', 'is_aigp_cost_community_capable', 'is_aigp_med_capable', 'is_client_reflection_disabled', 'is_common_admin_peers', 'is_directly_connected_ebgp_v6_peers', 'is_internal_peers', 'is_labeled_afi_enabled', 'is_llgr_capable', 'is_orr_root_address_configured', 'is_route_reflector_client', 'is_send_mcast_attr_enabled', 'is_unlabeled_afi_enabled', 'local_as', 'local_as_replace_as', 'minimum_advertisement_interval', 'minimum_advertisement_interval_msecs', 'orr_group_index', 'orr_group_name', 'process_instance_id', 'refresh_subgrp_count', 'remote_as', 'route_policy_out', 'session_af_name', 'should_remove_private_a_ss', 'should_remove_private_as_ent_path', 'should_send_communities', 'should_send_ext_communities', 'should_send_gshut_community', 'should_send_stitching_rt', 'soo_value', 'split_horizon', 'subgrp_merge_count', 'update_group_af_name', 'update_group_id', 'update_group_number', 'updates_formatted', 'updates_replicated', 'updgrp_cluster_id', 'updgrp_cluster_type', 'use_next_hop_self', 'use_next_hop_unchanged_mpath'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                            self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                            self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                            self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                            self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                            self.updgen_timer_process_time = YLeaf(YType.uint64, "updgen-timer-process-time")

                                            self.updgen_timer_start_time = YLeaf(YType.uint64, "updgen-timer-start-time")

                                            self.updgen_timer_stop_time = YLeaf(YType.uint64, "updgen-timer-stop-time")
                                            self._segment_path = lambda: "performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, ['update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'updgen_timer_process_time', 'updgen_timer_start_time', 'updgen_timer_stop_time'], name, value)


                                    class UpdateSubGroup(Entity):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                            self.yang_name = "update-sub-group"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor), "update-filter-group" : ("update_filter_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)}

                                            self.filter_group = YLeaf(YType.uint16, "filter-group")

                                            self.update_sub_group_number = YLeaf(YType.uint32, "update-sub-group-number")

                                            self.wait_for_eo_rs = YLeaf(YType.boolean, "wait-for-eo-rs")

                                            self.neighbor = YList(self)
                                            self.update_filter_group = YList(self)
                                            self._segment_path = lambda: "update-sub-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, ['filter_group', 'update_sub_group_number', 'wait_for_eo_rs'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class UpdateFilterGroup(Entity):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                self.yang_name = "update-filter-group"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity), "neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor)}

                                                self.fgroup_advertised_prefixes = YLeaf(YType.uint32, "fgroup-advertised-prefixes")

                                                self.fgroup_created_message_elements = YLeaf(YType.uint32, "fgroup-created-message-elements")

                                                self.fgroup_deleted_message_elements = YLeaf(YType.uint32, "fgroup-deleted-message-elements")

                                                self.fgroup_flags = YLeaf(YType.uint8, "fgroup-flags")

                                                self.fgroup_neighbors = YLeaf(YType.uint16, "fgroup-neighbors")

                                                self.fgroup_queued_message_elements = YLeaf(YType.uint32, "fgroup-queued-message-elements")

                                                self.fgroup_skipped_prefixes = YLeaf(YType.uint32, "fgroup-skipped-prefixes")

                                                self.fgroup_suppressed_prefixes = YLeaf(YType.uint32, "fgroup-suppressed-prefixes")

                                                self.fgroup_total_advertised_prefixes = YLeaf(YType.uint32, "fgroup-total-advertised-prefixes")

                                                self.fgroup_total_non_optimised_prefixes = YLeaf(YType.uint32, "fgroup-total-non-optimised-prefixes")

                                                self.fgroup_total_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-total-withdrawn-prefixes")

                                                self.fgroup_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-withdrawn-prefixes")

                                                self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                self.rts = YLeaf(YType.uint32, "rts")

                                                self.update_filter_group_number = YLeaf(YType.uint32, "update-filter-group-number")

                                                self.extended_community = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-filter-group"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, ['fgroup_advertised_prefixes', 'fgroup_created_message_elements', 'fgroup_deleted_message_elements', 'fgroup_flags', 'fgroup_neighbors', 'fgroup_queued_message_elements', 'fgroup_skipped_prefixes', 'fgroup_suppressed_prefixes', 'fgroup_total_advertised_prefixes', 'fgroup_total_non_optimised_prefixes', 'fgroup_total_withdrawn_prefixes', 'fgroup_withdrawn_prefixes', 'is_rt_present', 'rts', 'update_filter_group_number'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, ['entry'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class Bmp(Entity):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp, self).__init__()

                            self.yang_name = "bmp"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"server-neighbors" : ("server_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors), "server-summaries" : ("server_summaries", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries)}
                            self._child_list_classes = {}

                            self.server_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self._children_name_map["server_neighbors"] = "server-neighbors"
                            self._children_yang_names.add("server-neighbors")

                            self.server_summaries = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self
                            self._children_name_map["server_summaries"] = "server-summaries"
                            self._children_yang_names.add("server-summaries")
                            self._segment_path = lambda: "bmp"


                        class ServerNeighbors(Entity):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors, self).__init__()

                                self.yang_name = "server-neighbors"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"server-neighbor" : ("server_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor)}

                                self.server_neighbor = YList(self)
                                self._segment_path = lambda: "server-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors, [], name, value)


                            class ServerNeighbor(Entity):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                    self.yang_name = "server-neighbor"
                                    self.yang_parent_name = "server-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"monitored-neighbors" : ("monitored_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors)}
                                    self._child_list_classes = {}

                                    self.server_id = YLeaf(YType.uint32, "server-id")

                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self
                                    self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                    self._children_yang_names.add("monitored-neighbors")
                                    self._segment_path = lambda: "server-neighbor" + "[server-id='" + self.server_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                class MonitoredNeighbors(Entity):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                        self.yang_name = "monitored-neighbors"
                                        self.yang_parent_name = "server-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"monitored-neighbor" : ("monitored_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor)}

                                        self.monitored_neighbor = YList(self)
                                        self._segment_path = lambda: "monitored-neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                    class MonitoredNeighbor(Entity):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                        
                                        	Number of Route Monitor EOR Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                            self.yang_name = "monitored-neighbor"
                                            self.yang_parent_name = "monitored-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bmp-neighbor-address" : ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress)}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.bmp_neighbor_msg_dropped = YLeaf(YType.uint32, "bmp-neighbor-msg-dropped")

                                            self.bmp_neighbor_msg_pending = YLeaf(YType.uint32, "bmp-neighbor-msg-pending")

                                            self.bmp_neighbor_path_update_drop = YLeaf(YType.uint32, "bmp-neighbor-path-update-drop")

                                            self.bmp_neighbor_path_update_sent = YLeaf(YType.uint32, "bmp-neighbor-path-update-sent")

                                            self.bmp_neighbor_path_withdraw_drop = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-drop")

                                            self.bmp_neighbor_path_withdraw_sent = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-sent")

                                            self.bmp_neighbor_peer_down_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-down-sent")

                                            self.bmp_neighbor_peer_up_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-up-sent")

                                            self.bmp_neighbor_route_monitor_eor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-eor-sent")

                                            self.bmp_neighbor_route_monitor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-sent")

                                            self.bmp_neighbor_upd_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-upd-msg-sent")

                                            self.bmp_neighbor_wdraw_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-wdraw-msg-sent")

                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                            self._children_yang_names.add("bmp-neighbor-address")
                                            self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', 'bmp_neighbor_msg_dropped', 'bmp_neighbor_msg_pending', 'bmp_neighbor_path_update_drop', 'bmp_neighbor_path_update_sent', 'bmp_neighbor_path_withdraw_drop', 'bmp_neighbor_path_withdraw_sent', 'bmp_neighbor_peer_down_sent', 'bmp_neighbor_peer_up_sent', 'bmp_neighbor_route_monitor_eor_sent', 'bmp_neighbor_route_monitor_sent', 'bmp_neighbor_upd_msg_sent', 'bmp_neighbor_wdraw_msg_sent'], name, value)


                                        class BmpNeighborAddress(Entity):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-neighbor-address"
                                                self.yang_parent_name = "monitored-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "bmp-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class ServerSummaries(Entity):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries, self).__init__()

                                self.yang_name = "server-summaries"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"server-summary" : ("server_summary", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary)}

                                self.server_summary = YList(self)
                                self._segment_path = lambda: "server-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries, [], name, value)


                            class ServerSummary(Entity):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_maximum_buffer_size_route_mon
                                
                                	Buffer limit used for route mon
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_reset_walk_in_progress
                                
                                	Reset walk in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_rmon_cur_buffer_size
                                
                                	Current Buffer usage per BMP Route Mon
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\:  str
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\:  bool
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:   :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_server_up_count
                                
                                	Number of BMP server that are UP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_upd_gen_in_progress
                                
                                	Update generation in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:   :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\:  str
                                
                                .. attribute:: bmpafi_info
                                
                                	AFI specific info for BMP server
                                	**type**\: list of    :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpr_mon_eo_rmessages
                                
                                	Total bmpQ EOR update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\:  str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                    self.yang_name = "server-summary"
                                    self.yang_parent_name = "server-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"bmp-server-last-discon-time" : ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime), "bmp-server-state-age" : ("bmp_server_state_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge), "bmp-server-state-time-spec" : ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec), "update-source-address" : ("update_source_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)}
                                    self._child_list_classes = {"bmpafi-info" : ("bmpafi_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo)}

                                    self.server_id = YLeaf(YType.uint32, "server-id")

                                    self.bmp_bytes_written_tcp = YLeaf(YType.uint64, "bmp-bytes-written-tcp")

                                    self.bmp_init_msg_count = YLeaf(YType.uint32, "bmp-init-msg-count")

                                    self.bmp_maximum_buffer_size_route_mon = YLeaf(YType.uint64, "bmp-maximum-buffer-size-route-mon")

                                    self.bmp_messages_wdraw_discarded = YLeaf(YType.uint32, "bmp-messages-wdraw-discarded")

                                    self.bmp_peer_msg_drop_count = YLeaf(YType.uint32, "bmp-peer-msg-drop-count")

                                    self.bmp_peer_msg_pending_count = YLeaf(YType.uint32, "bmp-peer-msg-pending-count")

                                    self.bmp_peer_msg_pending_count_hwts = YLeaf(YType.uint64, "bmp-peer-msg-pending-count-hwts")

                                    self.bmp_peer_msg_pending_count_max = YLeaf(YType.uint32, "bmp-peer-msg-pending-count-max")

                                    self.bmp_per_peer_msg_count = YLeaf(YType.uint32, "bmp-per-peer-msg-count")

                                    self.bmp_per_peer_msg_route_mon_count = YLeaf(YType.uint32, "bmp-per-peer-msg-route-mon-count")

                                    self.bmp_pfx_wdraw_discarded = YLeaf(YType.uint32, "bmp-pfx-wdraw-discarded")

                                    self.bmp_reset_walk_in_progress = YLeaf(YType.boolean, "bmp-reset-walk-in-progress")

                                    self.bmp_rmon_cur_buffer_size = YLeaf(YType.uint64, "bmp-rmon-cur-buffer-size")

                                    self.bmp_server_host_name = YLeaf(YType.str, "bmp-server-host-name")

                                    self.bmp_server_id = YLeaf(YType.uint8, "bmp-server-id")

                                    self.bmp_server_is_flapping = YLeaf(YType.boolean, "bmp-server-is-flapping")

                                    self.bmp_server_nbr_count = YLeaf(YType.uint32, "bmp-server-nbr-count")

                                    self.bmp_server_port = YLeaf(YType.uint32, "bmp-server-port")

                                    self.bmp_server_state = YLeaf(YType.enumeration, "bmp-server-state")

                                    self.bmp_server_up_count = YLeaf(YType.uint32, "bmp-server-up-count")

                                    self.bmp_status_report_count = YLeaf(YType.uint32, "bmp-status-report-count")

                                    self.bmp_termination_msg_count = YLeaf(YType.uint32, "bmp-termination-msg-count")

                                    self.bmp_upd_gen_in_progress = YLeaf(YType.boolean, "bmp-upd-gen-in-progress")

                                    self.bmp_update_mode = YLeaf(YType.enumeration, "bmp-update-mode")

                                    self.bmp_vrf_id = YLeaf(YType.uint32, "bmp-vrf-id")

                                    self.bmp_vrf_name = YLeaf(YType.str, "bmp-vrf-name")

                                    self.bmpq_last_all_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-all-write-pulse-sent-time")

                                    self.bmpq_last_write_pulse_cb_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-cb-time")

                                    self.bmpq_last_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-sent-time")

                                    self.bmpr_mon_eo_rmessages = YLeaf(YType.uint32, "bmpr-mon-eo-rmessages")

                                    self.bmpr_mon_upd_messages = YLeaf(YType.uint32, "bmpr-mon-upd-messages")

                                    self.bmpr_mon_update_gen_time = YLeaf(YType.uint32, "bmpr-mon-update-gen-time")

                                    self.bmpr_mon_wdraw_messages = YLeaf(YType.uint32, "bmpr-mon-wdraw-messages")

                                    self.path_update_count = YLeaf(YType.uint32, "path-update-count")

                                    self.path_update_drop = YLeaf(YType.uint32, "path-update-drop")

                                    self.path_withdraw_count = YLeaf(YType.uint32, "path-withdraw-count")

                                    self.path_withdraw_drop = YLeaf(YType.uint32, "path-withdraw-drop")

                                    self.tcp_keep_alive_interval = YLeaf(YType.uint32, "tcp-keep-alive-interval")

                                    self.tcp_last_write_cb_time = YLeaf(YType.uint64, "tcp-last-write-cb-time")

                                    self.tcp_last_write_result = YLeaf(YType.uint32, "tcp-last-write-result")

                                    self.tcp_last_write_time = YLeaf(YType.uint64, "tcp-last-write-time")

                                    self.tcp_maximum_segment_size = YLeaf(YType.uint32, "tcp-maximum-segment-size")

                                    self.tcp_write_cb_pending = YLeaf(YType.uint32, "tcp-write-cb-pending")

                                    self.tcp_write_time = YLeaf(YType.uint32, "tcp-write-time")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.update_source_interface_name = YLeaf(YType.str, "update-source-interface-name")

                                    self.update_source_vrf_id = YLeaf(YType.uint32, "update-source-vrf-id")

                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"
                                    self._children_yang_names.add("bmp-server-last-discon-time")

                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"
                                    self._children_yang_names.add("bmp-server-state-age")

                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"
                                    self._children_yang_names.add("bmp-server-state-time-spec")

                                    self.update_source_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self._children_name_map["update_source_address"] = "update-source-address"
                                    self._children_yang_names.add("update-source-address")

                                    self.bmpafi_info = YList(self)
                                    self._segment_path = lambda: "server-summary" + "[server-id='" + self.server_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary, ['server_id', 'bmp_bytes_written_tcp', 'bmp_init_msg_count', 'bmp_maximum_buffer_size_route_mon', 'bmp_messages_wdraw_discarded', 'bmp_peer_msg_drop_count', 'bmp_peer_msg_pending_count', 'bmp_peer_msg_pending_count_hwts', 'bmp_peer_msg_pending_count_max', 'bmp_per_peer_msg_count', 'bmp_per_peer_msg_route_mon_count', 'bmp_pfx_wdraw_discarded', 'bmp_reset_walk_in_progress', 'bmp_rmon_cur_buffer_size', 'bmp_server_host_name', 'bmp_server_id', 'bmp_server_is_flapping', 'bmp_server_nbr_count', 'bmp_server_port', 'bmp_server_state', 'bmp_server_up_count', 'bmp_status_report_count', 'bmp_termination_msg_count', 'bmp_upd_gen_in_progress', 'bmp_update_mode', 'bmp_vrf_id', 'bmp_vrf_name', 'bmpq_last_all_write_pulse_sent_time', 'bmpq_last_write_pulse_cb_time', 'bmpq_last_write_pulse_sent_time', 'bmpr_mon_eo_rmessages', 'bmpr_mon_upd_messages', 'bmpr_mon_update_gen_time', 'bmpr_mon_wdraw_messages', 'path_update_count', 'path_update_drop', 'path_withdraw_count', 'path_withdraw_drop', 'tcp_keep_alive_interval', 'tcp_last_write_cb_time', 'tcp_last_write_result', 'tcp_last_write_time', 'tcp_maximum_segment_size', 'tcp_write_cb_pending', 'tcp_write_time', 'tos_type', 'tos_value', 'update_source_interface_name', 'update_source_vrf_id'], name, value)


                                class BmpServerLastDisconTime(Entity):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                        self.yang_name = "bmp-server-last-discon-time"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-last-discon-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, ['nanoseconds', 'seconds'], name, value)


                                class BmpServerStateAge(Entity):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                        self.yang_name = "bmp-server-state-age"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-state-age"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, ['nanoseconds', 'seconds'], name, value)


                                class BmpServerStateTimeSpec(Entity):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                        self.yang_name = "bmp-server-state-time-spec"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-state-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpafiInfo(Entity):
                                    """
                                    AFI specific info for BMP server
                                    
                                    .. attribute:: bmp_filter_nbr_cnt
                                    
                                    	Filter nbr Count for this AFI
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_filter_neighbor_address
                                    
                                    	Filter Neighbor Address
                                    	**type**\:   :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                    
                                    .. attribute:: bmp_filter_neighbor_address_set
                                    
                                    	Filter Neighbor Address Set ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_init_eor_end_version
                                    
                                    	Version to reach to send EOR
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_eor_pending_cnt
                                    
                                    	Count for pending EOR
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_resume_prefix
                                    
                                    	BMP Resume prefix
                                    	**type**\:   :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                    
                                    .. attribute:: bmp_resume_prefix_len
                                    
                                    	BMP Resume prefix Len
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught upto
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_end_version
                                    
                                    	Update Gen ResumeWalk end version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_net_version
                                    
                                    	Update Gen ResumeWalk Net version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_start_version
                                    
                                    	Update Gen ResumeWalk start version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_count
                                    
                                    	Number of times Update Gen ran
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                    
                                    	Last Update Gen Run time stamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_count
                                    
                                    	Number of times Update Gen Stopped
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                    
                                    	Last Update Gen Stop time stamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stopped
                                    
                                    	Update Gen WalkStopped
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmpaf_name
                                    
                                    	BMP Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                        self.yang_name = "bmpafi-info"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-filter-neighbor-address" : ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress), "bmp-resume-prefix" : ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)}
                                        self._child_list_classes = {}

                                        self.bmp_filter_nbr_cnt = YLeaf(YType.uint32, "bmp-filter-nbr-cnt")

                                        self.bmp_filter_neighbor_address_set = YLeaf(YType.boolean, "bmp-filter-neighbor-address-set")

                                        self.bmp_init_eor_end_version = YLeaf(YType.uint32, "bmp-init-eor-end-version")

                                        self.bmp_init_eor_pending_cnt = YLeaf(YType.uint32, "bmp-init-eor-pending-cnt")

                                        self.bmp_resume_prefix_len = YLeaf(YType.uint32, "bmp-resume-prefix-len")

                                        self.bmp_send_version = YLeaf(YType.uint32, "bmp-send-version")

                                        self.bmp_upd_gen_resume_end_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-end-version")

                                        self.bmp_upd_gen_resume_net_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-net-version")

                                        self.bmp_upd_gen_resume_start_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-start-version")

                                        self.bmp_upd_gen_walk_run_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-count")

                                        self.bmp_upd_gen_walk_run_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-time-stamp")

                                        self.bmp_upd_gen_walk_stop_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-count")

                                        self.bmp_upd_gen_walk_stop_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-time-stamp")

                                        self.bmp_upd_gen_walk_stopped = YLeaf(YType.boolean, "bmp-upd-gen-walk-stopped")

                                        self.bmpaf_name = YLeaf(YType.enumeration, "bmpaf-name")

                                        self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                        self.bmp_filter_neighbor_address.parent = self
                                        self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                        self._children_yang_names.add("bmp-filter-neighbor-address")

                                        self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                        self.bmp_resume_prefix.parent = self
                                        self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"
                                        self._children_yang_names.add("bmp-resume-prefix")
                                        self._segment_path = lambda: "bmpafi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, ['bmp_filter_nbr_cnt', 'bmp_filter_neighbor_address_set', 'bmp_init_eor_end_version', 'bmp_init_eor_pending_cnt', 'bmp_resume_prefix_len', 'bmp_send_version', 'bmp_upd_gen_resume_end_version', 'bmp_upd_gen_resume_net_version', 'bmp_upd_gen_resume_start_version', 'bmp_upd_gen_walk_run_count', 'bmp_upd_gen_walk_run_time_stamp', 'bmp_upd_gen_walk_stop_count', 'bmp_upd_gen_walk_stop_time_stamp', 'bmp_upd_gen_walk_stopped', 'bmpaf_name'], name, value)


                                    class BmpFilterNeighborAddress(Entity):
                                        """
                                        Filter Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                            self.yang_name = "bmp-filter-neighbor-address"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "bmp-filter-neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BmpResumePrefix(Entity):
                                        """
                                        BMP Resume prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                            self.yang_name = "bmp-resume-prefix"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bmp-resume-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bmp-resume-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateSourceAddress(Entity):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                        self.yang_name = "update-source-address"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-source-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class GlobalProcessInfo(Entity):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo, self).__init__()

                            self.yang_name = "global-process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf)}
                            self._child_list_classes = {}

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrfid = YLeaf(YType.uint32, "vrfid")

                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"
                            self._children_yang_names.add("global")

                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "global-process-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo, ['vrf_name', 'vrfid'], name, value)


                        class Global_(Entity):
                            """
                            Global information
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_cur_maximum_buffer_size
                            
                            	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                            
                            .. attribute:: color_id
                            
                            	All configured Color IDs
                            	**type**\: list of    :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ColorId>`
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\:  bool
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\:  str
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"cluster-id-entry" : ("cluster_id_entry", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry), "color-id" : ("color_id", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ColorId)}

                                self.asn_format = YLeaf(YType.uint32, "asn-format")

                                self.bmp_cur_maximum_buffer_size = YLeaf(YType.uint64, "bmp-cur-maximum-buffer-size")

                                self.bmp_current_buffer_size = YLeaf(YType.uint64, "bmp-current-buffer-size")

                                self.bmp_default_buffer_size = YLeaf(YType.uint64, "bmp-default-buffer-size")

                                self.bmp_maximum_buffer_size = YLeaf(YType.uint64, "bmp-maximum-buffer-size")

                                self.cluster_id = YLeaf(YType.uint32, "cluster-id")

                                self.confederation_id = YLeaf(YType.uint32, "confederation-id")

                                self.configured_cluster_id = YLeaf(YType.uint32, "configured-cluster-id")

                                self.generic_scan_period = YLeaf(YType.uint16, "generic-scan-period")

                                self.graceful_maint_all_nbrs = YLeaf(YType.boolean, "graceful-maint-all-nbrs")

                                self.graceful_maint_retain_routes = YLeaf(YType.boolean, "graceful-maint-retain-routes")

                                self.graceful_maintenance = YLeaf(YType.boolean, "graceful-maintenance")

                                self.in_standalone_mode = YLeaf(YType.boolean, "in-standalone-mode")

                                self.instance_name = YLeaf(YType.str, "instance-name")

                                self.is_cluster_id_specified_as_ip = YLeaf(YType.boolean, "is-cluster-id-specified-as-ip")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.process_rlimit = YLeaf(YType.uint64, "process-rlimit")

                                self.restart_count = YLeaf(YType.uint32, "restart-count")

                                self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                self.srgb_end_configured = YLeaf(YType.uint32, "srgb-end-configured")

                                self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                self.srgb_start_configured = YLeaf(YType.uint32, "srgb-start-configured")

                                self.update_delay = YLeaf(YType.uint32, "update-delay")

                                self.cluster_id_entry = YList(self)
                                self.color_id = YList(self)
                                self._segment_path = lambda: "global"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_, ['asn_format', 'bmp_cur_maximum_buffer_size', 'bmp_current_buffer_size', 'bmp_default_buffer_size', 'bmp_maximum_buffer_size', 'cluster_id', 'confederation_id', 'configured_cluster_id', 'generic_scan_period', 'graceful_maint_all_nbrs', 'graceful_maint_retain_routes', 'graceful_maintenance', 'in_standalone_mode', 'instance_name', 'is_cluster_id_specified_as_ip', 'local_as', 'process_rlimit', 'restart_count', 'srgb_end', 'srgb_end_configured', 'srgb_start', 'srgb_start_configured', 'update_delay'], name, value)


                            class ClusterIdEntry(Entity):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry, self).__init__()

                                    self.yang_name = "cluster-id-entry"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.cluster_id_type = YLeaf(YType.uint8, "cluster-id-type")

                                    self.cluster_id_val = YLeaf(YType.uint32, "cluster-id-val")
                                    self._segment_path = lambda: "cluster-id-entry"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry, ['cluster_id_type', 'cluster_id_val'], name, value)


                            class ColorId(Entity):
                                """
                                All configured Color IDs
                                
                                .. attribute:: color_id_val
                                
                                	Color ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ColorId, self).__init__()

                                    self.yang_name = "color-id"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.color_id_val = YLeaf(YType.uint32, "color-id-val")
                                    self._segment_path = lambda: "color-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ColorId, ['color_id_val'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\:  bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\:  bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.configured_router_id = YLeaf(YType.str, "configured-router-id")

                                self.default_local_preference = YLeaf(YType.uint32, "default-local-preference")

                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                self.hold_time = YLeaf(YType.uint16, "hold-time")

                                self.is_bestpath_aigp_ignore_enabled = YLeaf(YType.boolean, "is-bestpath-aigp-ignore-enabled")

                                self.is_bestpath_always_compare_med_enabled = YLeaf(YType.boolean, "is-bestpath-always-compare-med-enabled")

                                self.is_bestpath_as_path_mpath_relax_enabled = YLeaf(YType.boolean, "is-bestpath-as-path-mpath-relax-enabled")

                                self.is_bestpath_compare_med_from_confed_peer_enabled = YLeaf(YType.boolean, "is-bestpath-compare-med-from-confed-peer-enabled")

                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = YLeaf(YType.boolean, "is-bestpath-compare-router-id-for-ebgp-peers-enabled")

                                self.is_bestpath_ignore_as_path_enabled = YLeaf(YType.boolean, "is-bestpath-ignore-as-path-enabled")

                                self.is_bestpath_missing_med_is_worst_enabled = YLeaf(YType.boolean, "is-bestpath-missing-med-is-worst-enabled")

                                self.is_default_metric_configured = YLeaf(YType.boolean, "is-default-metric-configured")

                                self.is_default_originate_configured = YLeaf(YType.boolean, "is-default-originate-configured")

                                self.is_enforce_first_as_enabled = YLeaf(YType.boolean, "is-enforce-first-as-enabled")

                                self.is_fast_external_fallover_enabled = YLeaf(YType.boolean, "is-fast-external-fallover-enabled")

                                self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                                self.is_multipath_as_path_ignore_onwards_enabled = YLeaf(YType.boolean, "is-multipath-as-path-ignore-onwards-enabled")

                                self.is_neighbor_logging = YLeaf(YType.boolean, "is-neighbor-logging")

                                self.is_nsr = YLeaf(YType.boolean, "is-nsr")

                                self.is_redistribute_ibgp_to_ig_ps_enabled = YLeaf(YType.boolean, "is-redistribute-ibgp-to-ig-ps-enabled")

                                self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                self.min_acceptable_hold_time = YLeaf(YType.uint16, "min-acceptable-hold-time")

                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                self.rib_purge_timeout = YLeaf(YType.uint32, "rib-purge-timeout")

                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.stale_path_time = YLeaf(YType.uint32, "stale-path-time")

                                self.vrf_is_active = YLeaf(YType.boolean, "vrf-is-active")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf, ['configured_router_id', 'default_local_preference', 'default_metric', 'hold_time', 'is_bestpath_aigp_ignore_enabled', 'is_bestpath_always_compare_med_enabled', 'is_bestpath_as_path_mpath_relax_enabled', 'is_bestpath_compare_med_from_confed_peer_enabled', 'is_bestpath_compare_router_id_for_ebgp_peers_enabled', 'is_bestpath_ignore_as_path_enabled', 'is_bestpath_missing_med_is_worst_enabled', 'is_default_metric_configured', 'is_default_originate_configured', 'is_enforce_first_as_enabled', 'is_fast_external_fallover_enabled', 'is_graceful_restart', 'is_multipath_as_path_ignore_onwards_enabled', 'is_neighbor_logging', 'is_nsr', 'is_redistribute_ibgp_to_ig_ps_enabled', 'keep_alive_time', 'min_acceptable_hold_time', 'restart_time', 'rib_purge_timeout', 'route_distinguisher', 'router_id', 'stale_path_time', 'vrf_is_active'], name, value)


                    class Information(Entity):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")
                            self._segment_path = lambda: "information"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information, ['route_distinguisher'], name, value)


                    class MessageLogs(Entity):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs, self).__init__()

                            self.yang_name = "message-logs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"message-log" : ("message_log", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog)}

                            self.message_log = YList(self)
                            self._segment_path = lambda: "message-logs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs, [], name, value)


                        class MessageLog(Entity):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog, self).__init__()

                                self.yang_name = "message-log"
                                self.yang_parent_name = "message-logs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-message" : ("neighbor_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage)}

                                self.direction = YLeaf(YType.int32, "direction")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_message = YList(self)
                                self._segment_path = lambda: "message-log"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog, ['direction', 'neighbor_address'], name, value)


                            class NeighborMessage(Entity):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                    self.yang_name = "neighbor-message"
                                    self.yang_parent_name = "message-log"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"message-timestamp" : ("message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)}
                                    self._child_list_classes = {"logged-message-data" : ("logged_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData)}

                                    self.message_data_length = YLeaf(YType.uint16, "message-data-length")

                                    self.message_type_received = YLeaf(YType.uint8, "message-type-received")

                                    self.total_logged_message_count = YLeaf(YType.uint32, "total-logged-message-count")

                                    self.message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self._children_name_map["message_timestamp"] = "message-timestamp"
                                    self._children_yang_names.add("message-timestamp")

                                    self.logged_message_data = YList(self)
                                    self._segment_path = lambda: "neighbor-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, ['message_data_length', 'message_type_received', 'total_logged_message_count'], name, value)


                                class LoggedMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                        self.yang_name = "logged-message-data"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "logged-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, ['entry'], name, value)


                                class MessageTimestamp(Entity):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                        self.yang_name = "message-timestamp"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                    class NeighborRanges(Entity):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges, self).__init__()

                            self.yang_name = "neighbor-ranges"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-range" : ("neighbor_range", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange)}

                            self.neighbor_range = YList(self)
                            self._segment_path = lambda: "neighbor-ranges"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges, [], name, value)


                        class NeighborRange(Entity):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  <key>
                            
                            	Neighbor Range prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\:  bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\:  str
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\:  bool
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\:  bool
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\:  str
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\:  bool
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\:  bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange, self).__init__()

                                self.yang_name = "neighbor-range"
                                self.yang_parent_name = "neighbor-ranges"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"cfg-local-address" : ("cfg_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress), "connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance)}
                                self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData), "instance" : ("instance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance)}

                                self.neighbor_range_address = YLeaf(YType.str, "neighbor-range-address")

                                self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                self.addpath_receive_disable = YLeaf(YType.boolean, "addpath-receive-disable")

                                self.addpath_receive_enable = YLeaf(YType.boolean, "addpath-receive-enable")

                                self.addpath_send_disable = YLeaf(YType.boolean, "addpath-send-disable")

                                self.addpath_send_enable = YLeaf(YType.boolean, "addpath-send-enable")

                                self.attrf_group_name = YLeaf(YType.str, "attrf-group-name")

                                self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                self.current_peers = YLeaf(YType.uint32, "current-peers")

                                self.description = YLeaf(YType.str, "description")

                                self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                self.islocal_address_cfg = YLeaf(YType.boolean, "islocal-address-cfg")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                self.max_peers = YLeaf(YType.uint32, "max-peers")

                                self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                self.msg_bug_circular = YLeaf(YType.boolean, "msg-bug-circular")

                                self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                self.nbr_rcv_size = YLeaf(YType.uint32, "nbr-rcv-size")

                                self.nbr_send_size = YLeaf(YType.uint32, "nbr-send-size")

                                self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                self.neighbor_range_prefix_length = YLeaf(YType.uint8, "neighbor-range-prefix-length")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.oper_attrf_enable = YLeaf(YType.boolean, "oper-attrf-enable")

                                self.range_inst_error = YLeaf(YType.uint32, "range-inst-error")

                                self.range_max_drop = YLeaf(YType.uint32, "range-max-drop")

                                self.range_open_accepted = YLeaf(YType.uint32, "range-open-accepted")

                                self.range_open_match = YLeaf(YType.uint32, "range-open-match")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.remote_as_list_name = YLeaf(YType.str, "remote-as-list-name")

                                self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                self.syslog_enable = YLeaf(YType.boolean, "syslog-enable")

                                self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                self.tos_type = YLeaf(YType.uint8, "tos-type")

                                self.tos_value = YLeaf(YType.uint8, "tos-value")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.upd_errh_noreset = YLeaf(YType.boolean, "upd-errh-noreset")

                                self.update_source = YLeaf(YType.str, "update-source")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self._children_name_map["cfg_local_address"] = "cfg-local-address"
                                self._children_yang_names.add("cfg-local-address")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                self._children_yang_names.add("graceful-maintenance")

                                self.af_data = YList(self)
                                self.instance = YList(self)
                                self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + self.neighbor_range_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange, ['neighbor_range_address', 'active_bmp_servers', 'addpath_receive_disable', 'addpath_receive_enable', 'addpath_send_disable', 'addpath_send_enable', 'attrf_group_name', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_enable_mode', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'current_peers', 'description', 'discard_as4_path', 'dmz_link_bandwidth', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'idle_watch_time', 'ignore_connected', 'internal_vpn_client', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_passive_close', 'islocal_address_cfg', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'max_peers', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_buf_count', 'msg_bug_circular', 'msg_log_in', 'msg_log_out', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'nbr_rcv_size', 'nbr_send_size', 'neighbor_local_as', 'neighbor_range_prefix_length', 'nsr_enabled', 'oper_attrf_enable', 'range_inst_error', 'range_max_drop', 'range_open_accepted', 'range_open_match', 'remote_as', 'remote_as_list_name', 'remote_as_number', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'syslog_enable', 'tcp_session_open_mode', 'tcpmss', 'tos_type', 'tos_value', 'ttl_security_enabled', 'upd_errh_noreset', 'update_source', 'vrf_name'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby)}

                                    self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                    self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                    self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                    self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                    self.advertise_afi_local = YLeaf(YType.boolean, "advertise-afi-local")

                                    self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                    self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                    self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                    self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                    self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                    self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                    self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                    self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                    self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                    self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                    self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                    self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                    self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                    self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                    self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                    self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                    self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                    self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                    self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                    self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                    self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                    self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                    self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                    self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                    self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                    self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                    self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                    self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                    self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                    self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                    self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                    self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                    self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                    self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                    self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                    self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                    self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                    self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                    self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                    self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                    self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                    self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                    self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                    self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                    self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                    self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                    self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                    self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                    self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                    self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                    self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                    self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                    self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                    self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                    self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                    self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                    self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                    self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                    self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                    self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                    self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                    self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                    self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                    self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                    self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                    self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                    self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                    self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                    self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                    self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                    self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                    self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                    self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                    self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                    self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                    self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                    self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                    self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                    self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                    self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                    self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                    self.weight = YLeaf(YType.uint32, "weight")

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData, ['accept_own_enabled', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_disable', 'advertise_afi_local', 'advertise_afi_reorg', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'next_hop_unchanged', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, ['entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community-standby"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                            class CfgLocalAddress(Entity):
                                """
                                Configured local address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                    self.yang_name = "cfg-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "cfg-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                    self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                    self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                    self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                    self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                    self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                    self._segment_path = lambda: "graceful-maintenance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                            class Instance(Entity):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance, self).__init__()

                                    self.yang_name = "instance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"idle-watch-timer-remaining-value" : ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress), "neighbor-age" : ("neighbor_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge)}
                                    self._child_list_classes = {}

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.is_idle_watch_timer_running = YLeaf(YType.boolean, "is-idle-watch-timer-running")

                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                    self._children_yang_names.add("idle-watch-timer-remaining-value")

                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")

                                    self.neighbor_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge()
                                    self.neighbor_age.parent = self
                                    self._children_name_map["neighbor_age"] = "neighbor-age"
                                    self._children_yang_names.add("neighbor-age")
                                    self._segment_path = lambda: "instance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance, ['connection_state', 'is_idle_watch_timer_running'], name, value)


                                class IdleWatchTimerRemainingValue(Entity):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, self).__init__()

                                        self.yang_name = "idle-watch-timer-remaining-value"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "idle-watch-timer-remaining-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborAge(Entity):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge, self).__init__()

                                        self.yang_name = "neighbor-age"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "neighbor-age"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge, ['nanoseconds', 'seconds'], name, value)


                    class Neighbors(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\:  bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\:  bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\:  bool
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\:  bool
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\:  bool
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)}
                                self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                self.description = YLeaf(YType.str, "description")

                                self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                self.hold_time = YLeaf(YType.uint16, "hold-time")

                                self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                self.io_armed = YLeaf(YType.boolean, "io-armed")

                                self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                self.messages_received = YLeaf(YType.uint32, "messages-received")

                                self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                self.read_armed = YLeaf(YType.boolean, "read-armed")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                self.tos_type = YLeaf(YType.uint8, "tos-type")

                                self.tos_value = YLeaf(YType.uint8, "tos-value")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.write_armed = YLeaf(YType.boolean, "write-armed")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                self._children_yang_names.add("graceful-maintenance")

                                self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self._children_name_map["message_statistics"] = "message-statistics"
                                self._children_yang_names.add("message-statistics")

                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._children_yang_names.add("performance-statistics")

                                self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self._children_name_map["received_notification_info"] = "received-notification-info"
                                self._children_yang_names.add("received-notification-info")

                                self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self._children_name_map["send_notification_info"] = "send-notification-info"
                                self._children_yang_names.add("send-notification-info")

                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                self._children_yang_names.add("tcp-init-sync-time-spec")

                                self.af_data = YList(self)
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with 
                                	**type**\:  bool
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\:  bool
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: outstanding_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby)}

                                    self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                    self.acked_version = YLeaf(YType.uint32, "acked-version")

                                    self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                    self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                    self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                    self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                    self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                    self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                    self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                    self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                    self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                    self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                    self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                    self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                    self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                    self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                    self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                    self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                    self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                    self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                    self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                    self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                    self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                    self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                    self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                    self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                    self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                    self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                    self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                    self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                    self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                    self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                    self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                    self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                    self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                    self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                    self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                    self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                    self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                    self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                    self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                    self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                    self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                    self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                    self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                    self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                    self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                    self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                    self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                    self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                    self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                    self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                    self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                    self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                    self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                    self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                    self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                    self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                    self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                    self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                    self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                    self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                    self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                    self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                    self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                    self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                    self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                    self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                    self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                    self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                    self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                    self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                    self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                    self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                    self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                    self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                    self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                    self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                    self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                    self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                    self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                    self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                    self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                    self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                    self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                    self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                    self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                    self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                    self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                    self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                    self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                    self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                    self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                    self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                    self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                    self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                    self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                    self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                    self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                    self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                    self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                    self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                    self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                    self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                    self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                    self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                    self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                    self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                    self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                    self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                    self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                    self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                    self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                    self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                    self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                    self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                    self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                    self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                    self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                    self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                    self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                    self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                    self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                    self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                    self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                    self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                    self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                    self.weight = YLeaf(YType.uint32, "weight")

                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                    self._children_yang_names.add("neighbor-af-performance-statistics")

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community-standby"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                class NeighborAfPerformanceStatistics(Entity):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                        self.yang_name = "neighbor-af-performance-statistics"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                        self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                        self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                        self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                        self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                        self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                        self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                        self._segment_path = lambda: "neighbor-af-performance-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                    self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                    self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                    self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                    self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                    self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                    self._segment_path = lambda: "graceful-maintenance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                            class MessageStatistics(Entity):
                                """
                                Message statistics
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                    self.yang_name = "message-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update)}
                                    self._child_list_classes = {}

                                    self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self._children_name_map["keepalive"] = "keepalive"
                                    self._children_yang_names.add("keepalive")

                                    self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self._children_name_map["notification"] = "notification"
                                    self._children_yang_names.add("notification")

                                    self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self._children_name_map["open"] = "open"
                                    self._children_yang_names.add("open")

                                    self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self._children_name_map["route_refresh"] = "route-refresh"
                                    self._children_yang_names.add("route-refresh")

                                    self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                    self._children_yang_names.add("total")

                                    self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self
                                    self._children_name_map["update"] = "update"
                                    self._children_yang_names.add("update")
                                    self._segment_path = lambda: "message-statistics"


                                class Keepalive(Entity):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                        self.yang_name = "keepalive"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "keepalive"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Notification(Entity):
                                    """
                                    Notification
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                        self.yang_name = "notification"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "notification"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Open(Entity):
                                    """
                                    Open
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                        self.yang_name = "open"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "open"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class RouteRefresh(Entity):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                        self.yang_name = "route-refresh"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "route-refresh"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Total(Entity):
                                    """
                                    Total
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                        self.yang_name = "total"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "total"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Update(Entity):
                                    """
                                    Update
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                        self.yang_name = "update"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "update"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.active_collision = YLeaf(YType.uint32, "active-collision")

                                    self.actives = YLeaf(YType.uint32, "actives")

                                    self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                    self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                    self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                    self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                    self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                    self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                    self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                    self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                    self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                    self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                    self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                    self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                    self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                    self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                    self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                    self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                    self.network_status = YLeaf(YType.uint32, "network-status")

                                    self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                    self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                    self.passives = YLeaf(YType.uint32, "passives")

                                    self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                    self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                    self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                    self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                    self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                    self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                    self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                    self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                    self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                    self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                    self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                    self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                    self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                    self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                    self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                    self._segment_path = lambda: "performance-statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                            class ReceivedNotificationInfo(Entity):
                                """
                                Information on the last notification received
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                    self.yang_name = "received-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                    self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                    self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                    self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "received-notification-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "received-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "last-notification-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                            class SendNotificationInfo(Entity):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                    self.yang_name = "send-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData)}

                                    self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                    self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                    self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "send-notification-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "send-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "last-notification-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                            class TcpInitSyncDoneTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-done-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class TcpInitSyncTimeSpec(Entity):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                    class NextHopVrf(Entity):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf, self).__init__()

                            self.yang_name = "next-hop-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.last_notification_processing_time = YLeaf(YType.uint32, "last-notification-processing-time")

                            self.last_notificationication_time = YLeaf(YType.uint32, "last-notificationication-time")

                            self.max_notification_bestpath_changes = YLeaf(YType.uint32, "max-notification-bestpath-changes")

                            self.max_notification_bestpath_deletes = YLeaf(YType.uint32, "max-notification-bestpath-deletes")

                            self.max_proc_notification_time = YLeaf(YType.uint32, "max-proc-notification-time")

                            self.maximum_processing_time = YLeaf(YType.uint32, "maximum-processing-time")

                            self.total_processing_time = YLeaf(YType.uint32, "total-processing-time")
                            self._segment_path = lambda: "next-hop-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf, ['last_notification_processing_time', 'last_notificationication_time', 'max_notification_bestpath_changes', 'max_notification_bestpath_deletes', 'max_proc_notification_time', 'maximum_processing_time', 'total_processing_time'], name, value)


                    class Postits(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits, self).__init__()

                            self.yang_name = "postits"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"postit" : ("postit", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit)}

                            self.postit = YList(self)
                            self._segment_path = lambda: "postits"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits, [], name, value)


                        class Postit(Entity):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit, self).__init__()

                                self.yang_name = "postit"
                                self.yang_parent_name = "postits"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbors-address" : ("neighbors_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress)}
                                self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf), "postit-info" : ("postit_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.connect_state = YLeaf(YType.uint32, "connect-state")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.start_time = YLeaf(YType.uint32, "start-time")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.neighbors_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self._children_name_map["neighbors_address"] = "neighbors-address"
                                self._children_yang_names.add("neighbors-address")

                                self.neighbor_af = YList(self)
                                self.postit_info = YList(self)
                                self._segment_path = lambda: "postit" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit, ['neighbor_address', 'connect_state', 'nsr_state', 'start_time', 'vrf_name'], name, value)


                            class NeighborAf(Entity):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf, self).__init__()

                                    self.yang_name = "neighbor-af"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.boolean, "entry")
                                    self._segment_path = lambda: "neighbor-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf, ['entry'], name, value)


                            class NeighborsAddress(Entity):
                                """
                                Neighbor Addr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress, self).__init__()

                                    self.yang_name = "neighbors-address"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "neighbors-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PostitInfo(Entity):
                                """
                                Postit Info
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\:  str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo, self).__init__()

                                    self.yang_name = "postit-info"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"postit-notification" : ("postit_notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification)}
                                    self._child_list_classes = {}

                                    self.peer_id = YLeaf(YType.uint32, "peer-id")

                                    self.postit_af_name = YLeaf(YType.enumeration, "postit-af-name")

                                    self.postit_direction = YLeaf(YType.uint8, "postit-direction")

                                    self.postit_flags = YLeaf(YType.uint8, "postit-flags")

                                    self.postit_id = YLeaf(YType.uint32, "postit-id")

                                    self.postit_policy = YLeaf(YType.str, "postit-policy")

                                    self.postit_reset = YLeaf(YType.enumeration, "postit-reset")

                                    self.postit_subtype = YLeaf(YType.uint32, "postit-subtype")

                                    self.postit_ts = YLeaf(YType.uint64, "postit-ts")

                                    self.postit_type = YLeaf(YType.uint32, "postit-type")

                                    self.postit_notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self._children_name_map["postit_notification"] = "postit-notification"
                                    self._children_yang_names.add("postit-notification")
                                    self._segment_path = lambda: "postit-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo, ['peer_id', 'postit_af_name', 'postit_direction', 'postit_flags', 'postit_id', 'postit_policy', 'postit_reset', 'postit_subtype', 'postit_ts', 'postit_type'], name, value)


                                class PostitNotification(Entity):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                        self.yang_name = "postit-notification"
                                        self.yang_parent_name = "postit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "postit-notification"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "postit-notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, ['entry'], name, value)


                    class ProcessInfo(Entity):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo, self).__init__()

                            self.yang_name = "process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf)}
                            self._child_list_classes = {}

                            self.process_instance = YLeaf(YType.uint8, "process-instance")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"
                            self._children_yang_names.add("global")

                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self._children_name_map["performance_statistics"] = "performance-statistics"
                            self._children_yang_names.add("performance-statistics")

                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "process-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo, ['process_instance', 'vrf_name', 'vrf_totals'], name, value)


                        class Global_(Entity):
                            """
                            Global information
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize>`
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: large_community_entry_count
                            
                            	Number of large community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_memory
                            
                            	Memory (in bytes) used by large community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize>`
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount>`
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize>`
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\:  str
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bmp-pool-alloc-count" : ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount), "bmp-pool-free-count" : ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount), "bmp-pool-size" : ("bmp_pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize), "msg-log-pool-alloc-count" : ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount), "msg-log-pool-free-count" : ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount), "msg-log-pool-size" : ("msg_log_pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize), "pool-alloc-count" : ("pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount), "pool-free-count" : ("pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount), "pool-size" : ("pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize)}

                                self.as_path_entries_memory = YLeaf(YType.uint32, "as-path-entries-memory")

                                self.as_path_entry_count = YLeaf(YType.uint32, "as-path-entry-count")

                                self.attr_set_entry_count = YLeaf(YType.uint32, "attr-set-entry-count")

                                self.attr_set_memory = YLeaf(YType.uint32, "attr-set-memory")

                                self.community_entry_count = YLeaf(YType.uint32, "community-entry-count")

                                self.community_memory = YLeaf(YType.uint32, "community-memory")

                                self.established_neighbors_count_total = YLeaf(YType.uint32, "established-neighbors-count-total")

                                self.extended_community_entry_count = YLeaf(YType.uint32, "extended-community-entry-count")

                                self.extended_community_memory = YLeaf(YType.uint32, "extended-community-memory")

                                self.large_community_entry_count = YLeaf(YType.uint32, "large-community-entry-count")

                                self.large_community_memory = YLeaf(YType.uint32, "large-community-memory")

                                self.lindex_entry_count = YLeaf(YType.uint32, "lindex-entry-count")

                                self.lindex_memory = YLeaf(YType.uint32, "lindex-memory")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.lsattr_entry_count = YLeaf(YType.uint32, "lsattr-entry-count")

                                self.lsattr_memory = YLeaf(YType.uint32, "lsattr-memory")

                                self.neighbors_count_total = YLeaf(YType.uint32, "neighbors-count-total")

                                self.nexthop_count = YLeaf(YType.uint32, "nexthop-count")

                                self.nexthop_memory = YLeaf(YType.uint32, "nexthop-memory")

                                self.path_attribute_memory = YLeaf(YType.uint32, "path-attribute-memory")

                                self.path_attributes_entry_count = YLeaf(YType.uint32, "path-attributes-entry-count")

                                self.pe_distinguisher_label_entry_count = YLeaf(YType.uint32, "pe-distinguisher-label-entry-count")

                                self.pe_distinguisher_label_memory = YLeaf(YType.uint32, "pe-distinguisher-label-memory")

                                self.ppmp_entry_count = YLeaf(YType.uint32, "ppmp-entry-count")

                                self.ppmp_memory = YLeaf(YType.uint32, "ppmp-memory")

                                self.process_instance_node = YLeaf(YType.str, "process-instance-node")

                                self.pta_entry_count = YLeaf(YType.uint32, "pta-entry-count")

                                self.pta_memory = YLeaf(YType.uint32, "pta-memory")

                                self.restart_count = YLeaf(YType.uint32, "restart-count")

                                self.ribrnh_entry_count = YLeaf(YType.uint32, "ribrnh-entry-count")

                                self.ribrnh_memory = YLeaf(YType.uint32, "ribrnh-memory")

                                self.route_reflector_memory = YLeaf(YType.uint32, "route-reflector-memory")

                                self.route_reflectors = YLeaf(YType.uint32, "route-reflectors")

                                self.sn_num_non_dflt_vrf_nbrs = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs")

                                self.sn_num_non_dflt_vrf_nbrs_estab = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs-estab")

                                self.total_vrf_count = YLeaf(YType.uint32, "total-vrf-count")

                                self.tunnel_encap_entry_count = YLeaf(YType.uint32, "tunnel-encap-entry-count")

                                self.tunnel_encap_memory = YLeaf(YType.uint32, "tunnel-encap-memory")

                                self.bmp_pool_alloc_count = YList(self)
                                self.bmp_pool_free_count = YList(self)
                                self.bmp_pool_size = YList(self)
                                self.msg_log_pool_alloc_count = YList(self)
                                self.msg_log_pool_free_count = YList(self)
                                self.msg_log_pool_size = YList(self)
                                self.pool_alloc_count = YList(self)
                                self.pool_free_count = YList(self)
                                self.pool_size = YList(self)
                                self._segment_path = lambda: "global"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_, ['as_path_entries_memory', 'as_path_entry_count', 'attr_set_entry_count', 'attr_set_memory', 'community_entry_count', 'community_memory', 'established_neighbors_count_total', 'extended_community_entry_count', 'extended_community_memory', 'large_community_entry_count', 'large_community_memory', 'lindex_entry_count', 'lindex_memory', 'local_as', 'lsattr_entry_count', 'lsattr_memory', 'neighbors_count_total', 'nexthop_count', 'nexthop_memory', 'path_attribute_memory', 'path_attributes_entry_count', 'pe_distinguisher_label_entry_count', 'pe_distinguisher_label_memory', 'ppmp_entry_count', 'ppmp_memory', 'process_instance_node', 'pta_entry_count', 'pta_memory', 'restart_count', 'ribrnh_entry_count', 'ribrnh_memory', 'route_reflector_memory', 'route_reflectors', 'sn_num_non_dflt_vrf_nbrs', 'sn_num_non_dflt_vrf_nbrs_estab', 'total_vrf_count', 'tunnel_encap_entry_count', 'tunnel_encap_memory'], name, value)


                            class BmpPoolAllocCount(Entity):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount, self).__init__()

                                    self.yang_name = "bmp-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount, ['entry'], name, value)


                            class BmpPoolFreeCount(Entity):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount, self).__init__()

                                    self.yang_name = "bmp-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount, ['entry'], name, value)


                            class BmpPoolSize(Entity):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize, self).__init__()

                                    self.yang_name = "bmp-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize, ['entry'], name, value)


                            class MsgLogPoolAllocCount(Entity):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount, self).__init__()

                                    self.yang_name = "msg-log-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount, ['entry'], name, value)


                            class MsgLogPoolFreeCount(Entity):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount, self).__init__()

                                    self.yang_name = "msg-log-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount, ['entry'], name, value)


                            class MsgLogPoolSize(Entity):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize, self).__init__()

                                    self.yang_name = "msg-log-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize, ['entry'], name, value)


                            class PoolAllocCount(Entity):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount, self).__init__()

                                    self.yang_name = "pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount, ['entry'], name, value)


                            class PoolFreeCount(Entity):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount, self).__init__()

                                    self.yang_name = "pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount, ['entry'], name, value)


                            class PoolSize(Entity):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize, self).__init__()

                                    self.yang_name = "pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize, ['entry'], name, value)


                        class PerformanceStatistics(Entity):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                self.yang_name = "performance-statistics"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf)}
                                self._child_list_classes = {}

                                self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "performance-statistics"


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\:  bool
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\:  bool
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:   :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\:  bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\:  bool
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ds-npl" : ("ds_npl", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl), "ipv4rib-server" : ("ipv4rib_server", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer), "ipv6rib-server" : ("ipv6rib_server", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer), "lsd-connection" : ("lsd_connection", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection), "te-connection" : ("te_connection", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection)}
                                    self._child_list_classes = {"active-nsr-mode-enter-time" : ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime), "active-nsrfo-time" : ("active_nsrfo_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime), "issu-milestone" : ("issu_milestone", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone), "postit-count-info" : ("postit_count_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo), "standby-nsr-mode-enter-time" : ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime)}

                                    self.active_nsr_state = YLeaf(YType.uint32, "active-nsr-state")

                                    self.active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "active-nsrtcp-phase-two-enter-time")

                                    self.brib_api_input_bytes = YLeaf(YType.uint32, "brib-api-input-bytes")

                                    self.brib_api_input_messages = YLeaf(YType.uint32, "brib-api-input-messages")

                                    self.brib_api_input_prefixes_received = YLeaf(YType.uint32, "brib-api-input-prefixes-received")

                                    self.brib_api_input_processing_time = YLeaf(YType.uint32, "brib-api-input-processing-time")

                                    self.brib_api_input_withdrawn_prefixes = YLeaf(YType.uint32, "brib-api-input-withdrawn-prefixes")

                                    self.brib_api_output_bytes_generated = YLeaf(YType.uint32, "brib-api-output-bytes-generated")

                                    self.brib_api_output_bytes_sent = YLeaf(YType.uint32, "brib-api-output-bytes-sent")

                                    self.brib_api_output_calls = YLeaf(YType.uint32, "brib-api-output-calls")

                                    self.brib_api_output_generation_time = YLeaf(YType.uint32, "brib-api-output-generation-time")

                                    self.brib_api_output_messages_sent = YLeaf(YType.uint32, "brib-api-output-messages-sent")

                                    self.brib_api_output_prefixes_advertised = YLeaf(YType.uint32, "brib-api-output-prefixes-advertised")

                                    self.brib_api_output_prefixes_withdrawn = YLeaf(YType.uint32, "brib-api-output-prefixes-withdrawn")

                                    self.brib_api_output_sending_time = YLeaf(YType.uint32, "brib-api-output-sending-time")

                                    self.configuration_items_processed = YLeaf(YType.uint32, "configuration-items-processed")

                                    self.configuration_processing_time = YLeaf(YType.uint32, "configuration-processing-time")

                                    self.current_clock_time = YLeaf(YType.uint64, "current-clock-time")

                                    self.edm_processing_time = YLeaf(YType.uint32, "edm-processing-time")

                                    self.edm_requests_count = YLeaf(YType.uint32, "edm-requests-count")

                                    self.in_event_attach_calls = YLeaf(YType.uint32, "in-event-attach-calls")

                                    self.in_out_event_attach_calls = YLeaf(YType.uint32, "in-out-event-attach-calls")

                                    self.initial_sync_sessions_added = YLeaf(YType.boolean, "initial-sync-sessions-added")

                                    self.instance_node_role = YLeaf(YType.boolean, "instance-node-role")

                                    self.io_handler_tm = YLeaf(YType.uint64, "io-handler-tm")

                                    self.io_timer_id = YLeaf(YType.uint32, "io-timer-id")

                                    self.io_tree_timer_expiry = YLeaf(YType.uint64, "io-tree-timer-expiry")

                                    self.io_tree_timer_left = YLeaf(YType.uint64, "io-tree-timer-left")

                                    self.nsr_last_reset_reason = YLeaf(YType.uint8, "nsr-last-reset-reason")

                                    self.out_event_attach_calls = YLeaf(YType.uint32, "out-event-attach-calls")

                                    self.proc_scoped_sync_state = YLeaf(YType.enumeration, "proc-scoped-sync-state")

                                    self.qad_ac_ks_failure = YLeaf(YType.uint32, "qad-ac-ks-failure")

                                    self.qad_ac_ks_received = YLeaf(YType.uint32, "qad-ac-ks-received")

                                    self.qad_init_drops = YLeaf(YType.uint32, "qad-init-drops")

                                    self.qad_messages_received = YLeaf(YType.uint32, "qad-messages-received")

                                    self.qad_messages_sent = YLeaf(YType.uint32, "qad-messages-sent")

                                    self.qad_processed = YLeaf(YType.uint32, "qad-processed")

                                    self.qad_recv_drops = YLeaf(YType.uint32, "qad-recv-drops")

                                    self.qad_resumes = YLeaf(YType.uint32, "qad-resumes")

                                    self.qad_send_drops = YLeaf(YType.uint32, "qad-send-drops")

                                    self.qad_send_failure = YLeaf(YType.uint32, "qad-send-failure")

                                    self.qad_suspends = YLeaf(YType.uint32, "qad-suspends")

                                    self.qad_timeout_received = YLeaf(YType.uint32, "qad-timeout-received")

                                    self.qad_timeout_recvd = YLeaf(YType.uint32, "qad-timeout-recvd")

                                    self.qadack_sent = YLeaf(YType.uint32, "qadack-sent")

                                    self.qadoos_drops = YLeaf(YType.uint32, "qadoos-drops")

                                    self.redcon_nsr_ready = YLeaf(YType.boolean, "redcon-nsr-ready")

                                    self.redcon_state_time = YLeaf(YType.uint32, "redcon-state-time")

                                    self.sec_active_nsr_state = YLeaf(YType.uint32, "sec-active-nsr-state")

                                    self.sec_active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "sec-active-nsrtcp-phase-two-enter-time")

                                    self.tep2p_auto_tunnel_enabled = YLeaf(YType.boolean, "tep2p-auto-tunnel-enabled")

                                    self.total_neighbors_with_pending_postits = YLeaf(YType.uint32, "total-neighbors-with-pending-postits")

                                    self.total_outstanding_postits = YLeaf(YType.uint32, "total-outstanding-postits")

                                    self.updgen_handler_tm = YLeaf(YType.uint64, "updgen-handler-tm")

                                    self.updgen_timer_id = YLeaf(YType.uint32, "updgen-timer-id")

                                    self.updgen_tree_timer_expiry = YLeaf(YType.uint64, "updgen-tree-timer-expiry")

                                    self.updgen_tree_timer_left = YLeaf(YType.uint64, "updgen-tree-timer-left")

                                    self.ds_npl = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                    self.ds_npl.parent = self
                                    self._children_name_map["ds_npl"] = "ds-npl"
                                    self._children_yang_names.add("ds-npl")

                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                    self.ipv4rib_server.parent = self
                                    self._children_name_map["ipv4rib_server"] = "ipv4rib-server"
                                    self._children_yang_names.add("ipv4rib-server")

                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                    self.ipv6rib_server.parent = self
                                    self._children_name_map["ipv6rib_server"] = "ipv6rib-server"
                                    self._children_yang_names.add("ipv6rib-server")

                                    self.lsd_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self._children_name_map["lsd_connection"] = "lsd-connection"
                                    self._children_yang_names.add("lsd-connection")

                                    self.te_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                    self.te_connection.parent = self
                                    self._children_name_map["te_connection"] = "te-connection"
                                    self._children_yang_names.add("te-connection")

                                    self.active_nsr_mode_enter_time = YList(self)
                                    self.active_nsrfo_time = YList(self)
                                    self.issu_milestone = YList(self)
                                    self.postit_count_info = YList(self)
                                    self.standby_nsr_mode_enter_time = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_, ['active_nsr_state', 'active_nsrtcp_phase_two_enter_time', 'brib_api_input_bytes', 'brib_api_input_messages', 'brib_api_input_prefixes_received', 'brib_api_input_processing_time', 'brib_api_input_withdrawn_prefixes', 'brib_api_output_bytes_generated', 'brib_api_output_bytes_sent', 'brib_api_output_calls', 'brib_api_output_generation_time', 'brib_api_output_messages_sent', 'brib_api_output_prefixes_advertised', 'brib_api_output_prefixes_withdrawn', 'brib_api_output_sending_time', 'configuration_items_processed', 'configuration_processing_time', 'current_clock_time', 'edm_processing_time', 'edm_requests_count', 'in_event_attach_calls', 'in_out_event_attach_calls', 'initial_sync_sessions_added', 'instance_node_role', 'io_handler_tm', 'io_timer_id', 'io_tree_timer_expiry', 'io_tree_timer_left', 'nsr_last_reset_reason', 'out_event_attach_calls', 'proc_scoped_sync_state', 'qad_ac_ks_failure', 'qad_ac_ks_received', 'qad_init_drops', 'qad_messages_received', 'qad_messages_sent', 'qad_processed', 'qad_recv_drops', 'qad_resumes', 'qad_send_drops', 'qad_send_failure', 'qad_suspends', 'qad_timeout_received', 'qad_timeout_recvd', 'qadack_sent', 'qadoos_drops', 'redcon_nsr_ready', 'redcon_state_time', 'sec_active_nsr_state', 'sec_active_nsrtcp_phase_two_enter_time', 'tep2p_auto_tunnel_enabled', 'total_neighbors_with_pending_postits', 'total_outstanding_postits', 'updgen_handler_tm', 'updgen_timer_id', 'updgen_tree_timer_expiry', 'updgen_tree_timer_left'], name, value)


                                class ActiveNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, self).__init__()

                                        self.yang_name = "active-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "active-nsr-mode-enter-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, ['entry'], name, value)


                                class ActiveNsrfoTime(Entity):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, self).__init__()

                                        self.yang_name = "active-nsrfo-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "active-nsrfo-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, ['entry'], name, value)


                                class DsNpl(Entity):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:   :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:   :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\:  str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\:  bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\:  str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, self).__init__()

                                        self.yang_name = "ds-npl"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"npl-endpoint" : ("npl_endpoint", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint), "npl-priority-statistic" : ("npl_priority_statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic)}

                                        self.dir_service_conn_state = YLeaf(YType.enumeration, "dir-service-conn-state")

                                        self.dsissu_status_flag = YLeaf(YType.uint32, "dsissu-status-flag")

                                        self.issu_mgr_conn_state = YLeaf(YType.enumeration, "issu-mgr-conn-state")

                                        self.issu_phase = YLeaf(YType.str, "issu-phase")

                                        self.issu_type_ng = YLeaf(YType.boolean, "issu-type-ng")

                                        self.issuha_option = YLeaf(YType.str, "issuha-option")

                                        self.local_ds_handle = YLeaf(YType.uint64, "local-ds-handle")

                                        self.service_name = YLeaf(YType.str, "service-name")

                                        self.npl_endpoint = YList(self)
                                        self.npl_priority_statistic = YList(self)
                                        self._segment_path = lambda: "ds-npl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, ['dir_service_conn_state', 'dsissu_status_flag', 'issu_mgr_conn_state', 'issu_phase', 'issu_type_ng', 'issuha_option', 'local_ds_handle', 'service_name'], name, value)


                                    class NplEndpoint(Entity):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\:  str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\:  str
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, self).__init__()

                                            self.yang_name = "npl-endpoint"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"endpoint" : ("endpoint", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint)}

                                            self.endpoint_active_flag = YLeaf(YType.boolean, "endpoint-active-flag")

                                            self.endpoint_handle = YLeaf(YType.uint64, "endpoint-handle")

                                            self.endpoint_issu_role = YLeaf(YType.str, "endpoint-issu-role")

                                            self.endpoint_name = YLeaf(YType.str, "endpoint-name")

                                            self.endpoint_stale_flag = YLeaf(YType.boolean, "endpoint-stale-flag")

                                            self.expected_sequence_num = YLeaf(YType.uint32, "expected-sequence-num")

                                            self.msg_size = YLeaf(YType.uint32, "msg-size")

                                            self.node_id = YLeaf(YType.str, "node-id")

                                            self.sync_group_name = YLeaf(YType.str, "sync-group-name")

                                            self.wheel_id = YLeaf(YType.uint32, "wheel-id")

                                            self.endpoint = YList(self)
                                            self._segment_path = lambda: "npl-endpoint"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, ['endpoint_active_flag', 'endpoint_handle', 'endpoint_issu_role', 'endpoint_name', 'endpoint_stale_flag', 'expected_sequence_num', 'msg_size', 'node_id', 'sync_group_name', 'wheel_id'], name, value)


                                        class Endpoint(Entity):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                self.yang_name = "endpoint"
                                                self.yang_parent_name = "npl-endpoint"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "endpoint"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, ['entry'], name, value)


                                    class NplPriorityStatistic(Entity):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, self).__init__()

                                            self.yang_name = "npl-priority-statistic"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"num-recv" : ("num_recv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv), "num-recv-drop" : ("num_recv_drop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop), "num-sent" : ("num_sent", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent), "num-sent-drop" : ("num_sent_drop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop)}

                                            self.num_recv = YList(self)
                                            self.num_recv_drop = YList(self)
                                            self.num_sent = YList(self)
                                            self.num_sent_drop = YList(self)
                                            self._segment_path = lambda: "npl-priority-statistic"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, [], name, value)


                                        class NumRecv(Entity):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                self.yang_name = "num-recv"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "num-recv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, ['entry'], name, value)


                                        class NumRecvDrop(Entity):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                self.yang_name = "num-recv-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray)}

                                                self.nsr_pl_recv_drop_array = YList(self)
                                                self._segment_path = lambda: "num-recv-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                            class NsrPlRecvDropArray(Entity):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-recv-drop-array"
                                                    self.yang_parent_name = "num-recv-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                                        class NumSent(Entity):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                self.yang_name = "num-sent"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "num-sent"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, ['entry'], name, value)


                                        class NumSentDrop(Entity):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                self.yang_name = "num-sent-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray)}

                                                self.nsr_pl_send_drop_array = YList(self)
                                                self._segment_path = lambda: "num-sent-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                            class NsrPlSendDropArray(Entity):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-send-drop-array"
                                                    self.yang_parent_name = "num-sent-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "nsr-pl-send-drop-array"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                                class Ipv4RibServer(Entity):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, self).__init__()

                                        self.yang_name = "ipv4rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                        self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                        self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                        self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                        self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                        self._children_yang_names.add("first-rib-connection-down-timestamp")

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                        self._children_yang_names.add("first-rib-connection-up-timestamp")

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._children_yang_names.add("last-rib-connection-down-timestamp")

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                        self._children_yang_names.add("last-rib-connection-up-timestamp")
                                        self._segment_path = lambda: "ipv4rib-server"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Ipv6RibServer(Entity):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, self).__init__()

                                        self.yang_name = "ipv6rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                        self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                        self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                        self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                        self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                        self._children_yang_names.add("first-rib-connection-down-timestamp")

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                        self._children_yang_names.add("first-rib-connection-up-timestamp")

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._children_yang_names.add("last-rib-connection-down-timestamp")

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                        self._children_yang_names.add("last-rib-connection-up-timestamp")
                                        self._segment_path = lambda: "ipv6rib-server"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class IssuMilestone(Entity):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\:  str
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, self).__init__()

                                        self.yang_name = "issu-milestone"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.milestone_met_timestamp = YLeaf(YType.uint32, "milestone-met-timestamp")

                                        self.milestone_name = YLeaf(YType.str, "milestone-name")

                                        self.milestone_start_timestamp = YLeaf(YType.uint32, "milestone-start-timestamp")
                                        self._segment_path = lambda: "issu-milestone"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, ['milestone_met_timestamp', 'milestone_name', 'milestone_start_timestamp'], name, value)


                                class LsdConnection(Entity):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, self).__init__()

                                        self.yang_name = "lsd-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                        self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                        self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                        self._children_yang_names.add("first-connection-down-timestamp")

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                        self._children_yang_names.add("first-connection-up-timestamp")

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._children_yang_names.add("last-connection-down-timestamp")

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                        self._children_yang_names.add("last-connection-up-timestamp")
                                        self._segment_path = lambda: "lsd-connection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class PostitCountInfo(Entity):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, self).__init__()

                                        self.yang_name = "postit-count-info"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.postit_count = YLeaf(YType.uint32, "postit-count")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "postit-count-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, ['postit_count', 'vrf_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "postit-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class StandbyNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, self).__init__()

                                        self.yang_name = "standby-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "standby-nsr-mode-enter-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, ['entry'], name, value)


                                class TeConnection(Entity):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, self).__init__()

                                        self.yang_name = "te-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                        self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                        self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                        self._children_yang_names.add("first-connection-down-timestamp")

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                        self._children_yang_names.add("first-connection-up-timestamp")

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._children_yang_names.add("last-connection-down-timestamp")

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                        self._children_yang_names.add("last-connection-up-timestamp")
                                        self._segment_path = lambda: "te-connection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                    self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                    self.high_throttled_read_count = YLeaf(YType.uint32, "high-throttled-read-count")

                                    self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                    self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                    self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                    self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                    self.low_throttled_read_count = YLeaf(YType.uint32, "low-throttled-read-count")

                                    self.lpts_calls = YLeaf(YType.uint32, "lpts-calls")

                                    self.lpts_set_up_time = YLeaf(YType.uint32, "lpts-set-up-time")

                                    self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                    self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                    self.read_throttles_count = YLeaf(YType.uint32, "read-throttles-count")

                                    self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                    self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                    self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                    self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                    self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                    self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                    self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, ['data_bytes_read', 'data_bytes_written', 'high_throttled_read_count', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'low_throttled_read_count', 'lpts_calls', 'lpts_set_up_time', 'read_calls_count', 'read_messages_count', 'read_throttles_count', 'subgroup_list_time', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.established_neighbors_count = YLeaf(YType.uint32, "established-neighbors-count")

                                self.neighbors_count = YLeaf(YType.uint32, "neighbors-count")

                                self.network_count = YLeaf(YType.uint32, "network-count")

                                self.notifications_received = YLeaf(YType.uint32, "notifications-received")

                                self.notifications_sent = YLeaf(YType.uint32, "notifications-sent")

                                self.path_count = YLeaf(YType.uint32, "path-count")

                                self.update_messages_received = YLeaf(YType.uint32, "update-messages-received")

                                self.update_messages_sent = YLeaf(YType.uint32, "update-messages-sent")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf, ['established_neighbors_count', 'neighbors_count', 'network_count', 'notifications_received', 'notifications_sent', 'path_count', 'update_messages_received', 'update_messages_sent'], name, value)


                    class Sessions(Entity):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions, self).__init__()

                            self.yang_name = "sessions"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"session" : ("session", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session)}

                            self.session = YList(self)
                            self._segment_path = lambda: "sessions"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions, [], name, value)


                        class Session(Entity):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\:  bool
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress)}
                                self._child_list_classes = {}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                self.description = YLeaf(YType.str, "description")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.postit_pending = YLeaf(YType.boolean, "postit-pending")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")
                                self._segment_path = lambda: "session" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session, ['neighbor_address', 'connection_state', 'description', 'is_local_address_configured', 'local_as', 'messages_queued_in', 'messages_queued_out', 'nsr_enabled', 'nsr_state', 'postit_pending', 'remote_as', 'speaker_id', 'vrf_name'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundErrorNeighbors(Entity):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors, self).__init__()

                            self.yang_name = "update-inbound-error-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update-inbound-error-neighbor" : ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor)}

                            self.update_inbound_error_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-error-neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors, [], name, value)


                        class UpdateInboundErrorNeighbor(Entity):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\:  bool
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                self.yang_name = "update-inbound-error-neighbor"
                                self.yang_parent_name = "update-inbound-error-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"first-update-error-handling-reset-timestamp" : ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp), "first-update-malformed-timestamp" : ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp), "first-update-memory-allocation-fail-timestamp" : ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp), "last-error-handling-reset-timestamp" : ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp), "last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)}
                                self._child_list_classes = {"establishment-action-count" : ("establishment_action_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount), "update-error-message" : ("update_error_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.establishment_total_update_message_count = YLeaf(YType.uint32, "establishment-total-update-message-count")

                                self.last_error_handling_reset_age = YLeaf(YType.uint32, "last-error-handling-reset-age")

                                self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                self.total_update_message_count = YLeaf(YType.uint32, "total-update-message-count")

                                self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                self.update_error_handling_avoid_reset = YLeaf(YType.boolean, "update-error-handling-avoid-reset")

                                self.update_error_handling_reset_count = YLeaf(YType.uint32, "update-error-handling-reset-count")

                                self.update_error_message_list_count = YLeaf(YType.uint32, "update-error-message-list-count")

                                self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"
                                self._children_yang_names.add("first-update-error-handling-reset-timestamp")

                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"
                                self._children_yang_names.add("first-update-malformed-timestamp")

                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"
                                self._children_yang_names.add("first-update-memory-allocation-fail-timestamp")

                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"
                                self._children_yang_names.add("last-error-handling-reset-timestamp")

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._children_yang_names.add("last-update-malformed-timestamp")

                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                self._children_yang_names.add("update-neighbor-address")

                                self.establishment_action_count = YList(self)
                                self.update_error_message = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', 'establishment_total_update_message_count', 'last_error_handling_reset_age', 'last_update_malformed_age', 'last_update_memory_allocation_fail_age', 'total_update_message_count', 'update_attribute_discard_count', 'update_error_handling_avoid_reset', 'update_error_handling_reset_count', 'update_error_message_list_count', 'update_malformed_message_count', 'update_memory_allocation_fail_count', 'update_vrf_name'], name, value)


                            class EstablishmentActionCount(Entity):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                    self.yang_name = "establishment-action-count"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "establishment-action-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, ['entry'], name, value)


                            class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "first-update-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-error-handling-reset-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class FirstUpdateMalformedTimestamp(Entity):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "first-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastErrorHandlingResetTimestamp(Entity):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "last-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-error-handling-reset-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateErrorMessage(Entity):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                    self.yang_name = "update-error-message"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-message-reset-data" : ("update_message_reset_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData), "update-message-timestamp" : ("update_message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)}
                                    self._child_list_classes = {"update-error-element" : ("update_error_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement), "update-message-data" : ("update_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)}

                                    self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                    self.update_error_final_action = YLeaf(YType.enumeration, "update-error-final-action")

                                    self.update_error_nlri_address_family = YLeaf(YType.enumeration, "update-error-nlri-address-family")

                                    self.update_error_nlri_string = YLeaf(YType.str, "update-error-nlri-string")

                                    self.update_error_nlri_string_truncated = YLeaf(YType.boolean, "update-error-nlri-string-truncated")

                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self._children_name_map["update_message_reset_data"] = "update-message-reset-data"
                                    self._children_yang_names.add("update-message-reset-data")

                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self
                                    self._children_name_map["update_message_timestamp"] = "update-message-timestamp"
                                    self._children_yang_names.add("update-message-timestamp")

                                    self.update_error_element = YList(self)
                                    self.update_message_data = YList(self)
                                    self._segment_path = lambda: "update-error-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, ['update_attribute_discard_count', 'update_error_final_action', 'update_error_nlri_address_family', 'update_error_nlri_string', 'update_error_nlri_string_truncated'], name, value)


                                class UpdateErrorElement(Entity):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                        self.yang_name = "update-error-element"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                        self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                        self.update_attribute_length = YLeaf(YType.uint16, "update-attribute-length")

                                        self.update_error_action = YLeaf(YType.enumeration, "update-error-action")

                                        self.update_error_data = YLeaf(YType.str, "update-error-data")

                                        self.update_error_data_length = YLeaf(YType.uint16, "update-error-data-length")
                                        self._segment_path = lambda: "update-error-element"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, ['update_attribute_code', 'update_attribute_flags', 'update_attribute_length', 'update_error_action', 'update_error_data', 'update_error_data_length'], name, value)


                                class UpdateMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                        self.yang_name = "update-message-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "update-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, ['entry'], name, value)


                                class UpdateMessageResetData(Entity):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                        self.yang_name = "update-message-reset-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_error_reset_notification_code = YLeaf(YType.uint8, "update-error-reset-notification-code")

                                        self.update_error_reset_notification_data = YLeaf(YType.str, "update-error-reset-notification-data")

                                        self.update_error_reset_notification_data_length = YLeaf(YType.uint16, "update-error-reset-notification-data-length")

                                        self.update_error_reset_notification_sub_code = YLeaf(YType.uint16, "update-error-reset-notification-sub-code")

                                        self.update_error_reset_reason = YLeaf(YType.enumeration, "update-error-reset-reason")
                                        self._segment_path = lambda: "update-message-reset-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, ['update_error_reset_notification_code', 'update_error_reset_notification_data', 'update_error_reset_notification_data_length', 'update_error_reset_notification_sub_code', 'update_error_reset_reason'], name, value)


                                class UpdateMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                        self.yang_name = "update-message-timestamp"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "update-message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "update-neighbor-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundErrorVrf(Entity):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf, self).__init__()

                            self.yang_name = "update-inbound-error-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                            self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                            self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                            self._children_yang_names.add("last-update-malformed-timestamp")
                            self._segment_path = lambda: "update-inbound-error-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf, ['last_update_malformed_age', 'update_malformed_message_count', 'update_malformed_neighbor_count', 'update_vrf_name'], name, value)


                        class LastUpdateMalformedTimestamp(Entity):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                self.yang_name = "last-update-malformed-timestamp"
                                self.yang_parent_name = "update-inbound-error-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-malformed-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                    class UpdateInboundFilterNeighbors(Entity):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors, self).__init__()

                            self.yang_name = "update-inbound-filter-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update-inbound-filter-neighbor" : ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor)}

                            self.update_inbound_filter_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-filter-neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors, [], name, value)


                        class UpdateInboundFilterNeighbor(Entity):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbor"
                                self.yang_parent_name = "update-inbound-filter-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"first-update-filtered-timestamp" : ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp), "last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)}
                                self._child_list_classes = {"update-attribute-filter-attributes" : ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes), "update-filter-message" : ("update_filter_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.configured_update_filter_message_buffer_count = YLeaf(YType.uint32, "configured-update-filter-message-buffer-count")

                                self.establishment_total_filter_update_message_count = YLeaf(YType.uint32, "establishment-total-filter-update-message-count")

                                self.establishment_update_filtered_message_count = YLeaf(YType.uint32, "establishment-update-filtered-message-count")

                                self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                self.message_update_attribute_filtering_enabled = YLeaf(YType.boolean, "message-update-attribute-filtering-enabled")

                                self.operational_update_attribute_filtering_enabled = YLeaf(YType.boolean, "operational-update-attribute-filtering-enabled")

                                self.operational_update_filter_message_buffer_count = YLeaf(YType.uint32, "operational-update-filter-message-buffer-count")

                                self.total_filter_update_message_count = YLeaf(YType.uint32, "total-filter-update-message-count")

                                self.update_attribute_filter_group_name = YLeaf(YType.str, "update-attribute-filter-group-name")

                                self.update_filter_logging_enabled = YLeaf(YType.boolean, "update-filter-logging-enabled")

                                self.update_filter_message_buffer_circular = YLeaf(YType.boolean, "update-filter-message-buffer-circular")

                                self.update_filter_message_list_count = YLeaf(YType.uint32, "update-filter-message-list-count")

                                self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"
                                self._children_yang_names.add("first-update-filtered-timestamp")

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._children_yang_names.add("last-update-filtered-timestamp")

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                self._children_yang_names.add("update-neighbor-address")

                                self.update_attribute_filter_attributes = YList(self)
                                self.update_filter_message = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', 'configured_update_filter_message_buffer_count', 'establishment_total_filter_update_message_count', 'establishment_update_filtered_message_count', 'last_update_filtered_age', 'message_update_attribute_filtering_enabled', 'operational_update_attribute_filtering_enabled', 'operational_update_filter_message_buffer_count', 'total_filter_update_message_count', 'update_attribute_filter_group_name', 'update_filter_logging_enabled', 'update_filter_message_buffer_circular', 'update_filter_message_list_count', 'update_filtered_message_count', 'update_vrf_name'], name, value)


                            class FirstUpdateFilteredTimestamp(Entity):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "first-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateAttributeFilterAttributes(Entity):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                    self.yang_name = "update-attribute-filter-attributes"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"last-update-filter-match-timestamp" : ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp)}
                                    self._child_list_classes = {}

                                    self.establishment_update_filter_match_count = YLeaf(YType.uint32, "establishment-update-filter-match-count")

                                    self.last_update_filter_match_age = YLeaf(YType.uint32, "last-update-filter-match-age")

                                    self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")

                                    self.update_filter_match_count = YLeaf(YType.uint32, "update-filter-match-count")

                                    self.update_internal_attribute_code = YLeaf(YType.uint32, "update-internal-attribute-code")

                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                    self._children_yang_names.add("last-update-filter-match-timestamp")
                                    self._segment_path = lambda: "update-attribute-filter-attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, ['establishment_update_filter_match_count', 'last_update_filter_match_age', 'update_filter_action', 'update_filter_match_count', 'update_internal_attribute_code'], name, value)


                                class LastUpdateFilterMatchTimestamp(Entity):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                        self.yang_name = "last-update-filter-match-timestamp"
                                        self.yang_parent_name = "update-attribute-filter-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-filter-match-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateFilterMessage(Entity):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                    self.yang_name = "update-filter-message"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-filter-message-timestamp" : ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)}
                                    self._child_list_classes = {"update-filter-element" : ("update_filter_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement), "update-filter-message-data" : ("update_filter_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)}

                                    self.update_filter_final_action = YLeaf(YType.enumeration, "update-filter-final-action")

                                    self.update_filter_nlri_address_family = YLeaf(YType.enumeration, "update-filter-nlri-address-family")

                                    self.update_filter_nlri_string = YLeaf(YType.str, "update-filter-nlri-string")

                                    self.update_filter_nlri_string_truncated = YLeaf(YType.boolean, "update-filter-nlri-string-truncated")

                                    self.update_filtered_attribute_count = YLeaf(YType.uint32, "update-filtered-attribute-count")

                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"
                                    self._children_yang_names.add("update-filter-message-timestamp")

                                    self.update_filter_element = YList(self)
                                    self.update_filter_message_data = YList(self)
                                    self._segment_path = lambda: "update-filter-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, ['update_filter_final_action', 'update_filter_nlri_address_family', 'update_filter_nlri_string', 'update_filter_nlri_string_truncated', 'update_filtered_attribute_count'], name, value)


                                class UpdateFilterElement(Entity):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                        self.yang_name = "update-filter-element"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                        self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                        self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")
                                        self._segment_path = lambda: "update-filter-element"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, ['update_attribute_code', 'update_attribute_flags', 'update_filter_action'], name, value)


                                class UpdateFilterMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                        self.yang_name = "update-filter-message-data"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "update-filter-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, ['entry'], name, value)


                                class UpdateFilterMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                        self.yang_name = "update-filter-message-timestamp"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "update-filter-message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "update-neighbor-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundFilterVrf(Entity):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf, self).__init__()

                            self.yang_name = "update-inbound-filter-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                            self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                            self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                            self._children_yang_names.add("last-update-filtered-timestamp")
                            self._segment_path = lambda: "update-inbound-filter-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count', 'update_vrf_name'], name, value)


                        class LastUpdateFilteredTimestamp(Entity):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                self.yang_name = "last-update-filtered-timestamp"
                                self.yang_parent_name = "update-inbound-filter-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-filtered-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                class LabelEntries(Entity):
                    """
                    BGP Label Table
                    
                    .. attribute:: label_entry
                    
                    	BGP Label Entry
                    	**type**\: list of    :py:class:`LabelEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelEntries, self).__init__()

                        self.yang_name = "label-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"label-entry" : ("label_entry", Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry)}

                        self.label_entry = YList(self)
                        self._segment_path = lambda: "label-entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries, [], name, value)


                    class LabelEntry(Entity):
                        """
                        BGP Label Entry
                        
                        .. attribute:: label  <key>
                        
                        	Label index
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: entry
                        
                        	entry
                        	**type**\:   :py:class:`Entry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry, self).__init__()

                            self.yang_name = "label-entry"
                            self.yang_parent_name = "label-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"entry" : ("entry", Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry)}
                            self._child_list_classes = {}

                            self.label = YLeaf(YType.int32, "label")

                            self.entry = Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry()
                            self.entry.parent = self
                            self._children_name_map["entry"] = "entry"
                            self._children_yang_names.add("entry")
                            self._segment_path = lambda: "label-entry" + "[label='" + self.label.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry, ['label'], name, value)


                        class Entry(Entity):
                            """
                            entry
                            
                            .. attribute:: inactive
                            
                            	inactive
                            	**type**\:  bool
                            
                            .. attribute:: info
                            
                            	info
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ip6
                            
                            	ip6
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: masklen
                            
                            	masklen
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rds
                            
                            	rds
                            	**type**\:  str
                            
                            .. attribute:: refcount
                            
                            	refcount
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpc_set_id
                            
                            	rpc set id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ts_sec
                            
                            	ts sec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ts_ssec
                            
                            	ts ssec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	vrf
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry, self).__init__()

                                self.yang_name = "entry"
                                self.yang_parent_name = "label-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.inactive = YLeaf(YType.boolean, "inactive")

                                self.info = YLeaf(YType.uint16, "info")

                                self.ip = YLeaf(YType.str, "ip")

                                self.ip6 = YLeaf(YType.str, "ip6")

                                self.label = YLeaf(YType.uint32, "label")

                                self.masklen = YLeaf(YType.uint16, "masklen")

                                self.rds = YLeaf(YType.str, "rds")

                                self.refcount = YLeaf(YType.uint32, "refcount")

                                self.rpc_set_id = YLeaf(YType.uint32, "rpc-set-id")

                                self.ts_sec = YLeaf(YType.uint32, "ts-sec")

                                self.ts_ssec = YLeaf(YType.uint32, "ts-ssec")

                                self.vrf = YLeaf(YType.str, "vrf")
                                self._segment_path = lambda: "entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry, ['inactive', 'info', 'ip', 'ip6', 'label', 'masklen', 'rds', 'refcount', 'rpc_set_id', 'ts_sec', 'ts_ssec', 'vrf'], name, value)


                class LabelRpfEntries(Entity):
                    """
                    BGP Label RPF Table
                    
                    .. attribute:: label_rpf_entry
                    
                    	BGP Label RPF Entry
                    	**type**\: list of    :py:class:`LabelRpfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries, self).__init__()

                        self.yang_name = "label-rpf-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"label-rpf-entry" : ("label_rpf_entry", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry)}

                        self.label_rpf_entry = YList(self)
                        self._segment_path = lambda: "label-rpf-entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries, [], name, value)


                    class LabelRpfEntry(Entity):
                        """
                        BGP Label RPF Entry
                        
                        .. attribute:: label  <key>
                        
                        	Label index
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf
                        
                        	rpf
                        	**type**\:   :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry, self).__init__()

                            self.yang_name = "label-rpf-entry"
                            self.yang_parent_name = "label-rpf-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rpf" : ("rpf", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf)}
                            self._child_list_classes = {}

                            self.label = YLeaf(YType.int32, "label")

                            self.rpf = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf()
                            self.rpf.parent = self
                            self._children_name_map["rpf"] = "rpf"
                            self._children_yang_names.add("rpf")
                            self._segment_path = lambda: "label-rpf-entry" + "[label='" + self.label.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry, ['label'], name, value)


                        class Rpf(Entity):
                            """
                            rpf
                            
                            .. attribute:: flags
                            
                            	flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: install
                            
                            	install
                            	**type**\:   :py:class:`BgpLabelRpfInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpLabelRpfInstall>`
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpf
                            
                            	rpf
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "label-rpf-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpf" : ("rpf", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf)}

                                self.flags = YLeaf(YType.uint32, "flags")

                                self.install = YLeaf(YType.enumeration, "install")

                                self.label = YLeaf(YType.uint32, "label")

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf, ['flags', 'install', 'label'], name, value)


                            class Rpf(Entity):
                                """
                                rpf
                                
                                .. attribute:: count
                                
                                	count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip
                                
                                	ip
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ip6
                                
                                	ip6
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.count = YLeaf(YType.uint32, "count")

                                    self.flags = YLeaf(YType.uint32, "flags")

                                    self.ip = YLeaf(YType.str, "ip")

                                    self.ip6 = YLeaf(YType.str, "ip6")
                                    self._segment_path = lambda: "rpf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf, ['count', 'flags', 'ip', 'ip6'], name, value)


                class LabelSummary(Entity):
                    """
                    BGP Label Summary
                    
                    .. attribute:: stats
                    
                    	stats
                    	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelSummary, self).__init__()

                        self.yang_name = "label-summary"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"stats" : ("stats", Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats)}
                        self._child_list_classes = {}

                        self.stats = Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats()
                        self.stats.parent = self
                        self._children_name_map["stats"] = "stats"
                        self._children_yang_names.add("stats")
                        self._segment_path = lambda: "label-summary"


                    class Stats(Entity):
                        """
                        stats
                        
                        .. attribute:: bgp_label_rpf_lists
                        
                        	bgp label rpf lists
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bgp_label_rpf_nodes
                        
                        	bgp label rpf nodes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_asbr_nh
                        
                        	nBGP LABEL ALLOC TYPE ASBR NH
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv4
                        
                        	nBGP LABEL ALLOC TYPE CE IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv6
                        
                        	nBGP LABEL ALLOC TYPE CE IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_labels
                        
                        	nBGP LABELS
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats, self).__init__()

                            self.yang_name = "stats"
                            self.yang_parent_name = "label-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.bgp_label_rpf_lists = YLeaf(YType.uint32, "bgp-label-rpf-lists")

                            self.bgp_label_rpf_nodes = YLeaf(YType.uint32, "bgp-label-rpf-nodes")

                            self.nbgp_label_alloc_type_asbr_nh = YLeaf(YType.uint32, "nbgp-label-alloc-type-asbr-nh")

                            self.nbgp_label_alloc_type_ce_ipv4 = YLeaf(YType.uint32, "nbgp-label-alloc-type-ce-ipv4")

                            self.nbgp_label_alloc_type_ce_ipv6 = YLeaf(YType.uint32, "nbgp-label-alloc-type-ce-ipv6")

                            self.nbgp_label_alloc_type_gbl_ipv4 = YLeaf(YType.uint32, "nbgp-label-alloc-type-gbl-ipv4")

                            self.nbgp_label_alloc_type_gbl_ipv6 = YLeaf(YType.uint32, "nbgp-label-alloc-type-gbl-ipv6")

                            self.nbgp_label_alloc_type_tbl_ipv4 = YLeaf(YType.uint32, "nbgp-label-alloc-type-tbl-ipv4")

                            self.nbgp_label_alloc_type_tbl_ipv6 = YLeaf(YType.uint32, "nbgp-label-alloc-type-tbl-ipv6")

                            self.nbgp_label_alloc_type_vpn_ipv4 = YLeaf(YType.uint32, "nbgp-label-alloc-type-vpn-ipv4")

                            self.nbgp_label_alloc_type_vpn_ipv6 = YLeaf(YType.uint32, "nbgp-label-alloc-type-vpn-ipv6")

                            self.nbgp_label_alloc_type_vrf_ipv4 = YLeaf(YType.uint32, "nbgp-label-alloc-type-vrf-ipv4")

                            self.nbgp_label_alloc_type_vrf_ipv6 = YLeaf(YType.uint32, "nbgp-label-alloc-type-vrf-ipv6")

                            self.nbgp_labels = YLeaf(YType.uint32, "nbgp-labels")
                            self._segment_path = lambda: "stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats, ['bgp_label_rpf_lists', 'bgp_label_rpf_nodes', 'nbgp_label_alloc_type_asbr_nh', 'nbgp_label_alloc_type_ce_ipv4', 'nbgp_label_alloc_type_ce_ipv6', 'nbgp_label_alloc_type_gbl_ipv4', 'nbgp_label_alloc_type_gbl_ipv6', 'nbgp_label_alloc_type_tbl_ipv4', 'nbgp_label_alloc_type_tbl_ipv6', 'nbgp_label_alloc_type_vpn_ipv4', 'nbgp_label_alloc_type_vpn_ipv6', 'nbgp_label_alloc_type_vrf_ipv4', 'nbgp_label_alloc_type_vrf_ipv6', 'nbgp_labels'], name, value)


                class RpkiRefreshAfs(Entity):
                    """
                    RPKI Refresh Table (per AF)
                    
                    .. attribute:: rpki_refresh_af
                    
                    	RPKI Refresh List
                    	**type**\: list of    :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs, self).__init__()

                        self.yang_name = "rpki-refresh-afs"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-refresh-af" : ("rpki_refresh_af", Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf)}

                        self.rpki_refresh_af = YList(self)
                        self._segment_path = lambda: "rpki-refresh-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs, [], name, value)


                    class RpkiRefreshAf(Entity):
                        """
                        RPKI Refresh List
                        
                        .. attribute:: af_name  <key>
                        
                        	Adress family
                        	**type**\:   :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: refresh_entry
                        
                        	Array of refresh entries
                        	**type**\: list of    :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf, self).__init__()

                            self.yang_name = "rpki-refresh-af"
                            self.yang_parent_name = "rpki-refresh-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"refresh-entry" : ("refresh_entry", Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry)}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.refresh_entry = YList(self)
                            self._segment_path = lambda: "rpki-refresh-af" + "[af-name='" + self.af_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf, ['af_name'], name, value)


                        class RefreshEntry(Entity):
                            """
                            Array of refresh entries
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: drop
                            
                            	BGP paths were dropped
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	BGP neighbor
                            	**type**\:  str
                            
                            .. attribute:: paths
                            
                            	Number of BGP paths modified or dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: policy
                            
                            	Route Policy
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry, self).__init__()

                                self.yang_name = "refresh-entry"
                                self.yang_parent_name = "rpki-refresh-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.drop = YLeaf(YType.boolean, "drop")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.paths = YLeaf(YType.uint32, "paths")

                                self.policy = YLeaf(YType.str, "policy")
                                self._segment_path = lambda: "refresh-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry, ['af_name', 'drop', 'neighbor', 'paths', 'policy'], name, value)


                class RpkiRoutes(Entity):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes, self).__init__()

                        self.yang_name = "rpki-routes"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-route" : ("rpki_route", Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute)}

                        self.rpki_route = YList(self)
                        self._segment_path = lambda: "rpki-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes, [], name, value)


                    class RpkiRoute(Entity):
                        """
                        RPKI Path Group
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute, self).__init__()

                            self.yang_name = "rpki-route"
                            self.yang_parent_name = "rpki-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpki-route" : ("rpki_route", Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute)}

                            self.address = YLeaf(YType.str, "address")

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.maximum = YLeaf(YType.int32, "maximum")

                            self.minimum = YLeaf(YType.int32, "minimum")

                            self.rpki_route = YList(self)
                            self._segment_path = lambda: "rpki-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute, ['address', 'af_name', 'maximum', 'minimum'], name, value)


                        class RpkiRoute(Entity):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\:  str
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\:  str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute, self).__init__()

                                self.yang_name = "rpki-route"
                                self.yang_parent_name = "rpki-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address = YLeaf(YType.str, "address")

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.as_ = YLeaf(YType.uint32, "as")

                                self.max_prefix_len = YLeaf(YType.uint8, "max-prefix-len")

                                self.min_prefix_len = YLeaf(YType.uint8, "min-prefix-len")

                                self.refcount = YLeaf(YType.uint16, "refcount")

                                self.server = YLeaf(YType.str, "server")

                                self.stale = YLeaf(YType.boolean, "stale")
                                self._segment_path = lambda: "rpki-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute, ['address', 'af_name', 'as_', 'max_prefix_len', 'min_prefix_len', 'refcount', 'server', 'stale'], name, value)


                class RpkiServerList(Entity):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiServerList, self).__init__()

                        self.yang_name = "rpki-server-list"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-server" : ("rpki_server", Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer)}

                        self.rpki_server = YList(self)
                        self._segment_path = lambda: "rpki-server-list"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiServerList, [], name, value)


                    class RpkiServer(Entity):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:   :py:class:`BgpRpkiCreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreason>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\:  str
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\:  str
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:   :py:class:`BgpRpkiPerror <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerror>`
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:   :py:class:`BgpRpkiPstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstate>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:   :py:class:`BgpRpkiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiState>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\:  str
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer, self).__init__()

                            self.yang_name = "rpki-server"
                            self.yang_parent_name = "rpki-server-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.close_reason = YLeaf(YType.enumeration, "close-reason")

                            self.close_time = YLeaf(YType.uint32, "close-time")

                            self.close_time_real = YLeaf(YType.uint32, "close-time-real")

                            self.ipv4roa = YLeaf(YType.uint32, "ipv4roa")

                            self.ipv4roa_announce = YLeaf(YType.uint32, "ipv4roa-announce")

                            self.ipv4roa_withdraw = YLeaf(YType.uint32, "ipv4roa-withdraw")

                            self.ipv6roa = YLeaf(YType.uint32, "ipv6roa")

                            self.ipv6roa_announce = YLeaf(YType.uint32, "ipv6roa-announce")

                            self.ipv6roa_withdraw = YLeaf(YType.uint32, "ipv6roa-withdraw")

                            self.name = YLeaf(YType.str, "name")

                            self.nonce = YLeaf(YType.uint32, "nonce")

                            self.password = YLeaf(YType.str, "password")

                            self.port = YLeaf(YType.uint32, "port")

                            self.preference = YLeaf(YType.uint32, "preference")

                            self.proto_error = YLeaf(YType.enumeration, "proto-error")

                            self.proto_state = YLeaf(YType.enumeration, "proto-state")

                            self.proto_state_time = YLeaf(YType.uint32, "proto-state-time")

                            self.purge_time = YLeaf(YType.int32, "purge-time")

                            self.read_bytes = YLeaf(YType.uint32, "read-bytes")

                            self.refresh_time = YLeaf(YType.int32, "refresh-time")

                            self.response_time = YLeaf(YType.int32, "response-time")

                            self.retries = YLeaf(YType.uint32, "retries")

                            self.serial = YLeaf(YType.uint32, "serial")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sshpid = YLeaf(YType.uint32, "sshpid")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.state_time = YLeaf(YType.uint32, "state-time")

                            self.transport = YLeaf(YType.uint32, "transport")

                            self.username = YLeaf(YType.str, "username")

                            self.write_bytes = YLeaf(YType.uint32, "write-bytes")
                            self._segment_path = lambda: "rpki-server"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer, ['close_reason', 'close_time', 'close_time_real', 'ipv4roa', 'ipv4roa_announce', 'ipv4roa_withdraw', 'ipv6roa', 'ipv6roa_announce', 'ipv6roa_withdraw', 'name', 'nonce', 'password', 'port', 'preference', 'proto_error', 'proto_state', 'proto_state_time', 'purge_time', 'read_bytes', 'refresh_time', 'response_time', 'retries', 'serial', 'shutdown', 'sshpid', 'state', 'state_time', 'transport', 'username', 'write_bytes'], name, value)


                class RpkiSummary(Entity):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpki_allow_invalid
                    
                    	Allow invalid paths
                    	**type**\:  bool
                    
                    .. attribute:: rpki_disabled
                    
                    	RPKI Knob disabled
                    	**type**\:  bool
                    
                    .. attribute:: rpki_signal_ibgp
                    
                    	Signal RPKI validity to iBGP peers
                    	**type**\:  bool
                    
                    .. attribute:: rpki_use_validity
                    
                    	Use RPKI validity for bestpath calculation
                    	**type**\:  bool
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiSummary, self).__init__()

                        self.yang_name = "rpki-summary"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.ipv4roa_nets = YLeaf(YType.uint32, "ipv4roa-nets")

                        self.ipv4roa_paths = YLeaf(YType.uint32, "ipv4roa-paths")

                        self.ipv6roa_nets = YLeaf(YType.uint32, "ipv6roa-nets")

                        self.ipv6roa_paths = YLeaf(YType.uint32, "ipv6roa-paths")

                        self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                        self.rpki_disabled = YLeaf(YType.boolean, "rpki-disabled")

                        self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                        self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                        self.servers = YLeaf(YType.uint32, "servers")
                        self._segment_path = lambda: "rpki-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiSummary, ['ipv4roa_nets', 'ipv4roa_paths', 'ipv6roa_nets', 'ipv6roa_paths', 'rpki_allow_invalid', 'rpki_disabled', 'rpki_signal_ibgp', 'rpki_use_validity', 'servers'], name, value)


                class RtEntries(Entity):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of    :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RtEntries, self).__init__()

                        self.yang_name = "rt-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rt-entry" : ("rt_entry", Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry)}

                        self.rt_entry = YList(self)
                        self._segment_path = lambda: "rt-entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries, [], name, value)


                    class RtEntry(Entity):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\:  str
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:   :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry, self).__init__()

                            self.yang_name = "rt-entry"
                            self.yang_parent_name = "rt-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rt" : ("rt", Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt)}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.afs = YLeaf(YType.str, "afs")

                            self.request_id = YLeaf(YType.int32, "request-id")

                            self.route_target_lower_bytes = YLeaf(YType.int32, "route-target-lower-bytes")

                            self.route_target_upper_bytes = YLeaf(YType.int32, "route-target-upper-bytes")

                            self.rt = Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt()
                            self.rt.parent = self
                            self._children_name_map["rt"] = "rt"
                            self._children_yang_names.add("rt")
                            self._segment_path = lambda: "rt-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry, ['af_name', 'afs', 'request_id', 'route_target_lower_bytes', 'route_target_upper_bytes'], name, value)


                        class Rt(Entity):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt, self).__init__()

                                self.yang_name = "rt"
                                self.yang_parent_name = "rt-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_target = YLeaf(YType.str, "route-target")
                                self._segment_path = lambda: "rt"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt, ['route_target'], name, value)


                class UpdateGenerationProcess(Entity):
                    """
                    Update generation for the process
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of    :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\:  bool
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess, self).__init__()

                        self.yang_name = "update-generation-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics)}
                        self._child_list_classes = {"update-address-family" : ("update_address_family", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily)}

                        self.configured_update_limit_process = YLeaf(YType.uint32, "configured-update-limit-process")

                        self.current_update_limit_process = YLeaf(YType.uint32, "current-update-limit-process")

                        self.update_out_logging = YLeaf(YType.boolean, "update-out-logging")

                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self._children_name_map["update_statistics"] = "update-statistics"
                        self._children_yang_names.add("update-statistics")

                        self.update_address_family = YList(self)
                        self._segment_path = lambda: "update-generation-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess, ['configured_update_limit_process', 'current_update_limit_process', 'update_out_logging', 'update_out_queue_messages', 'update_out_queue_size', 'update_throttled'], name, value)


                    class UpdateAddressFamily(Entity):
                        """
                        List of address\-families
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\:  bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily, self).__init__()

                            self.yang_name = "update-address-family"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                            self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                            self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                            self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                            self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                            self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")
                            self._segment_path = lambda: "update-address-family"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily, ['current_update_limit_af', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_group_af_name', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_throttled', 'update_update_group_count'], name, value)


                    class UpdateStatistics(Entity):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics, self).__init__()

                            self.yang_name = "update-statistics"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                            self._children_yang_names.add("last-update-cleared-timestamp")

                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                            self._children_yang_names.add("last-update-discard-timestamp")

                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                            self._children_yang_names.add("last-update-recovery-timestamp")

                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                            self._children_yang_names.add("last-update-throttle-timestamp")
                            self._segment_path = lambda: "update-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                        class LastUpdateClearedTimestamp(Entity):
                            """
                            Last Cleared time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                self.yang_name = "last-update-cleared-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-cleared-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateDiscardTimestamp(Entity):
                            """
                            Last Discarded time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                self.yang_name = "last-update-discard-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-discard-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateRecoveryTimestamp(Entity):
                            """
                            Last Recovery time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                self.yang_name = "last-update-recovery-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-recovery-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateThrottleTimestamp(Entity):
                            """
                            Last Throttled time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                self.yang_name = "last-update-throttle-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-throttle-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                class UpdateInboundErrorProcess(Entity):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess, self).__init__()

                        self.yang_name = "update-inbound-error-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp)}
                        self._child_list_classes = {}

                        self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                        self.update_error_handling_basic_ebgp = YLeaf(YType.boolean, "update-error-handling-basic-ebgp")

                        self.update_error_handling_basic_ibgp = YLeaf(YType.boolean, "update-error-handling-basic-ibgp")

                        self.update_error_handling_extended_ebgp = YLeaf(YType.boolean, "update-error-handling-extended-ebgp")

                        self.update_error_handling_extended_ibgp = YLeaf(YType.boolean, "update-error-handling-extended-ibgp")

                        self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                        self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                        self._children_yang_names.add("last-update-malformed-timestamp")
                        self._segment_path = lambda: "update-inbound-error-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess, ['last_update_malformed_age', 'update_error_handling_basic_ebgp', 'update_error_handling_basic_ibgp', 'update_error_handling_extended_ebgp', 'update_error_handling_extended_ibgp', 'update_malformed_message_count', 'update_malformed_neighbor_count'], name, value)


                    class LastUpdateMalformedTimestamp(Entity):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, self).__init__()

                            self.yang_name = "last-update-malformed-timestamp"
                            self.yang_parent_name = "update-inbound-error-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")
                            self._segment_path = lambda: "last-update-malformed-timestamp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                class UpdateInboundFilterProcess(Entity):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess, self).__init__()

                        self.yang_name = "update-inbound-filter-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp)}
                        self._child_list_classes = {}

                        self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                        self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                        self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                        self._children_yang_names.add("last-update-filtered-timestamp")
                        self._segment_path = lambda: "update-inbound-filter-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count'], name, value)


                    class LastUpdateFilteredTimestamp(Entity):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, self).__init__()

                            self.yang_name = "last-update-filtered-timestamp"
                            self.yang_parent_name = "update-inbound-filter-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")
                            self._segment_path = lambda: "last-update-filtered-timestamp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                class Vrfs(Entity):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf)}

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs, [], name, value)


                    class Vrf(Entity):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  <key>
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"afs" : ("afs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs), "bmp" : ("bmp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp), "global-process-info" : ("global_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo), "information" : ("information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information), "message-logs" : ("message_logs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs), "neighbor-ranges" : ("neighbor_ranges", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges), "neighbors" : ("neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors), "next-hop-vrf" : ("next_hop_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf), "postits" : ("postits", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits), "process-info" : ("process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo), "sessions" : ("sessions", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions), "update-inbound-error-neighbors" : ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors), "update-inbound-error-vrf" : ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf), "update-inbound-filter-neighbors" : ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors), "update-inbound-filter-vrf" : ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf)}
                            self._child_list_classes = {}

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self._children_name_map["afs"] = "afs"
                            self._children_yang_names.add("afs")

                            self.bmp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self._children_name_map["bmp"] = "bmp"
                            self._children_yang_names.add("bmp")

                            self.global_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self._children_name_map["global_process_info"] = "global-process-info"
                            self._children_yang_names.add("global-process-info")

                            self.information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._children_yang_names.add("information")

                            self.message_logs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self._children_name_map["message_logs"] = "message-logs"
                            self._children_yang_names.add("message-logs")

                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self._children_name_map["neighbor_ranges"] = "neighbor-ranges"
                            self._children_yang_names.add("neighbor-ranges")

                            self.neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self._children_name_map["next_hop_vrf"] = "next-hop-vrf"
                            self._children_yang_names.add("next-hop-vrf")

                            self.postits = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self._children_name_map["postits"] = "postits"
                            self._children_yang_names.add("postits")

                            self.process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self._children_name_map["process_info"] = "process-info"
                            self._children_yang_names.add("process-info")

                            self.sessions = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"
                            self._children_yang_names.add("update-inbound-error-neighbors")

                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"
                            self._children_yang_names.add("update-inbound-error-vrf")

                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"
                            self._children_yang_names.add("update-inbound-filter-neighbors")

                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self
                            self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"
                            self._children_yang_names.add("update-inbound-filter-vrf")
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf, ['vrf_name'], name, value)


                        class Afs(Entity):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs, self).__init__()

                                self.yang_name = "afs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"af" : ("af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af)}

                                self.af = YList(self)
                                self._segment_path = lambda: "afs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs, [], name, value)


                            class Af(Entity):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                .. attribute:: bmp_path_table_generic
                                
                                	Summary Info about BMP Table
                                	**type**\:   :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: network_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds>`
                                
                                .. attribute:: network_lookup_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds>`
                                
                                .. attribute:: network_prefixes
                                
                                	The BGP Network Lookup table
                                	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af, self).__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertised-path-counts" : ("advertised_path_counts", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts), "advertised-path-xr" : ("advertised_path_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr), "advertised-paths" : ("advertised_paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths), "af-process-info" : ("af_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes), "bmp-path-table-generic" : ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric), "bmp-paths" : ("bmp_paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths), "convergence" : ("convergence", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence), "dampenings" : ("dampenings", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings), "epes" : ("epes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes), "global-af-process-info" : ("global_af_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo), "neighbor-af-table" : ("neighbor_af_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable), "network-all-rds" : ("network_all_rds", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds), "network-lookup-all-rds" : ("network_lookup_all_rds", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds), "network-prefixes" : ("network_prefixes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes), "networks" : ("networks", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks), "next-hop-address-families" : ("next_hop_address_families", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies), "path-labeled-table" : ("path_labeled_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable), "path-table" : ("path_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable), "path-used-table" : ("path_used_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable), "policies" : ("policies", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies), "prefix-filters" : ("prefix_filters", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters), "rpc-sets" : ("rpc_sets", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets), "rt-set-counters" : ("rt_set_counters", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters), "sourced-networks" : ("sourced_networks", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks), "update-generation-address-family" : ("update_generation_address_family", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily), "update-generation-filter-groups" : ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups), "update-generation-neighbors" : ("update_generation_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors), "update-generation-sub-groups" : ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups), "update-generation-update-groups" : ("update_generation_update_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups), "update-groups" : ("update_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self._children_name_map["advertised_path_counts"] = "advertised-path-counts"
                                    self._children_yang_names.add("advertised-path-counts")

                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self._children_name_map["advertised_path_xr"] = "advertised-path-xr"
                                    self._children_yang_names.add("advertised-path-xr")

                                    self.advertised_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self._children_name_map["advertised_paths"] = "advertised-paths"
                                    self._children_yang_names.add("advertised-paths")

                                    self.af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self._children_name_map["af_process_info"] = "af-process-info"
                                    self._children_yang_names.add("af-process-info")

                                    self.attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self._children_name_map["attributes"] = "attributes"
                                    self._children_yang_names.add("attributes")

                                    self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric()
                                    self.bmp_path_table_generic.parent = self
                                    self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"
                                    self._children_yang_names.add("bmp-path-table-generic")

                                    self.bmp_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self._children_name_map["bmp_paths"] = "bmp-paths"
                                    self._children_yang_names.add("bmp-paths")

                                    self.convergence = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self._children_name_map["convergence"] = "convergence"
                                    self._children_yang_names.add("convergence")

                                    self.dampenings = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self._children_name_map["dampenings"] = "dampenings"
                                    self._children_yang_names.add("dampenings")

                                    self.epes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self._children_name_map["epes"] = "epes"
                                    self._children_yang_names.add("epes")

                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self._children_name_map["global_af_process_info"] = "global-af-process-info"
                                    self._children_yang_names.add("global-af-process-info")

                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self._children_name_map["neighbor_af_table"] = "neighbor-af-table"
                                    self._children_yang_names.add("neighbor-af-table")

                                    self.network_all_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds()
                                    self.network_all_rds.parent = self
                                    self._children_name_map["network_all_rds"] = "network-all-rds"
                                    self._children_yang_names.add("network-all-rds")

                                    self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds()
                                    self.network_lookup_all_rds.parent = self
                                    self._children_name_map["network_lookup_all_rds"] = "network-lookup-all-rds"
                                    self._children_yang_names.add("network-lookup-all-rds")

                                    self.network_prefixes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes()
                                    self.network_prefixes.parent = self
                                    self._children_name_map["network_prefixes"] = "network-prefixes"
                                    self._children_yang_names.add("network-prefixes")

                                    self.networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self._children_name_map["networks"] = "networks"
                                    self._children_yang_names.add("networks")

                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self._children_name_map["next_hop_address_families"] = "next-hop-address-families"
                                    self._children_yang_names.add("next-hop-address-families")

                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self._children_name_map["path_labeled_table"] = "path-labeled-table"
                                    self._children_yang_names.add("path-labeled-table")

                                    self.path_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self._children_name_map["path_table"] = "path-table"
                                    self._children_yang_names.add("path-table")

                                    self.path_used_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self._children_name_map["path_used_table"] = "path-used-table"
                                    self._children_yang_names.add("path-used-table")

                                    self.policies = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self._children_name_map["policies"] = "policies"
                                    self._children_yang_names.add("policies")

                                    self.prefix_filters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self._children_name_map["prefix_filters"] = "prefix-filters"
                                    self._children_yang_names.add("prefix-filters")

                                    self.rpc_sets = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self._children_name_map["rpc_sets"] = "rpc-sets"
                                    self._children_yang_names.add("rpc-sets")

                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self._children_name_map["rt_set_counters"] = "rt-set-counters"
                                    self._children_yang_names.add("rt-set-counters")

                                    self.sourced_networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"
                                    self._children_yang_names.add("sourced-networks")

                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self._children_name_map["update_generation_address_family"] = "update-generation-address-family"
                                    self._children_yang_names.add("update-generation-address-family")

                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"
                                    self._children_yang_names.add("update-generation-filter-groups")

                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"
                                    self._children_yang_names.add("update-generation-neighbors")

                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"
                                    self._children_yang_names.add("update-generation-sub-groups")

                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"
                                    self._children_yang_names.add("update-generation-update-groups")

                                    self.update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self
                                    self._children_name_map["update_groups"] = "update-groups"
                                    self._children_yang_names.add("update-groups")
                                    self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                                class AdvertisedPathCounts(Entity):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                        self.yang_name = "advertised-path-counts"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path-count" : ("advertised_path_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount)}

                                        self.advertised_path_count = YList(self)
                                        self._segment_path = lambda: "advertised-path-counts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                    class AdvertisedPathCount(Entity):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                            self.yang_name = "advertised-path-count"
                                            self.yang_parent_name = "advertised-path-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.max_prefix_advertisedcount = YLeaf(YType.uint32, "max-prefix-advertisedcount")
                                            self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', 'max_prefix_advertisedcount'], name, value)


                                class AdvertisedPathXr(Entity):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                        self.yang_name = "advertised-path-xr"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath)}

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-path-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-path-xr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "advertised-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertisedPaths(Entity):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths, self).__init__()

                                        self.yang_name = "advertised-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath)}

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-paths"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"adv-path-info" : ("adv_path_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo), "paths" : ("paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.adv_path_info = YList(self)
                                            self.paths = YList(self)
                                            self._segment_path = lambda: "advertised-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['neighbor_address', 'network', 'prefix_length', 'rd'], name, value)


                                        class AdvPathInfo(Entity):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                                self.yang_name = "adv-path-info"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                                self._children_yang_names.add("attributes-after-policy-out")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                                self._children_yang_names.add("path-info-after-policy-in")

                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                                self._children_yang_names.add("path-info-after-policy-out")
                                                self._segment_path = lambda: "adv-path-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, ['af_name', 'no_path', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class AttributesAfterPolicyOut(Entity):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                    self.yang_name = "attributes-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-out"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInfoAfterPolicyIn(Entity):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                    self.yang_name = "path-info-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInfoAfterPolicyOut(Entity):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                    self.yang_name = "path-info-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-out"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class Paths(Entity):
                                            """
                                            paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "paths"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfProcessInfo(Entity):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo, self).__init__()

                                        self.yang_name = "af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.process_instance = YLeaf(YType.uint8, "process-instance")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "af-process-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo, ['af_name', 'process_instance', 'vrf_name', 'vrf_totals'], name, value)


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v4_next_hop
                                        
                                        	Max supported label stack depth for IPv4 Nexthop
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v6_next_hop
                                        
                                        	Max supported label stack depth for IPv6 Nexthop
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_bgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:   :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall), "trigger-import" : ("trigger_import", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport), "trigger-label" : ("trigger_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel), "trigger-rib" : ("trigger_rib", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib), "trigger-update" : ("trigger_update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate), "version-wrap-done-time-spec" : ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec), "version-wrap-start-time-spec" : ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec), "version-wrap-time-spec" : ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec)}
                                            self._child_list_classes = {}

                                            self.freed_rd_count = YLeaf(YType.uint32, "freed-rd-count")

                                            self.import_bgp_version = YLeaf(YType.uint32, "import-bgp-version")

                                            self.import_last_trigger = YLeaf(YType.uint64, "import-last-trigger")

                                            self.import_triggers = YLeaf(YType.uint32, "import-triggers")

                                            self.import_version = YLeaf(YType.uint32, "import-version")

                                            self.imported_paths_memory = YLeaf(YType.uint32, "imported-paths-memory")

                                            self.imported_paths_num = YLeaf(YType.uint32, "imported-paths-num")

                                            self.label_bgp_version = YLeaf(YType.uint32, "label-bgp-version")

                                            self.label_last_trigger = YLeaf(YType.uint64, "label-last-trigger")

                                            self.label_triggers = YLeaf(YType.uint32, "label-triggers")

                                            self.label_version = YLeaf(YType.uint32, "label-version")

                                            self.last_import_version = YLeaf(YType.uint32, "last-import-version")

                                            self.last_label_version = YLeaf(YType.uint32, "last-label-version")

                                            self.last_rib_version = YLeaf(YType.uint32, "last-rib-version")

                                            self.local_networks_freed_num = YLeaf(YType.uint32, "local-networks-freed-num")

                                            self.local_networks_malloced_num = YLeaf(YType.uint32, "local-networks-malloced-num")

                                            self.local_networks_memory = YLeaf(YType.uint32, "local-networks-memory")

                                            self.local_networks_num = YLeaf(YType.uint32, "local-networks-num")

                                            self.local_paths_freed_num = YLeaf(YType.uint32, "local-paths-freed-num")

                                            self.local_paths_malloced_num = YLeaf(YType.uint32, "local-paths-malloced-num")

                                            self.local_paths_memory = YLeaf(YType.uint32, "local-paths-memory")

                                            self.local_paths_num = YLeaf(YType.uint32, "local-paths-num")

                                            self.malloced_rd_count = YLeaf(YType.uint32, "malloced-rd-count")

                                            self.max_active_pelem_version = YLeaf(YType.uint32, "max-active-pelem-version")

                                            self.max_label_stack_depth_v4_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v4-next-hop")

                                            self.max_label_stack_depth_v6_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v6-next-hop")

                                            self.merged_table_version = YLeaf(YType.uint32, "merged-table-version")

                                            self.multipath_network_entry_count = YLeaf(YType.uint32, "multipath-network-entry-count")

                                            self.multipath_network_entry_memory = YLeaf(YType.uint32, "multipath-network-entry-memory")

                                            self.multipath_paths_count = YLeaf(YType.uint32, "multipath-paths-count")

                                            self.multipath_paths_memory = YLeaf(YType.uint32, "multipath-paths-memory")

                                            self.networks_freed_num = YLeaf(YType.uint32, "networks-freed-num")

                                            self.networks_malloced_num = YLeaf(YType.uint32, "networks-malloced-num")

                                            self.networks_memory = YLeaf(YType.uint32, "networks-memory")

                                            self.networks_num = YLeaf(YType.uint32, "networks-num")

                                            self.num_init_sync_pfx = YLeaf(YType.uint32, "num-init-sync-pfx")

                                            self.path_elems_freed_num = YLeaf(YType.uint32, "path-elems-freed-num")

                                            self.path_elems_malloced_num = YLeaf(YType.uint32, "path-elems-malloced-num")

                                            self.path_elems_memory = YLeaf(YType.uint32, "path-elems-memory")

                                            self.path_elems_num = YLeaf(YType.uint32, "path-elems-num")

                                            self.paths_freed_num = YLeaf(YType.uint32, "paths-freed-num")

                                            self.paths_malloced_num = YLeaf(YType.uint32, "paths-malloced-num")

                                            self.paths_memory = YLeaf(YType.uint32, "paths-memory")

                                            self.paths_num = YLeaf(YType.uint32, "paths-num")

                                            self.rd_memory = YLeaf(YType.uint32, "rd-memory")

                                            self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                            self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                            self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                            self.rib_bgp_version = YLeaf(YType.uint32, "rib-bgp-version")

                                            self.rib_brib_received_version = YLeaf(YType.uint32, "rib-brib-received-version")

                                            self.rib_last_trigger = YLeaf(YType.uint64, "rib-last-trigger")

                                            self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                            self.rib_triggers = YLeaf(YType.uint32, "rib-triggers")

                                            self.route_download_go_active_done_pending = YLeaf(YType.uint32, "route-download-go-active-done-pending")

                                            self.router_state = YLeaf(YType.enumeration, "router-state")

                                            self.send_version = YLeaf(YType.uint32, "send-version")

                                            self.standby_version = YLeaf(YType.uint32, "standby-version")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.total_r_ds_num = YLeaf(YType.uint32, "total-r-ds-num")

                                            self.total_remote_r_ds_num = YLeaf(YType.uint32, "total-remote-r-ds-num")

                                            self.total_same_r_ds_num = YLeaf(YType.uint32, "total-same-r-ds-num")

                                            self.update_gen_bgp_version = YLeaf(YType.uint32, "update-gen-bgp-version")

                                            self.update_gen_last_trigger = YLeaf(YType.uint64, "update-gen-last-trigger")

                                            self.update_triggers = YLeaf(YType.uint32, "update-triggers")

                                            self.update_wait_install_enabled = YLeaf(YType.uint32, "update-wait-install-enabled")

                                            self.version_wrapped = YLeaf(YType.uint32, "version-wrapped")

                                            self.version_wrapped_tid = YLeaf(YType.uint32, "version-wrapped-tid")

                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._children_yang_names.add("rib-install")

                                            self.trigger_import = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                            self.trigger_import.parent = self
                                            self._children_name_map["trigger_import"] = "trigger-import"
                                            self._children_yang_names.add("trigger-import")

                                            self.trigger_label = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self._children_name_map["trigger_label"] = "trigger-label"
                                            self._children_yang_names.add("trigger-label")

                                            self.trigger_rib = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self._children_name_map["trigger_rib"] = "trigger-rib"
                                            self._children_yang_names.add("trigger-rib")

                                            self.trigger_update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self._children_name_map["trigger_update"] = "trigger-update"
                                            self._children_yang_names.add("trigger-update")

                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"
                                            self._children_yang_names.add("version-wrap-done-time-spec")

                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"
                                            self._children_yang_names.add("version-wrap-start-time-spec")

                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"
                                            self._children_yang_names.add("version-wrap-time-spec")
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_, ['freed_rd_count', 'import_bgp_version', 'import_last_trigger', 'import_triggers', 'import_version', 'imported_paths_memory', 'imported_paths_num', 'label_bgp_version', 'label_last_trigger', 'label_triggers', 'label_version', 'last_import_version', 'last_label_version', 'last_rib_version', 'local_networks_freed_num', 'local_networks_malloced_num', 'local_networks_memory', 'local_networks_num', 'local_paths_freed_num', 'local_paths_malloced_num', 'local_paths_memory', 'local_paths_num', 'malloced_rd_count', 'max_active_pelem_version', 'max_label_stack_depth_v4_next_hop', 'max_label_stack_depth_v6_next_hop', 'merged_table_version', 'multipath_network_entry_count', 'multipath_network_entry_memory', 'multipath_paths_count', 'multipath_paths_memory', 'networks_freed_num', 'networks_malloced_num', 'networks_memory', 'networks_num', 'num_init_sync_pfx', 'path_elems_freed_num', 'path_elems_malloced_num', 'path_elems_memory', 'path_elems_num', 'paths_freed_num', 'paths_malloced_num', 'paths_memory', 'paths_num', 'rd_memory', 'rib_ack_requests', 'rib_acked_table_version', 'rib_acks_received', 'rib_bgp_version', 'rib_brib_received_version', 'rib_last_trigger', 'rib_slow_acks', 'rib_triggers', 'route_download_go_active_done_pending', 'router_state', 'send_version', 'standby_version', 'table_brib_version', 'table_version', 'total_r_ds_num', 'total_remote_r_ds_num', 'total_same_r_ds_num', 'update_gen_bgp_version', 'update_gen_last_trigger', 'update_triggers', 'update_wait_install_enabled', 'version_wrapped', 'version_wrapped_tid'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime)}
                                                self._child_list_classes = {}

                                                self.installed_count = YLeaf(YType.uint32, "installed-count")

                                                self.modified_count = YLeaf(YType.uint32, "modified-count")

                                                self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                                self.start_version = YLeaf(YType.uint32, "start-version")

                                                self.target_version = YLeaf(YType.uint32, "target-version")

                                                self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._children_yang_names.add("install-time")

                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"
                                                self._children_yang_names.add("update-time")
                                                self._segment_path = lambda: "rib-install"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "install-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerImport(Entity):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, self).__init__()

                                                self.yang_name = "trigger-import"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerLabel(Entity):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, self).__init__()

                                                self.yang_name = "trigger-label"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-label"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerRib(Entity):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, self).__init__()

                                                self.yang_name = "trigger-rib"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-rib"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-rib"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerUpdate(Entity):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, self).__init__()

                                                self.yang_name = "trigger-update"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-update"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapDoneTimeSpec(Entity):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-done-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-done-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapStartTimeSpec(Entity):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-start-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-start-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapTimeSpec(Entity):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf)}
                                            self._child_list_classes = {}

                                            self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                            self.global_.parent = self
                                            self._children_name_map["global_"] = "global"
                                            self._children_yang_names.add("global")

                                            self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")
                                            self._segment_path = lambda: "performance-statistics"


                                        class Global_(Entity):
                                            """
                                            Global information
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\:  bool
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                                self.yang_name = "global"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mode-enter-time" : ("mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime), "total-pim-callback-add" : ("total_pim_callback_add", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd), "total-pim-callback-add-local" : ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal), "total-pim-callback-del" : ("total_pim_callback_del", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel), "total-pim-callback-del-local" : ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal), "total-pim-install-add" : ("total_pim_install_add", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd), "total-pim-install-del" : ("total_pim_install_del", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel)}

                                                self.first_nbr_up_time = YLeaf(YType.uint32, "first-nbr-up-time")

                                                self.has_converged = YLeaf(YType.boolean, "has-converged")

                                                self.total_pim_callback_batch = YLeaf(YType.uint32, "total-pim-callback-batch")

                                                self.total_pim_callbacks = YLeaf(YType.uint32, "total-pim-callbacks")

                                                self.total_pim_install = YLeaf(YType.uint32, "total-pim-install")

                                                self.mode_enter_time = YList(self)
                                                self.total_pim_callback_add = YList(self)
                                                self.total_pim_callback_add_local = YList(self)
                                                self.total_pim_callback_del = YList(self)
                                                self.total_pim_callback_del_local = YList(self)
                                                self.total_pim_install_add = YList(self)
                                                self.total_pim_install_del = YList(self)
                                                self._segment_path = lambda: "global"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, ['first_nbr_up_time', 'has_converged', 'total_pim_callback_batch', 'total_pim_callbacks', 'total_pim_install'], name, value)


                                            class ModeEnterTime(Entity):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, self).__init__()

                                                    self.yang_name = "mode-enter-time"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "mode-enter-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, ['entry'], name, value)


                                            class TotalPimCallbackAdd(Entity):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, self).__init__()

                                                    self.yang_name = "total-pim-callback-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-add"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, ['entry'], name, value)


                                            class TotalPimCallbackAddLocal(Entity):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-add-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-add-local"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, ['entry'], name, value)


                                            class TotalPimCallbackDel(Entity):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, self).__init__()

                                                    self.yang_name = "total-pim-callback-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-del"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, ['entry'], name, value)


                                            class TotalPimCallbackDelLocal(Entity):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-del-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-del-local"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, ['entry'], name, value)


                                            class TotalPimInstallAdd(Entity):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, self).__init__()

                                                    self.yang_name = "total-pim-install-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-install-add"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, ['entry'], name, value)


                                            class TotalPimInstallDel(Entity):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, self).__init__()

                                                    self.yang_name = "total-pim-install-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-install-del"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, ['entry'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_not_sent_to_rib
                                            
                                            	No. of prefixes not sent to RIB due to unsupported label stack size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"first-rib-table-full-timestamp" : ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp), "first-rib-table-has-space-timestamp" : ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp), "last-rib-table-full-timestamp" : ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp), "last-rib-table-has-space-timestamp" : ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp), "time-label-retain" : ("time_label_retain", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain), "time-rib-coverged" : ("time_rib_coverged", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged), "time-rib-down" : ("time_rib_down", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)}
                                                self._child_list_classes = {}

                                                self.attributes_recover_from_rib = YLeaf(YType.uint32, "attributes-recover-from-rib")

                                                self.attributes_removed_from_rib = YLeaf(YType.uint32, "attributes-removed-from-rib")

                                                self.attributes_sent_to_rib = YLeaf(YType.uint32, "attributes-sent-to-rib")

                                                self.first_rib_table_full_version = YLeaf(YType.uint32, "first-rib-table-full-version")

                                                self.first_rib_table_has_space_version = YLeaf(YType.uint32, "first-rib-table-has-space-version")

                                                self.import_added_path_count = YLeaf(YType.uint32, "import-added-path-count")

                                                self.import_calls = YLeaf(YType.uint32, "import-calls")

                                                self.import_dest_net_processed_count = YLeaf(YType.uint32, "import-dest-net-processed-count")

                                                self.import_removed_path_count = YLeaf(YType.uint32, "import-removed-path-count")

                                                self.import_replaced_path_count = YLeaf(YType.uint32, "import-replaced-path-count")

                                                self.import_src_net_processed_count = YLeaf(YType.uint32, "import-src-net-processed-count")

                                                self.import_time = YLeaf(YType.uint32, "import-time")

                                                self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                                self.label_added_count = YLeaf(YType.uint32, "label-added-count")

                                                self.label_calls = YLeaf(YType.uint32, "label-calls")

                                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                                self.label_rewrite_count = YLeaf(YType.uint32, "label-rewrite-count")

                                                self.label_time = YLeaf(YType.uint32, "label-time")

                                                self.last_rib_table_full_age = YLeaf(YType.uint32, "last-rib-table-full-age")

                                                self.last_rib_table_full_version = YLeaf(YType.uint32, "last-rib-table-full-version")

                                                self.last_rib_table_has_space_age = YLeaf(YType.uint32, "last-rib-table-has-space-age")

                                                self.last_rib_table_has_space_version = YLeaf(YType.uint32, "last-rib-table-has-space-version")

                                                self.prefixes_not_sent_to_rib = YLeaf(YType.uint32, "prefixes-not-sent-to-rib")

                                                self.prefixes_removed_from_rib = YLeaf(YType.uint32, "prefixes-removed-from-rib")

                                                self.prefixes_resent_to_rib = YLeaf(YType.uint32, "prefixes-resent-to-rib")

                                                self.prefixes_sent_to_rib = YLeaf(YType.uint32, "prefixes-sent-to-rib")

                                                self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                                self.rib_tbl_del_calls = YLeaf(YType.uint32, "rib-tbl-del-calls")

                                                self.rib_tbl_invalid_calls = YLeaf(YType.uint32, "rib-tbl-invalid-calls")

                                                self.rib_tbl_local_label = YLeaf(YType.uint32, "rib-tbl-local-label")

                                                self.rib_tbl_retry = YLeaf(YType.uint32, "rib-tbl-retry")

                                                self.rib_tbl_skip_calls = YLeaf(YType.uint32, "rib-tbl-skip-calls")

                                                self.rib_trigger = YLeaf(YType.boolean, "rib-trigger")

                                                self.rib_update_calls = YLeaf(YType.uint32, "rib-update-calls")

                                                self.rib_update_time = YLeaf(YType.uint32, "rib-update-time")

                                                self.scanner_runs = YLeaf(YType.uint32, "scanner-runs")

                                                self.scanner_time = YLeaf(YType.uint32, "scanner-time")

                                                self.subgroup_count = YLeaf(YType.uint32, "subgroup-count")

                                                self.time_last_update_sent = YLeaf(YType.uint32, "time-last-update-sent")

                                                self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                                self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                                self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                                self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                                self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                                self.update_group_count = YLeaf(YType.uint32, "update-group-count")

                                                self.vrf_flags = YLeaf(YType.uint32, "vrf-flags")

                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"
                                                self._children_yang_names.add("first-rib-table-full-timestamp")

                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"
                                                self._children_yang_names.add("first-rib-table-has-space-timestamp")

                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"
                                                self._children_yang_names.add("last-rib-table-full-timestamp")

                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"
                                                self._children_yang_names.add("last-rib-table-has-space-timestamp")

                                                self.time_label_retain = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self._children_name_map["time_label_retain"] = "time-label-retain"
                                                self._children_yang_names.add("time-label-retain")

                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self._children_name_map["time_rib_coverged"] = "time-rib-coverged"
                                                self._children_yang_names.add("time-rib-coverged")

                                                self.time_rib_down = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self._children_name_map["time_rib_down"] = "time-rib-down"
                                                self._children_yang_names.add("time-rib-down")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, ['attributes_recover_from_rib', 'attributes_removed_from_rib', 'attributes_sent_to_rib', 'first_rib_table_full_version', 'first_rib_table_has_space_version', 'import_added_path_count', 'import_calls', 'import_dest_net_processed_count', 'import_removed_path_count', 'import_replaced_path_count', 'import_src_net_processed_count', 'import_time', 'is_rib_table_full', 'label_added_count', 'label_calls', 'label_release_count', 'label_rewrite_count', 'label_time', 'last_rib_table_full_age', 'last_rib_table_full_version', 'last_rib_table_has_space_age', 'last_rib_table_has_space_version', 'prefixes_not_sent_to_rib', 'prefixes_removed_from_rib', 'prefixes_resent_to_rib', 'prefixes_sent_to_rib', 'rib_table_full_version', 'rib_tbl_del_calls', 'rib_tbl_invalid_calls', 'rib_tbl_local_label', 'rib_tbl_retry', 'rib_tbl_skip_calls', 'rib_trigger', 'rib_update_calls', 'rib_update_time', 'scanner_runs', 'scanner_time', 'subgroup_count', 'time_last_update_sent', 'update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'update_group_count', 'vrf_flags'], name, value)


                                            class FirstRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "first-rib-table-full-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class FirstRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "first-rib-table-has-space-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-rib-table-full-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-rib-table-has-space-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class TimeLabelRetain(Entity):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                    self.yang_name = "time-label-retain"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-label-retain"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, ['nanoseconds', 'seconds'], name, value)


                                            class TimeRibCoverged(Entity):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                    self.yang_name = "time-rib-coverged"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-rib-coverged"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, ['nanoseconds', 'seconds'], name, value)


                                            class TimeRibDown(Entity):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                    self.yang_name = "time-rib-down"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-rib-down"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, ['nanoseconds', 'seconds'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\:  bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.add_path_install_disable = YLeaf(YType.boolean, "add-path-install-disable")

                                            self.add_path_install_enable = YLeaf(YType.boolean, "add-path-install-enable")

                                            self.any_ebgp_neighbor_missing_policy = YLeaf(YType.boolean, "any-ebgp-neighbor-missing-policy")

                                            self.asbr = YLeaf(YType.boolean, "asbr")

                                            self.attribute_download = YLeaf(YType.boolean, "attribute-download")

                                            self.best_external = YLeaf(YType.boolean, "best-external")

                                            self.best_external_disable = YLeaf(YType.boolean, "best-external-disable")

                                            self.bmp_network_entry_count = YLeaf(YType.uint32, "bmp-network-entry-count")

                                            self.bmp_path_memory = YLeaf(YType.uint32, "bmp-path-memory")

                                            self.bmp_paths_count = YLeaf(YType.uint32, "bmp-paths-count")

                                            self.bmp_prefix_memory = YLeaf(YType.uint32, "bmp-prefix-memory")

                                            self.damped_path_count = YLeaf(YType.uint32, "damped-path-count")

                                            self.freed_path_count = YLeaf(YType.uint32, "freed-path-count")

                                            self.freed_path_elem_count = YLeaf(YType.uint32, "freed-path-elem-count")

                                            self.freed_prefix_count = YLeaf(YType.uint32, "freed-prefix-count")

                                            self.history_path_count = YLeaf(YType.uint32, "history-path-count")

                                            self.ibgp_nexthop_self_count = YLeaf(YType.uint32, "ibgp-nexthop-self-count")

                                            self.imported_path_memory = YLeaf(YType.uint32, "imported-path-memory")

                                            self.imported_paths = YLeaf(YType.uint32, "imported-paths")

                                            self.is_route_reflector = YLeaf(YType.boolean, "is-route-reflector")

                                            self.label_retain = YLeaf(YType.boolean, "label-retain")

                                            self.label_retainvalue = YLeaf(YType.uint32, "label-retainvalue")

                                            self.local_path_memory = YLeaf(YType.uint32, "local-path-memory")

                                            self.local_paths = YLeaf(YType.uint32, "local-paths")

                                            self.malloced_path_count = YLeaf(YType.uint32, "malloced-path-count")

                                            self.malloced_path_elem_count = YLeaf(YType.uint32, "malloced-path-elem-count")

                                            self.malloced_prefix_count = YLeaf(YType.uint32, "malloced-prefix-count")

                                            self.network_entry_count = YLeaf(YType.uint32, "network-entry-count")

                                            self.path_elem_memory = YLeaf(YType.uint32, "path-elem-memory")

                                            self.path_elems_count = YLeaf(YType.uint32, "path-elems-count")

                                            self.path_memory = YLeaf(YType.uint32, "path-memory")

                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                            self.prefix_memory = YLeaf(YType.uint32, "prefix-memory")

                                            self.received_path_count = YLeaf(YType.uint32, "received-path-count")

                                            self.retain_rt_all = YLeaf(YType.boolean, "retain-rt-all")

                                            self.route_target_download = YLeaf(YType.boolean, "route-target-download")

                                            self.tbl_bitf_size = YLeaf(YType.uint16, "tbl-bitf-size")

                                            self.tbl_chunk_bitf_size = YLeaf(YType.uint16, "tbl-chunk-bitf-size")

                                            self.use_igpsr_label = YLeaf(YType.boolean, "use-igpsr-label")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf, ['add_path_install_disable', 'add_path_install_enable', 'any_ebgp_neighbor_missing_policy', 'asbr', 'attribute_download', 'best_external', 'best_external_disable', 'bmp_network_entry_count', 'bmp_path_memory', 'bmp_paths_count', 'bmp_prefix_memory', 'damped_path_count', 'freed_path_count', 'freed_path_elem_count', 'freed_prefix_count', 'history_path_count', 'ibgp_nexthop_self_count', 'imported_path_memory', 'imported_paths', 'is_route_reflector', 'label_retain', 'label_retainvalue', 'local_path_memory', 'local_paths', 'malloced_path_count', 'malloced_path_elem_count', 'malloced_prefix_count', 'network_entry_count', 'path_elem_memory', 'path_elems_count', 'path_memory', 'paths_count', 'prefix_memory', 'received_path_count', 'retain_rt_all', 'route_target_download', 'tbl_bitf_size', 'tbl_chunk_bitf_size', 'use_igpsr_label'], name, value)


                                class Attributes(Entity):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes, self).__init__()

                                        self.yang_name = "attributes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute)}

                                        self.attribute = YList(self)
                                        self._segment_path = lambda: "attributes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes, [], name, value)


                                    class Attribute(Entity):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute, self).__init__()

                                            self.yang_name = "attribute"
                                            self.yang_parent_name = "attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo)}
                                            self._child_list_classes = {}

                                            self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                                            self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                                            self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                                            self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                                            self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                                            self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.reference_count = YLeaf(YType.uint32, "reference-count")

                                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self._children_name_map["attribute_info"] = "attribute-info"
                                            self._children_yang_names.add("attribute-info")
                                            self._segment_path = lambda: "attribute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                                        class AttributeInfo(Entity):
                                            """
                                            Attributes
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                                self.yang_name = "attribute-info"
                                                self.yang_parent_name = "attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attribute-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                class BmpPathTableGeneric(Entity):
                                    """
                                    Summary Info about BMP Table
                                    
                                    .. attribute:: bmp_route_monitoringe_enabled
                                    
                                    	Is Route Monitoring mode enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_incremented
                                    
                                    	Is Version being incremented
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_version_inprogress
                                    
                                    	Is Version wrap in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrapped
                                    
                                    	Number of times Table Version Wrapped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped_tid
                                    
                                    	Version Wrapped trigger thread id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_count
                                    
                                    	Number of nets in the table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_count
                                    
                                    	Number of paths in the table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                        self.yang_name = "bmp-path-table-generic"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-version-wrap-done-time-spec" : ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec), "bmp-version-wrap-start-time-spec" : ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec), "bmp-version-wrap-time-spec" : ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)}
                                        self._child_list_classes = {}

                                        self.bmp_route_monitoringe_enabled = YLeaf(YType.boolean, "bmp-route-monitoringe-enabled")

                                        self.bmp_table_version = YLeaf(YType.uint32, "bmp-table-version")

                                        self.bmp_version_incremented = YLeaf(YType.boolean, "bmp-version-incremented")

                                        self.bmp_version_inprogress = YLeaf(YType.boolean, "bmp-version-inprogress")

                                        self.bmp_version_wrapped = YLeaf(YType.uint32, "bmp-version-wrapped")

                                        self.bmp_version_wrapped_tid = YLeaf(YType.uint32, "bmp-version-wrapped-tid")

                                        self.network_count = YLeaf(YType.uint32, "network-count")

                                        self.path_count = YLeaf(YType.uint32, "path-count")

                                        self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                        self.bmp_version_wrap_done_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-done-time-spec")

                                        self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                        self.bmp_version_wrap_start_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-start-time-spec")

                                        self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                        self.bmp_version_wrap_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-time-spec")
                                        self._segment_path = lambda: "bmp-path-table-generic"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, ['bmp_route_monitoringe_enabled', 'bmp_table_version', 'bmp_version_incremented', 'bmp_version_inprogress', 'bmp_version_wrapped', 'bmp_version_wrapped_tid', 'network_count', 'path_count'], name, value)


                                    class BmpVersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-done-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpVersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-start-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-start-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpVersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpPaths(Entity):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths, self).__init__()

                                        self.yang_name = "bmp-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath)}

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-paths"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths, [], name, value)


                                    class BmpPath(Entity):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath>`
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)}
                                            self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath)}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bmp_net_flags = YLeaf(YType.uint32, "bmp-net-flags")

                                            self.bmp_net_version = YLeaf(YType.uint32, "bmp-net-version")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.network = YLeaf(YType.str, "network")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.bmp_path = YList(self)
                                            self._segment_path = lambda: "bmp-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, ['af_name', 'bmp_net_flags', 'bmp_net_version', 'has_local_label', 'net_local_label', 'network', 'num_of_path', 'prefix_length'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BmpPath(Entity):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress>`
                                            
                                            .. attribute:: received_label
                                            
                                            	Label received from peer
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath, self).__init__()

                                                self.yang_name = "bmp-path"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.bmp_nbr_bit_map = YLeaf(YType.uint32, "bmp-nbr-bit-map")

                                                self.bmp_path_adv_bit_map = YLeaf(YType.uint16, "bmp-path-adv-bit-map")

                                                self.bmp_path_flags = YLeaf(YType.uint32, "bmp-path-flags")

                                                self.bmp_path_snd_bit_map = YLeaf(YType.uint16, "bmp-path-snd-bit-map")

                                                self.bpath_pointer = YLeaf(YType.uint64, "bpath-pointer")

                                                self.local_path = YLeaf(YType.boolean, "local-path")

                                                self.received_label = YLeaf(YType.uint32, "received-label")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bmp-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath, ['bmp_nbr_bit_map', 'bmp_path_adv_bit_map', 'bmp_path_flags', 'bmp_path_snd_bit_map', 'bpath_pointer', 'local_path', 'received_label'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Convergence(Entity):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence, self).__init__()

                                        self.yang_name = "convergence"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.are_write_queues_empty = YLeaf(YType.boolean, "are-write-queues-empty")

                                        self.has_converged = YLeaf(YType.boolean, "has-converged")
                                        self._segment_path = lambda: "convergence"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence, ['af_name', 'are_write_queues_empty', 'has_converged'], name, value)


                                class Dampenings(Entity):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings, self).__init__()

                                        self.yang_name = "dampenings"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"dampening" : ("dampening", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening)}

                                        self.dampening = YList(self)
                                        self._segment_path = lambda: "dampenings"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "dampenings"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.length = YLeaf(YType.int32, "length")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.reuse = YLeaf(YType.int32, "reuse")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.version = YLeaf(YType.int32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "dampening"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'length', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_version', 'process_instance_id', 'rd', 'reuse', 'route_distinguisher', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'version', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class Epes(Entity):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes, self).__init__()

                                        self.yang_name = "epes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"epe" : ("epe", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe)}

                                        self.epe = YList(self)
                                        self._segment_path = lambda: "epes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes, [], name, value)


                                    class Epe(Entity):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe, self).__init__()

                                            self.yang_name = "epe"
                                            self.yang_parent_name = "epes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"epe-local-address" : ("epe_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress), "epe-next-hop" : ("epe_next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop)}
                                            self._child_list_classes = {"epe-key" : ("epe_key", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey), "first-hop" : ("first_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop), "ifhandle" : ("ifhandle", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle), "nexthop-id" : ("nexthop_id", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId)}

                                            self.epe_flags = YLeaf(YType.uint8, "epe-flags")

                                            self.epe_key_length = YLeaf(YType.int32, "epe-key-length")

                                            self.epe_key_length_xr = YLeaf(YType.uint8, "epe-key-length-xr")

                                            self.epe_local_asn = YLeaf(YType.uint32, "epe-local-asn")

                                            self.epe_local_router_id = YLeaf(YType.uint32, "epe-local-router-id")

                                            self.epe_remote_asn = YLeaf(YType.uint32, "epe-remote-asn")

                                            self.epe_remote_router_id = YLeaf(YType.uint32, "epe-remote-router-id")

                                            self.epe_set_key = YLeaf(YType.str, "epe-set-key")

                                            self.epe_version = YLeaf(YType.uint32, "epe-version")

                                            self.label = YLeaf(YType.uint32, "label")

                                            self.ref_count = YLeaf(YType.uint32, "ref-count")

                                            self.epe_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self._children_name_map["epe_local_address"] = "epe-local-address"
                                            self._children_yang_names.add("epe-local-address")

                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self._children_name_map["epe_next_hop"] = "epe-next-hop"
                                            self._children_yang_names.add("epe-next-hop")

                                            self.epe_key = YList(self)
                                            self.first_hop = YList(self)
                                            self.ifhandle = YList(self)
                                            self.nexthop_id = YList(self)
                                            self._segment_path = lambda: "epe"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe, ['epe_flags', 'epe_key_length', 'epe_key_length_xr', 'epe_local_asn', 'epe_local_router_id', 'epe_remote_asn', 'epe_remote_router_id', 'epe_set_key', 'epe_version', 'label', 'ref_count'], name, value)


                                        class EpeKey(Entity):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                                self.yang_name = "epe-key"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "epe-key"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, ['entry'], name, value)


                                        class EpeLocalAddress(Entity):
                                            """
                                            Local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                                self.yang_name = "epe-local-address"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "epe-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class EpeNextHop(Entity):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                                self.yang_name = "epe-next-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "epe-next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class FirstHop(Entity):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                                self.yang_name = "first-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "first-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class Ifhandle(Entity):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                                self.yang_name = "ifhandle"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ifhandle"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, ['entry'], name, value)


                                        class NexthopId(Entity):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                                self.yang_name = "nexthop-id"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "nexthop-id"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, ['entry'], name, value)


                                class GlobalAfProcessInfo(Entity):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                        self.yang_name = "global-af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "global-af-process-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, ['af_name', 'is_nsr_enabled', 'vrf_name'], name, value)


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall)}
                                            self._child_list_classes = {"syncgrp-version" : ("syncgrp_version", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion)}

                                            self.gblafrpki_allow_invalid = YLeaf(YType.boolean, "gblafrpki-allow-invalid")

                                            self.gblafrpki_disable = YLeaf(YType.boolean, "gblafrpki-disable")

                                            self.gblafrpki_signal_ibgp = YLeaf(YType.boolean, "gblafrpki-signal-ibgp")

                                            self.gblafrpki_use_validity = YLeaf(YType.boolean, "gblafrpki-use-validity")

                                            self.global_mcast_enabled = YLeaf(YType.boolean, "global-mcast-enabled")

                                            self.inter_as_install_enabled = YLeaf(YType.boolean, "inter-as-install-enabled")

                                            self.is_perm_net_cfg = YLeaf(YType.boolean, "is-perm-net-cfg")

                                            self.nh_tunnel_version = YLeaf(YType.uint32, "nh-tunnel-version")

                                            self.perm_nbr_count = YLeaf(YType.uint16, "perm-nbr-count")

                                            self.perm_net_del_count = YLeaf(YType.uint16, "perm-net-del-count")

                                            self.perm_net_existing_count = YLeaf(YType.uint16, "perm-net-existing-count")

                                            self.perm_net_insert_count = YLeaf(YType.uint16, "perm-net-insert-count")

                                            self.perm_net_rpl_process_count = YLeaf(YType.uint16, "perm-net-rpl-process-count")

                                            self.perm_net_rpl_query_count = YLeaf(YType.uint16, "perm-net-rpl-query-count")

                                            self.perm_net_stale_del_count = YLeaf(YType.uint16, "perm-net-stale-del-count")

                                            self.perm_net_stale_mark_count = YLeaf(YType.uint16, "perm-net-stale-mark-count")

                                            self.perm_path_refresh_count = YLeaf(YType.uint16, "perm-path-refresh-count")

                                            self.perm_pelem_all_bump_count = YLeaf(YType.uint16, "perm-pelem-all-bump-count")

                                            self.perm_pelem_bump_count = YLeaf(YType.uint16, "perm-pelem-bump-count")

                                            self.perm_pelem_free_count = YLeaf(YType.uint16, "perm-pelem-free-count")

                                            self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                            self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                            self.rib_perm_path_found_count = YLeaf(YType.uint16, "rib-perm-path-found-count")

                                            self.rib_perm_path_not_found_count = YLeaf(YType.uint16, "rib-perm-path-not-found-count")

                                            self.rib_perm_pelem_found_count = YLeaf(YType.uint16, "rib-perm-pelem-found-count")

                                            self.rib_perm_pelem_not_found_count = YLeaf(YType.uint16, "rib-perm-pelem-not-found-count")

                                            self.rib_reg_path_found_count = YLeaf(YType.uint16, "rib-reg-path-found-count")

                                            self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                            self.scan_prefixes = YLeaf(YType.uint32, "scan-prefixes")

                                            self.scan_segment_prefixes = YLeaf(YType.uint32, "scan-segment-prefixes")

                                            self.scan_segments = YLeaf(YType.uint8, "scan-segments")

                                            self.scanner_period = YLeaf(YType.uint16, "scanner-period")

                                            self.segmented_mcast_enabled = YLeaf(YType.boolean, "segmented-mcast-enabled")

                                            self.update_wait_install_enabled = YLeaf(YType.boolean, "update-wait-install-enabled")

                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._children_yang_names.add("rib-install")

                                            self.syncgrp_version = YList(self)
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_, ['gblafrpki_allow_invalid', 'gblafrpki_disable', 'gblafrpki_signal_ibgp', 'gblafrpki_use_validity', 'global_mcast_enabled', 'inter_as_install_enabled', 'is_perm_net_cfg', 'nh_tunnel_version', 'perm_nbr_count', 'perm_net_del_count', 'perm_net_existing_count', 'perm_net_insert_count', 'perm_net_rpl_process_count', 'perm_net_rpl_query_count', 'perm_net_stale_del_count', 'perm_net_stale_mark_count', 'perm_path_refresh_count', 'perm_pelem_all_bump_count', 'perm_pelem_bump_count', 'perm_pelem_free_count', 'rib_ack_requests', 'rib_acks_received', 'rib_perm_path_found_count', 'rib_perm_path_not_found_count', 'rib_perm_pelem_found_count', 'rib_perm_pelem_not_found_count', 'rib_reg_path_found_count', 'rib_slow_acks', 'scan_prefixes', 'scan_segment_prefixes', 'scan_segments', 'scanner_period', 'segmented_mcast_enabled', 'update_wait_install_enabled'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime)}
                                                self._child_list_classes = {}

                                                self.installed_count = YLeaf(YType.uint32, "installed-count")

                                                self.modified_count = YLeaf(YType.uint32, "modified-count")

                                                self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                                self.start_version = YLeaf(YType.uint32, "start-version")

                                                self.target_version = YLeaf(YType.uint32, "target-version")

                                                self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._children_yang_names.add("install-time")

                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"
                                                self._children_yang_names.add("update-time")
                                                self._segment_path = lambda: "rib-install"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "install-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                        class SyncgrpVersion(Entity):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, self).__init__()

                                                self.yang_name = "syncgrp-version"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "syncgrp-version"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, ['entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.aggregates_distance = YLeaf(YType.uint16, "aggregates-distance")

                                            self.client_reflection_enabled = YLeaf(YType.boolean, "client-reflection-enabled")

                                            self.dampening_enabled = YLeaf(YType.boolean, "dampening-enabled")

                                            self.dynamic_med_enabled = YLeaf(YType.boolean, "dynamic-med-enabled")

                                            self.dynamic_med_interval = YLeaf(YType.uint16, "dynamic-med-interval")

                                            self.dynamic_med_periodic_timer_running = YLeaf(YType.boolean, "dynamic-med-periodic-timer-running")

                                            self.dynamic_med_periodic_timer_value = YLeaf(YType.uint16, "dynamic-med-periodic-timer-value")

                                            self.dynamic_med_timer_running = YLeaf(YType.boolean, "dynamic-med-timer-running")

                                            self.dynamic_med_timer_value = YLeaf(YType.uint16, "dynamic-med-timer-value")

                                            self.ebgp_distance = YLeaf(YType.uint16, "ebgp-distance")

                                            self.ibgp_distance = YLeaf(YType.uint16, "ibgp-distance")

                                            self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                            self.nexthop_resolution_minimum_prefix_length = YLeaf(YType.uint32, "nexthop-resolution-minimum-prefix-length")

                                            self.nexthop_resolution_minimum_prefix_length_configured = YLeaf(YType.boolean, "nexthop-resolution-minimum-prefix-length-configured")

                                            self.nsr_conv_version = YLeaf(YType.uint32, "nsr-conv-version")

                                            self.nsr_is_conv = YLeaf(YType.boolean, "nsr-is-conv")

                                            self.rd_version = YLeaf(YType.uint32, "rd-version")

                                            self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                            self.rib_convergence_version = YLeaf(YType.uint32, "rib-convergence-version")

                                            self.rib_has_converged = YLeaf(YType.boolean, "rib-has-converged")

                                            self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                            self.rib_version = YLeaf(YType.uint32, "rib-version")

                                            self.selective_ebgp_multipath_enabled = YLeaf(YType.boolean, "selective-ebgp-multipath-enabled")

                                            self.selective_eibgp_multipath_enabled = YLeaf(YType.boolean, "selective-eibgp-multipath-enabled")

                                            self.selective_ibgp_multipath_enabled = YLeaf(YType.boolean, "selective-ibgp-multipath-enabled")

                                            self.table_id = YLeaf(YType.uint32, "table-id")

                                            self.table_is_active = YLeaf(YType.boolean, "table-is-active")

                                            self.table_version = YLeaf(YType.uint32, "table-version")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf, ['aggregates_distance', 'client_reflection_enabled', 'dampening_enabled', 'dynamic_med_enabled', 'dynamic_med_interval', 'dynamic_med_periodic_timer_running', 'dynamic_med_periodic_timer_value', 'dynamic_med_timer_running', 'dynamic_med_timer_value', 'ebgp_distance', 'ibgp_distance', 'is_rib_table_full', 'nexthop_resolution_minimum_prefix_length', 'nexthop_resolution_minimum_prefix_length_configured', 'nsr_conv_version', 'nsr_is_conv', 'rd_version', 'rib_acked_table_version', 'rib_convergence_version', 'rib_has_converged', 'rib_table_full_version', 'rib_version', 'selective_ebgp_multipath_enabled', 'selective_eibgp_multipath_enabled', 'selective_ibgp_multipath_enabled', 'table_id', 'table_is_active', 'table_version'], name, value)


                                class NeighborAfTable(Entity):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable, self).__init__()

                                        self.yang_name = "neighbor-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbor-af-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\:  str
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\:  bool
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\:  bool
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbor-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)}
                                            self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData)}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                            self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                            self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                            self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                            self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                            self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                            self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                            self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                            self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                            self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                            self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                            self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                            self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                            self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                            self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                            self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                            self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                            self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                            self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                            self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                            self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                            self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                            self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                            self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                            self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                            self.description = YLeaf(YType.str, "description")

                                            self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                            self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                            self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                            self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                            self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                            self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                            self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                            self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                            self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                            self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                            self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                            self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                            self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                            self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                            self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                            self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                            self.hold_time = YLeaf(YType.uint16, "hold-time")

                                            self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                            self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                            self.io_armed = YLeaf(YType.boolean, "io-armed")

                                            self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                            self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                            self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                            self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                            self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                            self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                            self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                            self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                            self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                            self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                            self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                            self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                            self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                            self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                            self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                            self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                            self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                            self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                            self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                            self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                            self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                            self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                            self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                            self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                            self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                            self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                            self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                            self.local_as = YLeaf(YType.uint32, "local-as")

                                            self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                            self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                            self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                            self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                            self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                            self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                            self.messages_received = YLeaf(YType.uint32, "messages-received")

                                            self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                            self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                            self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                            self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                            self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                            self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                            self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                            self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                            self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                            self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                            self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                            self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                            self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                            self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                            self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                            self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                            self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                            self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                            self.read_armed = YLeaf(YType.boolean, "read-armed")

                                            self.remote_as = YLeaf(YType.uint32, "remote-as")

                                            self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                            self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                            self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                            self.router_id = YLeaf(YType.str, "router-id")

                                            self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                            self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                            self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                            self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                            self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                            self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                            self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                            self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                            self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                            self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                            self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                            self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                            self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                            self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                            self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                            self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                            self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                            self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                            self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                            self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                            self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                            self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                            self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                            self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                            self.tos_type = YLeaf(YType.uint8, "tos-type")

                                            self.tos_value = YLeaf(YType.uint8, "tos-value")

                                            self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                            self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                            self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                            self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.write_armed = YLeaf(YType.boolean, "write-armed")

                                            self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self._children_name_map["connection_local_address"] = "connection-local-address"
                                            self._children_yang_names.add("connection-local-address")

                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                            self._children_yang_names.add("connection-remote-address")

                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                            self._children_yang_names.add("graceful-maintenance")

                                            self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self._children_name_map["message_statistics"] = "message-statistics"
                                            self._children_yang_names.add("message-statistics")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")

                                            self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self._children_name_map["received_notification_info"] = "received-notification-info"
                                            self._children_yang_names.add("received-notification-info")

                                            self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self._children_name_map["send_notification_info"] = "send-notification-info"
                                            self._children_yang_names.add("send-notification-info")

                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-time-spec")

                                            self.af_data = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                        class AfData(Entity):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with 
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\:  bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\:  bool
                                            
                                            .. attribute:: enable_label_stack
                                            
                                            	Enable label stack
                                            	**type**\:  bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\:  bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\:  str
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\:  str
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                                self.yang_name = "af-data"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                                self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby)}

                                                self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                                self.acked_version = YLeaf(YType.uint32, "acked-version")

                                                self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                                self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                                self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                                self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                                self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                                self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                                self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                                self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                                self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                                self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                                self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                                self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                                self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                                self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                                self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                                self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                                self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                                self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                                self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                                self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                                self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                                self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                                self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                                self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                                self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                                self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                                self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                                self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                                self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                                self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                                self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                                self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                                self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                                self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                                self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                                self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                                self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                                self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                                self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                                self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                                self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                                self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                                self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                                self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                                self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                                self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                                self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                                self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                                self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                                self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                                self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                                self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                                self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                                self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                                self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                                self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                                self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                                self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                                self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                                self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                                self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                                self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                                self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                                self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                                self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                                self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                                self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                                self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                                self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                                self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                                self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                                self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                                self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                                self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                                self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                                self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                                self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                                self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                                self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                                self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                                self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                                self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                                self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                                self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                                self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                                self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                                self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                                self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                                self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                                self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                                self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                                self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                                self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                                self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                                self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                                self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                                self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                                self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                                self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                                self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                                self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                                self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                                self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                                self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                                self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                                self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                                self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                                self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                                self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                                self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                                self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                                self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                                self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                                self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                                self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                                self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                                self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                                self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                                self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                                self._children_yang_names.add("neighbor-af-performance-statistics")

                                                self.extended_community = YList(self)
                                                self.extended_community_standby = YList(self)
                                                self._segment_path = lambda: "af-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                            class ExtendedCommunityStandby(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                    self.yang_name = "extended-community-standby"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community-standby"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                            class NeighborAfPerformanceStatistics(Entity):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                    self.yang_name = "neighbor-af-performance-statistics"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                                    self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                                    self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                                    self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                                    self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                                    self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                                    self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                                    self._segment_path = lambda: "neighbor-af-performance-statistics"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                        class ConnectionLocalAddress(Entity):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                                self.yang_name = "connection-local-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "connection-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ConnectionRemoteAddress(Entity):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                                self.yang_name = "connection-remote-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "connection-remote-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class GracefulMaintenance(Entity):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                                self.yang_name = "graceful-maintenance"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                                self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                                self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                                self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                                self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                                self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                                self._segment_path = lambda: "graceful-maintenance"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                        class MessageStatistics(Entity):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                                self.yang_name = "message-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)}
                                                self._child_list_classes = {}

                                                self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self._children_name_map["keepalive"] = "keepalive"
                                                self._children_yang_names.add("keepalive")

                                                self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self._children_name_map["notification"] = "notification"
                                                self._children_yang_names.add("notification")

                                                self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self._children_name_map["open"] = "open"
                                                self._children_yang_names.add("open")

                                                self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self._children_name_map["route_refresh"] = "route-refresh"
                                                self._children_yang_names.add("route-refresh")

                                                self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self._children_name_map["total"] = "total"
                                                self._children_yang_names.add("total")

                                                self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self
                                                self._children_name_map["update"] = "update"
                                                self._children_yang_names.add("update")
                                                self._segment_path = lambda: "message-statistics"


                                            class Keepalive(Entity):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                    self.yang_name = "keepalive"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "keepalive"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Notification(Entity):
                                                """
                                                Notification
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                    self.yang_name = "notification"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "notification"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Open(Entity):
                                                """
                                                Open
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                    self.yang_name = "open"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "open"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class RouteRefresh(Entity):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                    self.yang_name = "route-refresh"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "route-refresh"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Total(Entity):
                                                """
                                                Total
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                    self.yang_name = "total"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "total"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Update(Entity):
                                                """
                                                Update
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                    self.yang_name = "update"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "update"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.active_collision = YLeaf(YType.uint32, "active-collision")

                                                self.actives = YLeaf(YType.uint32, "actives")

                                                self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                                self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                                self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                                self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                                self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                                self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                                self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                                self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                                self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                                self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                                self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                                self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                                self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                                self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                                self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                                self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                                self.network_status = YLeaf(YType.uint32, "network-status")

                                                self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                                self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                                self.passives = YLeaf(YType.uint32, "passives")

                                                self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                                self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                                self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                                self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                                self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                                self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                                self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                                self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                                self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                                self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                                self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                                self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                                self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                                self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                        class ReceivedNotificationInfo(Entity):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                                self.yang_name = "received-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                                self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                                self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                                self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "received-notification-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "received-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "last-notification-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                        class SendNotificationInfo(Entity):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                                self.yang_name = "send-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData)}

                                                self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                                self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                                self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "send-notification-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "send-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "last-notification-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                        class TcpInitSyncDoneTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-done-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TcpInitSyncTimeSpec(Entity):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class NetworkAllRds(Entity):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds, self).__init__()

                                        self.yang_name = "network-all-rds"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-all-rd" : ("network_all_rd", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd)}

                                        self.network_all_rd = YList(self)
                                        self._segment_path = lambda: "network-all-rds"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds, [], name, value)


                                    class NetworkAllRd(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: network_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd, self).__init__()

                                            self.yang_name = "network-all-rd"
                                            self.yang_parent_name = "network-all-rds"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"network-rds" : ("network_rds", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds)}
                                            self._child_list_classes = {}

                                            self.network = YLeaf(YType.str, "network")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.network_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                            self.network_rds.parent = self
                                            self._children_name_map["network_rds"] = "network-rds"
                                            self._children_yang_names.add("network-rds")
                                            self._segment_path = lambda: "network-all-rd"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd, ['network', 'prefix_length'], name, value)


                                        class NetworkRds(Entity):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, self).__init__()

                                                self.yang_name = "network-rds"
                                                self.yang_parent_name = "network-all-rd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"network-rd" : ("network_rd", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd)}

                                                self.network_rd = YList(self)
                                                self._segment_path = lambda: "network-rds"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, [], name, value)


                                            class NetworkRd(Entity):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, self).__init__()

                                                    self.yang_name = "network-rd"
                                                    self.yang_parent_name = "network-rds"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp)}
                                                    self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo)}

                                                    self.rd = YLeaf(YType.str, "rd")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.bit = YLeaf(YType.uint16, "bit")

                                                    self.flags = YLeaf(YType.uint8, "flags")

                                                    self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                    self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                    self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                    self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                    self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                    self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                    self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                    self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                    self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                    self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                    self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                    self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                    self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                    self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                    self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                    self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                    self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                    self.table_version = YLeaf(YType.uint32, "table-version")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self._children_name_map["version_age"] = "version-age"
                                                    self._children_yang_names.add("version-age")

                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self._children_name_map["version_timestamp"] = "version-timestamp"
                                                    self._children_yang_names.add("version-timestamp")

                                                    self.active_path_element = YList(self)
                                                    self.active_process_instance_path = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.local_path_element = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.local_process_instance_path = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self._segment_path = lambda: "network-rd" + "[rd='" + self.rd.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                                class ActivePathElement(Entity):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, self).__init__()

                                                        self.yang_name = "active-path-element"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "active-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ActiveProcessInstancePath(Entity):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, self).__init__()

                                                        self.yang_name = "active-process-instance-path"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "active-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPathElement(Entity):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, self).__init__()

                                                        self.yang_name = "local-path-element"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "local-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalProcessInstancePath(Entity):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, self).__init__()

                                                        self.yang_name = "local-process-instance-path"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "local-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class VersionAge(Entity):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, self).__init__()

                                                        self.yang_name = "version-age"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-age"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                                class VersionTimestamp(Entity):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, self).__init__()

                                                        self.yang_name = "version-timestamp"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-timestamp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NetworkLookupAllRds(Entity):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_lookup_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds, self).__init__()

                                        self.yang_name = "network-lookup-all-rds"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-lookup-all-rd" : ("network_lookup_all_rd", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd)}

                                        self.network_lookup_all_rd = YList(self)
                                        self._segment_path = lambda: "network-lookup-all-rds"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds, [], name, value)


                                    class NetworkLookupAllRd(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_lookup_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, self).__init__()

                                            self.yang_name = "network-lookup-all-rd"
                                            self.yang_parent_name = "network-lookup-all-rds"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"network-lookup-rds" : ("network_lookup_rds", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds)}
                                            self._child_list_classes = {}

                                            self.network_prefix = YLeaf(YType.str, "network-prefix")

                                            self.network_lookup_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                            self.network_lookup_rds.parent = self
                                            self._children_name_map["network_lookup_rds"] = "network-lookup-rds"
                                            self._children_yang_names.add("network-lookup-rds")
                                            self._segment_path = lambda: "network-lookup-all-rd" + "[network-prefix='" + self.network_prefix.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, ['network_prefix'], name, value)


                                        class NetworkLookupRds(Entity):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_lookup_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, self).__init__()

                                                self.yang_name = "network-lookup-rds"
                                                self.yang_parent_name = "network-lookup-all-rd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"network-lookup-rd" : ("network_lookup_rd", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd)}

                                                self.network_lookup_rd = YList(self)
                                                self._segment_path = lambda: "network-lookup-rds"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, [], name, value)


                                            class NetworkLookupRd(Entity):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, self).__init__()

                                                    self.yang_name = "network-lookup-rd"
                                                    self.yang_parent_name = "network-lookup-rds"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp)}
                                                    self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo)}

                                                    self.rd = YLeaf(YType.str, "rd")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.bit = YLeaf(YType.uint16, "bit")

                                                    self.flags = YLeaf(YType.uint8, "flags")

                                                    self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                    self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                    self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                    self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                    self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                    self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                    self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                    self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                    self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                    self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                    self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                    self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                    self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                    self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                    self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                    self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                    self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                    self.table_version = YLeaf(YType.uint32, "table-version")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self._children_name_map["version_age"] = "version-age"
                                                    self._children_yang_names.add("version-age")

                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self._children_name_map["version_timestamp"] = "version-timestamp"
                                                    self._children_yang_names.add("version-timestamp")

                                                    self.active_path_element = YList(self)
                                                    self.active_process_instance_path = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.local_path_element = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.local_process_instance_path = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self._segment_path = lambda: "network-lookup-rd" + "[rd='" + self.rd.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                                class ActivePathElement(Entity):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, self).__init__()

                                                        self.yang_name = "active-path-element"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "active-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ActiveProcessInstancePath(Entity):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, self).__init__()

                                                        self.yang_name = "active-process-instance-path"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "active-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPathElement(Entity):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, self).__init__()

                                                        self.yang_name = "local-path-element"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "local-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalProcessInstancePath(Entity):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, self).__init__()

                                                        self.yang_name = "local-process-instance-path"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "local-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class VersionAge(Entity):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, self).__init__()

                                                        self.yang_name = "version-age"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-age"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                                class VersionTimestamp(Entity):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, self).__init__()

                                                        self.yang_name = "version-timestamp"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-timestamp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NetworkPrefixes(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix
                                    
                                    	A BGP Network Lookup prefix entry
                                    	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes, self).__init__()

                                        self.yang_name = "network-prefixes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-prefix" : ("network_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix)}

                                        self.network_prefix = YList(self)
                                        self._segment_path = lambda: "network-prefixes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes, [], name, value)


                                    class NetworkPrefix(Entity):
                                        """
                                        A BGP Network Lookup prefix entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network_prefix
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix, self).__init__()

                                            self.yang_name = "network-prefix"
                                            self.yang_parent_name = "network-prefixes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp)}
                                            self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo)}

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bit = YLeaf(YType.uint16, "bit")

                                            self.flags = YLeaf(YType.uint8, "flags")

                                            self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                            self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                            self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                            self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                            self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                            self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                            self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                            self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                            self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                            self.net_flags = YLeaf(YType.uint32, "net-flags")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                            self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                            self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                            self.network_prefix = YLeaf(YType.str, "network-prefix")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.active_path_element = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.local_path_element = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self._segment_path = lambda: "network-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network_prefix', 'num_of_path', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "active-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "active-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "local-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "local-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Networks(Entity):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks, self).__init__()

                                        self.yang_name = "networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network" : ("network", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network)}

                                        self.network = YList(self)
                                        self._segment_path = lambda: "networks"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks, [], name, value)


                                    class Network(Entity):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp)}
                                            self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)}

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bit = YLeaf(YType.uint16, "bit")

                                            self.flags = YLeaf(YType.uint8, "flags")

                                            self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                            self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                            self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                            self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                            self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                            self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                            self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                            self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                            self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                            self.net_flags = YLeaf(YType.uint32, "net-flags")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                            self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                            self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                            self.network = YLeaf(YType.str, "network")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.active_path_element = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.local_path_element = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self._segment_path = lambda: "network"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network', 'num_of_path', 'prefix_length', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "active-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "active-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "local-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "local-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NextHopAddressFamilies(Entity):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                        self.yang_name = "next-hop-address-families"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"next-hop-address-family" : ("next_hop_address_family", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily)}

                                        self.next_hop_address_family = YList(self)
                                        self._segment_path = lambda: "next-hop-address-families"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                    class NextHopAddressFamily(Entity):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  <key>
                                        
                                        	Address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                            self.yang_name = "next-hop-address-family"
                                            self.yang_parent_name = "next-hop-address-families"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-af-vrf-af" : ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf), "next-hop-afs" : ("next_hop_afs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs)}
                                            self._child_list_classes = {}

                                            self.next_hop_af_name = YLeaf(YType.enumeration, "next-hop-af-name")

                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"
                                            self._children_yang_names.add("next-hop-af-vrf-af")

                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self
                                            self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                            self._children_yang_names.add("next-hop-afs")
                                            self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + self.next_hop_af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                        class NextHopAfVrfAf(Entity):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                                self.yang_name = "next-hop-af-vrf-af"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.critical_trigger_delay = YLeaf(YType.uint32, "critical-trigger-delay")

                                                self.epe_downloaded_version = YLeaf(YType.uint32, "epe-downloaded-version")

                                                self.epe_label_version = YLeaf(YType.uint32, "epe-label-version")

                                                self.epe_standby_version = YLeaf(YType.uint32, "epe-standby-version")

                                                self.epe_table_version = YLeaf(YType.uint32, "epe-table-version")

                                                self.gwaf_name = YLeaf(YType.enumeration, "gwaf-name")

                                                self.nh_nexthop_version = YLeaf(YType.uint32, "nh-nexthop-version")

                                                self.nh_rib_up = YLeaf(YType.boolean, "nh-rib-up")

                                                self.nh_rib_version = YLeaf(YType.uint32, "nh-rib-version")

                                                self.nh_table_id = YLeaf(YType.uint32, "nh-table-id")

                                                self.non_critical_trigger_delay = YLeaf(YType.uint32, "non-critical-trigger-delay")

                                                self.table_active = YLeaf(YType.boolean, "table-active")

                                                self.total_nexthops = YLeaf(YType.uint32, "total-nexthops")

                                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                                self._children_yang_names.add("performance-statistics")
                                                self._segment_path = lambda: "next-hop-af-vrf-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, ['af_name', 'critical_trigger_delay', 'epe_downloaded_version', 'epe_label_version', 'epe_standby_version', 'epe_table_version', 'gwaf_name', 'nh_nexthop_version', 'nh_rib_up', 'nh_rib_version', 'nh_table_id', 'non_critical_trigger_delay', 'table_active', 'total_nexthops'], name, value)


                                            class PerformanceStatistics(Entity):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                    self.yang_name = "performance-statistics"
                                                    self.yang_parent_name = "next-hop-af-vrf-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.critical_notf_count = YLeaf(YType.uint32, "critical-notf-count")

                                                    self.last_notf_bestpath_changes = YLeaf(YType.uint32, "last-notf-bestpath-changes")

                                                    self.last_notf_bestpath_deletes = YLeaf(YType.uint32, "last-notf-bestpath-deletes")

                                                    self.nexthops_removed_from_rib = YLeaf(YType.uint32, "nexthops-removed-from-rib")

                                                    self.nexthops_resent_to_rib = YLeaf(YType.uint32, "nexthops-resent-to-rib")

                                                    self.nexthops_sent_to_rib = YLeaf(YType.uint32, "nexthops-sent-to-rib")

                                                    self.nh_batch_finish_calls = YLeaf(YType.uint32, "nh-batch-finish-calls")

                                                    self.nh_flush_timer_calls = YLeaf(YType.uint32, "nh-flush-timer-calls")

                                                    self.nh_last_a_sync_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-reg-ts")

                                                    self.nh_last_a_sync_un_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-un-reg-ts")

                                                    self.nh_last_batch_finish_ts = YLeaf(YType.uint32, "nh-last-batch-finish-ts")

                                                    self.nh_last_flush_timer_ts = YLeaf(YType.uint32, "nh-last-flush-timer-ts")

                                                    self.nh_last_sync_reg_ts = YLeaf(YType.uint32, "nh-last-sync-reg-ts")

                                                    self.nh_peak_registrations = YLeaf(YType.uint32, "nh-peak-registrations")

                                                    self.nh_pending_registrations = YLeaf(YType.uint32, "nh-pending-registrations")

                                                    self.nh_sync_reg_calls = YLeaf(YType.uint32, "nh-sync-reg-calls")

                                                    self.nha_sync_reg_calls = YLeaf(YType.uint32, "nha-sync-reg-calls")

                                                    self.nha_sync_un_reg_calls = YLeaf(YType.uint32, "nha-sync-un-reg-calls")

                                                    self.nhrib_update_calls = YLeaf(YType.uint32, "nhrib-update-calls")

                                                    self.nhrib_update_time = YLeaf(YType.uint32, "nhrib-update-time")

                                                    self.noncritical_notf_count = YLeaf(YType.uint32, "noncritical-notf-count")

                                                    self.rib_sync_registers_failed = YLeaf(YType.uint32, "rib-sync-registers-failed")

                                                    self.riba_sync_registers_failed = YLeaf(YType.uint32, "riba-sync-registers-failed")

                                                    self.ribnh_reg_failed_for_no_rib_conn = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-rib-conn")

                                                    self.ribnh_reg_failed_for_no_tbl_id = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-tbl-id")

                                                    self.tunnel_walk_backup_creates = YLeaf(YType.uint32, "tunnel-walk-backup-creates")

                                                    self.tunnel_walk_gw_not_found = YLeaf(YType.uint32, "tunnel-walk-gw-not-found")

                                                    self.tunnel_walk_nh_not_found = YLeaf(YType.uint32, "tunnel-walk-nh-not-found")
                                                    self._segment_path = lambda: "performance-statistics"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, ['critical_notf_count', 'last_notf_bestpath_changes', 'last_notf_bestpath_deletes', 'nexthops_removed_from_rib', 'nexthops_resent_to_rib', 'nexthops_sent_to_rib', 'nh_batch_finish_calls', 'nh_flush_timer_calls', 'nh_last_a_sync_reg_ts', 'nh_last_a_sync_un_reg_ts', 'nh_last_batch_finish_ts', 'nh_last_flush_timer_ts', 'nh_last_sync_reg_ts', 'nh_peak_registrations', 'nh_pending_registrations', 'nh_sync_reg_calls', 'nha_sync_reg_calls', 'nha_sync_un_reg_calls', 'nhrib_update_calls', 'nhrib_update_time', 'noncritical_notf_count', 'rib_sync_registers_failed', 'riba_sync_registers_failed', 'ribnh_reg_failed_for_no_rib_conn', 'ribnh_reg_failed_for_no_tbl_id', 'tunnel_walk_backup_creates', 'tunnel_walk_gw_not_found', 'tunnel_walk_nh_not_found'], name, value)


                                        class NextHopAfs(Entity):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                                self.yang_name = "next-hop-afs"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"next-hop-af" : ("next_hop_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf)}

                                                self.next_hop_af = YList(self)
                                                self._segment_path = lambda: "next-hop-afs"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                            class NextHopAf(Entity):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                    self.yang_name = "next-hop-af"
                                                    self.yang_parent_name = "next-hop-afs"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress), "nexthop-internal-info" : ("nexthop_internal_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)}
                                                    self._child_list_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress), "nexthop-gateway-info" : ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.attribute_set = YLeaf(YType.str, "attribute-set")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.nexthop_aigp_metric = YLeaf(YType.uint32, "nexthop-aigp-metric")

                                                    self.nexthop_gateway_prefix_connected = YLeaf(YType.boolean, "nexthop-gateway-prefix-connected")

                                                    self.nexthop_gateway_prefix_length = YLeaf(YType.uint32, "nexthop-gateway-prefix-length")

                                                    self.nexthop_gateway_reachable = YLeaf(YType.boolean, "nexthop-gateway-reachable")

                                                    self.nexthop_pending_registration = YLeaf(YType.uint8, "nexthop-pending-registration")

                                                    self.nexthop_reference_count = YLeaf(YType.uint32, "nexthop-reference-count")

                                                    self.nh_first_hop_if_handle = YLeaf(YType.str, "nh-first-hop-if-handle")

                                                    self.nh_reference_count_total = YLeaf(YType.uint32, "nh-reference-count-total")

                                                    self.rib_nexthop_id = YLeaf(YType.uint32, "rib-nexthop-id")

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"
                                                    self._children_yang_names.add("nexthop-address")

                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"
                                                    self._children_yang_names.add("nexthop-internal-info")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.neighbor_address = YList(self)
                                                    self.nexthop_gateway_info = YList(self)
                                                    self._segment_path = lambda: "next-hop-af"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['af_name', 'attribute_set', 'next_hop_address', 'nexthop_aigp_metric', 'nexthop_gateway_prefix_connected', 'nexthop_gateway_prefix_length', 'nexthop_gateway_reachable', 'nexthop_pending_registration', 'nexthop_reference_count', 'nh_first_hop_if_handle', 'nh_reference_count_total', 'rib_nexthop_id'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopGatewayInfo(Entity):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:   :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:   :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-route" : ("nexthop_route", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)}
                                                        self._child_list_classes = {"nexthop-route-path" : ("nexthop_route_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath)}

                                                        self.critical_events = YLeaf(YType.uint32, "critical-events")

                                                        self.last_event_since = YLeaf(YType.uint32, "last-event-since")

                                                        self.last_event_type = YLeaf(YType.enumeration, "last-event-type")

                                                        self.last_rib_update = YLeaf(YType.uint32, "last-rib-update")

                                                        self.last_update_type = YLeaf(YType.enumeration, "last-update-type")

                                                        self.nexthop_af_invalid_bits = YLeaf(YType.uint16, "nexthop-af-invalid-bits")

                                                        self.nexthop_metric = YLeaf(YType.uint32, "nexthop-metric")

                                                        self.nexthop_mpls_enabled = YLeaf(YType.boolean, "nexthop-mpls-enabled")

                                                        self.nexthop_mpls_interfaces = YLeaf(YType.uint32, "nexthop-mpls-interfaces")

                                                        self.nexthop_mpls_label = YLeaf(YType.uint32, "nexthop-mpls-label")

                                                        self.nexthop_route_path_count = YLeaf(YType.uint32, "nexthop-route-path-count")

                                                        self.nexthop_route_prefix_length = YLeaf(YType.uint8, "nexthop-route-prefix-length")

                                                        self.nexthop_route_protocol = YLeaf(YType.str, "nexthop-route-protocol")

                                                        self.nexthop_status = YLeaf(YType.uint8, "nexthop-status")

                                                        self.nexthop_tableid = YLeaf(YType.uint64, "nexthop-tableid")

                                                        self.non_critical_events = YLeaf(YType.uint32, "non-critical-events")

                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self._children_name_map["nexthop_route"] = "nexthop-route"
                                                        self._children_yang_names.add("nexthop-route")

                                                        self.nexthop_route_path = YList(self)
                                                        self._segment_path = lambda: "nexthop-gateway-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, ['critical_events', 'last_event_since', 'last_event_type', 'last_rib_update', 'last_update_type', 'nexthop_af_invalid_bits', 'nexthop_metric', 'nexthop_mpls_enabled', 'nexthop_mpls_interfaces', 'nexthop_mpls_label', 'nexthop_route_path_count', 'nexthop_route_prefix_length', 'nexthop_route_protocol', 'nexthop_status', 'nexthop_tableid', 'non_critical_events'], name, value)


                                                    class NexthopRoute(Entity):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                            self.yang_name = "nexthop-route"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NexthopRoutePath(Entity):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                            self.yang_name = "nexthop-route-path"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-route-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopInternalInfo(Entity):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-internal-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)}
                                                        self._child_list_classes = {"nexthop-gateway-internal-info" : ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo), "nexthop-metrice" : ("nexthop_metrice", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice), "nexthop-refcount" : ("nexthop_refcount", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)}

                                                        self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                        self.nexthop_af_user_bits = YLeaf(YType.uint32, "nexthop-af-user-bits")

                                                        self.nexthop_flags = YLeaf(YType.uint32, "nexthop-flags")

                                                        self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                        self.nexthop_if_handle = YLeaf(YType.uint32, "nexthop-if-handle")

                                                        self.nexthop_label = YLeaf(YType.uint32, "nexthop-label")

                                                        self.nexthop_version = YLeaf(YType.uint32, "nexthop-version")

                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self._children_name_map["nexthop_address"] = "nexthop-address"
                                                        self._children_yang_names.add("nexthop-address")

                                                        self.nexthop_gateway_internal_info = YList(self)
                                                        self.nexthop_metrice = YList(self)
                                                        self.nexthop_refcount = YList(self)
                                                        self._segment_path = lambda: "nexthop-internal-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, ['gateway_flags', 'nexthop_af_user_bits', 'nexthop_flags', 'nexthop_id', 'nexthop_if_handle', 'nexthop_label', 'nexthop_version'], name, value)


                                                    class NexthopAddress(Entity):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                            self.yang_name = "nexthop-address"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NexthopGatewayInternalInfo(Entity):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:   :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                            self.yang_name = "nexthop-gateway-internal-info"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                            self.registration_since = YLeaf(YType.uint32, "registration-since")

                                                            self.registration_type = YLeaf(YType.enumeration, "registration-type")
                                                            self._segment_path = lambda: "nexthop-gateway-internal-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, ['gateway_flags', 'registration_since', 'registration_type'], name, value)


                                                    class NexthopMetrice(Entity):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                            self.yang_name = "nexthop-metrice"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "nexthop-metrice"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, ['entry'], name, value)


                                                    class NexthopRefcount(Entity):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                            self.yang_name = "nexthop-refcount"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "nexthop-refcount"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, ['entry'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                class PathLabeledTable(Entity):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable, self).__init__()

                                        self.yang_name = "path-labeled-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-labeled-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-labeled-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PathTable(Entity):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable, self).__init__()

                                        self.yang_name = "path-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PathUsedTable(Entity):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable, self).__init__()

                                        self.yang_name = "path-used-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-used-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-used-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class Policies(Entity):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies, self).__init__()

                                        self.yang_name = "policies"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"policy" : ("policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy)}

                                        self.policy = YList(self)
                                        self._segment_path = lambda: "policies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies, [], name, value)


                                    class Policy(Entity):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy, self).__init__()

                                            self.yang_name = "policy"
                                            self.yang_parent_name = "policies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._children_yang_names.add("attributes-after-policy-out")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                            self._children_yang_names.add("path-info-after-policy-in")

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                            self._children_yang_names.add("path-info-after-policy-out")
                                            self._segment_path = lambda: "policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy, ['af_name', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixFilters(Entity):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters, self).__init__()

                                        self.yang_name = "prefix-filters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"prefix-filter" : ("prefix_filter", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter)}

                                        self.prefix_filter = YList(self)
                                        self._segment_path = lambda: "prefix-filters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters, [], name, value)


                                    class PrefixFilter(Entity):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                            self.yang_name = "prefix-filter"
                                            self.yang_parent_name = "prefix-filters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr), "prefix-list-info" : ("prefix_list_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo)}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self
                                            self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                            self._children_yang_names.add("prefix-list-info")
                                            self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', 'af_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PrefixListInfo(Entity):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                                self.yang_name = "prefix-list-info"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bgp-pfxlst" : ("bgp_pfxlst", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst)}

                                                self.bgp_pfxlst = YList(self)
                                                self._segment_path = lambda: "prefix-list-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                            class BgpPfxlst(Entity):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\:  bool
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                    self.yang_name = "bgp-pfxlst"
                                                    self.yang_parent_name = "prefix-list-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix)}
                                                    self._child_list_classes = {}

                                                    self.is_prefix_grant = YLeaf(YType.boolean, "is-prefix-grant")

                                                    self.max_prefix_length = YLeaf(YType.uint8, "max-prefix-length")

                                                    self.min_prefix_length = YLeaf(YType.uint8, "min-prefix-length")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")
                                                    self._segment_path = lambda: "bgp-pfxlst"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, ['is_prefix_grant', 'max_prefix_length', 'min_prefix_length', 'sequence_number'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "bgp-pfxlst"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RpcSets(Entity):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets, self).__init__()

                                        self.yang_name = "rpc-sets"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"rpc-set" : ("rpc_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet)}

                                        self.rpc_set = YList(self)
                                        self._segment_path = lambda: "rpc-sets"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets, [], name, value)


                                    class RpcSet(Entity):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  <key>
                                        
                                        	Nexthop set index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                            self.yang_name = "rpc-set"
                                            self.yang_parent_name = "rpc-sets"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop)}

                                            self.rpc_set_index = YLeaf(YType.int32, "rpc-set-index")

                                            self.label = YLeaf(YType.uint32, "label")

                                            self.next_hop_xr = YLeaf(YType.uint32, "next-hop-xr")

                                            self.ref_count = YLeaf(YType.uint32, "ref-count")

                                            self.next_hop = YList(self)
                                            self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + self.rpc_set_index.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', 'label', 'next_hop_xr', 'ref_count'], name, value)


                                        class NextHop(Entity):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "rpc-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RtSetCounters(Entity):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters, self).__init__()

                                        self.yang_name = "rt-set-counters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"rt-set-counter" : ("rt_set_counter", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter)}

                                        self.rt_set_counter = YList(self)
                                        self._segment_path = lambda: "rt-set-counters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters, [], name, value)


                                    class RtSetCounter(Entity):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  <key>
                                        
                                        	RTSet ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                            self.yang_name = "rt-set-counter"
                                            self.yang_parent_name = "rt-set-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-target-set" : ("route_target_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet)}
                                            self._child_list_classes = {}

                                            self.rt_set_id = YLeaf(YType.int32, "rt-set-id")

                                            self.route_target_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self
                                            self._children_name_map["route_target_set"] = "route-target-set"
                                            self._children_yang_names.add("route-target-set")
                                            self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + self.rt_set_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                        class RouteTargetSet(Entity):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                                self.yang_name = "route-target-set"
                                                self.yang_parent_name = "rt-set-counter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"rt-set" : ("rt_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet)}

                                                self.rt_set_id = YLeaf(YType.uint32, "rt-set-id")

                                                self.rt_set_len = YLeaf(YType.uint8, "rt-set-len")

                                                self.rt_set_net_count = YLeaf(YType.uint32, "rt-set-net-count")

                                                self.rt_set = YList(self)
                                                self._segment_path = lambda: "route-target-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, ['rt_set_id', 'rt_set_len', 'rt_set_net_count'], name, value)


                                            class RtSet(Entity):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                    self.yang_name = "rt-set"
                                                    self.yang_parent_name = "route-target-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "rt-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, ['entry'], name, value)


                                class SourcedNetworks(Entity):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork)}

                                        self.sourced_network = YList(self)
                                        self._segment_path = lambda: "sourced-networks"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks, [], name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  <key>
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\:  bool
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sourced-prefix" : ("sourced_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix)}
                                            self._child_list_classes = {}

                                            self.network = YLeaf(YType.str, "network")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.is_backdoor = YLeaf(YType.boolean, "is-backdoor")

                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self
                                            self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                            self._children_yang_names.add("sourced-prefix")
                                            self._segment_path = lambda: "sourced-network" + "[network='" + self.network.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', 'af_name', 'is_backdoor'], name, value)


                                        class SourcedPrefix(Entity):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                                self.yang_name = "sourced-prefix"
                                                self.yang_parent_name = "sourced-network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "sourced-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "sourced-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateGenerationAddressFamily(Entity):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                        self.yang_name = "update-generation-address-family"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.configured_update_limit_af = YLeaf(YType.uint32, "configured-update-limit-af")

                                        self.configured_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "configured-update-limit-sub-group-ibgp")

                                        self.configured_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "configured-update-limit-subgrp-ebgp")

                                        self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                                        self.current_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "current-update-limit-sub-group-ibgp")

                                        self.current_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "current-update-limit-subgrp-ebgp")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                        self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                        self.table_neighbor_count = YLeaf(YType.uint32, "table-neighbor-count")

                                        self.table_refresh_sub_group_count = YLeaf(YType.uint32, "table-refresh-sub-group-count")

                                        self.table_refresh_sub_group_throttled_count = YLeaf(YType.uint32, "table-refresh-sub-group-throttled-count")

                                        self.table_sub_group_throttled_count = YLeaf(YType.uint32, "table-sub-group-throttled-count")

                                        self.table_update_group_count = YLeaf(YType.uint32, "table-update-group-count")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_min_neighbor_version = YLeaf(YType.uint32, "update-min-neighbor-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_rib_version = YLeaf(YType.uint32, "update-rib-version")

                                        self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                        self.update_table_filter_group_count = YLeaf(YType.uint32, "update-table-filter-group-count")

                                        self.update_table_sub_group_count = YLeaf(YType.uint32, "update-table-sub-group-count")

                                        self.update_table_vrf_name = YLeaf(YType.str, "update-table-vrf-name")

                                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                        self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")

                                        self.update_vrf_rd_version = YLeaf(YType.uint32, "update-vrf-rd-version")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.update_vrfaf_name = YLeaf(YType.uint32, "update-vrfaf-name")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-address-family"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, ['configured_update_limit_af', 'configured_update_limit_sub_group_ibgp', 'configured_update_limit_subgrp_ebgp', 'current_update_limit_af', 'current_update_limit_sub_group_ibgp', 'current_update_limit_subgrp_ebgp', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'table_neighbor_count', 'table_refresh_sub_group_count', 'table_refresh_sub_group_throttled_count', 'table_sub_group_throttled_count', 'table_update_group_count', 'update_group_af_name', 'update_main_table_version', 'update_min_neighbor_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_rib_version', 'update_sub_group_count', 'update_table_filter_group_count', 'update_table_sub_group_count', 'update_table_vrf_name', 'update_throttled', 'update_update_group_count', 'update_vrf_rd_version', 'update_vrf_table_rib_version', 'update_vrfaf_name'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationFilterGroups(Entity):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                        self.yang_name = "update-generation-filter-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-filter-group" : ("update_generation_filter_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup)}

                                        self.update_generation_filter_group = YList(self)
                                        self._segment_path = lambda: "update-generation-filter-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                    class UpdateGenerationFilterGroup(Entity):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                            self.yang_name = "update-generation-filter-group"
                                            self.yang_parent_name = "update-generation-filter-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.parent_filter_group_index = YLeaf(YType.uint32, "parent-filter-group-index")

                                            self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                            self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")
                                            self._segment_path = lambda: "update-generation-filter-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['filter_group_index', 'neighbor_count', 'parent_filter_group_index', 'parent_sub_group_id', 'parent_sub_group_index', 'process_id', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_filter_group_index', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_vrf_name'], name, value)


                                class UpdateGenerationNeighbors(Entity):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                        self.yang_name = "update-generation-neighbors"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-neighbor" : ("update_generation_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor)}

                                        self.update_generation_neighbor = YList(self)
                                        self._segment_path = lambda: "update-generation-neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                    class UpdateGenerationNeighbor(Entity):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                            self.yang_name = "update-generation-neighbor"
                                            self.yang_parent_name = "update-generation-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-default-originate-timestamp" : ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp), "first-update-queued-timestamp" : ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp), "first-update-write-timestamp" : ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp), "last-default-originate-timestamp" : ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp), "last-filter-group-add-timestamp" : ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp), "last-filter-group-remove-timestamp" : ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp), "last-refresh-update-queued-timestamp" : ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp), "last-refresh-update-write-timestamp" : ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp), "last-sub-group-add-timestamp" : ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp), "last-sub-group-remove-timestamp" : ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp), "last-update-group-expiry-timestamp" : ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp), "last-update-group-start-timestamp" : ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp), "last-update-write-timestamp" : ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.ack_version = YLeaf(YType.uint32, "ack-version")

                                            self.current_update_group_af_name = YLeaf(YType.enumeration, "current-update-group-af-name")

                                            self.default_originate_internal_context = YLeaf(YType.int32, "default-originate-internal-context")

                                            self.default_originate_state = YLeaf(YType.int32, "default-originate-state")

                                            self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                            self.inbound_refresh_count = YLeaf(YType.uint32, "inbound-refresh-count")

                                            self.is_eor_outstanding = YLeaf(YType.boolean, "is-eor-outstanding")

                                            self.is_update_group_timer_running = YLeaf(YType.boolean, "is-update-group-timer-running")

                                            self.last_default_originate_age = YLeaf(YType.uint32, "last-default-originate-age")

                                            self.last_refresh_update_queued_age = YLeaf(YType.uint32, "last-refresh-update-queued-age")

                                            self.last_refresh_update_write_age = YLeaf(YType.uint32, "last-refresh-update-write-age")

                                            self.last_update_group_af_name = YLeaf(YType.enumeration, "last-update-group-af-name")

                                            self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                            self.last_update_write_age = YLeaf(YType.uint32, "last-update-write-age")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                            self.outbound_refresh_count = YLeaf(YType.uint32, "outbound-refresh-count")

                                            self.outstanding_version_count = YLeaf(YType.uint32, "outstanding-version-count")

                                            self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_ack_version = YLeaf(YType.uint32, "refresh-ack-version")

                                            self.refresh_filter_group_index = YLeaf(YType.uint32, "refresh-filter-group-index")

                                            self.refresh_next_resume_version = YLeaf(YType.uint32, "refresh-next-resume-version")

                                            self.refresh_pending_target_version = YLeaf(YType.uint32, "refresh-pending-target-version")

                                            self.refresh_requested_target_version = YLeaf(YType.uint32, "refresh-requested-target-version")

                                            self.refresh_sub_group_id = YLeaf(YType.uint32, "refresh-sub-group-id")

                                            self.refresh_sub_group_index = YLeaf(YType.uint32, "refresh-sub-group-index")

                                            self.refresh_update_out_queue_messages = YLeaf(YType.uint32, "refresh-update-out-queue-messages")

                                            self.refresh_update_out_queue_size = YLeaf(YType.uint32, "refresh-update-out-queue-size")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.synced_ack_version = YLeaf(YType.uint32, "synced-ack-version")

                                            self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                            self.update_filter_group_messages = YLeaf(YType.uint32, "update-filter-group-messages")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                            self.update_refresh_version = YLeaf(YType.uint32, "update-refresh-version")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"
                                            self._children_yang_names.add("first-default-originate-timestamp")

                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"
                                            self._children_yang_names.add("first-update-queued-timestamp")

                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"
                                            self._children_yang_names.add("first-update-write-timestamp")

                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"
                                            self._children_yang_names.add("last-default-originate-timestamp")

                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"
                                            self._children_yang_names.add("last-filter-group-add-timestamp")

                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"
                                            self._children_yang_names.add("last-filter-group-remove-timestamp")

                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"
                                            self._children_yang_names.add("last-refresh-update-queued-timestamp")

                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"
                                            self._children_yang_names.add("last-refresh-update-write-timestamp")

                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"
                                            self._children_yang_names.add("last-sub-group-add-timestamp")

                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"
                                            self._children_yang_names.add("last-sub-group-remove-timestamp")

                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"
                                            self._children_yang_names.add("last-update-group-expiry-timestamp")

                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"
                                            self._children_yang_names.add("last-update-group-start-timestamp")

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                            self._children_yang_names.add("last-update-queued-timestamp")

                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"
                                            self._children_yang_names.add("last-update-write-timestamp")

                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                            self._children_yang_names.add("update-neighbor-address")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['ack_version', 'current_update_group_af_name', 'default_originate_internal_context', 'default_originate_state', 'filter_group_index', 'inbound_refresh_count', 'is_eor_outstanding', 'is_update_group_timer_running', 'last_default_originate_age', 'last_refresh_update_queued_age', 'last_refresh_update_write_age', 'last_update_group_af_name', 'last_update_queued_age', 'last_update_write_age', 'neighbor_address', 'next_resume_version', 'outbound_refresh_count', 'outstanding_version_count', 'pending_target_version', 'process_id', 'refresh_ack_version', 'refresh_filter_group_index', 'refresh_next_resume_version', 'refresh_pending_target_version', 'refresh_requested_target_version', 'refresh_sub_group_id', 'refresh_sub_group_index', 'refresh_update_out_queue_messages', 'refresh_update_out_queue_size', 'sub_group_id', 'sub_group_index', 'sub_group_index_xr', 'synced_ack_version', 'update_filter_group_index', 'update_filter_group_messages', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_refresh_version', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                        class FirstDefaultOriginateTimestamp(Entity):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "first-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-default-originate-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateQueuedTimestamp(Entity):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "first-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWriteTimestamp(Entity):
                                            """
                                            First update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "first-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastDefaultOriginateTimestamp(Entity):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "last-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-default-originate-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastFilterGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-filter-group-add-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastFilterGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-filter-group-remove-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRefreshUpdateQueuedTimestamp(Entity):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-refresh-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRefreshUpdateWriteTimestamp(Entity):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-refresh-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastSubGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-sub-group-add-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastSubGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-sub-group-remove-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateGroupExpiryTimestamp(Entity):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-group-expiry-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateGroupStartTimestamp(Entity):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-start-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-group-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWriteTimestamp(Entity):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateNeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                                self.yang_name = "update-neighbor-address"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "update-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationSubGroups(Entity):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                        self.yang_name = "update-generation-sub-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-sub-group" : ("update_generation_sub_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup)}

                                        self.update_generation_sub_group = YList(self)
                                        self._segment_path = lambda: "update-generation-sub-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                    class UpdateGenerationSubGroup(Entity):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                            self.yang_name = "update-generation-sub-group"
                                            self.yang_parent_name = "update-generation-sub-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"creation-timestamp" : ("creation_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp), "first-update-walk-end-timestamp" : ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp), "first-update-walk-start-timestamp" : ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp), "last-merge-timestamp" : ("last_merge_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp), "last-update-walk-end-timestamp" : ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp), "last-update-walk-start-timestamp" : ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.configured_update_limit_sub_group = YLeaf(YType.uint32, "configured-update-limit-sub-group")

                                            self.current_update_limit_sub_group = YLeaf(YType.uint32, "current-update-limit-sub-group")

                                            self.eo_r_attempted = YLeaf(YType.boolean, "eo-r-attempted")

                                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                            self.io_write_event_pending = YLeaf(YType.boolean, "io-write-event-pending")

                                            self.last_merged_sub_group_index = YLeaf(YType.uint32, "last-merged-sub-group-index")

                                            self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                            self.last_update_walk_end_age = YLeaf(YType.uint32, "last-update-walk-end-age")

                                            self.merge_count = YLeaf(YType.uint32, "merge-count")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                            self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                            self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                            self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.update_default_route_sent = YLeaf(YType.boolean, "update-default-route-sent")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                            self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self._children_name_map["creation_timestamp"] = "creation-timestamp"
                                            self._children_yang_names.add("creation-timestamp")

                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"
                                            self._children_yang_names.add("first-update-walk-end-timestamp")

                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"
                                            self._children_yang_names.add("first-update-walk-start-timestamp")

                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"
                                            self._children_yang_names.add("last-merge-timestamp")

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                            self._children_yang_names.add("last-update-queued-timestamp")

                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"
                                            self._children_yang_names.add("last-update-walk-end-timestamp")

                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"
                                            self._children_yang_names.add("last-update-walk-start-timestamp")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-sub-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['configured_update_limit_sub_group', 'current_update_limit_sub_group', 'eo_r_attempted', 'filter_group_count', 'io_write_event_pending', 'last_merged_sub_group_index', 'last_update_queued_age', 'last_update_walk_end_age', 'merge_count', 'neighbor_count', 'next_resume_version', 'nsr_version', 'parent_sub_group_id', 'parent_sub_group_index', 'pending_target_version', 'process_id', 'refresh_sub_group_count', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_default_route_sent', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_throttled', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                        class CreationTimestamp(Entity):
                                            """
                                            Creation time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                                self.yang_name = "creation-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "creation-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWalkEndTimestamp(Entity):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-walk-end-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWalkStartTimestamp(Entity):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-walk-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastMergeTimestamp(Entity):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                                self.yang_name = "last-merge-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-merge-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWalkEndTimestamp(Entity):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-walk-end-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWalkStartTimestamp(Entity):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-walk-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationUpdateGroups(Entity):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                        self.yang_name = "update-generation-update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-update-group" : ("update_generation_update_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup)}

                                        self.update_generation_update_group = YList(self)
                                        self._segment_path = lambda: "update-generation-update-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                    class UpdateGenerationUpdateGroup(Entity):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  <key>
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                            self.yang_name = "update-generation-update-group"
                                            self.yang_parent_name = "update-generation-update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-timer-delay-value" : ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue), "last-update-timer-expiry-timestamp" : ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp), "last-update-timer-remaining-value" : ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue), "last-update-timer-start-timestamp" : ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp), "last-update-timer-stop-timestamp" : ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                            self.is_permanent = YLeaf(YType.boolean, "is-permanent")

                                            self.is_update_timer_running = YLeaf(YType.boolean, "is-update-timer-running")

                                            self.last_update_timer_expiry_age = YLeaf(YType.uint32, "last-update-timer-expiry-age")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.neighbor_leaving_count = YLeaf(YType.uint32, "neighbor-leaving-count")

                                            self.neighbor_session_af_name = YLeaf(YType.uint8, "neighbor-session-af-name")

                                            self.perm_pelem_allowed = YLeaf(YType.uint32, "perm-pelem-allowed")

                                            self.perm_pelem_encountered = YLeaf(YType.uint32, "perm-pelem-encountered")

                                            self.perm_pelem_exp_wdr = YLeaf(YType.uint32, "perm-pelem-exp-wdr")

                                            self.perm_pelem_not_allowed = YLeaf(YType.uint32, "perm-pelem-not-allowed")

                                            self.perm_pelem_spur_wdr = YLeaf(YType.uint32, "perm-pelem-spur-wdr")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                            self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                            self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                            self.update_generation_recovery_pending = YLeaf(YType.boolean, "update-generation-recovery-pending")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_flags2 = YLeaf(YType.uint32, "update-group-flags2")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"
                                            self._children_yang_names.add("last-update-timer-delay-value")

                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"
                                            self._children_yang_names.add("last-update-timer-expiry-timestamp")

                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"
                                            self._children_yang_names.add("last-update-timer-remaining-value")

                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"
                                            self._children_yang_names.add("last-update-timer-start-timestamp")

                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"
                                            self._children_yang_names.add("last-update-timer-stop-timestamp")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + self.update_group_index.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', 'filter_group_count', 'is_permanent', 'is_update_timer_running', 'last_update_timer_expiry_age', 'neighbor_count', 'neighbor_leaving_count', 'neighbor_session_af_name', 'perm_pelem_allowed', 'perm_pelem_encountered', 'perm_pelem_exp_wdr', 'perm_pelem_not_allowed', 'perm_pelem_spur_wdr', 'process_id', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_generation_recovery_pending', 'update_group_af_name', 'update_group_flags2', 'update_group_index_xr', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_vrf_name'], name, value)


                                        class LastUpdateTimerDelayValue(Entity):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                                self.yang_name = "last-update-timer-delay-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-delay-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerExpiryTimestamp(Entity):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-expiry-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerRemainingValue(Entity):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                                self.yang_name = "last-update-timer-remaining-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-remaining-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerStartTimestamp(Entity):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-start-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerStopTimestamp(Entity):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-stop-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-stop-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGroups(Entity):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups, self).__init__()

                                        self.yang_name = "update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-group" : ("update_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup)}

                                        self.update_group = YList(self)
                                        self._segment_path = lambda: "update-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups, [], name, value)


                                    class UpdateGroup(Entity):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\:  bool
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\:  str
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\:  bool
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\:  bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                            self.yang_name = "update-group"
                                            self.yang_parent_name = "update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor), "update-sub-group" : ("update_sub_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup)}

                                            self.accepts_legacy_pe_rt_route = YLeaf(YType.boolean, "accepts-legacy-pe-rt-route")

                                            self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                            self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.desync_count = YLeaf(YType.uint32, "desync-count")

                                            self.disable_def_vrf_imp_advertisement = YLeaf(YType.boolean, "disable-def-vrf-imp-advertisement")

                                            self.disable_native_advertisement = YLeaf(YType.boolean, "disable-native-advertisement")

                                            self.disable_vrf_re_imp_advertisement = YLeaf(YType.boolean, "disable-vrf-re-imp-advertisement")

                                            self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                            self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                            self.ext_nh_encoding = YLeaf(YType.boolean, "ext-nh-encoding")

                                            self.filter_group_id = YLeaf(YType.int32, "filter-group-id")

                                            self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                            self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                            self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                            self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")

                                            self.has_orf_receive_capability = YLeaf(YType.boolean, "has-orf-receive-capability")

                                            self.is4_byte_as_peer = YLeaf(YType.boolean, "is4-byte-as-peer")

                                            self.is_addpath_capable = YLeaf(YType.boolean, "is-addpath-capable")

                                            self.is_adv_capable = YLeaf(YType.boolean, "is-adv-capable")

                                            self.is_adv_perm_net_capable = YLeaf(YType.boolean, "is-adv-perm-net-capable")

                                            self.is_adv_reorg_capable = YLeaf(YType.boolean, "is-adv-reorg-capable")

                                            self.is_aigp_capable = YLeaf(YType.boolean, "is-aigp-capable")

                                            self.is_aigp_cost_community_capable = YLeaf(YType.boolean, "is-aigp-cost-community-capable")

                                            self.is_aigp_med_capable = YLeaf(YType.boolean, "is-aigp-med-capable")

                                            self.is_client_reflection_disabled = YLeaf(YType.boolean, "is-client-reflection-disabled")

                                            self.is_common_admin_peers = YLeaf(YType.boolean, "is-common-admin-peers")

                                            self.is_directly_connected_ebgp_v6_peers = YLeaf(YType.boolean, "is-directly-connected-ebgp-v6-peers")

                                            self.is_internal_peers = YLeaf(YType.boolean, "is-internal-peers")

                                            self.is_labeled_afi_enabled = YLeaf(YType.boolean, "is-labeled-afi-enabled")

                                            self.is_llgr_capable = YLeaf(YType.boolean, "is-llgr-capable")

                                            self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                            self.is_route_reflector_client = YLeaf(YType.boolean, "is-route-reflector-client")

                                            self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                            self.is_unlabeled_afi_enabled = YLeaf(YType.boolean, "is-unlabeled-afi-enabled")

                                            self.local_as = YLeaf(YType.uint32, "local-as")

                                            self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                            self.minimum_advertisement_interval = YLeaf(YType.uint32, "minimum-advertisement-interval")

                                            self.minimum_advertisement_interval_msecs = YLeaf(YType.uint32, "minimum-advertisement-interval-msecs")

                                            self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                            self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.refresh_subgrp_count = YLeaf(YType.uint32, "refresh-subgrp-count")

                                            self.remote_as = YLeaf(YType.uint32, "remote-as")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.session_af_name = YLeaf(YType.uint8, "session-af-name")

                                            self.should_remove_private_a_ss = YLeaf(YType.boolean, "should-remove-private-a-ss")

                                            self.should_remove_private_as_ent_path = YLeaf(YType.boolean, "should-remove-private-as-ent-path")

                                            self.should_send_communities = YLeaf(YType.boolean, "should-send-communities")

                                            self.should_send_ext_communities = YLeaf(YType.boolean, "should-send-ext-communities")

                                            self.should_send_gshut_community = YLeaf(YType.boolean, "should-send-gshut-community")

                                            self.should_send_stitching_rt = YLeaf(YType.boolean, "should-send-stitching-rt")

                                            self.soo_value = YLeaf(YType.str, "soo-value")

                                            self.split_horizon = YLeaf(YType.boolean, "split-horizon")

                                            self.subgrp_merge_count = YLeaf(YType.uint32, "subgrp-merge-count")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_id = YLeaf(YType.int32, "update-group-id")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.updates_formatted = YLeaf(YType.uint32, "updates-formatted")

                                            self.updates_replicated = YLeaf(YType.uint32, "updates-replicated")

                                            self.updgrp_cluster_id = YLeaf(YType.uint32, "updgrp-cluster-id")

                                            self.updgrp_cluster_type = YLeaf(YType.uint8, "updgrp-cluster-type")

                                            self.use_next_hop_self = YLeaf(YType.boolean, "use-next-hop-self")

                                            self.use_next_hop_unchanged_mpath = YLeaf(YType.boolean, "use-next-hop-unchanged-mpath")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")

                                            self.neighbor = YList(self)
                                            self.update_sub_group = YList(self)
                                            self._segment_path = lambda: "update-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, ['accepts_legacy_pe_rt_route', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'as_override', 'desync_count', 'disable_def_vrf_imp_advertisement', 'disable_native_advertisement', 'disable_vrf_re_imp_advertisement', 'enable_label_stack', 'encapsulation_type', 'ext_nh_encoding', 'filter_group_id', 'gshut_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends', 'has_orf_receive_capability', 'is4_byte_as_peer', 'is_addpath_capable', 'is_adv_capable', 'is_adv_perm_net_capable', 'is_adv_reorg_capable', 'is_aigp_capable', 'is_aigp_cost_community_capable', 'is_aigp_med_capable', 'is_client_reflection_disabled', 'is_common_admin_peers', 'is_directly_connected_ebgp_v6_peers', 'is_internal_peers', 'is_labeled_afi_enabled', 'is_llgr_capable', 'is_orr_root_address_configured', 'is_route_reflector_client', 'is_send_mcast_attr_enabled', 'is_unlabeled_afi_enabled', 'local_as', 'local_as_replace_as', 'minimum_advertisement_interval', 'minimum_advertisement_interval_msecs', 'orr_group_index', 'orr_group_name', 'process_instance_id', 'refresh_subgrp_count', 'remote_as', 'route_policy_out', 'session_af_name', 'should_remove_private_a_ss', 'should_remove_private_as_ent_path', 'should_send_communities', 'should_send_ext_communities', 'should_send_gshut_community', 'should_send_stitching_rt', 'soo_value', 'split_horizon', 'subgrp_merge_count', 'update_group_af_name', 'update_group_id', 'update_group_number', 'updates_formatted', 'updates_replicated', 'updgrp_cluster_id', 'updgrp_cluster_type', 'use_next_hop_self', 'use_next_hop_unchanged_mpath'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                                self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                                self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                                self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                                self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                                self.updgen_timer_process_time = YLeaf(YType.uint64, "updgen-timer-process-time")

                                                self.updgen_timer_start_time = YLeaf(YType.uint64, "updgen-timer-start-time")

                                                self.updgen_timer_stop_time = YLeaf(YType.uint64, "updgen-timer-stop-time")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, ['update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'updgen_timer_process_time', 'updgen_timer_start_time', 'updgen_timer_stop_time'], name, value)


                                        class UpdateSubGroup(Entity):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                                self.yang_name = "update-sub-group"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor), "update-filter-group" : ("update_filter_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)}

                                                self.filter_group = YLeaf(YType.uint16, "filter-group")

                                                self.update_sub_group_number = YLeaf(YType.uint32, "update-sub-group-number")

                                                self.wait_for_eo_rs = YLeaf(YType.boolean, "wait-for-eo-rs")

                                                self.neighbor = YList(self)
                                                self.update_filter_group = YList(self)
                                                self._segment_path = lambda: "update-sub-group"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, ['filter_group', 'update_sub_group_number', 'wait_for_eo_rs'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class UpdateFilterGroup(Entity):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                    self.yang_name = "update-filter-group"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity), "neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor)}

                                                    self.fgroup_advertised_prefixes = YLeaf(YType.uint32, "fgroup-advertised-prefixes")

                                                    self.fgroup_created_message_elements = YLeaf(YType.uint32, "fgroup-created-message-elements")

                                                    self.fgroup_deleted_message_elements = YLeaf(YType.uint32, "fgroup-deleted-message-elements")

                                                    self.fgroup_flags = YLeaf(YType.uint8, "fgroup-flags")

                                                    self.fgroup_neighbors = YLeaf(YType.uint16, "fgroup-neighbors")

                                                    self.fgroup_queued_message_elements = YLeaf(YType.uint32, "fgroup-queued-message-elements")

                                                    self.fgroup_skipped_prefixes = YLeaf(YType.uint32, "fgroup-skipped-prefixes")

                                                    self.fgroup_suppressed_prefixes = YLeaf(YType.uint32, "fgroup-suppressed-prefixes")

                                                    self.fgroup_total_advertised_prefixes = YLeaf(YType.uint32, "fgroup-total-advertised-prefixes")

                                                    self.fgroup_total_non_optimised_prefixes = YLeaf(YType.uint32, "fgroup-total-non-optimised-prefixes")

                                                    self.fgroup_total_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-total-withdrawn-prefixes")

                                                    self.fgroup_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-withdrawn-prefixes")

                                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                    self.rts = YLeaf(YType.uint32, "rts")

                                                    self.update_filter_group_number = YLeaf(YType.uint32, "update-filter-group-number")

                                                    self.extended_community = YList(self)
                                                    self.neighbor = YList(self)
                                                    self._segment_path = lambda: "update-filter-group"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, ['fgroup_advertised_prefixes', 'fgroup_created_message_elements', 'fgroup_deleted_message_elements', 'fgroup_flags', 'fgroup_neighbors', 'fgroup_queued_message_elements', 'fgroup_skipped_prefixes', 'fgroup_suppressed_prefixes', 'fgroup_total_advertised_prefixes', 'fgroup_total_non_optimised_prefixes', 'fgroup_total_withdrawn_prefixes', 'fgroup_withdrawn_prefixes', 'is_rt_present', 'rts', 'update_filter_group_number'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, ['entry'], name, value)


                                                class Neighbor(Entity):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                        self.yang_name = "neighbor"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class Bmp(Entity):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp, self).__init__()

                                self.yang_name = "bmp"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"server-neighbors" : ("server_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors), "server-summaries" : ("server_summaries", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries)}
                                self._child_list_classes = {}

                                self.server_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self._children_name_map["server_neighbors"] = "server-neighbors"
                                self._children_yang_names.add("server-neighbors")

                                self.server_summaries = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self
                                self._children_name_map["server_summaries"] = "server-summaries"
                                self._children_yang_names.add("server-summaries")
                                self._segment_path = lambda: "bmp"


                            class ServerNeighbors(Entity):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors, self).__init__()

                                    self.yang_name = "server-neighbors"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"server-neighbor" : ("server_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor)}

                                    self.server_neighbor = YList(self)
                                    self._segment_path = lambda: "server-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors, [], name, value)


                                class ServerNeighbor(Entity):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                        self.yang_name = "server-neighbor"
                                        self.yang_parent_name = "server-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"monitored-neighbors" : ("monitored_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors)}
                                        self._child_list_classes = {}

                                        self.server_id = YLeaf(YType.uint32, "server-id")

                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self
                                        self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                        self._children_yang_names.add("monitored-neighbors")
                                        self._segment_path = lambda: "server-neighbor" + "[server-id='" + self.server_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                    class MonitoredNeighbors(Entity):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                            self.yang_name = "monitored-neighbors"
                                            self.yang_parent_name = "server-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"monitored-neighbor" : ("monitored_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor)}

                                            self.monitored_neighbor = YList(self)
                                            self._segment_path = lambda: "monitored-neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                        class MonitoredNeighbor(Entity):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                            
                                            	Number of Route Monitor EOR Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                                self.yang_name = "monitored-neighbor"
                                                self.yang_parent_name = "monitored-neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bmp-neighbor-address" : ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress)}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.bmp_neighbor_msg_dropped = YLeaf(YType.uint32, "bmp-neighbor-msg-dropped")

                                                self.bmp_neighbor_msg_pending = YLeaf(YType.uint32, "bmp-neighbor-msg-pending")

                                                self.bmp_neighbor_path_update_drop = YLeaf(YType.uint32, "bmp-neighbor-path-update-drop")

                                                self.bmp_neighbor_path_update_sent = YLeaf(YType.uint32, "bmp-neighbor-path-update-sent")

                                                self.bmp_neighbor_path_withdraw_drop = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-drop")

                                                self.bmp_neighbor_path_withdraw_sent = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-sent")

                                                self.bmp_neighbor_peer_down_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-down-sent")

                                                self.bmp_neighbor_peer_up_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-up-sent")

                                                self.bmp_neighbor_route_monitor_eor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-eor-sent")

                                                self.bmp_neighbor_route_monitor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-sent")

                                                self.bmp_neighbor_upd_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-upd-msg-sent")

                                                self.bmp_neighbor_wdraw_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-wdraw-msg-sent")

                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                                self._children_yang_names.add("bmp-neighbor-address")
                                                self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', 'bmp_neighbor_msg_dropped', 'bmp_neighbor_msg_pending', 'bmp_neighbor_path_update_drop', 'bmp_neighbor_path_update_sent', 'bmp_neighbor_path_withdraw_drop', 'bmp_neighbor_path_withdraw_sent', 'bmp_neighbor_peer_down_sent', 'bmp_neighbor_peer_up_sent', 'bmp_neighbor_route_monitor_eor_sent', 'bmp_neighbor_route_monitor_sent', 'bmp_neighbor_upd_msg_sent', 'bmp_neighbor_wdraw_msg_sent'], name, value)


                                            class BmpNeighborAddress(Entity):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                    self.yang_name = "bmp-neighbor-address"
                                                    self.yang_parent_name = "monitored-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "bmp-neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ServerSummaries(Entity):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries, self).__init__()

                                    self.yang_name = "server-summaries"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"server-summary" : ("server_summary", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary)}

                                    self.server_summary = YList(self)
                                    self._segment_path = lambda: "server-summaries"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries, [], name, value)


                                class ServerSummary(Entity):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_maximum_buffer_size_route_mon
                                    
                                    	Buffer limit used for route mon
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_reset_walk_in_progress
                                    
                                    	Reset walk in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_rmon_cur_buffer_size
                                    
                                    	Current Buffer usage per BMP Route Mon
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\:  str
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:   :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_server_up_count
                                    
                                    	Number of BMP server that are UP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_in_progress
                                    
                                    	Update generation in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:   :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\:  str
                                    
                                    .. attribute:: bmpafi_info
                                    
                                    	AFI specific info for BMP server
                                    	**type**\: list of    :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpr_mon_eo_rmessages
                                    
                                    	Total bmpQ EOR update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\:  str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                        self.yang_name = "server-summary"
                                        self.yang_parent_name = "server-summaries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-server-last-discon-time" : ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime), "bmp-server-state-age" : ("bmp_server_state_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge), "bmp-server-state-time-spec" : ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec), "update-source-address" : ("update_source_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)}
                                        self._child_list_classes = {"bmpafi-info" : ("bmpafi_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo)}

                                        self.server_id = YLeaf(YType.uint32, "server-id")

                                        self.bmp_bytes_written_tcp = YLeaf(YType.uint64, "bmp-bytes-written-tcp")

                                        self.bmp_init_msg_count = YLeaf(YType.uint32, "bmp-init-msg-count")

                                        self.bmp_maximum_buffer_size_route_mon = YLeaf(YType.uint64, "bmp-maximum-buffer-size-route-mon")

                                        self.bmp_messages_wdraw_discarded = YLeaf(YType.uint32, "bmp-messages-wdraw-discarded")

                                        self.bmp_peer_msg_drop_count = YLeaf(YType.uint32, "bmp-peer-msg-drop-count")

                                        self.bmp_peer_msg_pending_count = YLeaf(YType.uint32, "bmp-peer-msg-pending-count")

                                        self.bmp_peer_msg_pending_count_hwts = YLeaf(YType.uint64, "bmp-peer-msg-pending-count-hwts")

                                        self.bmp_peer_msg_pending_count_max = YLeaf(YType.uint32, "bmp-peer-msg-pending-count-max")

                                        self.bmp_per_peer_msg_count = YLeaf(YType.uint32, "bmp-per-peer-msg-count")

                                        self.bmp_per_peer_msg_route_mon_count = YLeaf(YType.uint32, "bmp-per-peer-msg-route-mon-count")

                                        self.bmp_pfx_wdraw_discarded = YLeaf(YType.uint32, "bmp-pfx-wdraw-discarded")

                                        self.bmp_reset_walk_in_progress = YLeaf(YType.boolean, "bmp-reset-walk-in-progress")

                                        self.bmp_rmon_cur_buffer_size = YLeaf(YType.uint64, "bmp-rmon-cur-buffer-size")

                                        self.bmp_server_host_name = YLeaf(YType.str, "bmp-server-host-name")

                                        self.bmp_server_id = YLeaf(YType.uint8, "bmp-server-id")

                                        self.bmp_server_is_flapping = YLeaf(YType.boolean, "bmp-server-is-flapping")

                                        self.bmp_server_nbr_count = YLeaf(YType.uint32, "bmp-server-nbr-count")

                                        self.bmp_server_port = YLeaf(YType.uint32, "bmp-server-port")

                                        self.bmp_server_state = YLeaf(YType.enumeration, "bmp-server-state")

                                        self.bmp_server_up_count = YLeaf(YType.uint32, "bmp-server-up-count")

                                        self.bmp_status_report_count = YLeaf(YType.uint32, "bmp-status-report-count")

                                        self.bmp_termination_msg_count = YLeaf(YType.uint32, "bmp-termination-msg-count")

                                        self.bmp_upd_gen_in_progress = YLeaf(YType.boolean, "bmp-upd-gen-in-progress")

                                        self.bmp_update_mode = YLeaf(YType.enumeration, "bmp-update-mode")

                                        self.bmp_vrf_id = YLeaf(YType.uint32, "bmp-vrf-id")

                                        self.bmp_vrf_name = YLeaf(YType.str, "bmp-vrf-name")

                                        self.bmpq_last_all_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-all-write-pulse-sent-time")

                                        self.bmpq_last_write_pulse_cb_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-cb-time")

                                        self.bmpq_last_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-sent-time")

                                        self.bmpr_mon_eo_rmessages = YLeaf(YType.uint32, "bmpr-mon-eo-rmessages")

                                        self.bmpr_mon_upd_messages = YLeaf(YType.uint32, "bmpr-mon-upd-messages")

                                        self.bmpr_mon_update_gen_time = YLeaf(YType.uint32, "bmpr-mon-update-gen-time")

                                        self.bmpr_mon_wdraw_messages = YLeaf(YType.uint32, "bmpr-mon-wdraw-messages")

                                        self.path_update_count = YLeaf(YType.uint32, "path-update-count")

                                        self.path_update_drop = YLeaf(YType.uint32, "path-update-drop")

                                        self.path_withdraw_count = YLeaf(YType.uint32, "path-withdraw-count")

                                        self.path_withdraw_drop = YLeaf(YType.uint32, "path-withdraw-drop")

                                        self.tcp_keep_alive_interval = YLeaf(YType.uint32, "tcp-keep-alive-interval")

                                        self.tcp_last_write_cb_time = YLeaf(YType.uint64, "tcp-last-write-cb-time")

                                        self.tcp_last_write_result = YLeaf(YType.uint32, "tcp-last-write-result")

                                        self.tcp_last_write_time = YLeaf(YType.uint64, "tcp-last-write-time")

                                        self.tcp_maximum_segment_size = YLeaf(YType.uint32, "tcp-maximum-segment-size")

                                        self.tcp_write_cb_pending = YLeaf(YType.uint32, "tcp-write-cb-pending")

                                        self.tcp_write_time = YLeaf(YType.uint32, "tcp-write-time")

                                        self.tos_type = YLeaf(YType.uint8, "tos-type")

                                        self.tos_value = YLeaf(YType.uint8, "tos-value")

                                        self.update_source_interface_name = YLeaf(YType.str, "update-source-interface-name")

                                        self.update_source_vrf_id = YLeaf(YType.uint32, "update-source-vrf-id")

                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"
                                        self._children_yang_names.add("bmp-server-last-discon-time")

                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"
                                        self._children_yang_names.add("bmp-server-state-age")

                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"
                                        self._children_yang_names.add("bmp-server-state-time-spec")

                                        self.update_source_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self._children_name_map["update_source_address"] = "update-source-address"
                                        self._children_yang_names.add("update-source-address")

                                        self.bmpafi_info = YList(self)
                                        self._segment_path = lambda: "server-summary" + "[server-id='" + self.server_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, ['server_id', 'bmp_bytes_written_tcp', 'bmp_init_msg_count', 'bmp_maximum_buffer_size_route_mon', 'bmp_messages_wdraw_discarded', 'bmp_peer_msg_drop_count', 'bmp_peer_msg_pending_count', 'bmp_peer_msg_pending_count_hwts', 'bmp_peer_msg_pending_count_max', 'bmp_per_peer_msg_count', 'bmp_per_peer_msg_route_mon_count', 'bmp_pfx_wdraw_discarded', 'bmp_reset_walk_in_progress', 'bmp_rmon_cur_buffer_size', 'bmp_server_host_name', 'bmp_server_id', 'bmp_server_is_flapping', 'bmp_server_nbr_count', 'bmp_server_port', 'bmp_server_state', 'bmp_server_up_count', 'bmp_status_report_count', 'bmp_termination_msg_count', 'bmp_upd_gen_in_progress', 'bmp_update_mode', 'bmp_vrf_id', 'bmp_vrf_name', 'bmpq_last_all_write_pulse_sent_time', 'bmpq_last_write_pulse_cb_time', 'bmpq_last_write_pulse_sent_time', 'bmpr_mon_eo_rmessages', 'bmpr_mon_upd_messages', 'bmpr_mon_update_gen_time', 'bmpr_mon_wdraw_messages', 'path_update_count', 'path_update_drop', 'path_withdraw_count', 'path_withdraw_drop', 'tcp_keep_alive_interval', 'tcp_last_write_cb_time', 'tcp_last_write_result', 'tcp_last_write_time', 'tcp_maximum_segment_size', 'tcp_write_cb_pending', 'tcp_write_time', 'tos_type', 'tos_value', 'update_source_interface_name', 'update_source_vrf_id'], name, value)


                                    class BmpServerLastDisconTime(Entity):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                            self.yang_name = "bmp-server-last-discon-time"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-last-discon-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, ['nanoseconds', 'seconds'], name, value)


                                    class BmpServerStateAge(Entity):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                            self.yang_name = "bmp-server-state-age"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-state-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, ['nanoseconds', 'seconds'], name, value)


                                    class BmpServerStateTimeSpec(Entity):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                            self.yang_name = "bmp-server-state-time-spec"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-state-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpafiInfo(Entity):
                                        """
                                        AFI specific info for BMP server
                                        
                                        .. attribute:: bmp_filter_nbr_cnt
                                        
                                        	Filter nbr Count for this AFI
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_filter_neighbor_address
                                        
                                        	Filter Neighbor Address
                                        	**type**\:   :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                        
                                        .. attribute:: bmp_filter_neighbor_address_set
                                        
                                        	Filter Neighbor Address Set ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_init_eor_end_version
                                        
                                        	Version to reach to send EOR
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_init_eor_pending_cnt
                                        
                                        	Count for pending EOR
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_resume_prefix
                                        
                                        	BMP Resume prefix
                                        	**type**\:   :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                        
                                        .. attribute:: bmp_resume_prefix_len
                                        
                                        	BMP Resume prefix Len
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_send_version
                                        
                                        	Table Version that this BMP server has caught upto
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_end_version
                                        
                                        	Update Gen ResumeWalk end version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_net_version
                                        
                                        	Update Gen ResumeWalk Net version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_start_version
                                        
                                        	Update Gen ResumeWalk start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_count
                                        
                                        	Number of times Update Gen ran
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                        
                                        	Last Update Gen Run time stamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_count
                                        
                                        	Number of times Update Gen Stopped
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                        
                                        	Last Update Gen Stop time stamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stopped
                                        
                                        	Update Gen WalkStopped
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmpaf_name
                                        
                                        	BMP Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                            self.yang_name = "bmpafi-info"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bmp-filter-neighbor-address" : ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress), "bmp-resume-prefix" : ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)}
                                            self._child_list_classes = {}

                                            self.bmp_filter_nbr_cnt = YLeaf(YType.uint32, "bmp-filter-nbr-cnt")

                                            self.bmp_filter_neighbor_address_set = YLeaf(YType.boolean, "bmp-filter-neighbor-address-set")

                                            self.bmp_init_eor_end_version = YLeaf(YType.uint32, "bmp-init-eor-end-version")

                                            self.bmp_init_eor_pending_cnt = YLeaf(YType.uint32, "bmp-init-eor-pending-cnt")

                                            self.bmp_resume_prefix_len = YLeaf(YType.uint32, "bmp-resume-prefix-len")

                                            self.bmp_send_version = YLeaf(YType.uint32, "bmp-send-version")

                                            self.bmp_upd_gen_resume_end_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-end-version")

                                            self.bmp_upd_gen_resume_net_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-net-version")

                                            self.bmp_upd_gen_resume_start_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-start-version")

                                            self.bmp_upd_gen_walk_run_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-count")

                                            self.bmp_upd_gen_walk_run_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-time-stamp")

                                            self.bmp_upd_gen_walk_stop_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-count")

                                            self.bmp_upd_gen_walk_stop_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-time-stamp")

                                            self.bmp_upd_gen_walk_stopped = YLeaf(YType.boolean, "bmp-upd-gen-walk-stopped")

                                            self.bmpaf_name = YLeaf(YType.enumeration, "bmpaf-name")

                                            self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                            self.bmp_filter_neighbor_address.parent = self
                                            self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                            self._children_yang_names.add("bmp-filter-neighbor-address")

                                            self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                            self.bmp_resume_prefix.parent = self
                                            self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"
                                            self._children_yang_names.add("bmp-resume-prefix")
                                            self._segment_path = lambda: "bmpafi-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, ['bmp_filter_nbr_cnt', 'bmp_filter_neighbor_address_set', 'bmp_init_eor_end_version', 'bmp_init_eor_pending_cnt', 'bmp_resume_prefix_len', 'bmp_send_version', 'bmp_upd_gen_resume_end_version', 'bmp_upd_gen_resume_net_version', 'bmp_upd_gen_resume_start_version', 'bmp_upd_gen_walk_run_count', 'bmp_upd_gen_walk_run_time_stamp', 'bmp_upd_gen_walk_stop_count', 'bmp_upd_gen_walk_stop_time_stamp', 'bmp_upd_gen_walk_stopped', 'bmpaf_name'], name, value)


                                        class BmpFilterNeighborAddress(Entity):
                                            """
                                            Filter Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-filter-neighbor-address"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "bmp-filter-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BmpResumePrefix(Entity):
                                            """
                                            BMP Resume prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                                self.yang_name = "bmp-resume-prefix"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bmp-resume-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bmp-resume-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class UpdateSourceAddress(Entity):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                            self.yang_name = "update-source-address"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "update-source-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class GlobalProcessInfo(Entity):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo, self).__init__()

                                self.yang_name = "global-process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf)}
                                self._child_list_classes = {}

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.vrfid = YLeaf(YType.uint32, "vrfid")

                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "global-process-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo, ['vrf_name', 'vrfid'], name, value)


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_cur_maximum_buffer_size
                                
                                	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                                
                                .. attribute:: color_id
                                
                                	All configured Color IDs
                                	**type**\: list of    :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId>`
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\:  bool
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\:  str
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"cluster-id-entry" : ("cluster_id_entry", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry), "color-id" : ("color_id", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId)}

                                    self.asn_format = YLeaf(YType.uint32, "asn-format")

                                    self.bmp_cur_maximum_buffer_size = YLeaf(YType.uint64, "bmp-cur-maximum-buffer-size")

                                    self.bmp_current_buffer_size = YLeaf(YType.uint64, "bmp-current-buffer-size")

                                    self.bmp_default_buffer_size = YLeaf(YType.uint64, "bmp-default-buffer-size")

                                    self.bmp_maximum_buffer_size = YLeaf(YType.uint64, "bmp-maximum-buffer-size")

                                    self.cluster_id = YLeaf(YType.uint32, "cluster-id")

                                    self.confederation_id = YLeaf(YType.uint32, "confederation-id")

                                    self.configured_cluster_id = YLeaf(YType.uint32, "configured-cluster-id")

                                    self.generic_scan_period = YLeaf(YType.uint16, "generic-scan-period")

                                    self.graceful_maint_all_nbrs = YLeaf(YType.boolean, "graceful-maint-all-nbrs")

                                    self.graceful_maint_retain_routes = YLeaf(YType.boolean, "graceful-maint-retain-routes")

                                    self.graceful_maintenance = YLeaf(YType.boolean, "graceful-maintenance")

                                    self.in_standalone_mode = YLeaf(YType.boolean, "in-standalone-mode")

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.is_cluster_id_specified_as_ip = YLeaf(YType.boolean, "is-cluster-id-specified-as-ip")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.process_rlimit = YLeaf(YType.uint64, "process-rlimit")

                                    self.restart_count = YLeaf(YType.uint32, "restart-count")

                                    self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                    self.srgb_end_configured = YLeaf(YType.uint32, "srgb-end-configured")

                                    self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                    self.srgb_start_configured = YLeaf(YType.uint32, "srgb-start-configured")

                                    self.update_delay = YLeaf(YType.uint32, "update-delay")

                                    self.cluster_id_entry = YList(self)
                                    self.color_id = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_, ['asn_format', 'bmp_cur_maximum_buffer_size', 'bmp_current_buffer_size', 'bmp_default_buffer_size', 'bmp_maximum_buffer_size', 'cluster_id', 'confederation_id', 'configured_cluster_id', 'generic_scan_period', 'graceful_maint_all_nbrs', 'graceful_maint_retain_routes', 'graceful_maintenance', 'in_standalone_mode', 'instance_name', 'is_cluster_id_specified_as_ip', 'local_as', 'process_rlimit', 'restart_count', 'srgb_end', 'srgb_end_configured', 'srgb_start', 'srgb_start_configured', 'update_delay'], name, value)


                                class ClusterIdEntry(Entity):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry, self).__init__()

                                        self.yang_name = "cluster-id-entry"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_type = YLeaf(YType.uint8, "cluster-id-type")

                                        self.cluster_id_val = YLeaf(YType.uint32, "cluster-id-val")
                                        self._segment_path = lambda: "cluster-id-entry"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry, ['cluster_id_type', 'cluster_id_val'], name, value)


                                class ColorId(Entity):
                                    """
                                    All configured Color IDs
                                    
                                    .. attribute:: color_id_val
                                    
                                    	Color ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId, self).__init__()

                                        self.yang_name = "color-id"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.color_id_val = YLeaf(YType.uint32, "color-id-val")
                                        self._segment_path = lambda: "color-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId, ['color_id_val'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\:  bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\:  bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.configured_router_id = YLeaf(YType.str, "configured-router-id")

                                    self.default_local_preference = YLeaf(YType.uint32, "default-local-preference")

                                    self.default_metric = YLeaf(YType.uint32, "default-metric")

                                    self.hold_time = YLeaf(YType.uint16, "hold-time")

                                    self.is_bestpath_aigp_ignore_enabled = YLeaf(YType.boolean, "is-bestpath-aigp-ignore-enabled")

                                    self.is_bestpath_always_compare_med_enabled = YLeaf(YType.boolean, "is-bestpath-always-compare-med-enabled")

                                    self.is_bestpath_as_path_mpath_relax_enabled = YLeaf(YType.boolean, "is-bestpath-as-path-mpath-relax-enabled")

                                    self.is_bestpath_compare_med_from_confed_peer_enabled = YLeaf(YType.boolean, "is-bestpath-compare-med-from-confed-peer-enabled")

                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = YLeaf(YType.boolean, "is-bestpath-compare-router-id-for-ebgp-peers-enabled")

                                    self.is_bestpath_ignore_as_path_enabled = YLeaf(YType.boolean, "is-bestpath-ignore-as-path-enabled")

                                    self.is_bestpath_missing_med_is_worst_enabled = YLeaf(YType.boolean, "is-bestpath-missing-med-is-worst-enabled")

                                    self.is_default_metric_configured = YLeaf(YType.boolean, "is-default-metric-configured")

                                    self.is_default_originate_configured = YLeaf(YType.boolean, "is-default-originate-configured")

                                    self.is_enforce_first_as_enabled = YLeaf(YType.boolean, "is-enforce-first-as-enabled")

                                    self.is_fast_external_fallover_enabled = YLeaf(YType.boolean, "is-fast-external-fallover-enabled")

                                    self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                                    self.is_multipath_as_path_ignore_onwards_enabled = YLeaf(YType.boolean, "is-multipath-as-path-ignore-onwards-enabled")

                                    self.is_neighbor_logging = YLeaf(YType.boolean, "is-neighbor-logging")

                                    self.is_nsr = YLeaf(YType.boolean, "is-nsr")

                                    self.is_redistribute_ibgp_to_ig_ps_enabled = YLeaf(YType.boolean, "is-redistribute-ibgp-to-ig-ps-enabled")

                                    self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                    self.min_acceptable_hold_time = YLeaf(YType.uint16, "min-acceptable-hold-time")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout = YLeaf(YType.uint32, "rib-purge-timeout")

                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.stale_path_time = YLeaf(YType.uint32, "stale-path-time")

                                    self.vrf_is_active = YLeaf(YType.boolean, "vrf-is-active")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf, ['configured_router_id', 'default_local_preference', 'default_metric', 'hold_time', 'is_bestpath_aigp_ignore_enabled', 'is_bestpath_always_compare_med_enabled', 'is_bestpath_as_path_mpath_relax_enabled', 'is_bestpath_compare_med_from_confed_peer_enabled', 'is_bestpath_compare_router_id_for_ebgp_peers_enabled', 'is_bestpath_ignore_as_path_enabled', 'is_bestpath_missing_med_is_worst_enabled', 'is_default_metric_configured', 'is_default_originate_configured', 'is_enforce_first_as_enabled', 'is_fast_external_fallover_enabled', 'is_graceful_restart', 'is_multipath_as_path_ignore_onwards_enabled', 'is_neighbor_logging', 'is_nsr', 'is_redistribute_ibgp_to_ig_ps_enabled', 'keep_alive_time', 'min_acceptable_hold_time', 'restart_time', 'rib_purge_timeout', 'route_distinguisher', 'router_id', 'stale_path_time', 'vrf_is_active'], name, value)


                        class Information(Entity):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")
                                self._segment_path = lambda: "information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information, ['route_distinguisher'], name, value)


                        class MessageLogs(Entity):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs, self).__init__()

                                self.yang_name = "message-logs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"message-log" : ("message_log", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog)}

                                self.message_log = YList(self)
                                self._segment_path = lambda: "message-logs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs, [], name, value)


                            class MessageLog(Entity):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog, self).__init__()

                                    self.yang_name = "message-log"
                                    self.yang_parent_name = "message-logs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor-message" : ("neighbor_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage)}

                                    self.direction = YLeaf(YType.int32, "direction")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_message = YList(self)
                                    self._segment_path = lambda: "message-log"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog, ['direction', 'neighbor_address'], name, value)


                                class NeighborMessage(Entity):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                        self.yang_name = "neighbor-message"
                                        self.yang_parent_name = "message-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-timestamp" : ("message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)}
                                        self._child_list_classes = {"logged-message-data" : ("logged_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData)}

                                        self.message_data_length = YLeaf(YType.uint16, "message-data-length")

                                        self.message_type_received = YLeaf(YType.uint8, "message-type-received")

                                        self.total_logged_message_count = YLeaf(YType.uint32, "total-logged-message-count")

                                        self.message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self._children_name_map["message_timestamp"] = "message-timestamp"
                                        self._children_yang_names.add("message-timestamp")

                                        self.logged_message_data = YList(self)
                                        self._segment_path = lambda: "neighbor-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, ['message_data_length', 'message_type_received', 'total_logged_message_count'], name, value)


                                    class LoggedMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                            self.yang_name = "logged-message-data"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "logged-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, ['entry'], name, value)


                                    class MessageTimestamp(Entity):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                            self.yang_name = "message-timestamp"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class NeighborRanges(Entity):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges, self).__init__()

                                self.yang_name = "neighbor-ranges"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-range" : ("neighbor_range", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange)}

                                self.neighbor_range = YList(self)
                                self._segment_path = lambda: "neighbor-ranges"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges, [], name, value)


                            class NeighborRange(Entity):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  <key>
                                
                                	Neighbor Range prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\:  bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\:  str
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\:  bool
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\:  bool
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\:  str
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\:  bool
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\:  bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\:  str
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange, self).__init__()

                                    self.yang_name = "neighbor-range"
                                    self.yang_parent_name = "neighbor-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"cfg-local-address" : ("cfg_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress), "connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance)}
                                    self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData), "instance" : ("instance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance)}

                                    self.neighbor_range_address = YLeaf(YType.str, "neighbor-range-address")

                                    self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                    self.addpath_receive_disable = YLeaf(YType.boolean, "addpath-receive-disable")

                                    self.addpath_receive_enable = YLeaf(YType.boolean, "addpath-receive-enable")

                                    self.addpath_send_disable = YLeaf(YType.boolean, "addpath-send-disable")

                                    self.addpath_send_enable = YLeaf(YType.boolean, "addpath-send-enable")

                                    self.attrf_group_name = YLeaf(YType.str, "attrf-group-name")

                                    self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                    self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                    self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                    self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                    self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                    self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                    self.current_peers = YLeaf(YType.uint32, "current-peers")

                                    self.description = YLeaf(YType.str, "description")

                                    self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                    self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                    self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                    self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                    self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                    self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                    self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                    self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                    self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                    self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                    self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                    self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                    self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                    self.islocal_address_cfg = YLeaf(YType.boolean, "islocal-address-cfg")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                    self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                    self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                    self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                    self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                    self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                    self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                    self.msg_bug_circular = YLeaf(YType.boolean, "msg-bug-circular")

                                    self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                    self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                    self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                    self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                    self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                    self.nbr_rcv_size = YLeaf(YType.uint32, "nbr-rcv-size")

                                    self.nbr_send_size = YLeaf(YType.uint32, "nbr-send-size")

                                    self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                    self.neighbor_range_prefix_length = YLeaf(YType.uint8, "neighbor-range-prefix-length")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.oper_attrf_enable = YLeaf(YType.boolean, "oper-attrf-enable")

                                    self.range_inst_error = YLeaf(YType.uint32, "range-inst-error")

                                    self.range_max_drop = YLeaf(YType.uint32, "range-max-drop")

                                    self.range_open_accepted = YLeaf(YType.uint32, "range-open-accepted")

                                    self.range_open_match = YLeaf(YType.uint32, "range-open-match")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.remote_as_list_name = YLeaf(YType.str, "remote-as-list-name")

                                    self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                    self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                    self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                    self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                    self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                    self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                    self.syslog_enable = YLeaf(YType.boolean, "syslog-enable")

                                    self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                    self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.upd_errh_noreset = YLeaf(YType.boolean, "upd-errh-noreset")

                                    self.update_source = YLeaf(YType.str, "update-source")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self._children_name_map["cfg_local_address"] = "cfg-local-address"
                                    self._children_yang_names.add("cfg-local-address")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.af_data = YList(self)
                                    self.instance = YList(self)
                                    self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + self.neighbor_range_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange, ['neighbor_range_address', 'active_bmp_servers', 'addpath_receive_disable', 'addpath_receive_enable', 'addpath_send_disable', 'addpath_send_enable', 'attrf_group_name', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_enable_mode', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'current_peers', 'description', 'discard_as4_path', 'dmz_link_bandwidth', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'idle_watch_time', 'ignore_connected', 'internal_vpn_client', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_passive_close', 'islocal_address_cfg', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'max_peers', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_buf_count', 'msg_bug_circular', 'msg_log_in', 'msg_log_out', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'nbr_rcv_size', 'nbr_send_size', 'neighbor_local_as', 'neighbor_range_prefix_length', 'nsr_enabled', 'oper_attrf_enable', 'range_inst_error', 'range_max_drop', 'range_open_accepted', 'range_open_match', 'remote_as', 'remote_as_list_name', 'remote_as_number', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'syslog_enable', 'tcp_session_open_mode', 'tcpmss', 'tos_type', 'tos_value', 'ttl_security_enabled', 'upd_errh_noreset', 'update_source', 'vrf_name'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby)}

                                        self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                        self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                        self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                        self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                        self.advertise_afi_local = YLeaf(YType.boolean, "advertise-afi-local")

                                        self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                        self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                        self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                        self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                        self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                        self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                        self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                        self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                        self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                        self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                        self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                        self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                        self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                        self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                        self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                        self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                        self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                        self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                        self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                        self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                        self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                        self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                        self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                        self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                        self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                        self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                        self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                        self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                        self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                        self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                        self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                        self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                        self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                        self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                        self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                        self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                        self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                        self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                        self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                        self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                        self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                        self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                        self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                        self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                        self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                        self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                        self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                        self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                        self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                        self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                        self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                        self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                        self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                        self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                        self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                        self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                        self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                        self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                        self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                        self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                        self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                        self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                        self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                        self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                        self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                        self.restart_time = YLeaf(YType.uint32, "restart-time")

                                        self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                        self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                        self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                        self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                        self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                        self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                        self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                        self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                        self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                        self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                        self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                        self.weight = YLeaf(YType.uint32, "weight")

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, ['accept_own_enabled', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_disable', 'advertise_afi_local', 'advertise_afi_reorg', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'next_hop_unchanged', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, ['entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community-standby"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                class CfgLocalAddress(Entity):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                        self.yang_name = "cfg-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "cfg-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                        self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                class Instance(Entity):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance, self).__init__()

                                        self.yang_name = "instance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"idle-watch-timer-remaining-value" : ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress), "neighbor-age" : ("neighbor_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge)}
                                        self._child_list_classes = {}

                                        self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                        self.is_idle_watch_timer_running = YLeaf(YType.boolean, "is-idle-watch-timer-running")

                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                        self._children_yang_names.add("idle-watch-timer-remaining-value")

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")

                                        self.neighbor_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge()
                                        self.neighbor_age.parent = self
                                        self._children_name_map["neighbor_age"] = "neighbor-age"
                                        self._children_yang_names.add("neighbor-age")
                                        self._segment_path = lambda: "instance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance, ['connection_state', 'is_idle_watch_timer_running'], name, value)


                                    class IdleWatchTimerRemainingValue(Entity):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, self).__init__()

                                            self.yang_name = "idle-watch-timer-remaining-value"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "idle-watch-timer-remaining-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class NeighborAge(Entity):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge, self).__init__()

                                            self.yang_name = "neighbor-age"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "neighbor-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge, ['nanoseconds', 'seconds'], name, value)


                        class Neighbors(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor)}

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\:  bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\:  bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\:  bool
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\:  bool
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\:  bool
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)}
                                    self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                    self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                    self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                    self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                    self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                    self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                    self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                    self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                    self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                    self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                    self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                    self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                    self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                    self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                    self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                    self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                    self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                    self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                    self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                    self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                    self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                    self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                    self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                    self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                    self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                    self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                    self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                    self.description = YLeaf(YType.str, "description")

                                    self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                    self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                    self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                    self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                    self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                    self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                    self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                    self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                    self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                    self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                    self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                    self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                    self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                    self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                    self.hold_time = YLeaf(YType.uint16, "hold-time")

                                    self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                    self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                    self.io_armed = YLeaf(YType.boolean, "io-armed")

                                    self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                    self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                    self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                    self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                    self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                    self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                    self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                    self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                    self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                    self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                    self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                    self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                    self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                    self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                    self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                    self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                    self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                    self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                    self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                    self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                    self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                    self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                    self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                    self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                    self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                    self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                    self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                    self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                    self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                    self.messages_received = YLeaf(YType.uint32, "messages-received")

                                    self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                    self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                    self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                    self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                    self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                    self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                    self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                    self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                    self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                    self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                    self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                    self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                    self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                    self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                    self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                    self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                    self.read_armed = YLeaf(YType.boolean, "read-armed")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                    self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                    self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                    self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                    self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                    self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                    self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                    self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                    self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                    self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                    self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                    self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                    self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                    self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                    self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                    self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                    self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                    self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                    self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                    self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                    self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                    self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                    self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                    self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                    self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                    self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.write_armed = YLeaf(YType.boolean, "write-armed")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self._children_name_map["message_statistics"] = "message-statistics"
                                    self._children_yang_names.add("message-statistics")

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._children_yang_names.add("performance-statistics")

                                    self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self._children_name_map["received_notification_info"] = "received-notification-info"
                                    self._children_yang_names.add("received-notification-info")

                                    self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self._children_name_map["send_notification_info"] = "send-notification-info"
                                    self._children_yang_names.add("send-notification-info")

                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-time-spec")

                                    self.af_data = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with 
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                        self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby)}

                                        self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                        self.acked_version = YLeaf(YType.uint32, "acked-version")

                                        self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                        self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                        self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                        self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                        self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                        self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                        self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                        self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                        self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                        self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                        self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                        self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                        self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                        self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                        self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                        self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                        self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                        self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                        self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                        self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                        self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                        self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                        self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                        self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                        self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                        self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                        self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                        self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                        self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                        self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                        self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                        self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                        self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                        self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                        self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                        self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                        self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                        self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                        self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                        self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                        self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                        self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                        self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                        self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                        self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                        self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                        self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                        self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                        self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                        self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                        self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                        self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                        self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                        self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                        self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                        self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                        self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                        self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                        self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                        self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                        self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                        self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                        self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                        self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                        self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                        self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                        self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                        self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                        self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                        self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                        self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                        self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                        self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                        self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                        self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                        self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                        self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                        self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                        self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                        self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                        self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                        self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                        self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                        self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                        self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                        self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                        self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                        self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                        self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                        self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                        self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                        self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                        self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                        self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                        self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                        self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                        self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                        self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                        self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                        self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                        self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                        self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                        self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                        self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                        self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                        self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                        self.restart_time = YLeaf(YType.uint32, "restart-time")

                                        self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                        self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                        self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                        self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                        self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                        self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                        self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                        self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                        self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                        self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                        self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                        self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                        self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                        self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                        self.weight = YLeaf(YType.uint32, "weight")

                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                        self._children_yang_names.add("neighbor-af-performance-statistics")

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community-standby"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                    class NeighborAfPerformanceStatistics(Entity):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                            self.yang_name = "neighbor-af-performance-statistics"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                            self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                            self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                            self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                            self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                            self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                            self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                            self._segment_path = lambda: "neighbor-af-performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                        self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                class MessageStatistics(Entity):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                        self.yang_name = "message-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update)}
                                        self._child_list_classes = {}

                                        self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self._children_name_map["keepalive"] = "keepalive"
                                        self._children_yang_names.add("keepalive")

                                        self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self._children_name_map["notification"] = "notification"
                                        self._children_yang_names.add("notification")

                                        self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self._children_name_map["open"] = "open"
                                        self._children_yang_names.add("open")

                                        self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self._children_name_map["route_refresh"] = "route-refresh"
                                        self._children_yang_names.add("route-refresh")

                                        self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self._children_name_map["total"] = "total"
                                        self._children_yang_names.add("total")

                                        self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self
                                        self._children_name_map["update"] = "update"
                                        self._children_yang_names.add("update")
                                        self._segment_path = lambda: "message-statistics"


                                    class Keepalive(Entity):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                            self.yang_name = "keepalive"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "keepalive"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Notification(Entity):
                                        """
                                        Notification
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                            self.yang_name = "notification"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "notification"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Open(Entity):
                                        """
                                        Open
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                            self.yang_name = "open"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "open"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class RouteRefresh(Entity):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                            self.yang_name = "route-refresh"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "route-refresh"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Total(Entity):
                                        """
                                        Total
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                            self.yang_name = "total"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "total"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Update(Entity):
                                        """
                                        Update
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                            self.yang_name = "update"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "update"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.active_collision = YLeaf(YType.uint32, "active-collision")

                                        self.actives = YLeaf(YType.uint32, "actives")

                                        self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                        self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                        self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                        self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                        self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                        self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                        self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                        self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                        self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                        self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                        self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                        self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                        self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                        self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                        self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                        self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                        self.network_status = YLeaf(YType.uint32, "network-status")

                                        self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                        self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                        self.passives = YLeaf(YType.uint32, "passives")

                                        self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                        self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                        self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                        self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                        self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                        self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                        self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                        self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                        self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                        self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                        self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                        self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                        self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                        self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                        self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                        self._segment_path = lambda: "performance-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                class ReceivedNotificationInfo(Entity):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                        self.yang_name = "received-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "received-notification-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "received-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                class SendNotificationInfo(Entity):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                        self.yang_name = "send-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "send-notification-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "send-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                class TcpInitSyncDoneTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-done-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class TcpInitSyncTimeSpec(Entity):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                        class NextHopVrf(Entity):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf, self).__init__()

                                self.yang_name = "next-hop-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.last_notification_processing_time = YLeaf(YType.uint32, "last-notification-processing-time")

                                self.last_notificationication_time = YLeaf(YType.uint32, "last-notificationication-time")

                                self.max_notification_bestpath_changes = YLeaf(YType.uint32, "max-notification-bestpath-changes")

                                self.max_notification_bestpath_deletes = YLeaf(YType.uint32, "max-notification-bestpath-deletes")

                                self.max_proc_notification_time = YLeaf(YType.uint32, "max-proc-notification-time")

                                self.maximum_processing_time = YLeaf(YType.uint32, "maximum-processing-time")

                                self.total_processing_time = YLeaf(YType.uint32, "total-processing-time")
                                self._segment_path = lambda: "next-hop-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf, ['last_notification_processing_time', 'last_notificationication_time', 'max_notification_bestpath_changes', 'max_notification_bestpath_deletes', 'max_proc_notification_time', 'maximum_processing_time', 'total_processing_time'], name, value)


                        class Postits(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits, self).__init__()

                                self.yang_name = "postits"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"postit" : ("postit", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit)}

                                self.postit = YList(self)
                                self._segment_path = lambda: "postits"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits, [], name, value)


                            class Postit(Entity):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit, self).__init__()

                                    self.yang_name = "postit"
                                    self.yang_parent_name = "postits"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbors-address" : ("neighbors_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress)}
                                    self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf), "postit-info" : ("postit_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.connect_state = YLeaf(YType.uint32, "connect-state")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.start_time = YLeaf(YType.uint32, "start-time")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.neighbors_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self._children_name_map["neighbors_address"] = "neighbors-address"
                                    self._children_yang_names.add("neighbors-address")

                                    self.neighbor_af = YList(self)
                                    self.postit_info = YList(self)
                                    self._segment_path = lambda: "postit" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit, ['neighbor_address', 'connect_state', 'nsr_state', 'start_time', 'vrf_name'], name, value)


                                class NeighborAf(Entity):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf, self).__init__()

                                        self.yang_name = "neighbor-af"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.boolean, "entry")
                                        self._segment_path = lambda: "neighbor-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf, ['entry'], name, value)


                                class NeighborsAddress(Entity):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress, self).__init__()

                                        self.yang_name = "neighbors-address"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbors-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PostitInfo(Entity):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\:  str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo, self).__init__()

                                        self.yang_name = "postit-info"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"postit-notification" : ("postit_notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification)}
                                        self._child_list_classes = {}

                                        self.peer_id = YLeaf(YType.uint32, "peer-id")

                                        self.postit_af_name = YLeaf(YType.enumeration, "postit-af-name")

                                        self.postit_direction = YLeaf(YType.uint8, "postit-direction")

                                        self.postit_flags = YLeaf(YType.uint8, "postit-flags")

                                        self.postit_id = YLeaf(YType.uint32, "postit-id")

                                        self.postit_policy = YLeaf(YType.str, "postit-policy")

                                        self.postit_reset = YLeaf(YType.enumeration, "postit-reset")

                                        self.postit_subtype = YLeaf(YType.uint32, "postit-subtype")

                                        self.postit_ts = YLeaf(YType.uint64, "postit-ts")

                                        self.postit_type = YLeaf(YType.uint32, "postit-type")

                                        self.postit_notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self._children_name_map["postit_notification"] = "postit-notification"
                                        self._children_yang_names.add("postit-notification")
                                        self._segment_path = lambda: "postit-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo, ['peer_id', 'postit_af_name', 'postit_direction', 'postit_flags', 'postit_id', 'postit_policy', 'postit_reset', 'postit_subtype', 'postit_ts', 'postit_type'], name, value)


                                    class PostitNotification(Entity):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                            self.yang_name = "postit-notification"
                                            self.yang_parent_name = "postit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "postit-notification"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "postit-notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, ['entry'], name, value)


                        class ProcessInfo(Entity):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo, self).__init__()

                                self.yang_name = "process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf)}
                                self._child_list_classes = {}

                                self.process_instance = YLeaf(YType.uint8, "process-instance")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._children_yang_names.add("performance-statistics")

                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "process-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo, ['process_instance', 'vrf_name', 'vrf_totals'], name, value)


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize>`
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: large_community_entry_count
                                
                                	Number of large community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_memory
                                
                                	Memory (in bytes) used by large community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize>`
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount>`
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize>`
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\:  str
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bmp-pool-alloc-count" : ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount), "bmp-pool-free-count" : ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount), "bmp-pool-size" : ("bmp_pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize), "msg-log-pool-alloc-count" : ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount), "msg-log-pool-free-count" : ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount), "msg-log-pool-size" : ("msg_log_pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize), "pool-alloc-count" : ("pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount), "pool-free-count" : ("pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount), "pool-size" : ("pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize)}

                                    self.as_path_entries_memory = YLeaf(YType.uint32, "as-path-entries-memory")

                                    self.as_path_entry_count = YLeaf(YType.uint32, "as-path-entry-count")

                                    self.attr_set_entry_count = YLeaf(YType.uint32, "attr-set-entry-count")

                                    self.attr_set_memory = YLeaf(YType.uint32, "attr-set-memory")

                                    self.community_entry_count = YLeaf(YType.uint32, "community-entry-count")

                                    self.community_memory = YLeaf(YType.uint32, "community-memory")

                                    self.established_neighbors_count_total = YLeaf(YType.uint32, "established-neighbors-count-total")

                                    self.extended_community_entry_count = YLeaf(YType.uint32, "extended-community-entry-count")

                                    self.extended_community_memory = YLeaf(YType.uint32, "extended-community-memory")

                                    self.large_community_entry_count = YLeaf(YType.uint32, "large-community-entry-count")

                                    self.large_community_memory = YLeaf(YType.uint32, "large-community-memory")

                                    self.lindex_entry_count = YLeaf(YType.uint32, "lindex-entry-count")

                                    self.lindex_memory = YLeaf(YType.uint32, "lindex-memory")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.lsattr_entry_count = YLeaf(YType.uint32, "lsattr-entry-count")

                                    self.lsattr_memory = YLeaf(YType.uint32, "lsattr-memory")

                                    self.neighbors_count_total = YLeaf(YType.uint32, "neighbors-count-total")

                                    self.nexthop_count = YLeaf(YType.uint32, "nexthop-count")

                                    self.nexthop_memory = YLeaf(YType.uint32, "nexthop-memory")

                                    self.path_attribute_memory = YLeaf(YType.uint32, "path-attribute-memory")

                                    self.path_attributes_entry_count = YLeaf(YType.uint32, "path-attributes-entry-count")

                                    self.pe_distinguisher_label_entry_count = YLeaf(YType.uint32, "pe-distinguisher-label-entry-count")

                                    self.pe_distinguisher_label_memory = YLeaf(YType.uint32, "pe-distinguisher-label-memory")

                                    self.ppmp_entry_count = YLeaf(YType.uint32, "ppmp-entry-count")

                                    self.ppmp_memory = YLeaf(YType.uint32, "ppmp-memory")

                                    self.process_instance_node = YLeaf(YType.str, "process-instance-node")

                                    self.pta_entry_count = YLeaf(YType.uint32, "pta-entry-count")

                                    self.pta_memory = YLeaf(YType.uint32, "pta-memory")

                                    self.restart_count = YLeaf(YType.uint32, "restart-count")

                                    self.ribrnh_entry_count = YLeaf(YType.uint32, "ribrnh-entry-count")

                                    self.ribrnh_memory = YLeaf(YType.uint32, "ribrnh-memory")

                                    self.route_reflector_memory = YLeaf(YType.uint32, "route-reflector-memory")

                                    self.route_reflectors = YLeaf(YType.uint32, "route-reflectors")

                                    self.sn_num_non_dflt_vrf_nbrs = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs")

                                    self.sn_num_non_dflt_vrf_nbrs_estab = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs-estab")

                                    self.total_vrf_count = YLeaf(YType.uint32, "total-vrf-count")

                                    self.tunnel_encap_entry_count = YLeaf(YType.uint32, "tunnel-encap-entry-count")

                                    self.tunnel_encap_memory = YLeaf(YType.uint32, "tunnel-encap-memory")

                                    self.bmp_pool_alloc_count = YList(self)
                                    self.bmp_pool_free_count = YList(self)
                                    self.bmp_pool_size = YList(self)
                                    self.msg_log_pool_alloc_count = YList(self)
                                    self.msg_log_pool_free_count = YList(self)
                                    self.msg_log_pool_size = YList(self)
                                    self.pool_alloc_count = YList(self)
                                    self.pool_free_count = YList(self)
                                    self.pool_size = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_, ['as_path_entries_memory', 'as_path_entry_count', 'attr_set_entry_count', 'attr_set_memory', 'community_entry_count', 'community_memory', 'established_neighbors_count_total', 'extended_community_entry_count', 'extended_community_memory', 'large_community_entry_count', 'large_community_memory', 'lindex_entry_count', 'lindex_memory', 'local_as', 'lsattr_entry_count', 'lsattr_memory', 'neighbors_count_total', 'nexthop_count', 'nexthop_memory', 'path_attribute_memory', 'path_attributes_entry_count', 'pe_distinguisher_label_entry_count', 'pe_distinguisher_label_memory', 'ppmp_entry_count', 'ppmp_memory', 'process_instance_node', 'pta_entry_count', 'pta_memory', 'restart_count', 'ribrnh_entry_count', 'ribrnh_memory', 'route_reflector_memory', 'route_reflectors', 'sn_num_non_dflt_vrf_nbrs', 'sn_num_non_dflt_vrf_nbrs_estab', 'total_vrf_count', 'tunnel_encap_entry_count', 'tunnel_encap_memory'], name, value)


                                class BmpPoolAllocCount(Entity):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount, self).__init__()

                                        self.yang_name = "bmp-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount, ['entry'], name, value)


                                class BmpPoolFreeCount(Entity):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount, self).__init__()

                                        self.yang_name = "bmp-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount, ['entry'], name, value)


                                class BmpPoolSize(Entity):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize, self).__init__()

                                        self.yang_name = "bmp-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize, ['entry'], name, value)


                                class MsgLogPoolAllocCount(Entity):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount, self).__init__()

                                        self.yang_name = "msg-log-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount, ['entry'], name, value)


                                class MsgLogPoolFreeCount(Entity):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount, self).__init__()

                                        self.yang_name = "msg-log-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount, ['entry'], name, value)


                                class MsgLogPoolSize(Entity):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize, self).__init__()

                                        self.yang_name = "msg-log-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize, ['entry'], name, value)


                                class PoolAllocCount(Entity):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount, self).__init__()

                                        self.yang_name = "pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount, ['entry'], name, value)


                                class PoolFreeCount(Entity):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount, self).__init__()

                                        self.yang_name = "pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount, ['entry'], name, value)


                                class PoolSize(Entity):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize, self).__init__()

                                        self.yang_name = "pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize, ['entry'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf)}
                                    self._child_list_classes = {}

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "performance-statistics"


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\:  bool
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:   :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\:  bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\:  bool
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ds-npl" : ("ds_npl", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl), "ipv4rib-server" : ("ipv4rib_server", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer), "ipv6rib-server" : ("ipv6rib_server", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer), "lsd-connection" : ("lsd_connection", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection), "te-connection" : ("te_connection", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection)}
                                        self._child_list_classes = {"active-nsr-mode-enter-time" : ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime), "active-nsrfo-time" : ("active_nsrfo_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime), "issu-milestone" : ("issu_milestone", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone), "postit-count-info" : ("postit_count_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo), "standby-nsr-mode-enter-time" : ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime)}

                                        self.active_nsr_state = YLeaf(YType.uint32, "active-nsr-state")

                                        self.active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "active-nsrtcp-phase-two-enter-time")

                                        self.brib_api_input_bytes = YLeaf(YType.uint32, "brib-api-input-bytes")

                                        self.brib_api_input_messages = YLeaf(YType.uint32, "brib-api-input-messages")

                                        self.brib_api_input_prefixes_received = YLeaf(YType.uint32, "brib-api-input-prefixes-received")

                                        self.brib_api_input_processing_time = YLeaf(YType.uint32, "brib-api-input-processing-time")

                                        self.brib_api_input_withdrawn_prefixes = YLeaf(YType.uint32, "brib-api-input-withdrawn-prefixes")

                                        self.brib_api_output_bytes_generated = YLeaf(YType.uint32, "brib-api-output-bytes-generated")

                                        self.brib_api_output_bytes_sent = YLeaf(YType.uint32, "brib-api-output-bytes-sent")

                                        self.brib_api_output_calls = YLeaf(YType.uint32, "brib-api-output-calls")

                                        self.brib_api_output_generation_time = YLeaf(YType.uint32, "brib-api-output-generation-time")

                                        self.brib_api_output_messages_sent = YLeaf(YType.uint32, "brib-api-output-messages-sent")

                                        self.brib_api_output_prefixes_advertised = YLeaf(YType.uint32, "brib-api-output-prefixes-advertised")

                                        self.brib_api_output_prefixes_withdrawn = YLeaf(YType.uint32, "brib-api-output-prefixes-withdrawn")

                                        self.brib_api_output_sending_time = YLeaf(YType.uint32, "brib-api-output-sending-time")

                                        self.configuration_items_processed = YLeaf(YType.uint32, "configuration-items-processed")

                                        self.configuration_processing_time = YLeaf(YType.uint32, "configuration-processing-time")

                                        self.current_clock_time = YLeaf(YType.uint64, "current-clock-time")

                                        self.edm_processing_time = YLeaf(YType.uint32, "edm-processing-time")

                                        self.edm_requests_count = YLeaf(YType.uint32, "edm-requests-count")

                                        self.in_event_attach_calls = YLeaf(YType.uint32, "in-event-attach-calls")

                                        self.in_out_event_attach_calls = YLeaf(YType.uint32, "in-out-event-attach-calls")

                                        self.initial_sync_sessions_added = YLeaf(YType.boolean, "initial-sync-sessions-added")

                                        self.instance_node_role = YLeaf(YType.boolean, "instance-node-role")

                                        self.io_handler_tm = YLeaf(YType.uint64, "io-handler-tm")

                                        self.io_timer_id = YLeaf(YType.uint32, "io-timer-id")

                                        self.io_tree_timer_expiry = YLeaf(YType.uint64, "io-tree-timer-expiry")

                                        self.io_tree_timer_left = YLeaf(YType.uint64, "io-tree-timer-left")

                                        self.nsr_last_reset_reason = YLeaf(YType.uint8, "nsr-last-reset-reason")

                                        self.out_event_attach_calls = YLeaf(YType.uint32, "out-event-attach-calls")

                                        self.proc_scoped_sync_state = YLeaf(YType.enumeration, "proc-scoped-sync-state")

                                        self.qad_ac_ks_failure = YLeaf(YType.uint32, "qad-ac-ks-failure")

                                        self.qad_ac_ks_received = YLeaf(YType.uint32, "qad-ac-ks-received")

                                        self.qad_init_drops = YLeaf(YType.uint32, "qad-init-drops")

                                        self.qad_messages_received = YLeaf(YType.uint32, "qad-messages-received")

                                        self.qad_messages_sent = YLeaf(YType.uint32, "qad-messages-sent")

                                        self.qad_processed = YLeaf(YType.uint32, "qad-processed")

                                        self.qad_recv_drops = YLeaf(YType.uint32, "qad-recv-drops")

                                        self.qad_resumes = YLeaf(YType.uint32, "qad-resumes")

                                        self.qad_send_drops = YLeaf(YType.uint32, "qad-send-drops")

                                        self.qad_send_failure = YLeaf(YType.uint32, "qad-send-failure")

                                        self.qad_suspends = YLeaf(YType.uint32, "qad-suspends")

                                        self.qad_timeout_received = YLeaf(YType.uint32, "qad-timeout-received")

                                        self.qad_timeout_recvd = YLeaf(YType.uint32, "qad-timeout-recvd")

                                        self.qadack_sent = YLeaf(YType.uint32, "qadack-sent")

                                        self.qadoos_drops = YLeaf(YType.uint32, "qadoos-drops")

                                        self.redcon_nsr_ready = YLeaf(YType.boolean, "redcon-nsr-ready")

                                        self.redcon_state_time = YLeaf(YType.uint32, "redcon-state-time")

                                        self.sec_active_nsr_state = YLeaf(YType.uint32, "sec-active-nsr-state")

                                        self.sec_active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "sec-active-nsrtcp-phase-two-enter-time")

                                        self.tep2p_auto_tunnel_enabled = YLeaf(YType.boolean, "tep2p-auto-tunnel-enabled")

                                        self.total_neighbors_with_pending_postits = YLeaf(YType.uint32, "total-neighbors-with-pending-postits")

                                        self.total_outstanding_postits = YLeaf(YType.uint32, "total-outstanding-postits")

                                        self.updgen_handler_tm = YLeaf(YType.uint64, "updgen-handler-tm")

                                        self.updgen_timer_id = YLeaf(YType.uint32, "updgen-timer-id")

                                        self.updgen_tree_timer_expiry = YLeaf(YType.uint64, "updgen-tree-timer-expiry")

                                        self.updgen_tree_timer_left = YLeaf(YType.uint64, "updgen-tree-timer-left")

                                        self.ds_npl = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                        self.ds_npl.parent = self
                                        self._children_name_map["ds_npl"] = "ds-npl"
                                        self._children_yang_names.add("ds-npl")

                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                        self.ipv4rib_server.parent = self
                                        self._children_name_map["ipv4rib_server"] = "ipv4rib-server"
                                        self._children_yang_names.add("ipv4rib-server")

                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                        self.ipv6rib_server.parent = self
                                        self._children_name_map["ipv6rib_server"] = "ipv6rib-server"
                                        self._children_yang_names.add("ipv6rib-server")

                                        self.lsd_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self._children_name_map["lsd_connection"] = "lsd-connection"
                                        self._children_yang_names.add("lsd-connection")

                                        self.te_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                        self.te_connection.parent = self
                                        self._children_name_map["te_connection"] = "te-connection"
                                        self._children_yang_names.add("te-connection")

                                        self.active_nsr_mode_enter_time = YList(self)
                                        self.active_nsrfo_time = YList(self)
                                        self.issu_milestone = YList(self)
                                        self.postit_count_info = YList(self)
                                        self.standby_nsr_mode_enter_time = YList(self)
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_, ['active_nsr_state', 'active_nsrtcp_phase_two_enter_time', 'brib_api_input_bytes', 'brib_api_input_messages', 'brib_api_input_prefixes_received', 'brib_api_input_processing_time', 'brib_api_input_withdrawn_prefixes', 'brib_api_output_bytes_generated', 'brib_api_output_bytes_sent', 'brib_api_output_calls', 'brib_api_output_generation_time', 'brib_api_output_messages_sent', 'brib_api_output_prefixes_advertised', 'brib_api_output_prefixes_withdrawn', 'brib_api_output_sending_time', 'configuration_items_processed', 'configuration_processing_time', 'current_clock_time', 'edm_processing_time', 'edm_requests_count', 'in_event_attach_calls', 'in_out_event_attach_calls', 'initial_sync_sessions_added', 'instance_node_role', 'io_handler_tm', 'io_timer_id', 'io_tree_timer_expiry', 'io_tree_timer_left', 'nsr_last_reset_reason', 'out_event_attach_calls', 'proc_scoped_sync_state', 'qad_ac_ks_failure', 'qad_ac_ks_received', 'qad_init_drops', 'qad_messages_received', 'qad_messages_sent', 'qad_processed', 'qad_recv_drops', 'qad_resumes', 'qad_send_drops', 'qad_send_failure', 'qad_suspends', 'qad_timeout_received', 'qad_timeout_recvd', 'qadack_sent', 'qadoos_drops', 'redcon_nsr_ready', 'redcon_state_time', 'sec_active_nsr_state', 'sec_active_nsrtcp_phase_two_enter_time', 'tep2p_auto_tunnel_enabled', 'total_neighbors_with_pending_postits', 'total_outstanding_postits', 'updgen_handler_tm', 'updgen_timer_id', 'updgen_tree_timer_expiry', 'updgen_tree_timer_left'], name, value)


                                    class ActiveNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, self).__init__()

                                            self.yang_name = "active-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "active-nsr-mode-enter-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, ['entry'], name, value)


                                    class ActiveNsrfoTime(Entity):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, self).__init__()

                                            self.yang_name = "active-nsrfo-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "active-nsrfo-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, ['entry'], name, value)


                                    class DsNpl(Entity):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:   :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:   :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\:  str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\:  bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\:  str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, self).__init__()

                                            self.yang_name = "ds-npl"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"npl-endpoint" : ("npl_endpoint", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint), "npl-priority-statistic" : ("npl_priority_statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic)}

                                            self.dir_service_conn_state = YLeaf(YType.enumeration, "dir-service-conn-state")

                                            self.dsissu_status_flag = YLeaf(YType.uint32, "dsissu-status-flag")

                                            self.issu_mgr_conn_state = YLeaf(YType.enumeration, "issu-mgr-conn-state")

                                            self.issu_phase = YLeaf(YType.str, "issu-phase")

                                            self.issu_type_ng = YLeaf(YType.boolean, "issu-type-ng")

                                            self.issuha_option = YLeaf(YType.str, "issuha-option")

                                            self.local_ds_handle = YLeaf(YType.uint64, "local-ds-handle")

                                            self.service_name = YLeaf(YType.str, "service-name")

                                            self.npl_endpoint = YList(self)
                                            self.npl_priority_statistic = YList(self)
                                            self._segment_path = lambda: "ds-npl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, ['dir_service_conn_state', 'dsissu_status_flag', 'issu_mgr_conn_state', 'issu_phase', 'issu_type_ng', 'issuha_option', 'local_ds_handle', 'service_name'], name, value)


                                        class NplEndpoint(Entity):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\:  str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\:  str
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, self).__init__()

                                                self.yang_name = "npl-endpoint"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"endpoint" : ("endpoint", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint)}

                                                self.endpoint_active_flag = YLeaf(YType.boolean, "endpoint-active-flag")

                                                self.endpoint_handle = YLeaf(YType.uint64, "endpoint-handle")

                                                self.endpoint_issu_role = YLeaf(YType.str, "endpoint-issu-role")

                                                self.endpoint_name = YLeaf(YType.str, "endpoint-name")

                                                self.endpoint_stale_flag = YLeaf(YType.boolean, "endpoint-stale-flag")

                                                self.expected_sequence_num = YLeaf(YType.uint32, "expected-sequence-num")

                                                self.msg_size = YLeaf(YType.uint32, "msg-size")

                                                self.node_id = YLeaf(YType.str, "node-id")

                                                self.sync_group_name = YLeaf(YType.str, "sync-group-name")

                                                self.wheel_id = YLeaf(YType.uint32, "wheel-id")

                                                self.endpoint = YList(self)
                                                self._segment_path = lambda: "npl-endpoint"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, ['endpoint_active_flag', 'endpoint_handle', 'endpoint_issu_role', 'endpoint_name', 'endpoint_stale_flag', 'expected_sequence_num', 'msg_size', 'node_id', 'sync_group_name', 'wheel_id'], name, value)


                                            class Endpoint(Entity):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                    self.yang_name = "endpoint"
                                                    self.yang_parent_name = "npl-endpoint"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "endpoint"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, ['entry'], name, value)


                                        class NplPriorityStatistic(Entity):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, self).__init__()

                                                self.yang_name = "npl-priority-statistic"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"num-recv" : ("num_recv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv), "num-recv-drop" : ("num_recv_drop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop), "num-sent" : ("num_sent", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent), "num-sent-drop" : ("num_sent_drop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop)}

                                                self.num_recv = YList(self)
                                                self.num_recv_drop = YList(self)
                                                self.num_sent = YList(self)
                                                self.num_sent_drop = YList(self)
                                                self._segment_path = lambda: "npl-priority-statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, [], name, value)


                                            class NumRecv(Entity):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                    self.yang_name = "num-recv"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "num-recv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, ['entry'], name, value)


                                            class NumRecvDrop(Entity):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                    self.yang_name = "num-recv-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray)}

                                                    self.nsr_pl_recv_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-recv-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                                class NsrPlRecvDropArray(Entity):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-recv-drop-array"
                                                        self.yang_parent_name = "num-recv-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                                            class NumSent(Entity):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                    self.yang_name = "num-sent"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "num-sent"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, ['entry'], name, value)


                                            class NumSentDrop(Entity):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                    self.yang_name = "num-sent-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray)}

                                                    self.nsr_pl_send_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-sent-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                                class NsrPlSendDropArray(Entity):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-send-drop-array"
                                                        self.yang_parent_name = "num-sent-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nsr-pl-send-drop-array"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                                    class Ipv4RibServer(Entity):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, self).__init__()

                                            self.yang_name = "ipv4rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                            self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                            self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                            self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                            self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                            self._children_yang_names.add("first-rib-connection-down-timestamp")

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                            self._children_yang_names.add("first-rib-connection-up-timestamp")

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._children_yang_names.add("last-rib-connection-down-timestamp")

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                            self._children_yang_names.add("last-rib-connection-up-timestamp")
                                            self._segment_path = lambda: "ipv4rib-server"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class Ipv6RibServer(Entity):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, self).__init__()

                                            self.yang_name = "ipv6rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                            self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                            self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                            self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                            self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                            self._children_yang_names.add("first-rib-connection-down-timestamp")

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                            self._children_yang_names.add("first-rib-connection-up-timestamp")

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._children_yang_names.add("last-rib-connection-down-timestamp")

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                            self._children_yang_names.add("last-rib-connection-up-timestamp")
                                            self._segment_path = lambda: "ipv6rib-server"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class IssuMilestone(Entity):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\:  str
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, self).__init__()

                                            self.yang_name = "issu-milestone"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.milestone_met_timestamp = YLeaf(YType.uint32, "milestone-met-timestamp")

                                            self.milestone_name = YLeaf(YType.str, "milestone-name")

                                            self.milestone_start_timestamp = YLeaf(YType.uint32, "milestone-start-timestamp")
                                            self._segment_path = lambda: "issu-milestone"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, ['milestone_met_timestamp', 'milestone_name', 'milestone_start_timestamp'], name, value)


                                    class LsdConnection(Entity):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, self).__init__()

                                            self.yang_name = "lsd-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                            self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                            self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                            self._children_yang_names.add("first-connection-down-timestamp")

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                            self._children_yang_names.add("first-connection-up-timestamp")

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._children_yang_names.add("last-connection-down-timestamp")

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                            self._children_yang_names.add("last-connection-up-timestamp")
                                            self._segment_path = lambda: "lsd-connection"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class PostitCountInfo(Entity):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, self).__init__()

                                            self.yang_name = "postit-count-info"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.postit_count = YLeaf(YType.uint32, "postit-count")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "postit-count-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, ['postit_count', 'vrf_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "postit-count-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class StandbyNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, self).__init__()

                                            self.yang_name = "standby-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "standby-nsr-mode-enter-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, ['entry'], name, value)


                                    class TeConnection(Entity):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, self).__init__()

                                            self.yang_name = "te-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                            self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                            self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                            self._children_yang_names.add("first-connection-down-timestamp")

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                            self._children_yang_names.add("first-connection-up-timestamp")

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._children_yang_names.add("last-connection-down-timestamp")

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                            self._children_yang_names.add("last-connection-up-timestamp")
                                            self._segment_path = lambda: "te-connection"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                        self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                        self.high_throttled_read_count = YLeaf(YType.uint32, "high-throttled-read-count")

                                        self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                        self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                        self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                        self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                        self.low_throttled_read_count = YLeaf(YType.uint32, "low-throttled-read-count")

                                        self.lpts_calls = YLeaf(YType.uint32, "lpts-calls")

                                        self.lpts_set_up_time = YLeaf(YType.uint32, "lpts-set-up-time")

                                        self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                        self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                        self.read_throttles_count = YLeaf(YType.uint32, "read-throttles-count")

                                        self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                        self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                        self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                        self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                        self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                        self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                        self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf, ['data_bytes_read', 'data_bytes_written', 'high_throttled_read_count', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'low_throttled_read_count', 'lpts_calls', 'lpts_set_up_time', 'read_calls_count', 'read_messages_count', 'read_throttles_count', 'subgroup_list_time', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.established_neighbors_count = YLeaf(YType.uint32, "established-neighbors-count")

                                    self.neighbors_count = YLeaf(YType.uint32, "neighbors-count")

                                    self.network_count = YLeaf(YType.uint32, "network-count")

                                    self.notifications_received = YLeaf(YType.uint32, "notifications-received")

                                    self.notifications_sent = YLeaf(YType.uint32, "notifications-sent")

                                    self.path_count = YLeaf(YType.uint32, "path-count")

                                    self.update_messages_received = YLeaf(YType.uint32, "update-messages-received")

                                    self.update_messages_sent = YLeaf(YType.uint32, "update-messages-sent")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf, ['established_neighbors_count', 'neighbors_count', 'network_count', 'notifications_received', 'notifications_sent', 'path_count', 'update_messages_received', 'update_messages_sent'], name, value)


                        class Sessions(Entity):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"session" : ("session", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session)}

                                self.session = YList(self)
                                self._segment_path = lambda: "sessions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions, [], name, value)


                            class Session(Entity):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\:  bool
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "sessions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress)}
                                    self._child_list_classes = {}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.description = YLeaf(YType.str, "description")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                    self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.postit_pending = YLeaf(YType.boolean, "postit-pending")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")
                                    self._segment_path = lambda: "session" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session, ['neighbor_address', 'connection_state', 'description', 'is_local_address_configured', 'local_as', 'messages_queued_in', 'messages_queued_out', 'nsr_enabled', 'nsr_state', 'postit_pending', 'remote_as', 'speaker_id', 'vrf_name'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundErrorNeighbors(Entity):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors, self).__init__()

                                self.yang_name = "update-inbound-error-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"update-inbound-error-neighbor" : ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor)}

                                self.update_inbound_error_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors, [], name, value)


                            class UpdateInboundErrorNeighbor(Entity):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\:  bool
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-error-neighbor"
                                    self.yang_parent_name = "update-inbound-error-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"first-update-error-handling-reset-timestamp" : ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp), "first-update-malformed-timestamp" : ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp), "first-update-memory-allocation-fail-timestamp" : ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp), "last-error-handling-reset-timestamp" : ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp), "last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)}
                                    self._child_list_classes = {"establishment-action-count" : ("establishment_action_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount), "update-error-message" : ("update_error_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.establishment_total_update_message_count = YLeaf(YType.uint32, "establishment-total-update-message-count")

                                    self.last_error_handling_reset_age = YLeaf(YType.uint32, "last-error-handling-reset-age")

                                    self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                    self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                    self.total_update_message_count = YLeaf(YType.uint32, "total-update-message-count")

                                    self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                    self.update_error_handling_avoid_reset = YLeaf(YType.boolean, "update-error-handling-avoid-reset")

                                    self.update_error_handling_reset_count = YLeaf(YType.uint32, "update-error-handling-reset-count")

                                    self.update_error_message_list_count = YLeaf(YType.uint32, "update-error-message-list-count")

                                    self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                    self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                    self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"
                                    self._children_yang_names.add("first-update-error-handling-reset-timestamp")

                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"
                                    self._children_yang_names.add("first-update-malformed-timestamp")

                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"
                                    self._children_yang_names.add("first-update-memory-allocation-fail-timestamp")

                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"
                                    self._children_yang_names.add("last-error-handling-reset-timestamp")

                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                    self._children_yang_names.add("last-update-malformed-timestamp")

                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                    self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                    self._children_yang_names.add("update-neighbor-address")

                                    self.establishment_action_count = YList(self)
                                    self.update_error_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', 'establishment_total_update_message_count', 'last_error_handling_reset_age', 'last_update_malformed_age', 'last_update_memory_allocation_fail_age', 'total_update_message_count', 'update_attribute_discard_count', 'update_error_handling_avoid_reset', 'update_error_handling_reset_count', 'update_error_message_list_count', 'update_malformed_message_count', 'update_memory_allocation_fail_count', 'update_vrf_name'], name, value)


                                class EstablishmentActionCount(Entity):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                        self.yang_name = "establishment-action-count"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "establishment-action-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, ['entry'], name, value)


                                class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "first-update-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-error-handling-reset-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class FirstUpdateMalformedTimestamp(Entity):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "first-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-malformed-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastErrorHandlingResetTimestamp(Entity):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "last-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-error-handling-reset-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateMalformedTimestamp(Entity):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "last-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-malformed-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateErrorMessage(Entity):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                        self.yang_name = "update-error-message"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-message-reset-data" : ("update_message_reset_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData), "update-message-timestamp" : ("update_message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)}
                                        self._child_list_classes = {"update-error-element" : ("update_error_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement), "update-message-data" : ("update_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)}

                                        self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                        self.update_error_final_action = YLeaf(YType.enumeration, "update-error-final-action")

                                        self.update_error_nlri_address_family = YLeaf(YType.enumeration, "update-error-nlri-address-family")

                                        self.update_error_nlri_string = YLeaf(YType.str, "update-error-nlri-string")

                                        self.update_error_nlri_string_truncated = YLeaf(YType.boolean, "update-error-nlri-string-truncated")

                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self._children_name_map["update_message_reset_data"] = "update-message-reset-data"
                                        self._children_yang_names.add("update-message-reset-data")

                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self
                                        self._children_name_map["update_message_timestamp"] = "update-message-timestamp"
                                        self._children_yang_names.add("update-message-timestamp")

                                        self.update_error_element = YList(self)
                                        self.update_message_data = YList(self)
                                        self._segment_path = lambda: "update-error-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, ['update_attribute_discard_count', 'update_error_final_action', 'update_error_nlri_address_family', 'update_error_nlri_string', 'update_error_nlri_string_truncated'], name, value)


                                    class UpdateErrorElement(Entity):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                            self.yang_name = "update-error-element"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                            self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                            self.update_attribute_length = YLeaf(YType.uint16, "update-attribute-length")

                                            self.update_error_action = YLeaf(YType.enumeration, "update-error-action")

                                            self.update_error_data = YLeaf(YType.str, "update-error-data")

                                            self.update_error_data_length = YLeaf(YType.uint16, "update-error-data-length")
                                            self._segment_path = lambda: "update-error-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, ['update_attribute_code', 'update_attribute_flags', 'update_attribute_length', 'update_error_action', 'update_error_data', 'update_error_data_length'], name, value)


                                    class UpdateMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                            self.yang_name = "update-message-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "update-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, ['entry'], name, value)


                                    class UpdateMessageResetData(Entity):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                            self.yang_name = "update-message-reset-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_error_reset_notification_code = YLeaf(YType.uint8, "update-error-reset-notification-code")

                                            self.update_error_reset_notification_data = YLeaf(YType.str, "update-error-reset-notification-data")

                                            self.update_error_reset_notification_data_length = YLeaf(YType.uint16, "update-error-reset-notification-data-length")

                                            self.update_error_reset_notification_sub_code = YLeaf(YType.uint16, "update-error-reset-notification-sub-code")

                                            self.update_error_reset_reason = YLeaf(YType.enumeration, "update-error-reset-reason")
                                            self._segment_path = lambda: "update-message-reset-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, ['update_error_reset_notification_code', 'update_error_reset_notification_data', 'update_error_reset_notification_data_length', 'update_error_reset_notification_sub_code', 'update_error_reset_reason'], name, value)


                                    class UpdateMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                            self.yang_name = "update-message-timestamp"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "update-message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundErrorVrf(Entity):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf, self).__init__()

                                self.yang_name = "update-inbound-error-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp)}
                                self._child_list_classes = {}

                                self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._children_yang_names.add("last-update-malformed-timestamp")
                                self._segment_path = lambda: "update-inbound-error-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf, ['last_update_malformed_age', 'update_malformed_message_count', 'update_malformed_neighbor_count', 'update_vrf_name'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class UpdateInboundFilterNeighbors(Entity):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"update-inbound-filter-neighbor" : ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor)}

                                self.update_inbound_filter_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors, [], name, value)


                            class UpdateInboundFilterNeighbor(Entity):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-filter-neighbor"
                                    self.yang_parent_name = "update-inbound-filter-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"first-update-filtered-timestamp" : ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp), "last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)}
                                    self._child_list_classes = {"update-attribute-filter-attributes" : ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes), "update-filter-message" : ("update_filter_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.configured_update_filter_message_buffer_count = YLeaf(YType.uint32, "configured-update-filter-message-buffer-count")

                                    self.establishment_total_filter_update_message_count = YLeaf(YType.uint32, "establishment-total-filter-update-message-count")

                                    self.establishment_update_filtered_message_count = YLeaf(YType.uint32, "establishment-update-filtered-message-count")

                                    self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                    self.message_update_attribute_filtering_enabled = YLeaf(YType.boolean, "message-update-attribute-filtering-enabled")

                                    self.operational_update_attribute_filtering_enabled = YLeaf(YType.boolean, "operational-update-attribute-filtering-enabled")

                                    self.operational_update_filter_message_buffer_count = YLeaf(YType.uint32, "operational-update-filter-message-buffer-count")

                                    self.total_filter_update_message_count = YLeaf(YType.uint32, "total-filter-update-message-count")

                                    self.update_attribute_filter_group_name = YLeaf(YType.str, "update-attribute-filter-group-name")

                                    self.update_filter_logging_enabled = YLeaf(YType.boolean, "update-filter-logging-enabled")

                                    self.update_filter_message_buffer_circular = YLeaf(YType.boolean, "update-filter-message-buffer-circular")

                                    self.update_filter_message_list_count = YLeaf(YType.uint32, "update-filter-message-list-count")

                                    self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                    self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"
                                    self._children_yang_names.add("first-update-filtered-timestamp")

                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                    self._children_yang_names.add("last-update-filtered-timestamp")

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                    self._children_yang_names.add("update-neighbor-address")

                                    self.update_attribute_filter_attributes = YList(self)
                                    self.update_filter_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', 'configured_update_filter_message_buffer_count', 'establishment_total_filter_update_message_count', 'establishment_update_filtered_message_count', 'last_update_filtered_age', 'message_update_attribute_filtering_enabled', 'operational_update_attribute_filtering_enabled', 'operational_update_filter_message_buffer_count', 'total_filter_update_message_count', 'update_attribute_filter_group_name', 'update_filter_logging_enabled', 'update_filter_message_buffer_circular', 'update_filter_message_list_count', 'update_filtered_message_count', 'update_vrf_name'], name, value)


                                class FirstUpdateFilteredTimestamp(Entity):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "first-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-filtered-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateFilteredTimestamp(Entity):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "last-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-filtered-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateAttributeFilterAttributes(Entity):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                        self.yang_name = "update-attribute-filter-attributes"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-filter-match-timestamp" : ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp)}
                                        self._child_list_classes = {}

                                        self.establishment_update_filter_match_count = YLeaf(YType.uint32, "establishment-update-filter-match-count")

                                        self.last_update_filter_match_age = YLeaf(YType.uint32, "last-update-filter-match-age")

                                        self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")

                                        self.update_filter_match_count = YLeaf(YType.uint32, "update-filter-match-count")

                                        self.update_internal_attribute_code = YLeaf(YType.uint32, "update-internal-attribute-code")

                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                        self._children_yang_names.add("last-update-filter-match-timestamp")
                                        self._segment_path = lambda: "update-attribute-filter-attributes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, ['establishment_update_filter_match_count', 'last_update_filter_match_age', 'update_filter_action', 'update_filter_match_count', 'update_internal_attribute_code'], name, value)


                                    class LastUpdateFilterMatchTimestamp(Entity):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                            self.yang_name = "last-update-filter-match-timestamp"
                                            self.yang_parent_name = "update-attribute-filter-attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-filter-match-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateFilterMessage(Entity):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                        self.yang_name = "update-filter-message"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-filter-message-timestamp" : ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)}
                                        self._child_list_classes = {"update-filter-element" : ("update_filter_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement), "update-filter-message-data" : ("update_filter_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)}

                                        self.update_filter_final_action = YLeaf(YType.enumeration, "update-filter-final-action")

                                        self.update_filter_nlri_address_family = YLeaf(YType.enumeration, "update-filter-nlri-address-family")

                                        self.update_filter_nlri_string = YLeaf(YType.str, "update-filter-nlri-string")

                                        self.update_filter_nlri_string_truncated = YLeaf(YType.boolean, "update-filter-nlri-string-truncated")

                                        self.update_filtered_attribute_count = YLeaf(YType.uint32, "update-filtered-attribute-count")

                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"
                                        self._children_yang_names.add("update-filter-message-timestamp")

                                        self.update_filter_element = YList(self)
                                        self.update_filter_message_data = YList(self)
                                        self._segment_path = lambda: "update-filter-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, ['update_filter_final_action', 'update_filter_nlri_address_family', 'update_filter_nlri_string', 'update_filter_nlri_string_truncated', 'update_filtered_attribute_count'], name, value)


                                    class UpdateFilterElement(Entity):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                            self.yang_name = "update-filter-element"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                            self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                            self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")
                                            self._segment_path = lambda: "update-filter-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, ['update_attribute_code', 'update_attribute_flags', 'update_filter_action'], name, value)


                                    class UpdateFilterMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                            self.yang_name = "update-filter-message-data"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "update-filter-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, ['entry'], name, value)


                                    class UpdateFilterMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                            self.yang_name = "update-filter-message-timestamp"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "update-filter-message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundFilterVrf(Entity):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf, self).__init__()

                                self.yang_name = "update-inbound-filter-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp)}
                                self._child_list_classes = {}

                                self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._children_yang_names.add("last-update-filtered-timestamp")
                                self._segment_path = lambda: "update-inbound-filter-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count', 'update_vrf_name'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


            class InstanceStandby(Entity):
                """
                Standby BGP operational data
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf>`
                
                .. attribute:: rpki_refresh_afs
                
                	RPKI Refresh Table (per AF)
                	**type**\:   :py:class:`RpkiRefreshAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:   :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:   :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:   :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiSummary>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:   :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries>`
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:   :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:   :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:   :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.Instances.Instance.InstanceStandby, self).__init__()

                    self.yang_name = "instance-standby"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"attribute-filter-groups" : ("attribute_filter_groups", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceStandby.Attributes), "default-vrf" : ("default_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf), "rpki-refresh-afs" : ("rpki_refresh_afs", Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs), "rpki-routes" : ("rpki_routes", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes), "rpki-server-list" : ("rpki_server_list", Bgp.Instances.Instance.InstanceStandby.RpkiServerList), "rpki-summary" : ("rpki_summary", Bgp.Instances.Instance.InstanceStandby.RpkiSummary), "rt-entries" : ("rt_entries", Bgp.Instances.Instance.InstanceStandby.RtEntries), "update-generation-process" : ("update_generation_process", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess), "update-inbound-error-process" : ("update_inbound_error_process", Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess), "update-inbound-filter-process" : ("update_inbound_filter_process", Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess), "vrfs" : ("vrfs", Bgp.Instances.Instance.InstanceStandby.Vrfs)}
                    self._child_list_classes = {}

                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"
                    self._children_yang_names.add("attribute-filter-groups")

                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Attributes()
                    self.attributes.parent = self
                    self._children_name_map["attributes"] = "attributes"
                    self._children_yang_names.add("attributes")

                    self.default_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"
                    self._children_yang_names.add("default-vrf")

                    self.rpki_refresh_afs = Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs()
                    self.rpki_refresh_afs.parent = self
                    self._children_name_map["rpki_refresh_afs"] = "rpki-refresh-afs"
                    self._children_yang_names.add("rpki-refresh-afs")

                    self.rpki_routes = Bgp.Instances.Instance.InstanceStandby.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self._children_name_map["rpki_routes"] = "rpki-routes"
                    self._children_yang_names.add("rpki-routes")

                    self.rpki_server_list = Bgp.Instances.Instance.InstanceStandby.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self._children_name_map["rpki_server_list"] = "rpki-server-list"
                    self._children_yang_names.add("rpki-server-list")

                    self.rpki_summary = Bgp.Instances.Instance.InstanceStandby.RpkiSummary()
                    self.rpki_summary.parent = self
                    self._children_name_map["rpki_summary"] = "rpki-summary"
                    self._children_yang_names.add("rpki-summary")

                    self.rt_entries = Bgp.Instances.Instance.InstanceStandby.RtEntries()
                    self.rt_entries.parent = self
                    self._children_name_map["rt_entries"] = "rt-entries"
                    self._children_yang_names.add("rt-entries")

                    self.update_generation_process = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self._children_name_map["update_generation_process"] = "update-generation-process"
                    self._children_yang_names.add("update-generation-process")

                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self._children_name_map["update_inbound_error_process"] = "update-inbound-error-process"
                    self._children_yang_names.add("update-inbound-error-process")

                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self._children_name_map["update_inbound_filter_process"] = "update-inbound-filter-process"
                    self._children_yang_names.add("update-inbound-filter-process")

                    self.vrfs = Bgp.Instances.Instance.InstanceStandby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                    self._children_yang_names.add("vrfs")
                    self._segment_path = lambda: "instance-standby"


                class AttributeFilterGroups(Entity):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups, self).__init__()

                        self.yang_name = "attribute-filter-groups"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"attribute-filter-group" : ("attribute_filter_group", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup)}

                        self.attribute_filter_group = YList(self)
                        self._segment_path = lambda: "attribute-filter-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups, [], name, value)


                    class AttributeFilterGroup(Entity):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  <key>
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of    :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                            self.yang_name = "attribute-filter-group"
                            self.yang_parent_name = "attribute-filter-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"attribute-filter-entry" : ("attribute_filter_entry", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry)}

                            self.group_name = YLeaf(YType.str, "group-name")

                            self.attribute_filter_group_name = YLeaf(YType.str, "attribute-filter-group-name")

                            self.attribute_filter_total_group_count = YLeaf(YType.uint32, "attribute-filter-total-group-count")

                            self.attribute_filter_entry = YList(self)
                            self._segment_path = lambda: "attribute-filter-group" + "[group-name='" + self.group_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup, ['group_name', 'attribute_filter_group_name', 'attribute_filter_total_group_count'], name, value)


                        class AttributeFilterEntry(Entity):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, self).__init__()

                                self.yang_name = "attribute-filter-entry"
                                self.yang_parent_name = "attribute-filter-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.attribute_filter_entry_range_end = YLeaf(YType.uint32, "attribute-filter-entry-range-end")

                                self.attribute_filter_entry_range_start = YLeaf(YType.uint32, "attribute-filter-entry-range-start")

                                self.attribute_filter_entry_requested_action = YLeaf(YType.enumeration, "attribute-filter-entry-requested-action")
                                self._segment_path = lambda: "attribute-filter-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, ['attribute_filter_entry_range_end', 'attribute_filter_entry_range_start', 'attribute_filter_entry_requested_action'], name, value)


                class Attributes(Entity):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.Attributes, self).__init__()

                        self.yang_name = "attributes"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute)}

                        self.attribute = YList(self)
                        self._segment_path = lambda: "attributes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes, [], name, value)


                    class Attribute(Entity):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo)}
                            self._child_list_classes = {}

                            self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                            self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                            self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                            self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                            self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                            self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                            self.reference_count = YLeaf(YType.uint32, "reference-count")

                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self._children_name_map["attribute_info"] = "attribute-info"
                            self._children_yang_names.add("attribute-info")
                            self._segment_path = lambda: "attribute"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                        class AttributeInfo(Entity):
                            """
                            Attributes
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\:  bool
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\:  bool
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\:  bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\:  bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\:  bool
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo, self).__init__()

                                self.yang_name = "attribute-info"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                self._child_list_classes = {}

                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self._children_name_map["attr_set"] = "attr-set"
                                self._children_yang_names.add("attr-set")

                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self._children_name_map["common_attributes"] = "common-attributes"
                                self._children_yang_names.add("common-attributes")

                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                self._children_yang_names.add("ribrnh-ip")

                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                self._children_yang_names.add("rnh-addr")
                                self._segment_path = lambda: "attribute-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                            class AttrSet(Entity):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                    self.yang_name = "attr-set"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                    self.as_path = YLeaf(YType.str, "as-path")

                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                    self.origin = YLeaf(YType.uint16, "origin")

                                    self.originator = YLeaf(YType.str, "originator")

                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                    self._children_yang_names.add("tunnel-encap")

                                    self.cluster = YList(self)
                                    self.community = YList(self)
                                    self.connector_value = YList(self)
                                    self.extended_community = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.label_index_attr = YList(self)
                                    self.large_community = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self._segment_path = lambda: "attr-set"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "cluster"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "connector-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                class L2Tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "l2tpv3-cookie"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                class LabelIndexAttr(Entity):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                        self.yang_name = "label-index-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "label-index-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                        self._segment_path = lambda: "large-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "ls-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                        self._segment_path = lambda: "pe-distinguisher-label"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "pmsi-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                        self._child_list_classes = {}

                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._children_yang_names.add("sr-policy")
                                        self._segment_path = lambda: "tunnel-encap"


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\:  bool
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                            self.preference = YLeaf(YType.uint32, "preference")

                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                            self.state = YLeaf(YType.boolean, "state")

                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                            self._children_yang_names.add("allocated-binding-sid")

                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"
                                            self._children_yang_names.add("binding-sid")

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "allocated-binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                self.weight = YLeaf(YType.uint8, "weight")

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.type = YLeaf(YType.enumeration, "type")
                                                    self._segment_path = lambda: "segment"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "unknown-attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                            class CommonAttributes(Entity):
                                """
                                Common attributes
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                    self.yang_name = "common-attributes"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                    self.as_path = YLeaf(YType.str, "as-path")

                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                    self.origin = YLeaf(YType.uint16, "origin")

                                    self.originator = YLeaf(YType.str, "originator")

                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                    self._children_yang_names.add("tunnel-encap")

                                    self.cluster = YList(self)
                                    self.community = YList(self)
                                    self.connector_value = YList(self)
                                    self.extended_community = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.label_index_attr = YList(self)
                                    self.large_community = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self._segment_path = lambda: "common-attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "cluster"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "connector-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                class L2Tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "l2tpv3-cookie"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                class LabelIndexAttr(Entity):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                        self.yang_name = "label-index-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "label-index-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                        self._segment_path = lambda: "large-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "ls-attr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                        self._segment_path = lambda: "pe-distinguisher-label"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "pmsi-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                        self._child_list_classes = {}

                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._children_yang_names.add("sr-policy")
                                        self._segment_path = lambda: "tunnel-encap"


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\:  bool
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                            self.preference = YLeaf(YType.uint32, "preference")

                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                            self.state = YLeaf(YType.boolean, "state")

                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                            self._children_yang_names.add("allocated-binding-sid")

                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"
                                            self._children_yang_names.add("binding-sid")

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "allocated-binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.label = YLeaf(YType.uint32, "label")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "binding-sid"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                self.weight = YLeaf(YType.uint8, "weight")

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.type = YLeaf(YType.enumeration, "type")
                                                    self._segment_path = lambda: "segment"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "unknown-attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                            class RibrnhIp(Entity):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                    self.yang_name = "ribrnh-ip"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "ribrnh-ip"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RnhAddr(Entity):
                                """
                                RNH Address
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                    self.yang_name = "rnh-addr"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.len = YLeaf(YType.enumeration, "len")

                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                    self._segment_path = lambda: "rnh-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                class DefaultVrf(Entity):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"afs" : ("afs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs), "bmp" : ("bmp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp), "global-process-info" : ("global_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo), "information" : ("information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information), "message-logs" : ("message_logs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs), "neighbor-ranges" : ("neighbor_ranges", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges), "neighbors" : ("neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors), "next-hop-vrf" : ("next_hop_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf), "postits" : ("postits", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits), "process-info" : ("process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo), "sessions" : ("sessions", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions), "update-inbound-error-neighbors" : ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors), "update-inbound-error-vrf" : ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf), "update-inbound-filter-neighbors" : ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors), "update-inbound-filter-vrf" : ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf)}
                        self._child_list_classes = {}

                        self.afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"
                        self._children_yang_names.add("afs")

                        self.bmp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self._children_name_map["bmp"] = "bmp"
                        self._children_yang_names.add("bmp")

                        self.global_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self._children_name_map["global_process_info"] = "global-process-info"
                        self._children_yang_names.add("global-process-info")

                        self.information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information()
                        self.information.parent = self
                        self._children_name_map["information"] = "information"
                        self._children_yang_names.add("information")

                        self.message_logs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self._children_name_map["message_logs"] = "message-logs"
                        self._children_yang_names.add("message-logs")

                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self._children_name_map["neighbor_ranges"] = "neighbor-ranges"
                        self._children_yang_names.add("neighbor-ranges")

                        self.neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self._children_name_map["next_hop_vrf"] = "next-hop-vrf"
                        self._children_yang_names.add("next-hop-vrf")

                        self.postits = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits()
                        self.postits.parent = self
                        self._children_name_map["postits"] = "postits"
                        self._children_yang_names.add("postits")

                        self.process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self._children_name_map["process_info"] = "process-info"
                        self._children_yang_names.add("process-info")

                        self.sessions = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self._children_name_map["sessions"] = "sessions"
                        self._children_yang_names.add("sessions")

                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"
                        self._children_yang_names.add("update-inbound-error-neighbors")

                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"
                        self._children_yang_names.add("update-inbound-error-vrf")

                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"
                        self._children_yang_names.add("update-inbound-filter-neighbors")

                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self
                        self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"
                        self._children_yang_names.add("update-inbound-filter-vrf")
                        self._segment_path = lambda: "default-vrf"


                    class Afs(Entity):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"af" : ("af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af)}

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address family
                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes>`
                            
                            .. attribute:: bmp_path_table_generic
                            
                            	Summary Info about BMP Table
                            	**type**\:   :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: network_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds>`
                            
                            .. attribute:: network_lookup_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds>`
                            
                            .. attribute:: network_prefixes
                            
                            	The BGP Network Lookup table
                            	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"advertised-path-counts" : ("advertised_path_counts", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts), "advertised-path-xr" : ("advertised_path_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr), "advertised-paths" : ("advertised_paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths), "af-process-info" : ("af_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes), "bmp-path-table-generic" : ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric), "bmp-paths" : ("bmp_paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths), "convergence" : ("convergence", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence), "dampenings" : ("dampenings", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings), "epes" : ("epes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes), "global-af-process-info" : ("global_af_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo), "neighbor-af-table" : ("neighbor_af_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable), "network-all-rds" : ("network_all_rds", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds), "network-lookup-all-rds" : ("network_lookup_all_rds", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds), "network-prefixes" : ("network_prefixes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes), "networks" : ("networks", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks), "next-hop-address-families" : ("next_hop_address_families", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies), "path-labeled-table" : ("path_labeled_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable), "path-table" : ("path_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable), "path-used-table" : ("path_used_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable), "policies" : ("policies", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies), "prefix-filters" : ("prefix_filters", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters), "rpc-sets" : ("rpc_sets", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets), "rt-set-counters" : ("rt_set_counters", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters), "sourced-networks" : ("sourced_networks", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks), "update-generation-address-family" : ("update_generation_address_family", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily), "update-generation-filter-groups" : ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups), "update-generation-neighbors" : ("update_generation_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors), "update-generation-sub-groups" : ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups), "update-generation-update-groups" : ("update_generation_update_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups), "update-groups" : ("update_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups)}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self._children_name_map["advertised_path_counts"] = "advertised-path-counts"
                                self._children_yang_names.add("advertised-path-counts")

                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self._children_name_map["advertised_path_xr"] = "advertised-path-xr"
                                self._children_yang_names.add("advertised-path-xr")

                                self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self._children_name_map["advertised_paths"] = "advertised-paths"
                                self._children_yang_names.add("advertised-paths")

                                self.af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self._children_name_map["af_process_info"] = "af-process-info"
                                self._children_yang_names.add("af-process-info")

                                self.attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self._children_name_map["attributes"] = "attributes"
                                self._children_yang_names.add("attributes")

                                self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric()
                                self.bmp_path_table_generic.parent = self
                                self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"
                                self._children_yang_names.add("bmp-path-table-generic")

                                self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self._children_name_map["bmp_paths"] = "bmp-paths"
                                self._children_yang_names.add("bmp-paths")

                                self.convergence = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self._children_name_map["convergence"] = "convergence"
                                self._children_yang_names.add("convergence")

                                self.dampenings = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self._children_name_map["dampenings"] = "dampenings"
                                self._children_yang_names.add("dampenings")

                                self.epes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self._children_name_map["epes"] = "epes"
                                self._children_yang_names.add("epes")

                                self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self._children_name_map["global_af_process_info"] = "global-af-process-info"
                                self._children_yang_names.add("global-af-process-info")

                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self._children_name_map["neighbor_af_table"] = "neighbor-af-table"
                                self._children_yang_names.add("neighbor-af-table")

                                self.network_all_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds()
                                self.network_all_rds.parent = self
                                self._children_name_map["network_all_rds"] = "network-all-rds"
                                self._children_yang_names.add("network-all-rds")

                                self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds()
                                self.network_lookup_all_rds.parent = self
                                self._children_name_map["network_lookup_all_rds"] = "network-lookup-all-rds"
                                self._children_yang_names.add("network-lookup-all-rds")

                                self.network_prefixes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes()
                                self.network_prefixes.parent = self
                                self._children_name_map["network_prefixes"] = "network-prefixes"
                                self._children_yang_names.add("network-prefixes")

                                self.networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self._children_name_map["networks"] = "networks"
                                self._children_yang_names.add("networks")

                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self._children_name_map["next_hop_address_families"] = "next-hop-address-families"
                                self._children_yang_names.add("next-hop-address-families")

                                self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self._children_name_map["path_labeled_table"] = "path-labeled-table"
                                self._children_yang_names.add("path-labeled-table")

                                self.path_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self._children_name_map["path_table"] = "path-table"
                                self._children_yang_names.add("path-table")

                                self.path_used_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self._children_name_map["path_used_table"] = "path-used-table"
                                self._children_yang_names.add("path-used-table")

                                self.policies = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self._children_name_map["policies"] = "policies"
                                self._children_yang_names.add("policies")

                                self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self._children_name_map["prefix_filters"] = "prefix-filters"
                                self._children_yang_names.add("prefix-filters")

                                self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self._children_name_map["rpc_sets"] = "rpc-sets"
                                self._children_yang_names.add("rpc-sets")

                                self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self._children_name_map["rt_set_counters"] = "rt-set-counters"
                                self._children_yang_names.add("rt-set-counters")

                                self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self._children_name_map["sourced_networks"] = "sourced-networks"
                                self._children_yang_names.add("sourced-networks")

                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self._children_name_map["update_generation_address_family"] = "update-generation-address-family"
                                self._children_yang_names.add("update-generation-address-family")

                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"
                                self._children_yang_names.add("update-generation-filter-groups")

                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"
                                self._children_yang_names.add("update-generation-neighbors")

                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"
                                self._children_yang_names.add("update-generation-sub-groups")

                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"
                                self._children_yang_names.add("update-generation-update-groups")

                                self.update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self
                                self._children_name_map["update_groups"] = "update-groups"
                                self._children_yang_names.add("update-groups")
                                self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af, ['af_name'], name, value)


                            class AdvertisedPathCounts(Entity):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                    self.yang_name = "advertised-path-counts"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path-count" : ("advertised_path_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount)}

                                    self.advertised_path_count = YList(self)
                                    self._segment_path = lambda: "advertised-path-counts"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                class AdvertisedPathCount(Entity):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                        self.yang_name = "advertised-path-count"
                                        self.yang_parent_name = "advertised-path-counts"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.max_prefix_advertisedcount = YLeaf(YType.uint32, "max-prefix-advertisedcount")
                                        self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', 'max_prefix_advertisedcount'], name, value)


                            class AdvertisedPathXr(Entity):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                    self.yang_name = "advertised-path-xr"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath)}

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-path-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-path-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "advertised-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AdvertisedPaths(Entity):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths, self).__init__()

                                    self.yang_name = "advertised-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath)}

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-paths"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"adv-path-info" : ("adv_path_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo), "paths" : ("paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.adv_path_info = YList(self)
                                        self.paths = YList(self)
                                        self._segment_path = lambda: "advertised-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['neighbor_address', 'network', 'prefix_length', 'rd'], name, value)


                                    class AdvPathInfo(Entity):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                            self.yang_name = "adv-path-info"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._children_yang_names.add("attributes-after-policy-out")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                            self._children_yang_names.add("path-info-after-policy-in")

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                            self._children_yang_names.add("path-info-after-policy-out")
                                            self._segment_path = lambda: "adv-path-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, ['af_name', 'no_path', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class Paths(Entity):
                                        """
                                        paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "paths"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class AfProcessInfo(Entity):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo, self).__init__()

                                    self.yang_name = "af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.process_instance = YLeaf(YType.uint8, "process-instance")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._children_yang_names.add("performance-statistics")

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "af-process-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo, ['af_name', 'process_instance', 'vrf_name', 'vrf_totals'], name, value)


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v4_next_hop
                                    
                                    	Max supported label stack depth for IPv4 Nexthop
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v6_next_hop
                                    
                                    	Max supported label stack depth for IPv6 Nexthop
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_bgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:   :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall), "trigger-import" : ("trigger_import", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport), "trigger-label" : ("trigger_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel), "trigger-rib" : ("trigger_rib", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib), "trigger-update" : ("trigger_update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate), "version-wrap-done-time-spec" : ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec), "version-wrap-start-time-spec" : ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec), "version-wrap-time-spec" : ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec)}
                                        self._child_list_classes = {}

                                        self.freed_rd_count = YLeaf(YType.uint32, "freed-rd-count")

                                        self.import_bgp_version = YLeaf(YType.uint32, "import-bgp-version")

                                        self.import_last_trigger = YLeaf(YType.uint64, "import-last-trigger")

                                        self.import_triggers = YLeaf(YType.uint32, "import-triggers")

                                        self.import_version = YLeaf(YType.uint32, "import-version")

                                        self.imported_paths_memory = YLeaf(YType.uint32, "imported-paths-memory")

                                        self.imported_paths_num = YLeaf(YType.uint32, "imported-paths-num")

                                        self.label_bgp_version = YLeaf(YType.uint32, "label-bgp-version")

                                        self.label_last_trigger = YLeaf(YType.uint64, "label-last-trigger")

                                        self.label_triggers = YLeaf(YType.uint32, "label-triggers")

                                        self.label_version = YLeaf(YType.uint32, "label-version")

                                        self.last_import_version = YLeaf(YType.uint32, "last-import-version")

                                        self.last_label_version = YLeaf(YType.uint32, "last-label-version")

                                        self.last_rib_version = YLeaf(YType.uint32, "last-rib-version")

                                        self.local_networks_freed_num = YLeaf(YType.uint32, "local-networks-freed-num")

                                        self.local_networks_malloced_num = YLeaf(YType.uint32, "local-networks-malloced-num")

                                        self.local_networks_memory = YLeaf(YType.uint32, "local-networks-memory")

                                        self.local_networks_num = YLeaf(YType.uint32, "local-networks-num")

                                        self.local_paths_freed_num = YLeaf(YType.uint32, "local-paths-freed-num")

                                        self.local_paths_malloced_num = YLeaf(YType.uint32, "local-paths-malloced-num")

                                        self.local_paths_memory = YLeaf(YType.uint32, "local-paths-memory")

                                        self.local_paths_num = YLeaf(YType.uint32, "local-paths-num")

                                        self.malloced_rd_count = YLeaf(YType.uint32, "malloced-rd-count")

                                        self.max_active_pelem_version = YLeaf(YType.uint32, "max-active-pelem-version")

                                        self.max_label_stack_depth_v4_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v4-next-hop")

                                        self.max_label_stack_depth_v6_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v6-next-hop")

                                        self.merged_table_version = YLeaf(YType.uint32, "merged-table-version")

                                        self.multipath_network_entry_count = YLeaf(YType.uint32, "multipath-network-entry-count")

                                        self.multipath_network_entry_memory = YLeaf(YType.uint32, "multipath-network-entry-memory")

                                        self.multipath_paths_count = YLeaf(YType.uint32, "multipath-paths-count")

                                        self.multipath_paths_memory = YLeaf(YType.uint32, "multipath-paths-memory")

                                        self.networks_freed_num = YLeaf(YType.uint32, "networks-freed-num")

                                        self.networks_malloced_num = YLeaf(YType.uint32, "networks-malloced-num")

                                        self.networks_memory = YLeaf(YType.uint32, "networks-memory")

                                        self.networks_num = YLeaf(YType.uint32, "networks-num")

                                        self.num_init_sync_pfx = YLeaf(YType.uint32, "num-init-sync-pfx")

                                        self.path_elems_freed_num = YLeaf(YType.uint32, "path-elems-freed-num")

                                        self.path_elems_malloced_num = YLeaf(YType.uint32, "path-elems-malloced-num")

                                        self.path_elems_memory = YLeaf(YType.uint32, "path-elems-memory")

                                        self.path_elems_num = YLeaf(YType.uint32, "path-elems-num")

                                        self.paths_freed_num = YLeaf(YType.uint32, "paths-freed-num")

                                        self.paths_malloced_num = YLeaf(YType.uint32, "paths-malloced-num")

                                        self.paths_memory = YLeaf(YType.uint32, "paths-memory")

                                        self.paths_num = YLeaf(YType.uint32, "paths-num")

                                        self.rd_memory = YLeaf(YType.uint32, "rd-memory")

                                        self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                        self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                        self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                        self.rib_bgp_version = YLeaf(YType.uint32, "rib-bgp-version")

                                        self.rib_brib_received_version = YLeaf(YType.uint32, "rib-brib-received-version")

                                        self.rib_last_trigger = YLeaf(YType.uint64, "rib-last-trigger")

                                        self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                        self.rib_triggers = YLeaf(YType.uint32, "rib-triggers")

                                        self.route_download_go_active_done_pending = YLeaf(YType.uint32, "route-download-go-active-done-pending")

                                        self.router_state = YLeaf(YType.enumeration, "router-state")

                                        self.send_version = YLeaf(YType.uint32, "send-version")

                                        self.standby_version = YLeaf(YType.uint32, "standby-version")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.total_r_ds_num = YLeaf(YType.uint32, "total-r-ds-num")

                                        self.total_remote_r_ds_num = YLeaf(YType.uint32, "total-remote-r-ds-num")

                                        self.total_same_r_ds_num = YLeaf(YType.uint32, "total-same-r-ds-num")

                                        self.update_gen_bgp_version = YLeaf(YType.uint32, "update-gen-bgp-version")

                                        self.update_gen_last_trigger = YLeaf(YType.uint64, "update-gen-last-trigger")

                                        self.update_triggers = YLeaf(YType.uint32, "update-triggers")

                                        self.update_wait_install_enabled = YLeaf(YType.uint32, "update-wait-install-enabled")

                                        self.version_wrapped = YLeaf(YType.uint32, "version-wrapped")

                                        self.version_wrapped_tid = YLeaf(YType.uint32, "version-wrapped-tid")

                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._children_yang_names.add("rib-install")

                                        self.trigger_import = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                        self.trigger_import.parent = self
                                        self._children_name_map["trigger_import"] = "trigger-import"
                                        self._children_yang_names.add("trigger-import")

                                        self.trigger_label = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self._children_name_map["trigger_label"] = "trigger-label"
                                        self._children_yang_names.add("trigger-label")

                                        self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self._children_name_map["trigger_rib"] = "trigger-rib"
                                        self._children_yang_names.add("trigger-rib")

                                        self.trigger_update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self._children_name_map["trigger_update"] = "trigger-update"
                                        self._children_yang_names.add("trigger-update")

                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"
                                        self._children_yang_names.add("version-wrap-done-time-spec")

                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"
                                        self._children_yang_names.add("version-wrap-start-time-spec")

                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"
                                        self._children_yang_names.add("version-wrap-time-spec")
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_, ['freed_rd_count', 'import_bgp_version', 'import_last_trigger', 'import_triggers', 'import_version', 'imported_paths_memory', 'imported_paths_num', 'label_bgp_version', 'label_last_trigger', 'label_triggers', 'label_version', 'last_import_version', 'last_label_version', 'last_rib_version', 'local_networks_freed_num', 'local_networks_malloced_num', 'local_networks_memory', 'local_networks_num', 'local_paths_freed_num', 'local_paths_malloced_num', 'local_paths_memory', 'local_paths_num', 'malloced_rd_count', 'max_active_pelem_version', 'max_label_stack_depth_v4_next_hop', 'max_label_stack_depth_v6_next_hop', 'merged_table_version', 'multipath_network_entry_count', 'multipath_network_entry_memory', 'multipath_paths_count', 'multipath_paths_memory', 'networks_freed_num', 'networks_malloced_num', 'networks_memory', 'networks_num', 'num_init_sync_pfx', 'path_elems_freed_num', 'path_elems_malloced_num', 'path_elems_memory', 'path_elems_num', 'paths_freed_num', 'paths_malloced_num', 'paths_memory', 'paths_num', 'rd_memory', 'rib_ack_requests', 'rib_acked_table_version', 'rib_acks_received', 'rib_bgp_version', 'rib_brib_received_version', 'rib_last_trigger', 'rib_slow_acks', 'rib_triggers', 'route_download_go_active_done_pending', 'router_state', 'send_version', 'standby_version', 'table_brib_version', 'table_version', 'total_r_ds_num', 'total_remote_r_ds_num', 'total_same_r_ds_num', 'update_gen_bgp_version', 'update_gen_last_trigger', 'update_triggers', 'update_wait_install_enabled', 'version_wrapped', 'version_wrapped_tid'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime)}
                                            self._child_list_classes = {}

                                            self.installed_count = YLeaf(YType.uint32, "installed-count")

                                            self.modified_count = YLeaf(YType.uint32, "modified-count")

                                            self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                            self.start_version = YLeaf(YType.uint32, "start-version")

                                            self.target_version = YLeaf(YType.uint32, "target-version")

                                            self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._children_yang_names.add("install-time")

                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"
                                            self._children_yang_names.add("update-time")
                                            self._segment_path = lambda: "rib-install"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "install-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerImport(Entity):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, self).__init__()

                                            self.yang_name = "trigger-import"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerLabel(Entity):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, self).__init__()

                                            self.yang_name = "trigger-label"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-label"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-label"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerRib(Entity):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, self).__init__()

                                            self.yang_name = "trigger-rib"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-rib"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-rib"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TriggerUpdate(Entity):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, self).__init__()

                                            self.yang_name = "trigger-update"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic)}

                                            self.triggers = YLeaf(YType.uint32, "triggers")

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-update"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, ['triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec)}
                                                self._child_list_classes = {}

                                                self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._children_yang_names.add("trigger-time-spec")
                                                self._segment_path = lambda: "statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "trigger-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-done-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-start-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-start-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class VersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-wrap-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf)}
                                        self._child_list_classes = {}

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "performance-statistics"


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mode-enter-time" : ("mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime), "total-pim-callback-add" : ("total_pim_callback_add", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd), "total-pim-callback-add-local" : ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal), "total-pim-callback-del" : ("total_pim_callback_del", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel), "total-pim-callback-del-local" : ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal), "total-pim-install-add" : ("total_pim_install_add", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd), "total-pim-install-del" : ("total_pim_install_del", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel)}

                                            self.first_nbr_up_time = YLeaf(YType.uint32, "first-nbr-up-time")

                                            self.has_converged = YLeaf(YType.boolean, "has-converged")

                                            self.total_pim_callback_batch = YLeaf(YType.uint32, "total-pim-callback-batch")

                                            self.total_pim_callbacks = YLeaf(YType.uint32, "total-pim-callbacks")

                                            self.total_pim_install = YLeaf(YType.uint32, "total-pim-install")

                                            self.mode_enter_time = YList(self)
                                            self.total_pim_callback_add = YList(self)
                                            self.total_pim_callback_add_local = YList(self)
                                            self.total_pim_callback_del = YList(self)
                                            self.total_pim_callback_del_local = YList(self)
                                            self.total_pim_install_add = YList(self)
                                            self.total_pim_install_del = YList(self)
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, ['first_nbr_up_time', 'has_converged', 'total_pim_callback_batch', 'total_pim_callbacks', 'total_pim_install'], name, value)


                                        class ModeEnterTime(Entity):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, self).__init__()

                                                self.yang_name = "mode-enter-time"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "mode-enter-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, ['entry'], name, value)


                                        class TotalPimCallbackAdd(Entity):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, self).__init__()

                                                self.yang_name = "total-pim-callback-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-add"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, ['entry'], name, value)


                                        class TotalPimCallbackAddLocal(Entity):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-add-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-add-local"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, ['entry'], name, value)


                                        class TotalPimCallbackDel(Entity):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, self).__init__()

                                                self.yang_name = "total-pim-callback-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-del"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, ['entry'], name, value)


                                        class TotalPimCallbackDelLocal(Entity):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-del-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-callback-del-local"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, ['entry'], name, value)


                                        class TotalPimInstallAdd(Entity):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, self).__init__()

                                                self.yang_name = "total-pim-install-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-install-add"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, ['entry'], name, value)


                                        class TotalPimInstallDel(Entity):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, self).__init__()

                                                self.yang_name = "total-pim-install-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "total-pim-install-del"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, ['entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_not_sent_to_rib
                                        
                                        	No. of prefixes not sent to RIB due to unsupported label stack size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-table-full-timestamp" : ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp), "first-rib-table-has-space-timestamp" : ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp), "last-rib-table-full-timestamp" : ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp), "last-rib-table-has-space-timestamp" : ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp), "time-label-retain" : ("time_label_retain", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain), "time-rib-coverged" : ("time_rib_coverged", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged), "time-rib-down" : ("time_rib_down", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)}
                                            self._child_list_classes = {}

                                            self.attributes_recover_from_rib = YLeaf(YType.uint32, "attributes-recover-from-rib")

                                            self.attributes_removed_from_rib = YLeaf(YType.uint32, "attributes-removed-from-rib")

                                            self.attributes_sent_to_rib = YLeaf(YType.uint32, "attributes-sent-to-rib")

                                            self.first_rib_table_full_version = YLeaf(YType.uint32, "first-rib-table-full-version")

                                            self.first_rib_table_has_space_version = YLeaf(YType.uint32, "first-rib-table-has-space-version")

                                            self.import_added_path_count = YLeaf(YType.uint32, "import-added-path-count")

                                            self.import_calls = YLeaf(YType.uint32, "import-calls")

                                            self.import_dest_net_processed_count = YLeaf(YType.uint32, "import-dest-net-processed-count")

                                            self.import_removed_path_count = YLeaf(YType.uint32, "import-removed-path-count")

                                            self.import_replaced_path_count = YLeaf(YType.uint32, "import-replaced-path-count")

                                            self.import_src_net_processed_count = YLeaf(YType.uint32, "import-src-net-processed-count")

                                            self.import_time = YLeaf(YType.uint32, "import-time")

                                            self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                            self.label_added_count = YLeaf(YType.uint32, "label-added-count")

                                            self.label_calls = YLeaf(YType.uint32, "label-calls")

                                            self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                            self.label_rewrite_count = YLeaf(YType.uint32, "label-rewrite-count")

                                            self.label_time = YLeaf(YType.uint32, "label-time")

                                            self.last_rib_table_full_age = YLeaf(YType.uint32, "last-rib-table-full-age")

                                            self.last_rib_table_full_version = YLeaf(YType.uint32, "last-rib-table-full-version")

                                            self.last_rib_table_has_space_age = YLeaf(YType.uint32, "last-rib-table-has-space-age")

                                            self.last_rib_table_has_space_version = YLeaf(YType.uint32, "last-rib-table-has-space-version")

                                            self.prefixes_not_sent_to_rib = YLeaf(YType.uint32, "prefixes-not-sent-to-rib")

                                            self.prefixes_removed_from_rib = YLeaf(YType.uint32, "prefixes-removed-from-rib")

                                            self.prefixes_resent_to_rib = YLeaf(YType.uint32, "prefixes-resent-to-rib")

                                            self.prefixes_sent_to_rib = YLeaf(YType.uint32, "prefixes-sent-to-rib")

                                            self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                            self.rib_tbl_del_calls = YLeaf(YType.uint32, "rib-tbl-del-calls")

                                            self.rib_tbl_invalid_calls = YLeaf(YType.uint32, "rib-tbl-invalid-calls")

                                            self.rib_tbl_local_label = YLeaf(YType.uint32, "rib-tbl-local-label")

                                            self.rib_tbl_retry = YLeaf(YType.uint32, "rib-tbl-retry")

                                            self.rib_tbl_skip_calls = YLeaf(YType.uint32, "rib-tbl-skip-calls")

                                            self.rib_trigger = YLeaf(YType.boolean, "rib-trigger")

                                            self.rib_update_calls = YLeaf(YType.uint32, "rib-update-calls")

                                            self.rib_update_time = YLeaf(YType.uint32, "rib-update-time")

                                            self.scanner_runs = YLeaf(YType.uint32, "scanner-runs")

                                            self.scanner_time = YLeaf(YType.uint32, "scanner-time")

                                            self.subgroup_count = YLeaf(YType.uint32, "subgroup-count")

                                            self.time_last_update_sent = YLeaf(YType.uint32, "time-last-update-sent")

                                            self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                            self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                            self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                            self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                            self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                            self.update_group_count = YLeaf(YType.uint32, "update-group-count")

                                            self.vrf_flags = YLeaf(YType.uint32, "vrf-flags")

                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"
                                            self._children_yang_names.add("first-rib-table-full-timestamp")

                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"
                                            self._children_yang_names.add("first-rib-table-has-space-timestamp")

                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"
                                            self._children_yang_names.add("last-rib-table-full-timestamp")

                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"
                                            self._children_yang_names.add("last-rib-table-has-space-timestamp")

                                            self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self._children_name_map["time_label_retain"] = "time-label-retain"
                                            self._children_yang_names.add("time-label-retain")

                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self._children_name_map["time_rib_coverged"] = "time-rib-coverged"
                                            self._children_yang_names.add("time-rib-coverged")

                                            self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self._children_name_map["time_rib_down"] = "time-rib-down"
                                            self._children_yang_names.add("time-rib-down")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, ['attributes_recover_from_rib', 'attributes_removed_from_rib', 'attributes_sent_to_rib', 'first_rib_table_full_version', 'first_rib_table_has_space_version', 'import_added_path_count', 'import_calls', 'import_dest_net_processed_count', 'import_removed_path_count', 'import_replaced_path_count', 'import_src_net_processed_count', 'import_time', 'is_rib_table_full', 'label_added_count', 'label_calls', 'label_release_count', 'label_rewrite_count', 'label_time', 'last_rib_table_full_age', 'last_rib_table_full_version', 'last_rib_table_has_space_age', 'last_rib_table_has_space_version', 'prefixes_not_sent_to_rib', 'prefixes_removed_from_rib', 'prefixes_resent_to_rib', 'prefixes_sent_to_rib', 'rib_table_full_version', 'rib_tbl_del_calls', 'rib_tbl_invalid_calls', 'rib_tbl_local_label', 'rib_tbl_retry', 'rib_tbl_skip_calls', 'rib_trigger', 'rib_update_calls', 'rib_update_time', 'scanner_runs', 'scanner_time', 'subgroup_count', 'time_last_update_sent', 'update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'update_group_count', 'vrf_flags'], name, value)


                                        class FirstRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-table-full-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-table-has-space-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-table-full-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-table-has-space-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class TimeLabelRetain(Entity):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                self.yang_name = "time-label-retain"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-label-retain"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, ['nanoseconds', 'seconds'], name, value)


                                        class TimeRibCoverged(Entity):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                self.yang_name = "time-rib-coverged"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-rib-coverged"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, ['nanoseconds', 'seconds'], name, value)


                                        class TimeRibDown(Entity):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                self.yang_name = "time-rib-down"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "time-rib-down"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, ['nanoseconds', 'seconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\:  bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.add_path_install_disable = YLeaf(YType.boolean, "add-path-install-disable")

                                        self.add_path_install_enable = YLeaf(YType.boolean, "add-path-install-enable")

                                        self.any_ebgp_neighbor_missing_policy = YLeaf(YType.boolean, "any-ebgp-neighbor-missing-policy")

                                        self.asbr = YLeaf(YType.boolean, "asbr")

                                        self.attribute_download = YLeaf(YType.boolean, "attribute-download")

                                        self.best_external = YLeaf(YType.boolean, "best-external")

                                        self.best_external_disable = YLeaf(YType.boolean, "best-external-disable")

                                        self.bmp_network_entry_count = YLeaf(YType.uint32, "bmp-network-entry-count")

                                        self.bmp_path_memory = YLeaf(YType.uint32, "bmp-path-memory")

                                        self.bmp_paths_count = YLeaf(YType.uint32, "bmp-paths-count")

                                        self.bmp_prefix_memory = YLeaf(YType.uint32, "bmp-prefix-memory")

                                        self.damped_path_count = YLeaf(YType.uint32, "damped-path-count")

                                        self.freed_path_count = YLeaf(YType.uint32, "freed-path-count")

                                        self.freed_path_elem_count = YLeaf(YType.uint32, "freed-path-elem-count")

                                        self.freed_prefix_count = YLeaf(YType.uint32, "freed-prefix-count")

                                        self.history_path_count = YLeaf(YType.uint32, "history-path-count")

                                        self.ibgp_nexthop_self_count = YLeaf(YType.uint32, "ibgp-nexthop-self-count")

                                        self.imported_path_memory = YLeaf(YType.uint32, "imported-path-memory")

                                        self.imported_paths = YLeaf(YType.uint32, "imported-paths")

                                        self.is_route_reflector = YLeaf(YType.boolean, "is-route-reflector")

                                        self.label_retain = YLeaf(YType.boolean, "label-retain")

                                        self.label_retainvalue = YLeaf(YType.uint32, "label-retainvalue")

                                        self.local_path_memory = YLeaf(YType.uint32, "local-path-memory")

                                        self.local_paths = YLeaf(YType.uint32, "local-paths")

                                        self.malloced_path_count = YLeaf(YType.uint32, "malloced-path-count")

                                        self.malloced_path_elem_count = YLeaf(YType.uint32, "malloced-path-elem-count")

                                        self.malloced_prefix_count = YLeaf(YType.uint32, "malloced-prefix-count")

                                        self.network_entry_count = YLeaf(YType.uint32, "network-entry-count")

                                        self.path_elem_memory = YLeaf(YType.uint32, "path-elem-memory")

                                        self.path_elems_count = YLeaf(YType.uint32, "path-elems-count")

                                        self.path_memory = YLeaf(YType.uint32, "path-memory")

                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                        self.prefix_memory = YLeaf(YType.uint32, "prefix-memory")

                                        self.received_path_count = YLeaf(YType.uint32, "received-path-count")

                                        self.retain_rt_all = YLeaf(YType.boolean, "retain-rt-all")

                                        self.route_target_download = YLeaf(YType.boolean, "route-target-download")

                                        self.tbl_bitf_size = YLeaf(YType.uint16, "tbl-bitf-size")

                                        self.tbl_chunk_bitf_size = YLeaf(YType.uint16, "tbl-chunk-bitf-size")

                                        self.use_igpsr_label = YLeaf(YType.boolean, "use-igpsr-label")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, ['add_path_install_disable', 'add_path_install_enable', 'any_ebgp_neighbor_missing_policy', 'asbr', 'attribute_download', 'best_external', 'best_external_disable', 'bmp_network_entry_count', 'bmp_path_memory', 'bmp_paths_count', 'bmp_prefix_memory', 'damped_path_count', 'freed_path_count', 'freed_path_elem_count', 'freed_prefix_count', 'history_path_count', 'ibgp_nexthop_self_count', 'imported_path_memory', 'imported_paths', 'is_route_reflector', 'label_retain', 'label_retainvalue', 'local_path_memory', 'local_paths', 'malloced_path_count', 'malloced_path_elem_count', 'malloced_prefix_count', 'network_entry_count', 'path_elem_memory', 'path_elems_count', 'path_memory', 'paths_count', 'prefix_memory', 'received_path_count', 'retain_rt_all', 'route_target_download', 'tbl_bitf_size', 'tbl_chunk_bitf_size', 'use_igpsr_label'], name, value)


                            class Attributes(Entity):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes, self).__init__()

                                    self.yang_name = "attributes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute)}

                                    self.attribute = YList(self)
                                    self._segment_path = lambda: "attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes, [], name, value)


                                class Attribute(Entity):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo)}
                                        self._child_list_classes = {}

                                        self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                                        self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                                        self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                                        self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                                        self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                                        self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.reference_count = YLeaf(YType.uint32, "reference-count")

                                        self.attribute_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self._children_name_map["attribute_info"] = "attribute-info"
                                        self._children_yang_names.add("attribute-info")
                                        self._segment_path = lambda: "attribute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                                    class AttributeInfo(Entity):
                                        """
                                        Attributes
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                            self.yang_name = "attribute-info"
                                            self.yang_parent_name = "attribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attribute-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                            class BmpPathTableGeneric(Entity):
                                """
                                Summary Info about BMP Table
                                
                                .. attribute:: bmp_route_monitoringe_enabled
                                
                                	Is Route Monitoring mode enabled
                                	**type**\:  bool
                                
                                .. attribute:: bmp_table_version
                                
                                	Table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_incremented
                                
                                	Is Version being incremented
                                	**type**\:  bool
                                
                                .. attribute:: bmp_version_inprogress
                                
                                	Is Version wrap in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_version_wrap_done_time_spec
                                
                                	Version Wrap handle Done timestamp
                                	**type**\:   :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_start_time_spec
                                
                                	Version Wrap handle start timestamp
                                	**type**\:   :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_time_spec
                                
                                	Version Wrap timestamp
                                	**type**\:   :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                
                                .. attribute:: bmp_version_wrapped
                                
                                	Number of times Table Version Wrapped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped_tid
                                
                                	Version Wrapped trigger thread id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of nets in the table
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths in the table
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                    self.yang_name = "bmp-path-table-generic"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"bmp-version-wrap-done-time-spec" : ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec), "bmp-version-wrap-start-time-spec" : ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec), "bmp-version-wrap-time-spec" : ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)}
                                    self._child_list_classes = {}

                                    self.bmp_route_monitoringe_enabled = YLeaf(YType.boolean, "bmp-route-monitoringe-enabled")

                                    self.bmp_table_version = YLeaf(YType.uint32, "bmp-table-version")

                                    self.bmp_version_incremented = YLeaf(YType.boolean, "bmp-version-incremented")

                                    self.bmp_version_inprogress = YLeaf(YType.boolean, "bmp-version-inprogress")

                                    self.bmp_version_wrapped = YLeaf(YType.uint32, "bmp-version-wrapped")

                                    self.bmp_version_wrapped_tid = YLeaf(YType.uint32, "bmp-version-wrapped-tid")

                                    self.network_count = YLeaf(YType.uint32, "network-count")

                                    self.path_count = YLeaf(YType.uint32, "path-count")

                                    self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                    self.bmp_version_wrap_done_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-done-time-spec")

                                    self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                    self.bmp_version_wrap_start_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-start-time-spec")

                                    self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                    self.bmp_version_wrap_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"
                                    self._children_yang_names.add("bmp-version-wrap-time-spec")
                                    self._segment_path = lambda: "bmp-path-table-generic"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric, ['bmp_route_monitoringe_enabled', 'bmp_table_version', 'bmp_version_incremented', 'bmp_version_inprogress', 'bmp_version_wrapped', 'bmp_version_wrapped_tid', 'network_count', 'path_count'], name, value)


                                class BmpVersionWrapDoneTimeSpec(Entity):
                                    """
                                    Version Wrap handle Done timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-done-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-done-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpVersionWrapStartTimeSpec(Entity):
                                    """
                                    Version Wrap handle start timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-start-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-start-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpVersionWrapTimeSpec(Entity):
                                    """
                                    Version Wrap timestamp
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-version-wrap-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class BmpPaths(Entity):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths, self).__init__()

                                    self.yang_name = "bmp-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath)}

                                    self.bmp_path = YList(self)
                                    self._segment_path = lambda: "bmp-paths"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths, [], name, value)


                                class BmpPath(Entity):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath>`
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                        self.yang_name = "bmp-path"
                                        self.yang_parent_name = "bmp-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)}
                                        self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath)}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bmp_net_flags = YLeaf(YType.uint32, "bmp-net-flags")

                                        self.bmp_net_version = YLeaf(YType.uint32, "bmp-net-version")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.network = YLeaf(YType.str, "network")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath, ['af_name', 'bmp_net_flags', 'bmp_net_version', 'has_local_label', 'net_local_label', 'network', 'num_of_path', 'prefix_length'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BmpPath(Entity):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress>`
                                        
                                        .. attribute:: received_label
                                        
                                        	Label received from peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.bmp_nbr_bit_map = YLeaf(YType.uint32, "bmp-nbr-bit-map")

                                            self.bmp_path_adv_bit_map = YLeaf(YType.uint16, "bmp-path-adv-bit-map")

                                            self.bmp_path_flags = YLeaf(YType.uint32, "bmp-path-flags")

                                            self.bmp_path_snd_bit_map = YLeaf(YType.uint16, "bmp-path-snd-bit-map")

                                            self.bpath_pointer = YLeaf(YType.uint64, "bpath-pointer")

                                            self.local_path = YLeaf(YType.boolean, "local-path")

                                            self.received_label = YLeaf(YType.uint32, "received-label")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "bmp-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath, ['bmp_nbr_bit_map', 'bmp_path_adv_bit_map', 'bmp_path_flags', 'bmp_path_snd_bit_map', 'bpath_pointer', 'local_path', 'received_label'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Convergence(Entity):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\:  bool
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence, self).__init__()

                                    self.yang_name = "convergence"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.are_write_queues_empty = YLeaf(YType.boolean, "are-write-queues-empty")

                                    self.has_converged = YLeaf(YType.boolean, "has-converged")
                                    self._segment_path = lambda: "convergence"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence, ['af_name', 'are_write_queues_empty', 'has_converged'], name, value)


                            class Dampenings(Entity):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings, self).__init__()

                                    self.yang_name = "dampenings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"dampening" : ("dampening", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening)}

                                    self.dampening = YList(self)
                                    self._segment_path = lambda: "dampenings"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings, [], name, value)


                                class Dampening(Entity):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "dampenings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.length = YLeaf(YType.int32, "length")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.reuse = YLeaf(YType.int32, "reuse")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.version = YLeaf(YType.int32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "dampening"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'length', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_version', 'process_instance_id', 'rd', 'reuse', 'route_distinguisher', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'version', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class Epes(Entity):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes, self).__init__()

                                    self.yang_name = "epes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"epe" : ("epe", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe)}

                                    self.epe = YList(self)
                                    self._segment_path = lambda: "epes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes, [], name, value)


                                class Epe(Entity):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe, self).__init__()

                                        self.yang_name = "epe"
                                        self.yang_parent_name = "epes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"epe-local-address" : ("epe_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress), "epe-next-hop" : ("epe_next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop)}
                                        self._child_list_classes = {"epe-key" : ("epe_key", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey), "first-hop" : ("first_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop), "ifhandle" : ("ifhandle", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle), "nexthop-id" : ("nexthop_id", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId)}

                                        self.epe_flags = YLeaf(YType.uint8, "epe-flags")

                                        self.epe_key_length = YLeaf(YType.int32, "epe-key-length")

                                        self.epe_key_length_xr = YLeaf(YType.uint8, "epe-key-length-xr")

                                        self.epe_local_asn = YLeaf(YType.uint32, "epe-local-asn")

                                        self.epe_local_router_id = YLeaf(YType.uint32, "epe-local-router-id")

                                        self.epe_remote_asn = YLeaf(YType.uint32, "epe-remote-asn")

                                        self.epe_remote_router_id = YLeaf(YType.uint32, "epe-remote-router-id")

                                        self.epe_set_key = YLeaf(YType.str, "epe-set-key")

                                        self.epe_version = YLeaf(YType.uint32, "epe-version")

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.ref_count = YLeaf(YType.uint32, "ref-count")

                                        self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self._children_name_map["epe_local_address"] = "epe-local-address"
                                        self._children_yang_names.add("epe-local-address")

                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self._children_name_map["epe_next_hop"] = "epe-next-hop"
                                        self._children_yang_names.add("epe-next-hop")

                                        self.epe_key = YList(self)
                                        self.first_hop = YList(self)
                                        self.ifhandle = YList(self)
                                        self.nexthop_id = YList(self)
                                        self._segment_path = lambda: "epe"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe, ['epe_flags', 'epe_key_length', 'epe_key_length_xr', 'epe_local_asn', 'epe_local_router_id', 'epe_remote_asn', 'epe_remote_router_id', 'epe_set_key', 'epe_version', 'label', 'ref_count'], name, value)


                                    class EpeKey(Entity):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                            self.yang_name = "epe-key"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "epe-key"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, ['entry'], name, value)


                                    class EpeLocalAddress(Entity):
                                        """
                                        Local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                            self.yang_name = "epe-local-address"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "epe-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class EpeNextHop(Entity):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                            self.yang_name = "epe-next-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "epe-next-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class FirstHop(Entity):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                            self.yang_name = "first-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "first-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class Ifhandle(Entity):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                            self.yang_name = "ifhandle"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "ifhandle"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, ['entry'], name, value)


                                    class NexthopId(Entity):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                            self.yang_name = "nexthop-id"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "nexthop-id"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, ['entry'], name, value)


                            class GlobalAfProcessInfo(Entity):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                    self.yang_name = "global-af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "global-af-process-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo, ['af_name', 'is_nsr_enabled', 'vrf_name'], name, value)


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall)}
                                        self._child_list_classes = {"syncgrp-version" : ("syncgrp_version", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion)}

                                        self.gblafrpki_allow_invalid = YLeaf(YType.boolean, "gblafrpki-allow-invalid")

                                        self.gblafrpki_disable = YLeaf(YType.boolean, "gblafrpki-disable")

                                        self.gblafrpki_signal_ibgp = YLeaf(YType.boolean, "gblafrpki-signal-ibgp")

                                        self.gblafrpki_use_validity = YLeaf(YType.boolean, "gblafrpki-use-validity")

                                        self.global_mcast_enabled = YLeaf(YType.boolean, "global-mcast-enabled")

                                        self.inter_as_install_enabled = YLeaf(YType.boolean, "inter-as-install-enabled")

                                        self.is_perm_net_cfg = YLeaf(YType.boolean, "is-perm-net-cfg")

                                        self.nh_tunnel_version = YLeaf(YType.uint32, "nh-tunnel-version")

                                        self.perm_nbr_count = YLeaf(YType.uint16, "perm-nbr-count")

                                        self.perm_net_del_count = YLeaf(YType.uint16, "perm-net-del-count")

                                        self.perm_net_existing_count = YLeaf(YType.uint16, "perm-net-existing-count")

                                        self.perm_net_insert_count = YLeaf(YType.uint16, "perm-net-insert-count")

                                        self.perm_net_rpl_process_count = YLeaf(YType.uint16, "perm-net-rpl-process-count")

                                        self.perm_net_rpl_query_count = YLeaf(YType.uint16, "perm-net-rpl-query-count")

                                        self.perm_net_stale_del_count = YLeaf(YType.uint16, "perm-net-stale-del-count")

                                        self.perm_net_stale_mark_count = YLeaf(YType.uint16, "perm-net-stale-mark-count")

                                        self.perm_path_refresh_count = YLeaf(YType.uint16, "perm-path-refresh-count")

                                        self.perm_pelem_all_bump_count = YLeaf(YType.uint16, "perm-pelem-all-bump-count")

                                        self.perm_pelem_bump_count = YLeaf(YType.uint16, "perm-pelem-bump-count")

                                        self.perm_pelem_free_count = YLeaf(YType.uint16, "perm-pelem-free-count")

                                        self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                        self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                        self.rib_perm_path_found_count = YLeaf(YType.uint16, "rib-perm-path-found-count")

                                        self.rib_perm_path_not_found_count = YLeaf(YType.uint16, "rib-perm-path-not-found-count")

                                        self.rib_perm_pelem_found_count = YLeaf(YType.uint16, "rib-perm-pelem-found-count")

                                        self.rib_perm_pelem_not_found_count = YLeaf(YType.uint16, "rib-perm-pelem-not-found-count")

                                        self.rib_reg_path_found_count = YLeaf(YType.uint16, "rib-reg-path-found-count")

                                        self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                        self.scan_prefixes = YLeaf(YType.uint32, "scan-prefixes")

                                        self.scan_segment_prefixes = YLeaf(YType.uint32, "scan-segment-prefixes")

                                        self.scan_segments = YLeaf(YType.uint8, "scan-segments")

                                        self.scanner_period = YLeaf(YType.uint16, "scanner-period")

                                        self.segmented_mcast_enabled = YLeaf(YType.boolean, "segmented-mcast-enabled")

                                        self.update_wait_install_enabled = YLeaf(YType.boolean, "update-wait-install-enabled")

                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._children_yang_names.add("rib-install")

                                        self.syncgrp_version = YList(self)
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_, ['gblafrpki_allow_invalid', 'gblafrpki_disable', 'gblafrpki_signal_ibgp', 'gblafrpki_use_validity', 'global_mcast_enabled', 'inter_as_install_enabled', 'is_perm_net_cfg', 'nh_tunnel_version', 'perm_nbr_count', 'perm_net_del_count', 'perm_net_existing_count', 'perm_net_insert_count', 'perm_net_rpl_process_count', 'perm_net_rpl_query_count', 'perm_net_stale_del_count', 'perm_net_stale_mark_count', 'perm_path_refresh_count', 'perm_pelem_all_bump_count', 'perm_pelem_bump_count', 'perm_pelem_free_count', 'rib_ack_requests', 'rib_acks_received', 'rib_perm_path_found_count', 'rib_perm_path_not_found_count', 'rib_perm_pelem_found_count', 'rib_perm_pelem_not_found_count', 'rib_reg_path_found_count', 'rib_slow_acks', 'scan_prefixes', 'scan_segment_prefixes', 'scan_segments', 'scanner_period', 'segmented_mcast_enabled', 'update_wait_install_enabled'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime)}
                                            self._child_list_classes = {}

                                            self.installed_count = YLeaf(YType.uint32, "installed-count")

                                            self.modified_count = YLeaf(YType.uint32, "modified-count")

                                            self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                            self.start_version = YLeaf(YType.uint32, "start-version")

                                            self.target_version = YLeaf(YType.uint32, "target-version")

                                            self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._children_yang_names.add("install-time")

                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"
                                            self._children_yang_names.add("update-time")
                                            self._segment_path = lambda: "rib-install"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "install-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                    class SyncgrpVersion(Entity):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, self).__init__()

                                            self.yang_name = "syncgrp-version"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "syncgrp-version"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, ['entry'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\:  bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\:  bool
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\:  bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.aggregates_distance = YLeaf(YType.uint16, "aggregates-distance")

                                        self.client_reflection_enabled = YLeaf(YType.boolean, "client-reflection-enabled")

                                        self.dampening_enabled = YLeaf(YType.boolean, "dampening-enabled")

                                        self.dynamic_med_enabled = YLeaf(YType.boolean, "dynamic-med-enabled")

                                        self.dynamic_med_interval = YLeaf(YType.uint16, "dynamic-med-interval")

                                        self.dynamic_med_periodic_timer_running = YLeaf(YType.boolean, "dynamic-med-periodic-timer-running")

                                        self.dynamic_med_periodic_timer_value = YLeaf(YType.uint16, "dynamic-med-periodic-timer-value")

                                        self.dynamic_med_timer_running = YLeaf(YType.boolean, "dynamic-med-timer-running")

                                        self.dynamic_med_timer_value = YLeaf(YType.uint16, "dynamic-med-timer-value")

                                        self.ebgp_distance = YLeaf(YType.uint16, "ebgp-distance")

                                        self.ibgp_distance = YLeaf(YType.uint16, "ibgp-distance")

                                        self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                        self.nexthop_resolution_minimum_prefix_length = YLeaf(YType.uint32, "nexthop-resolution-minimum-prefix-length")

                                        self.nexthop_resolution_minimum_prefix_length_configured = YLeaf(YType.boolean, "nexthop-resolution-minimum-prefix-length-configured")

                                        self.nsr_conv_version = YLeaf(YType.uint32, "nsr-conv-version")

                                        self.nsr_is_conv = YLeaf(YType.boolean, "nsr-is-conv")

                                        self.rd_version = YLeaf(YType.uint32, "rd-version")

                                        self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                        self.rib_convergence_version = YLeaf(YType.uint32, "rib-convergence-version")

                                        self.rib_has_converged = YLeaf(YType.boolean, "rib-has-converged")

                                        self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                        self.rib_version = YLeaf(YType.uint32, "rib-version")

                                        self.selective_ebgp_multipath_enabled = YLeaf(YType.boolean, "selective-ebgp-multipath-enabled")

                                        self.selective_eibgp_multipath_enabled = YLeaf(YType.boolean, "selective-eibgp-multipath-enabled")

                                        self.selective_ibgp_multipath_enabled = YLeaf(YType.boolean, "selective-ibgp-multipath-enabled")

                                        self.table_id = YLeaf(YType.uint32, "table-id")

                                        self.table_is_active = YLeaf(YType.boolean, "table-is-active")

                                        self.table_version = YLeaf(YType.uint32, "table-version")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, ['aggregates_distance', 'client_reflection_enabled', 'dampening_enabled', 'dynamic_med_enabled', 'dynamic_med_interval', 'dynamic_med_periodic_timer_running', 'dynamic_med_periodic_timer_value', 'dynamic_med_timer_running', 'dynamic_med_timer_value', 'ebgp_distance', 'ibgp_distance', 'is_rib_table_full', 'nexthop_resolution_minimum_prefix_length', 'nexthop_resolution_minimum_prefix_length_configured', 'nsr_conv_version', 'nsr_is_conv', 'rd_version', 'rib_acked_table_version', 'rib_convergence_version', 'rib_has_converged', 'rib_table_full_version', 'rib_version', 'selective_ebgp_multipath_enabled', 'selective_eibgp_multipath_enabled', 'selective_ibgp_multipath_enabled', 'table_id', 'table_is_active', 'table_version'], name, value)


                            class NeighborAfTable(Entity):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable, self).__init__()

                                    self.yang_name = "neighbor-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor)}

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-af-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\:  str
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\:  bool
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\:  bool
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)}
                                        self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData)}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                        self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                        self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                        self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                        self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                        self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                        self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                        self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                        self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                        self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                        self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                        self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                        self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                        self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                        self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                        self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                        self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                        self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                        self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                        self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                        self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                        self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                        self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                        self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                        self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                        self.description = YLeaf(YType.str, "description")

                                        self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                        self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                        self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                        self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                        self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                        self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                        self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                        self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                        self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                        self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                        self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                        self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                        self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                        self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                        self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                        self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                        self.hold_time = YLeaf(YType.uint16, "hold-time")

                                        self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                        self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                        self.io_armed = YLeaf(YType.boolean, "io-armed")

                                        self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                        self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                        self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                        self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                        self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                        self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                        self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                        self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                        self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                        self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                        self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                        self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                        self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                        self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                        self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                        self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                        self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                        self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                        self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                        self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                        self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                        self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                        self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                        self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                        self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                        self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                        self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                        self.local_as = YLeaf(YType.uint32, "local-as")

                                        self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                        self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                        self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                        self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                        self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                        self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                        self.messages_received = YLeaf(YType.uint32, "messages-received")

                                        self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                        self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                        self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                        self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                        self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                        self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                        self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                        self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                        self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                        self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                        self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                        self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                        self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                        self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                        self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                        self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                        self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                        self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                        self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                        self.read_armed = YLeaf(YType.boolean, "read-armed")

                                        self.remote_as = YLeaf(YType.uint32, "remote-as")

                                        self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                        self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                        self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                        self.router_id = YLeaf(YType.str, "router-id")

                                        self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                        self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                        self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                        self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                        self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                        self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                        self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                        self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                        self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                        self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                        self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                        self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                        self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                        self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                        self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                        self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                        self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                        self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                        self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                        self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                        self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                        self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                        self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                        self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                        self.tos_type = YLeaf(YType.uint8, "tos-type")

                                        self.tos_value = YLeaf(YType.uint8, "tos-value")

                                        self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                        self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                        self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                        self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.write_armed = YLeaf(YType.boolean, "write-armed")

                                        self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self._children_name_map["connection_local_address"] = "connection-local-address"
                                        self._children_yang_names.add("connection-local-address")

                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                        self._children_yang_names.add("connection-remote-address")

                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                        self._children_yang_names.add("graceful-maintenance")

                                        self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self._children_name_map["message_statistics"] = "message-statistics"
                                        self._children_yang_names.add("message-statistics")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self._children_name_map["received_notification_info"] = "received-notification-info"
                                        self._children_yang_names.add("received-notification-info")

                                        self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self._children_name_map["send_notification_info"] = "send-notification-info"
                                        self._children_yang_names.add("send-notification-info")

                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                        self._children_yang_names.add("tcp-init-sync-time-spec")

                                        self.af_data = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                    class AfData(Entity):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with 
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\:  bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                            self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby)}

                                            self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                            self.acked_version = YLeaf(YType.uint32, "acked-version")

                                            self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                            self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                            self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                            self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                            self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                            self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                            self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                            self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                            self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                            self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                            self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                            self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                            self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                            self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                            self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                            self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                            self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                            self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                            self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                            self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                            self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                            self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                            self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                            self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                            self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                            self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                            self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                            self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                            self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                            self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                            self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                            self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                            self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                            self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                            self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                            self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                            self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                            self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                            self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                            self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                            self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                            self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                            self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                            self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                            self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                            self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                            self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                            self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                            self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                            self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                            self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                            self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                            self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                            self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                            self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                            self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                            self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                            self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                            self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                            self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                            self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                            self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                            self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                            self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                            self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                            self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                            self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                            self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                            self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                            self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                            self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                            self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                            self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                            self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                            self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                            self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                            self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                            self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                            self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                            self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                            self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                            self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                            self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                            self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                            self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                            self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                            self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                            self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                            self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                            self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                            self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                            self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                            self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                            self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                            self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                            self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                            self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                            self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                            self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                            self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                            self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                            self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                            self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                            self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                            self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                            self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                            self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                            self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                            self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                            self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                            self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                            self.restart_time = YLeaf(YType.uint32, "restart-time")

                                            self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                            self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                            self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                            self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                            self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                            self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                            self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                            self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                            self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                            self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                            self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                            self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                            self.weight = YLeaf(YType.uint32, "weight")

                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                            self._children_yang_names.add("neighbor-af-performance-statistics")

                                            self.extended_community = YList(self)
                                            self.extended_community_standby = YList(self)
                                            self._segment_path = lambda: "af-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                        class ExtendedCommunityStandby(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                self.yang_name = "extended-community-standby"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community-standby"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                        class NeighborAfPerformanceStatistics(Entity):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                self.yang_name = "neighbor-af-performance-statistics"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                                self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                                self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                                self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                                self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                                self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                                self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                                self._segment_path = lambda: "neighbor-af-performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                    class ConnectionLocalAddress(Entity):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                            self.yang_name = "connection-local-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "connection-local-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ConnectionRemoteAddress(Entity):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                            self.yang_name = "connection-remote-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "connection-remote-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class GracefulMaintenance(Entity):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                            self.yang_name = "graceful-maintenance"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                            self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                            self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                            self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                            self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                            self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                            self._segment_path = lambda: "graceful-maintenance"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                    class MessageStatistics(Entity):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                            self.yang_name = "message-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)}
                                            self._child_list_classes = {}

                                            self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self._children_name_map["keepalive"] = "keepalive"
                                            self._children_yang_names.add("keepalive")

                                            self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self._children_name_map["notification"] = "notification"
                                            self._children_yang_names.add("notification")

                                            self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self._children_name_map["open"] = "open"
                                            self._children_yang_names.add("open")

                                            self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self._children_name_map["route_refresh"] = "route-refresh"
                                            self._children_yang_names.add("route-refresh")

                                            self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self._children_name_map["total"] = "total"
                                            self._children_yang_names.add("total")

                                            self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self
                                            self._children_name_map["update"] = "update"
                                            self._children_yang_names.add("update")
                                            self._segment_path = lambda: "message-statistics"


                                        class Keepalive(Entity):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                self.yang_name = "keepalive"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "keepalive"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Notification(Entity):
                                            """
                                            Notification
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                self.yang_name = "notification"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "notification"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Open(Entity):
                                            """
                                            Open
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                self.yang_name = "open"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "open"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class RouteRefresh(Entity):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                self.yang_name = "route-refresh"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "route-refresh"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Total(Entity):
                                            """
                                            Total
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                self.yang_name = "total"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "total"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Update(Entity):
                                            """
                                            Update
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                self.yang_name = "update"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)}
                                                self._child_list_classes = {}

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._children_yang_names.add("rx")

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"
                                                self._children_yang_names.add("tx")
                                                self._segment_path = lambda: "update"


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "rx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.count = YLeaf(YType.uint32, "count")

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._children_yang_names.add("last-time-spec")
                                                    self._segment_path = lambda: "tx"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "last-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.active_collision = YLeaf(YType.uint32, "active-collision")

                                            self.actives = YLeaf(YType.uint32, "actives")

                                            self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                            self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                            self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                            self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                            self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                            self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                            self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                            self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                            self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                            self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                            self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                            self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                            self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                            self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                            self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                            self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                            self.network_status = YLeaf(YType.uint32, "network-status")

                                            self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                            self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                            self.passives = YLeaf(YType.uint32, "passives")

                                            self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                            self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                            self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                            self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                            self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                            self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                            self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                            self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                            self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                            self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                            self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                            self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                            self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                            self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                            self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                            self._segment_path = lambda: "performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                    class ReceivedNotificationInfo(Entity):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                            self.yang_name = "received-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "received-notification-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "received-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                    class SendNotificationInfo(Entity):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                            self.yang_name = "send-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "send-notification-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "send-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                    class TcpInitSyncDoneTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-done-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class TcpInitSyncTimeSpec(Entity):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "tcp-init-sync-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class NetworkAllRds(Entity):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds, self).__init__()

                                    self.yang_name = "network-all-rds"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-all-rd" : ("network_all_rd", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd)}

                                    self.network_all_rd = YList(self)
                                    self._segment_path = lambda: "network-all-rds"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds, [], name, value)


                                class NetworkAllRd(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: network_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd, self).__init__()

                                        self.yang_name = "network-all-rd"
                                        self.yang_parent_name = "network-all-rds"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"network-rds" : ("network_rds", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds)}
                                        self._child_list_classes = {}

                                        self.network = YLeaf(YType.str, "network")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.network_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                        self.network_rds.parent = self
                                        self._children_name_map["network_rds"] = "network-rds"
                                        self._children_yang_names.add("network-rds")
                                        self._segment_path = lambda: "network-all-rd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd, ['network', 'prefix_length'], name, value)


                                    class NetworkRds(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, self).__init__()

                                            self.yang_name = "network-rds"
                                            self.yang_parent_name = "network-all-rd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"network-rd" : ("network_rd", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd)}

                                            self.network_rd = YList(self)
                                            self._segment_path = lambda: "network-rds"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, [], name, value)


                                        class NetworkRd(Entity):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, self).__init__()

                                                self.yang_name = "network-rd"
                                                self.yang_parent_name = "network-rds"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp)}
                                                self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo)}

                                                self.rd = YLeaf(YType.str, "rd")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.bit = YLeaf(YType.uint16, "bit")

                                                self.flags = YLeaf(YType.uint8, "flags")

                                                self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                self.table_version = YLeaf(YType.uint32, "table-version")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                self.version_age.parent = self
                                                self._children_name_map["version_age"] = "version-age"
                                                self._children_yang_names.add("version-age")

                                                self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self._children_name_map["version_timestamp"] = "version-timestamp"
                                                self._children_yang_names.add("version-timestamp")

                                                self.active_path_element = YList(self)
                                                self.active_process_instance_path = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.local_path_element = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.local_process_instance_path = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self._segment_path = lambda: "network-rd" + "[rd='" + self.rd.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                            class ActivePathElement(Entity):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, self).__init__()

                                                    self.yang_name = "active-path-element"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "active-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ActiveProcessInstancePath(Entity):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, self).__init__()

                                                    self.yang_name = "active-process-instance-path"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "active-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPathElement(Entity):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, self).__init__()

                                                    self.yang_name = "local-path-element"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "local-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalProcessInstancePath(Entity):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, self).__init__()

                                                    self.yang_name = "local-process-instance-path"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "local-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class VersionAge(Entity):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, self).__init__()

                                                    self.yang_name = "version-age"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-age"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                            class VersionTimestamp(Entity):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, self).__init__()

                                                    self.yang_name = "version-timestamp"
                                                    self.yang_parent_name = "network-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NetworkLookupAllRds(Entity):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_lookup_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds, self).__init__()

                                    self.yang_name = "network-lookup-all-rds"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-lookup-all-rd" : ("network_lookup_all_rd", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd)}

                                    self.network_lookup_all_rd = YList(self)
                                    self._segment_path = lambda: "network-lookup-all-rds"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds, [], name, value)


                                class NetworkLookupAllRd(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_lookup_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, self).__init__()

                                        self.yang_name = "network-lookup-all-rd"
                                        self.yang_parent_name = "network-lookup-all-rds"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"network-lookup-rds" : ("network_lookup_rds", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds)}
                                        self._child_list_classes = {}

                                        self.network_prefix = YLeaf(YType.str, "network-prefix")

                                        self.network_lookup_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                        self.network_lookup_rds.parent = self
                                        self._children_name_map["network_lookup_rds"] = "network-lookup-rds"
                                        self._children_yang_names.add("network-lookup-rds")
                                        self._segment_path = lambda: "network-lookup-all-rd" + "[network-prefix='" + self.network_prefix.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, ['network_prefix'], name, value)


                                    class NetworkLookupRds(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_lookup_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, self).__init__()

                                            self.yang_name = "network-lookup-rds"
                                            self.yang_parent_name = "network-lookup-all-rd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"network-lookup-rd" : ("network_lookup_rd", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd)}

                                            self.network_lookup_rd = YList(self)
                                            self._segment_path = lambda: "network-lookup-rds"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, [], name, value)


                                        class NetworkLookupRd(Entity):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, self).__init__()

                                                self.yang_name = "network-lookup-rd"
                                                self.yang_parent_name = "network-lookup-rds"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp)}
                                                self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo)}

                                                self.rd = YLeaf(YType.str, "rd")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.bit = YLeaf(YType.uint16, "bit")

                                                self.flags = YLeaf(YType.uint8, "flags")

                                                self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                self.table_version = YLeaf(YType.uint32, "table-version")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                self.version_age.parent = self
                                                self._children_name_map["version_age"] = "version-age"
                                                self._children_yang_names.add("version-age")

                                                self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self._children_name_map["version_timestamp"] = "version-timestamp"
                                                self._children_yang_names.add("version-timestamp")

                                                self.active_path_element = YList(self)
                                                self.active_process_instance_path = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.local_path_element = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.local_process_instance_path = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self._segment_path = lambda: "network-lookup-rd" + "[rd='" + self.rd.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                            class ActivePathElement(Entity):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, self).__init__()

                                                    self.yang_name = "active-path-element"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "active-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "active-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ActiveProcessInstancePath(Entity):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, self).__init__()

                                                    self.yang_name = "active-process-instance-path"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "active-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "active-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPathElement(Entity):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, self).__init__()

                                                    self.yang_name = "local-path-element"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop)}
                                                    self._child_list_classes = {}

                                                    self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                    self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                    self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                    self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                    self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                    self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                    self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                    self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                    self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                    self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                    self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                    self._children_yang_names.add("pelem-path-neighbor-addr")

                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                    self._children_yang_names.add("pelem-path-nexthop")
                                                    self._segment_path = lambda: "local-path-element"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PelemPathNeighborAddr(Entity):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                        self.yang_name = "pelem-path-neighbor-addr"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-neighbor-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PelemPathNexthop(Entity):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                        self.yang_name = "pelem-path-nexthop"
                                                        self.yang_parent_name = "local-path-element"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "pelem-path-nexthop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "pelem-path-nexthop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class LocalProcessInstancePath(Entity):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, self).__init__()

                                                    self.yang_name = "local-process-instance-path"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation)}
                                                    self._child_list_classes = {}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                    self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                    self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                    self.no_path = YLeaf(YType.boolean, "no-path")

                                                    self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                    self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                    self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                    self._children_yang_names.add("attributes-after-policy-in")

                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                    self._children_yang_names.add("neighbor-address-xr")

                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self._children_name_map["path_information"] = "path-information"
                                                    self._children_yang_names.add("path-information")
                                                    self._segment_path = lambda: "local-process-instance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                class AttributesAfterPolicyIn(Entity):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                        self.yang_name = "attributes-after-policy-in"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                        self._child_list_classes = {}

                                                        self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                        self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                        self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                        self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                        self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                        self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                        self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                        self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                        self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                        self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                        self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                        self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                        self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                        self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                        self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                        self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                        self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                        self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                        self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                        self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                        self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                        self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                        self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self._children_name_map["attr_set"] = "attr-set"
                                                        self._children_yang_names.add("attr-set")

                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self._children_name_map["common_attributes"] = "common-attributes"
                                                        self._children_yang_names.add("common-attributes")

                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                        self._children_yang_names.add("ribrnh-ip")

                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self._children_name_map["rnh_addr"] = "rnh-addr"
                                                        self._children_yang_names.add("rnh-addr")
                                                        self._segment_path = lambda: "attributes-after-policy-in"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                    class AttrSet(Entity):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                            self.yang_name = "attr-set"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "attr-set"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "attr-set"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                    class CommonAttributes(Entity):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_large_community_present
                                                        
                                                        	Large Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: large_community
                                                        
                                                        	Large Community attribute
                                                        	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap
                                                        
                                                        	Tunnel Encapsulation attribute
                                                        	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                            self.yang_name = "common-attributes"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                            self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                            self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                            self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                            self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                            self.as_path = YLeaf(YType.str, "as-path")

                                                            self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                            self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                            self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                            self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                            self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                            self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                            self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                            self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                            self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                            self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                            self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                            self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                            self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                            self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                            self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                            self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                            self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                            self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                            self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                            self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                            self.origin = YLeaf(YType.uint16, "origin")

                                                            self.originator = YLeaf(YType.str, "originator")

                                                            self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                            self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                            self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                            self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                            self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                            self.tunnel_encap.parent = self
                                                            self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                            self._children_yang_names.add("tunnel-encap")

                                                            self.cluster = YList(self)
                                                            self.community = YList(self)
                                                            self.connector_value = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2tpv3_cookie = YList(self)
                                                            self.label_index_attr = YList(self)
                                                            self.large_community = YList(self)
                                                            self.ls_attr = YList(self)
                                                            self.pe_distinguisher_label = YList(self)
                                                            self.pmsi_value = YList(self)
                                                            self.unknown_attribute = YList(self)
                                                            self._segment_path = lambda: "common-attributes"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                        class Cluster(Entity):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                self.yang_name = "cluster"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "cluster"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                        class Community(Entity):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                self.yang_name = "community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                        class ConnectorValue(Entity):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                self.yang_name = "connector-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "connector-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                        class L2Tpv3Cookie(Entity):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                self.yang_name = "l2tpv3-cookie"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2tpv3-cookie"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                        class LabelIndexAttr(Entity):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                self.yang_name = "label-index-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "label-index-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                        class LargeCommunity(Entity):
                                                            """
                                                            Large Community attribute
                                                            
                                                            .. attribute:: global_admin
                                                            
                                                            	Global Administrator
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data1
                                                            
                                                            	Local Data 1
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: local_data2
                                                            
                                                            	Local Data 2
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                self.yang_name = "large-community"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                self._segment_path = lambda: "large-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                        class LsAttr(Entity):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                self.yang_name = "ls-attr"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "ls-attr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                        class PeDistinguisherLabel(Entity):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                self.yang_name = "pe-distinguisher-label"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.pe_address = YLeaf(YType.str, "pe-address")
                                                                self._segment_path = lambda: "pe-distinguisher-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                        class PmsiValue(Entity):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                self.yang_name = "pmsi-value"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                        class TunnelEncap(Entity):
                                                            """
                                                            Tunnel Encapsulation attribute
                                                            
                                                            .. attribute:: sr_policy
                                                            
                                                            	Tunnel encap type SR policy
                                                            	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                self.yang_name = "tunnel-encap"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                self._child_list_classes = {}

                                                                self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                self.sr_policy.parent = self
                                                                self._children_name_map["sr_policy"] = "sr-policy"
                                                                self._children_yang_names.add("sr-policy")
                                                                self._segment_path = lambda: "tunnel-encap"


                                                            class SrPolicy(Entity):
                                                                """
                                                                Tunnel encap type SR policy
                                                                
                                                                .. attribute:: allocated_binding_sid
                                                                
                                                                	SR Policy allocated Binding sid by the router
                                                                	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                
                                                                .. attribute:: binding_sid
                                                                
                                                                	SR Policy incoming Binding sid
                                                                	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                
                                                                .. attribute:: preference
                                                                
                                                                	SR Policy Preference
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: request_state
                                                                
                                                                	SR Policy programming Status
                                                                	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                
                                                                .. attribute:: segment_list
                                                                
                                                                	SR Policy Segment Lists
                                                                	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	SR Policy active state in forwarding
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_encap_type
                                                                
                                                                	Tunnel Encapsulation Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                    self.yang_name = "sr-policy"
                                                                    self.yang_parent_name = "tunnel-encap"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                    self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                    self.preference = YLeaf(YType.uint32, "preference")

                                                                    self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                    self.state = YLeaf(YType.boolean, "state")

                                                                    self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                    self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                    self.allocated_binding_sid.parent = self
                                                                    self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                    self._children_yang_names.add("allocated-binding-sid")

                                                                    self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                    self.binding_sid.parent = self
                                                                    self._children_name_map["binding_sid"] = "binding-sid"
                                                                    self._children_yang_names.add("binding-sid")

                                                                    self.segment_list = YList(self)
                                                                    self._segment_path = lambda: "sr-policy"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                class AllocatedBindingSid(Entity):
                                                                    """
                                                                    SR Policy allocated Binding sid by the router
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                        self.yang_name = "allocated-binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "allocated-binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class BindingSid(Entity):
                                                                    """
                                                                    SR Policy incoming Binding sid
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 Addr
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                        self.yang_name = "binding-sid"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "binding-sid"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                class SegmentList(Entity):
                                                                    """
                                                                    SR Policy Segment Lists
                                                                    
                                                                    .. attribute:: segment
                                                                    
                                                                    	Segments in segment list
                                                                    	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                    
                                                                    .. attribute:: weight
                                                                    
                                                                    	Weight of segment list
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                        self.yang_name = "segment-list"
                                                                        self.yang_parent_name = "sr-policy"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                        self.weight = YLeaf(YType.uint8, "weight")

                                                                        self.segment = YList(self)
                                                                        self._segment_path = lambda: "segment-list"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                    class Segment(Entity):
                                                                        """
                                                                        Segments in segment list
                                                                        
                                                                        .. attribute:: ipv4_address
                                                                        
                                                                        	IPv4 Address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 address value
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label value
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                            self.yang_name = "segment"
                                                                            self.yang_parent_name = "segment-list"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "segment"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                        class UnknownAttribute(Entity):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                self.yang_name = "unknown-attribute"
                                                                self.yang_parent_name = "common-attributes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "unknown-attribute"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                    class RibrnhIp(Entity):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                            self.yang_name = "ribrnh-ip"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "ribrnh-ip"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "ribrnh-ip"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RnhAddr(Entity):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                            self.yang_name = "rnh-addr"
                                                            self.yang_parent_name = "attributes-after-policy-in"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")

                                                            self.mac_address = YLeaf(YType.str, "mac-address")
                                                            self._segment_path = lambda: "rnh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                class NeighborAddressXr(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                        self.yang_name = "neighbor-address-xr"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address-xr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address-xr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PathInformation(Entity):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Original Source Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_nh_addr
                                                    
                                                    	Path has next\-hop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_vpn_nexthop_addr
                                                    
                                                    	Path has VPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_orig_src_rd_present
                                                    
                                                    	Original Source RD  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebgps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nh_addr
                                                    
                                                    	Path next\-hop Address
                                                    	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label stack
                                                    	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                    
                                                    .. attribute:: rcvd_label_count
                                                    
                                                    	Path received label count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Original Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: vpn_nexthop_addr
                                                    
                                                    	Vpn nexthop Address for the path
                                                    	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                    
                                                    .. attribute:: vpn_path_flags
                                                    
                                                    	Vpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                        self.yang_name = "path-information"
                                                        self.yang_parent_name = "local-process-instance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                        self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                        self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                        self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                        self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                        self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                        self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                        self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                        self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                        self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                        self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                        self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                        self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                        self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                        self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                        self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                        self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                        self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                        self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                        self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                        self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                        self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                        self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                        self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                        self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                        self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                        self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                        self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                        self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                        self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                        self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                        self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                        self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                        self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                        self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                        self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                        self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                        self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                        self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                        self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                        self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                        self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                        self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                        self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                        self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                        self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                        self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                        self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                        self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                        self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                        self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                        self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                        self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                        self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                        self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                        self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                        self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                        self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                        self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                        self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                        self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                        self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                        self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                        self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                        self.local_label = YLeaf(YType.uint32, "local-label")

                                                        self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                        self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                        self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                        self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                        self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                        self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                        self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                        self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                        self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                        self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                        self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                        self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                        self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                        self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                        self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                        self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                        self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                        self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                        self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                                        self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                        self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                        self.second_label = YLeaf(YType.uint32, "second-label")

                                                        self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                        self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                        self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                        self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                        self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                        self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                        self._children_yang_names.add("best-path-comp-winner")

                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                        self._children_yang_names.add("bgp-prefix")

                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self._children_name_map["gw_addr"] = "gw-addr"
                                                        self._children_yang_names.add("gw-addr")

                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                        self._children_yang_names.add("mdt-group-addr")

                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                        self._children_yang_names.add("mvpn-nbr-addr")

                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                        self._children_yang_names.add("mvpn-nexthop-addr")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")

                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self._children_name_map["next_hop"] = "next-hop"
                                                        self._children_yang_names.add("next-hop")

                                                        self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                        self.nh_addr.parent = self
                                                        self._children_name_map["nh_addr"] = "nh-addr"
                                                        self._children_yang_names.add("nh-addr")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                        self.vpn_nexthop_addr.parent = self
                                                        self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                        self._children_yang_names.add("vpn-nexthop-addr")

                                                        self.add_path_orr_bitfield = YList(self)
                                                        self.best_path_orr_bitfield = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2vpn_circuit_status_value = YList(self)
                                                        self.local_peers_advertised_to = YList(self)
                                                        self.mvpn_pmsi_value = YList(self)
                                                        self.pe_peers_advertised_to = YList(self)
                                                        self.rcvd_label = YList(self)
                                                        self._segment_path = lambda: "path-information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                    class AddPathOrrBitfield(Entity):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                            self.yang_name = "add-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathCompWinner(Entity):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                            self.yang_name = "best-path-comp-winner"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "best-path-comp-winner"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "best-path-comp-winner"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BestPathOrrBitfield(Entity):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                            self.yang_name = "best-path-orr-bitfield"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class BgpPrefix(Entity):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                            self.yang_name = "bgp-prefix"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                            self._child_list_classes = {}

                                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self._children_name_map["prefix"] = "prefix"
                                                            self._children_yang_names.add("prefix")
                                                            self._segment_path = lambda: "bgp-prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                        class Prefix(Entity):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                self.yang_name = "prefix"
                                                                self.yang_parent_name = "bgp-prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                    class GwAddr(Entity):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                            self.yang_name = "gw-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "gw-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class L2VpnCircuitStatusValue(Entity):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                            self.yang_name = "l2vpn-circuit-status-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                    class LocalPeersAdvertisedTo(Entity):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "local-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "local-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "local-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MdtGroupAddr(Entity):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                            self.yang_name = "mdt-group-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mdt-group-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mdt-group-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNbrAddr(Entity):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                            self.yang_name = "mvpn-nbr-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nbr-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nbr-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnNexthopAddr(Entity):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                            self.yang_name = "mvpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "mvpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "mvpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class MvpnPmsiValue(Entity):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                            self.yang_name = "mvpn-pmsi-value"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "mvpn-pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NextHop(Entity):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                            self.yang_name = "next-hop"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "next-hop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "next-hop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NhAddr(Entity):
                                                        """
                                                        Path next\-hop Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                            self.yang_name = "nh-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.len = YLeaf(YType.enumeration, "len")
                                                            self._segment_path = lambda: "nh-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PePeersAdvertisedTo(Entity):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                            self.yang_name = "pe-peers-advertised-to"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                            self._child_list_classes = {}

                                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")
                                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class RcvdLabel(Entity):
                                                        """
                                                        Path received label stack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                            self.yang_name = "rcvd-label"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "rcvd-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                    class VpnNexthopAddr(Entity):
                                                        """
                                                        Vpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                            self.yang_name = "vpn-nexthop-addr"
                                                            self.yang_parent_name = "path-information"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "vpn-nexthop-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "vpn-nexthop-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class VersionAge(Entity):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, self).__init__()

                                                    self.yang_name = "version-age"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-age"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                            class VersionTimestamp(Entity):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, self).__init__()

                                                    self.yang_name = "version-timestamp"
                                                    self.yang_parent_name = "network-lookup-rd"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "version-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NetworkPrefixes(Entity):
                                """
                                The BGP Network Lookup table
                                
                                .. attribute:: network_prefix
                                
                                	A BGP Network Lookup prefix entry
                                	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes, self).__init__()

                                    self.yang_name = "network-prefixes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network-prefix" : ("network_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix)}

                                    self.network_prefix = YList(self)
                                    self._segment_path = lambda: "network-prefixes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes, [], name, value)


                                class NetworkPrefix(Entity):
                                    """
                                    A BGP Network Lookup prefix entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_prefix
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix, self).__init__()

                                        self.yang_name = "network-prefix"
                                        self.yang_parent_name = "network-prefixes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp)}
                                        self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo)}

                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bit = YLeaf(YType.uint16, "bit")

                                        self.flags = YLeaf(YType.uint8, "flags")

                                        self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                        self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                        self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                        self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                        self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                        self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                        self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                        self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                        self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                        self.net_flags = YLeaf(YType.uint32, "net-flags")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                        self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                        self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                        self.network_prefix = YLeaf(YType.str, "network-prefix")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.active_path_element = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.local_path_element = YList(self)
                                        self.local_peers_advertised_to = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self._segment_path = lambda: "network-prefix"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network_prefix', 'num_of_path', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "active-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "active-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "local-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "local-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "local-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Networks(Entity):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks, self).__init__()

                                    self.yang_name = "networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"network" : ("network", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network)}

                                    self.network = YList(self)
                                    self._segment_path = lambda: "networks"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks, [], name, value)


                                class Network(Entity):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp)}
                                        self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)}

                                        self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.bit = YLeaf(YType.uint16, "bit")

                                        self.flags = YLeaf(YType.uint8, "flags")

                                        self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                        self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                        self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                        self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                        self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                        self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                        self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                        self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                        self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                        self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                        self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                        self.net_flags = YLeaf(YType.uint32, "net-flags")

                                        self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                        self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                        self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                        self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                        self.network = YLeaf(YType.str, "network")

                                        self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                        self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                        self.table_version = YLeaf(YType.uint32, "table-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                        self._children_yang_names.add("bgp-prefix")

                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"
                                        self._children_yang_names.add("version-age")

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"
                                        self._children_yang_names.add("version-timestamp")

                                        self.active_path_element = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.local_path_element = YList(self)
                                        self.local_peers_advertised_to = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self._segment_path = lambda: "network"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network', 'num_of_path', 'prefix_length', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "active-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "active-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "add-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "best-path-orr-bitfield"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bgp-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)}
                                            self._child_list_classes = {}

                                            self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                            self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                            self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                            self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                            self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                            self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                            self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                            self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                            self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                            self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                            self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._children_yang_names.add("pelem-path-neighbor-addr")

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                            self._children_yang_names.add("pelem-path-nexthop")
                                            self._segment_path = lambda: "local-path-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "pelem-path-nexthop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "local-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "local-process-instance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "pe-peers-advertised-to"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "version-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class NextHopAddressFamilies(Entity):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                    self.yang_name = "next-hop-address-families"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"next-hop-address-family" : ("next_hop_address_family", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily)}

                                    self.next_hop_address_family = YList(self)
                                    self._segment_path = lambda: "next-hop-address-families"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                class NextHopAddressFamily(Entity):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                        self.yang_name = "next-hop-address-family"
                                        self.yang_parent_name = "next-hop-address-families"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"next-hop-af-vrf-af" : ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf), "next-hop-afs" : ("next_hop_afs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs)}
                                        self._child_list_classes = {}

                                        self.next_hop_af_name = YLeaf(YType.enumeration, "next-hop-af-name")

                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"
                                        self._children_yang_names.add("next-hop-af-vrf-af")

                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self
                                        self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                        self._children_yang_names.add("next-hop-afs")
                                        self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + self.next_hop_af_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                    class NextHopAfVrfAf(Entity):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                            self.yang_name = "next-hop-af-vrf-af"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.critical_trigger_delay = YLeaf(YType.uint32, "critical-trigger-delay")

                                            self.epe_downloaded_version = YLeaf(YType.uint32, "epe-downloaded-version")

                                            self.epe_label_version = YLeaf(YType.uint32, "epe-label-version")

                                            self.epe_standby_version = YLeaf(YType.uint32, "epe-standby-version")

                                            self.epe_table_version = YLeaf(YType.uint32, "epe-table-version")

                                            self.gwaf_name = YLeaf(YType.enumeration, "gwaf-name")

                                            self.nh_nexthop_version = YLeaf(YType.uint32, "nh-nexthop-version")

                                            self.nh_rib_up = YLeaf(YType.boolean, "nh-rib-up")

                                            self.nh_rib_version = YLeaf(YType.uint32, "nh-rib-version")

                                            self.nh_table_id = YLeaf(YType.uint32, "nh-table-id")

                                            self.non_critical_trigger_delay = YLeaf(YType.uint32, "non-critical-trigger-delay")

                                            self.table_active = YLeaf(YType.boolean, "table-active")

                                            self.total_nexthops = YLeaf(YType.uint32, "total-nexthops")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")
                                            self._segment_path = lambda: "next-hop-af-vrf-af"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, ['af_name', 'critical_trigger_delay', 'epe_downloaded_version', 'epe_label_version', 'epe_standby_version', 'epe_table_version', 'gwaf_name', 'nh_nexthop_version', 'nh_rib_up', 'nh_rib_version', 'nh_table_id', 'non_critical_trigger_delay', 'table_active', 'total_nexthops'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "next-hop-af-vrf-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.critical_notf_count = YLeaf(YType.uint32, "critical-notf-count")

                                                self.last_notf_bestpath_changes = YLeaf(YType.uint32, "last-notf-bestpath-changes")

                                                self.last_notf_bestpath_deletes = YLeaf(YType.uint32, "last-notf-bestpath-deletes")

                                                self.nexthops_removed_from_rib = YLeaf(YType.uint32, "nexthops-removed-from-rib")

                                                self.nexthops_resent_to_rib = YLeaf(YType.uint32, "nexthops-resent-to-rib")

                                                self.nexthops_sent_to_rib = YLeaf(YType.uint32, "nexthops-sent-to-rib")

                                                self.nh_batch_finish_calls = YLeaf(YType.uint32, "nh-batch-finish-calls")

                                                self.nh_flush_timer_calls = YLeaf(YType.uint32, "nh-flush-timer-calls")

                                                self.nh_last_a_sync_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-reg-ts")

                                                self.nh_last_a_sync_un_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-un-reg-ts")

                                                self.nh_last_batch_finish_ts = YLeaf(YType.uint32, "nh-last-batch-finish-ts")

                                                self.nh_last_flush_timer_ts = YLeaf(YType.uint32, "nh-last-flush-timer-ts")

                                                self.nh_last_sync_reg_ts = YLeaf(YType.uint32, "nh-last-sync-reg-ts")

                                                self.nh_peak_registrations = YLeaf(YType.uint32, "nh-peak-registrations")

                                                self.nh_pending_registrations = YLeaf(YType.uint32, "nh-pending-registrations")

                                                self.nh_sync_reg_calls = YLeaf(YType.uint32, "nh-sync-reg-calls")

                                                self.nha_sync_reg_calls = YLeaf(YType.uint32, "nha-sync-reg-calls")

                                                self.nha_sync_un_reg_calls = YLeaf(YType.uint32, "nha-sync-un-reg-calls")

                                                self.nhrib_update_calls = YLeaf(YType.uint32, "nhrib-update-calls")

                                                self.nhrib_update_time = YLeaf(YType.uint32, "nhrib-update-time")

                                                self.noncritical_notf_count = YLeaf(YType.uint32, "noncritical-notf-count")

                                                self.rib_sync_registers_failed = YLeaf(YType.uint32, "rib-sync-registers-failed")

                                                self.riba_sync_registers_failed = YLeaf(YType.uint32, "riba-sync-registers-failed")

                                                self.ribnh_reg_failed_for_no_rib_conn = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-rib-conn")

                                                self.ribnh_reg_failed_for_no_tbl_id = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-tbl-id")

                                                self.tunnel_walk_backup_creates = YLeaf(YType.uint32, "tunnel-walk-backup-creates")

                                                self.tunnel_walk_gw_not_found = YLeaf(YType.uint32, "tunnel-walk-gw-not-found")

                                                self.tunnel_walk_nh_not_found = YLeaf(YType.uint32, "tunnel-walk-nh-not-found")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, ['critical_notf_count', 'last_notf_bestpath_changes', 'last_notf_bestpath_deletes', 'nexthops_removed_from_rib', 'nexthops_resent_to_rib', 'nexthops_sent_to_rib', 'nh_batch_finish_calls', 'nh_flush_timer_calls', 'nh_last_a_sync_reg_ts', 'nh_last_a_sync_un_reg_ts', 'nh_last_batch_finish_ts', 'nh_last_flush_timer_ts', 'nh_last_sync_reg_ts', 'nh_peak_registrations', 'nh_pending_registrations', 'nh_sync_reg_calls', 'nha_sync_reg_calls', 'nha_sync_un_reg_calls', 'nhrib_update_calls', 'nhrib_update_time', 'noncritical_notf_count', 'rib_sync_registers_failed', 'riba_sync_registers_failed', 'ribnh_reg_failed_for_no_rib_conn', 'ribnh_reg_failed_for_no_tbl_id', 'tunnel_walk_backup_creates', 'tunnel_walk_gw_not_found', 'tunnel_walk_nh_not_found'], name, value)


                                    class NextHopAfs(Entity):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                            self.yang_name = "next-hop-afs"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"next-hop-af" : ("next_hop_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf)}

                                            self.next_hop_af = YList(self)
                                            self._segment_path = lambda: "next-hop-afs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                        class NextHopAf(Entity):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                self.yang_name = "next-hop-af"
                                                self.yang_parent_name = "next-hop-afs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress), "nexthop-internal-info" : ("nexthop_internal_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)}
                                                self._child_list_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress), "nexthop-gateway-info" : ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.attribute_set = YLeaf(YType.str, "attribute-set")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.nexthop_aigp_metric = YLeaf(YType.uint32, "nexthop-aigp-metric")

                                                self.nexthop_gateway_prefix_connected = YLeaf(YType.boolean, "nexthop-gateway-prefix-connected")

                                                self.nexthop_gateway_prefix_length = YLeaf(YType.uint32, "nexthop-gateway-prefix-length")

                                                self.nexthop_gateway_reachable = YLeaf(YType.boolean, "nexthop-gateway-reachable")

                                                self.nexthop_pending_registration = YLeaf(YType.uint8, "nexthop-pending-registration")

                                                self.nexthop_reference_count = YLeaf(YType.uint32, "nexthop-reference-count")

                                                self.nh_first_hop_if_handle = YLeaf(YType.str, "nh-first-hop-if-handle")

                                                self.nh_reference_count_total = YLeaf(YType.uint32, "nh-reference-count-total")

                                                self.rib_nexthop_id = YLeaf(YType.uint32, "rib-nexthop-id")

                                                self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self._children_name_map["nexthop_address"] = "nexthop-address"
                                                self._children_yang_names.add("nexthop-address")

                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"
                                                self._children_yang_names.add("nexthop-internal-info")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.neighbor_address = YList(self)
                                                self.nexthop_gateway_info = YList(self)
                                                self._segment_path = lambda: "next-hop-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['af_name', 'attribute_set', 'next_hop_address', 'nexthop_aigp_metric', 'nexthop_gateway_prefix_connected', 'nexthop_gateway_prefix_length', 'nexthop_gateway_reachable', 'nexthop_pending_registration', 'nexthop_reference_count', 'nh_first_hop_if_handle', 'nh_reference_count_total', 'rib_nexthop_id'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopAddress(Entity):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                    self.yang_name = "nexthop-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "nexthop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopGatewayInfo(Entity):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:   :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:   :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\:  str
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                    self.yang_name = "nexthop-gateway-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-route" : ("nexthop_route", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)}
                                                    self._child_list_classes = {"nexthop-route-path" : ("nexthop_route_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath)}

                                                    self.critical_events = YLeaf(YType.uint32, "critical-events")

                                                    self.last_event_since = YLeaf(YType.uint32, "last-event-since")

                                                    self.last_event_type = YLeaf(YType.enumeration, "last-event-type")

                                                    self.last_rib_update = YLeaf(YType.uint32, "last-rib-update")

                                                    self.last_update_type = YLeaf(YType.enumeration, "last-update-type")

                                                    self.nexthop_af_invalid_bits = YLeaf(YType.uint16, "nexthop-af-invalid-bits")

                                                    self.nexthop_metric = YLeaf(YType.uint32, "nexthop-metric")

                                                    self.nexthop_mpls_enabled = YLeaf(YType.boolean, "nexthop-mpls-enabled")

                                                    self.nexthop_mpls_interfaces = YLeaf(YType.uint32, "nexthop-mpls-interfaces")

                                                    self.nexthop_mpls_label = YLeaf(YType.uint32, "nexthop-mpls-label")

                                                    self.nexthop_route_path_count = YLeaf(YType.uint32, "nexthop-route-path-count")

                                                    self.nexthop_route_prefix_length = YLeaf(YType.uint8, "nexthop-route-prefix-length")

                                                    self.nexthop_route_protocol = YLeaf(YType.str, "nexthop-route-protocol")

                                                    self.nexthop_status = YLeaf(YType.uint8, "nexthop-status")

                                                    self.nexthop_tableid = YLeaf(YType.uint64, "nexthop-tableid")

                                                    self.non_critical_events = YLeaf(YType.uint32, "non-critical-events")

                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self._children_name_map["nexthop_route"] = "nexthop-route"
                                                    self._children_yang_names.add("nexthop-route")

                                                    self.nexthop_route_path = YList(self)
                                                    self._segment_path = lambda: "nexthop-gateway-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, ['critical_events', 'last_event_since', 'last_event_type', 'last_rib_update', 'last_update_type', 'nexthop_af_invalid_bits', 'nexthop_metric', 'nexthop_mpls_enabled', 'nexthop_mpls_interfaces', 'nexthop_mpls_label', 'nexthop_route_path_count', 'nexthop_route_prefix_length', 'nexthop_route_protocol', 'nexthop_status', 'nexthop_tableid', 'non_critical_events'], name, value)


                                                class NexthopRoute(Entity):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                        self.yang_name = "nexthop-route"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-route"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopRoutePath(Entity):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                        self.yang_name = "nexthop-route-path"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NexthopInternalInfo(Entity):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                    self.yang_name = "nexthop-internal-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)}
                                                    self._child_list_classes = {"nexthop-gateway-internal-info" : ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo), "nexthop-metrice" : ("nexthop_metrice", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice), "nexthop-refcount" : ("nexthop_refcount", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)}

                                                    self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                    self.nexthop_af_user_bits = YLeaf(YType.uint32, "nexthop-af-user-bits")

                                                    self.nexthop_flags = YLeaf(YType.uint32, "nexthop-flags")

                                                    self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                    self.nexthop_if_handle = YLeaf(YType.uint32, "nexthop-if-handle")

                                                    self.nexthop_label = YLeaf(YType.uint32, "nexthop-label")

                                                    self.nexthop_version = YLeaf(YType.uint32, "nexthop-version")

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"
                                                    self._children_yang_names.add("nexthop-address")

                                                    self.nexthop_gateway_internal_info = YList(self)
                                                    self.nexthop_metrice = YList(self)
                                                    self.nexthop_refcount = YList(self)
                                                    self._segment_path = lambda: "nexthop-internal-info"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, ['gateway_flags', 'nexthop_af_user_bits', 'nexthop_flags', 'nexthop_id', 'nexthop_if_handle', 'nexthop_label', 'nexthop_version'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopGatewayInternalInfo(Entity):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:   :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-internal-info"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                        self.registration_since = YLeaf(YType.uint32, "registration-since")

                                                        self.registration_type = YLeaf(YType.enumeration, "registration-type")
                                                        self._segment_path = lambda: "nexthop-gateway-internal-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, ['gateway_flags', 'registration_since', 'registration_type'], name, value)


                                                class NexthopMetrice(Entity):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                        self.yang_name = "nexthop-metrice"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nexthop-metrice"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, ['entry'], name, value)


                                                class NexthopRefcount(Entity):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                        self.yang_name = "nexthop-refcount"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nexthop-refcount"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, ['entry'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                            class PathLabeledTable(Entity):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable, self).__init__()

                                    self.yang_name = "path-labeled-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-labeled-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-labeled-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PathTable(Entity):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable, self).__init__()

                                    self.yang_name = "path-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PathUsedTable(Entity):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable, self).__init__()

                                    self.yang_name = "path-used-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path)}

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-used-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-used-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.path_id = YLeaf(YType.int32, "path-id")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.source_rd = YLeaf(YType.str, "source-rd")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"
                                        self._children_yang_names.add("path-information")
                                        self._segment_path = lambda: "path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class Policies(Entity):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies, self).__init__()

                                    self.yang_name = "policies"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"policy" : ("policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy)}

                                    self.policy = YList(self)
                                    self._segment_path = lambda: "policies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies, [], name, value)


                                class Policy(Entity):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy, self).__init__()

                                        self.yang_name = "policy"
                                        self.yang_parent_name = "policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.network = YLeaf(YType.str, "network")

                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                        self.rd = YLeaf(YType.str, "rd")

                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._children_yang_names.add("attributes-after-policy-in")

                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                        self._children_yang_names.add("attributes-after-policy-out")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                        self._children_yang_names.add("path-info-after-policy-in")

                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                        self._children_yang_names.add("path-info-after-policy-out")
                                        self._segment_path = lambda: "policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy, ['af_name', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class AttributesAfterPolicyOut(Entity):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                            self.yang_name = "attributes-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)}
                                            self._child_list_classes = {}

                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"
                                            self._children_yang_names.add("attr-set")

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"
                                            self._children_yang_names.add("common-attributes")

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._children_yang_names.add("ribrnh-ip")

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                            self._children_yang_names.add("rnh-addr")
                                            self._segment_path = lambda: "attributes-after-policy-out"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "attr-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                self.as_path = YLeaf(YType.str, "as-path")

                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                self.origin = YLeaf(YType.uint16, "origin")

                                                self.originator = YLeaf(YType.str, "originator")

                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                self._children_yang_names.add("tunnel-encap")

                                                self.cluster = YList(self)
                                                self.community = YList(self)
                                                self.connector_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.label_index_attr = YList(self)
                                                self.large_community = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self._segment_path = lambda: "common-attributes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "cluster"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "connector-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                            class L2Tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                            class LabelIndexAttr(Entity):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                    self.yang_name = "label-index-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "label-index-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                    self._segment_path = lambda: "large-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "ls-attr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.label = YLeaf(YType.uint32, "label")

                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                    self._child_list_classes = {}

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._children_yang_names.add("sr-policy")
                                                    self._segment_path = lambda: "tunnel-encap"


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                        self.state = YLeaf(YType.boolean, "state")

                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                        self._children_yang_names.add("allocated-binding-sid")

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                        self._children_yang_names.add("binding-sid")

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.type = YLeaf(YType.enumeration, "type")
                                                            self._segment_path = lambda: "binding-sid"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "segment"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "unknown-attribute"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "ribrnh-ip"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")

                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                self._segment_path = lambda: "rnh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInfoAfterPolicyIn(Entity):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                            self.yang_name = "path-info-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-in"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PathInfoAfterPolicyOut(Entity):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:  str
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                        
                                        .. attribute:: rcvd_label_count
                                        
                                        	Path received label count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_path_flags
                                        
                                        	Vpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                            self.yang_name = "path-info-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)}

                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                            self._children_yang_names.add("best-path-comp-winner")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"
                                            self._children_yang_names.add("gw-addr")

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                            self._children_yang_names.add("mdt-group-addr")

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                            self._children_yang_names.add("mvpn-nbr-addr")

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"
                                            self._children_yang_names.add("next-hop")

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"
                                            self._children_yang_names.add("nh-addr")

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                            self._children_yang_names.add("nh-tunnel")

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                            self._children_yang_names.add("vpn-nexthop-addr")

                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.extended_community = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.rcvd_label = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-out"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "best-path-comp-winner"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "extended-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "gw-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class L2VpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mdt-group-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.len = YLeaf(YType.enumeration, "len")
                                                self._segment_path = lambda: "nh-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                self._segment_path = lambda: "nh-tunnel"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "rcvd-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PrefixFilters(Entity):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters, self).__init__()

                                    self.yang_name = "prefix-filters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"prefix-filter" : ("prefix_filter", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter)}

                                    self.prefix_filter = YList(self)
                                    self._segment_path = lambda: "prefix-filters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters, [], name, value)


                                class PrefixFilter(Entity):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                        self.yang_name = "prefix-filter"
                                        self.yang_parent_name = "prefix-filters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr), "prefix-list-info" : ("prefix_list_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo)}
                                        self._child_list_classes = {}

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                        self._children_yang_names.add("neighbor-address-xr")

                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self
                                        self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                        self._children_yang_names.add("prefix-list-info")
                                        self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', 'af_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address-xr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PrefixListInfo(Entity):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                            self.yang_name = "prefix-list-info"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bgp-pfxlst" : ("bgp_pfxlst", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst)}

                                            self.bgp_pfxlst = YList(self)
                                            self._segment_path = lambda: "prefix-list-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                        class BgpPfxlst(Entity):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                self.yang_name = "bgp-pfxlst"
                                                self.yang_parent_name = "prefix-list-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix)}
                                                self._child_list_classes = {}

                                                self.is_prefix_grant = YLeaf(YType.boolean, "is-prefix-grant")

                                                self.max_prefix_length = YLeaf(YType.uint8, "max-prefix-length")

                                                self.min_prefix_length = YLeaf(YType.uint8, "min-prefix-length")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")
                                                self._segment_path = lambda: "bgp-pfxlst"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, ['is_prefix_grant', 'max_prefix_length', 'min_prefix_length', 'sequence_number'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "bgp-pfxlst"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RpcSets(Entity):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets, self).__init__()

                                    self.yang_name = "rpc-sets"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"rpc-set" : ("rpc_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet)}

                                    self.rpc_set = YList(self)
                                    self._segment_path = lambda: "rpc-sets"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets, [], name, value)


                                class RpcSet(Entity):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  <key>
                                    
                                    	Nexthop set index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                        self.yang_name = "rpc-set"
                                        self.yang_parent_name = "rpc-sets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop)}

                                        self.rpc_set_index = YLeaf(YType.int32, "rpc-set-index")

                                        self.label = YLeaf(YType.uint32, "label")

                                        self.next_hop_xr = YLeaf(YType.uint32, "next-hop-xr")

                                        self.ref_count = YLeaf(YType.uint32, "ref-count")

                                        self.next_hop = YList(self)
                                        self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + self.rpc_set_index.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', 'label', 'next_hop_xr', 'ref_count'], name, value)


                                    class NextHop(Entity):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                            self.yang_name = "next-hop"
                                            self.yang_parent_name = "rpc-set"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "next-hop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class RtSetCounters(Entity):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters, self).__init__()

                                    self.yang_name = "rt-set-counters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"rt-set-counter" : ("rt_set_counter", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter)}

                                    self.rt_set_counter = YList(self)
                                    self._segment_path = lambda: "rt-set-counters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters, [], name, value)


                                class RtSetCounter(Entity):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  <key>
                                    
                                    	RTSet ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                        self.yang_name = "rt-set-counter"
                                        self.yang_parent_name = "rt-set-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-target-set" : ("route_target_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet)}
                                        self._child_list_classes = {}

                                        self.rt_set_id = YLeaf(YType.int32, "rt-set-id")

                                        self.route_target_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self
                                        self._children_name_map["route_target_set"] = "route-target-set"
                                        self._children_yang_names.add("route-target-set")
                                        self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + self.rt_set_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                    class RouteTargetSet(Entity):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                            self.yang_name = "route-target-set"
                                            self.yang_parent_name = "rt-set-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"rt-set" : ("rt_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet)}

                                            self.rt_set_id = YLeaf(YType.uint32, "rt-set-id")

                                            self.rt_set_len = YLeaf(YType.uint8, "rt-set-len")

                                            self.rt_set_net_count = YLeaf(YType.uint32, "rt-set-net-count")

                                            self.rt_set = YList(self)
                                            self._segment_path = lambda: "route-target-set"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, ['rt_set_id', 'rt_set_len', 'rt_set_net_count'], name, value)


                                        class RtSet(Entity):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                self.yang_name = "rt-set"
                                                self.yang_parent_name = "route-target-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "rt-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, ['entry'], name, value)


                            class SourcedNetworks(Entity):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks, self).__init__()

                                    self.yang_name = "sourced-networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork)}

                                    self.sourced_network = YList(self)
                                    self._segment_path = lambda: "sourced-networks"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks, [], name, value)


                                class SourcedNetwork(Entity):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  <key>
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\:  bool
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                        self.yang_name = "sourced-network"
                                        self.yang_parent_name = "sourced-networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sourced-prefix" : ("sourced_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix)}
                                        self._child_list_classes = {}

                                        self.network = YLeaf(YType.str, "network")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.is_backdoor = YLeaf(YType.boolean, "is-backdoor")

                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self
                                        self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                        self._children_yang_names.add("sourced-prefix")
                                        self._segment_path = lambda: "sourced-network" + "[network='" + self.network.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', 'af_name', 'is_backdoor'], name, value)


                                    class SourcedPrefix(Entity):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                            self.yang_name = "sourced-prefix"
                                            self.yang_parent_name = "sourced-network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "sourced-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "sourced-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class UpdateGenerationAddressFamily(Entity):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\:  bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                    self.yang_name = "update-generation-address-family"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics)}
                                    self._child_list_classes = {}

                                    self.configured_update_limit_af = YLeaf(YType.uint32, "configured-update-limit-af")

                                    self.configured_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "configured-update-limit-sub-group-ibgp")

                                    self.configured_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "configured-update-limit-subgrp-ebgp")

                                    self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                                    self.current_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "current-update-limit-sub-group-ibgp")

                                    self.current_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "current-update-limit-subgrp-ebgp")

                                    self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                    self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                    self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                    self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                    self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                    self.table_neighbor_count = YLeaf(YType.uint32, "table-neighbor-count")

                                    self.table_refresh_sub_group_count = YLeaf(YType.uint32, "table-refresh-sub-group-count")

                                    self.table_refresh_sub_group_throttled_count = YLeaf(YType.uint32, "table-refresh-sub-group-throttled-count")

                                    self.table_sub_group_throttled_count = YLeaf(YType.uint32, "table-sub-group-throttled-count")

                                    self.table_update_group_count = YLeaf(YType.uint32, "table-update-group-count")

                                    self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                    self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                    self.update_min_neighbor_version = YLeaf(YType.uint32, "update-min-neighbor-version")

                                    self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                    self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                    self.update_rib_version = YLeaf(YType.uint32, "update-rib-version")

                                    self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                    self.update_table_filter_group_count = YLeaf(YType.uint32, "update-table-filter-group-count")

                                    self.update_table_sub_group_count = YLeaf(YType.uint32, "update-table-sub-group-count")

                                    self.update_table_vrf_name = YLeaf(YType.str, "update-table-vrf-name")

                                    self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                    self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")

                                    self.update_vrf_rd_version = YLeaf(YType.uint32, "update-vrf-rd-version")

                                    self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                    self.update_vrfaf_name = YLeaf(YType.uint32, "update-vrfaf-name")

                                    self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self._children_name_map["update_statistics"] = "update-statistics"
                                    self._children_yang_names.add("update-statistics")
                                    self._segment_path = lambda: "update-generation-address-family"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, ['configured_update_limit_af', 'configured_update_limit_sub_group_ibgp', 'configured_update_limit_subgrp_ebgp', 'current_update_limit_af', 'current_update_limit_sub_group_ibgp', 'current_update_limit_subgrp_ebgp', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'table_neighbor_count', 'table_refresh_sub_group_count', 'table_refresh_sub_group_throttled_count', 'table_sub_group_throttled_count', 'table_update_group_count', 'update_group_af_name', 'update_main_table_version', 'update_min_neighbor_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_rib_version', 'update_sub_group_count', 'update_table_filter_group_count', 'update_table_sub_group_count', 'update_table_vrf_name', 'update_throttled', 'update_update_group_count', 'update_vrf_rd_version', 'update_vrf_table_rib_version', 'update_vrfaf_name'], name, value)


                                class UpdateStatistics(Entity):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                        self.yang_name = "update-statistics"
                                        self.yang_parent_name = "update-generation-address-family"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                        self._child_list_classes = {}

                                        self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                        self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                        self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                        self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                        self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                        self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                        self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                        self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                        self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                        self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                        self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                        self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                        self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                        self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                        self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                        self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                        self._children_yang_names.add("last-update-cleared-timestamp")

                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                        self._children_yang_names.add("last-update-discard-timestamp")

                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                        self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                        self._children_yang_names.add("last-update-recovery-timestamp")

                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                        self._children_yang_names.add("last-update-throttle-timestamp")
                                        self._segment_path = lambda: "update-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                    class LastUpdateClearedTimestamp(Entity):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                            self.yang_name = "last-update-cleared-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-cleared-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateDiscardTimestamp(Entity):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                            self.yang_name = "last-update-discard-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-discard-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                            self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateRecoveryTimestamp(Entity):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                            self.yang_name = "last-update-recovery-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-recovery-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateThrottleTimestamp(Entity):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                            self.yang_name = "last-update-throttle-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-throttle-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationFilterGroups(Entity):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                    self.yang_name = "update-generation-filter-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-filter-group" : ("update_generation_filter_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup)}

                                    self.update_generation_filter_group = YList(self)
                                    self._segment_path = lambda: "update-generation-filter-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                class UpdateGenerationFilterGroup(Entity):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                        self.yang_name = "update-generation-filter-group"
                                        self.yang_parent_name = "update-generation-filter-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.parent_filter_group_index = YLeaf(YType.uint32, "parent-filter-group-index")

                                        self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                        self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")
                                        self._segment_path = lambda: "update-generation-filter-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['filter_group_index', 'neighbor_count', 'parent_filter_group_index', 'parent_sub_group_id', 'parent_sub_group_index', 'process_id', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_filter_group_index', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_vrf_name'], name, value)


                            class UpdateGenerationNeighbors(Entity):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                    self.yang_name = "update-generation-neighbors"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-neighbor" : ("update_generation_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor)}

                                    self.update_generation_neighbor = YList(self)
                                    self._segment_path = lambda: "update-generation-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                class UpdateGenerationNeighbor(Entity):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                        self.yang_name = "update-generation-neighbor"
                                        self.yang_parent_name = "update-generation-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-default-originate-timestamp" : ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp), "first-update-queued-timestamp" : ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp), "first-update-write-timestamp" : ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp), "last-default-originate-timestamp" : ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp), "last-filter-group-add-timestamp" : ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp), "last-filter-group-remove-timestamp" : ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp), "last-refresh-update-queued-timestamp" : ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp), "last-refresh-update-write-timestamp" : ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp), "last-sub-group-add-timestamp" : ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp), "last-sub-group-remove-timestamp" : ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp), "last-update-group-expiry-timestamp" : ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp), "last-update-group-start-timestamp" : ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp), "last-update-write-timestamp" : ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.ack_version = YLeaf(YType.uint32, "ack-version")

                                        self.current_update_group_af_name = YLeaf(YType.enumeration, "current-update-group-af-name")

                                        self.default_originate_internal_context = YLeaf(YType.int32, "default-originate-internal-context")

                                        self.default_originate_state = YLeaf(YType.int32, "default-originate-state")

                                        self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                        self.inbound_refresh_count = YLeaf(YType.uint32, "inbound-refresh-count")

                                        self.is_eor_outstanding = YLeaf(YType.boolean, "is-eor-outstanding")

                                        self.is_update_group_timer_running = YLeaf(YType.boolean, "is-update-group-timer-running")

                                        self.last_default_originate_age = YLeaf(YType.uint32, "last-default-originate-age")

                                        self.last_refresh_update_queued_age = YLeaf(YType.uint32, "last-refresh-update-queued-age")

                                        self.last_refresh_update_write_age = YLeaf(YType.uint32, "last-refresh-update-write-age")

                                        self.last_update_group_af_name = YLeaf(YType.enumeration, "last-update-group-af-name")

                                        self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                        self.last_update_write_age = YLeaf(YType.uint32, "last-update-write-age")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                        self.outbound_refresh_count = YLeaf(YType.uint32, "outbound-refresh-count")

                                        self.outstanding_version_count = YLeaf(YType.uint32, "outstanding-version-count")

                                        self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_ack_version = YLeaf(YType.uint32, "refresh-ack-version")

                                        self.refresh_filter_group_index = YLeaf(YType.uint32, "refresh-filter-group-index")

                                        self.refresh_next_resume_version = YLeaf(YType.uint32, "refresh-next-resume-version")

                                        self.refresh_pending_target_version = YLeaf(YType.uint32, "refresh-pending-target-version")

                                        self.refresh_requested_target_version = YLeaf(YType.uint32, "refresh-requested-target-version")

                                        self.refresh_sub_group_id = YLeaf(YType.uint32, "refresh-sub-group-id")

                                        self.refresh_sub_group_index = YLeaf(YType.uint32, "refresh-sub-group-index")

                                        self.refresh_update_out_queue_messages = YLeaf(YType.uint32, "refresh-update-out-queue-messages")

                                        self.refresh_update_out_queue_size = YLeaf(YType.uint32, "refresh-update-out-queue-size")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.synced_ack_version = YLeaf(YType.uint32, "synced-ack-version")

                                        self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                        self.update_filter_group_messages = YLeaf(YType.uint32, "update-filter-group-messages")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                        self.update_refresh_version = YLeaf(YType.uint32, "update-refresh-version")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"
                                        self._children_yang_names.add("first-default-originate-timestamp")

                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"
                                        self._children_yang_names.add("first-update-queued-timestamp")

                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"
                                        self._children_yang_names.add("first-update-write-timestamp")

                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"
                                        self._children_yang_names.add("last-default-originate-timestamp")

                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"
                                        self._children_yang_names.add("last-filter-group-add-timestamp")

                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"
                                        self._children_yang_names.add("last-filter-group-remove-timestamp")

                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"
                                        self._children_yang_names.add("last-refresh-update-queued-timestamp")

                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"
                                        self._children_yang_names.add("last-refresh-update-write-timestamp")

                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"
                                        self._children_yang_names.add("last-sub-group-add-timestamp")

                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"
                                        self._children_yang_names.add("last-sub-group-remove-timestamp")

                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"
                                        self._children_yang_names.add("last-update-group-expiry-timestamp")

                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"
                                        self._children_yang_names.add("last-update-group-start-timestamp")

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                        self._children_yang_names.add("last-update-queued-timestamp")

                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"
                                        self._children_yang_names.add("last-update-write-timestamp")

                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                        self._children_yang_names.add("update-neighbor-address")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['ack_version', 'current_update_group_af_name', 'default_originate_internal_context', 'default_originate_state', 'filter_group_index', 'inbound_refresh_count', 'is_eor_outstanding', 'is_update_group_timer_running', 'last_default_originate_age', 'last_refresh_update_queued_age', 'last_refresh_update_write_age', 'last_update_group_af_name', 'last_update_queued_age', 'last_update_write_age', 'neighbor_address', 'next_resume_version', 'outbound_refresh_count', 'outstanding_version_count', 'pending_target_version', 'process_id', 'refresh_ack_version', 'refresh_filter_group_index', 'refresh_next_resume_version', 'refresh_pending_target_version', 'refresh_requested_target_version', 'refresh_sub_group_id', 'refresh_sub_group_index', 'refresh_update_out_queue_messages', 'refresh_update_out_queue_size', 'sub_group_id', 'sub_group_index', 'sub_group_index_xr', 'synced_ack_version', 'update_filter_group_index', 'update_filter_group_messages', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_refresh_version', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                    class FirstDefaultOriginateTimestamp(Entity):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "first-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-default-originate-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateQueuedTimestamp(Entity):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "first-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWriteTimestamp(Entity):
                                        """
                                        First update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "first-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastDefaultOriginateTimestamp(Entity):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "last-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-default-originate-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastFilterGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-filter-group-add-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastFilterGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-filter-group-remove-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRefreshUpdateQueuedTimestamp(Entity):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-refresh-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRefreshUpdateWriteTimestamp(Entity):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-refresh-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastSubGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-sub-group-add-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastSubGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-sub-group-remove-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateGroupExpiryTimestamp(Entity):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-group-expiry-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateGroupStartTimestamp(Entity):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-start-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-group-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWriteTimestamp(Entity):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-write-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateNeighborAddress(Entity):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                            self.yang_name = "update-neighbor-address"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "update-neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationSubGroups(Entity):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                    self.yang_name = "update-generation-sub-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-sub-group" : ("update_generation_sub_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup)}

                                    self.update_generation_sub_group = YList(self)
                                    self._segment_path = lambda: "update-generation-sub-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                class UpdateGenerationSubGroup(Entity):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                        self.yang_name = "update-generation-sub-group"
                                        self.yang_parent_name = "update-generation-sub-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"creation-timestamp" : ("creation_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp), "first-update-walk-end-timestamp" : ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp), "first-update-walk-start-timestamp" : ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp), "last-merge-timestamp" : ("last_merge_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp), "last-update-walk-end-timestamp" : ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp), "last-update-walk-start-timestamp" : ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.configured_update_limit_sub_group = YLeaf(YType.uint32, "configured-update-limit-sub-group")

                                        self.current_update_limit_sub_group = YLeaf(YType.uint32, "current-update-limit-sub-group")

                                        self.eo_r_attempted = YLeaf(YType.boolean, "eo-r-attempted")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.io_write_event_pending = YLeaf(YType.boolean, "io-write-event-pending")

                                        self.last_merged_sub_group_index = YLeaf(YType.uint32, "last-merged-sub-group-index")

                                        self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                        self.last_update_walk_end_age = YLeaf(YType.uint32, "last-update-walk-end-age")

                                        self.merge_count = YLeaf(YType.uint32, "merge-count")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                        self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                        self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                        self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                        self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                        self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                        self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                        self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                        self.update_default_route_sent = YLeaf(YType.boolean, "update-default-route-sent")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.version = YLeaf(YType.uint32, "version")

                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self._children_name_map["creation_timestamp"] = "creation-timestamp"
                                        self._children_yang_names.add("creation-timestamp")

                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"
                                        self._children_yang_names.add("first-update-walk-end-timestamp")

                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"
                                        self._children_yang_names.add("first-update-walk-start-timestamp")

                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"
                                        self._children_yang_names.add("last-merge-timestamp")

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                        self._children_yang_names.add("last-update-queued-timestamp")

                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"
                                        self._children_yang_names.add("last-update-walk-end-timestamp")

                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"
                                        self._children_yang_names.add("last-update-walk-start-timestamp")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-sub-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['configured_update_limit_sub_group', 'current_update_limit_sub_group', 'eo_r_attempted', 'filter_group_count', 'io_write_event_pending', 'last_merged_sub_group_index', 'last_update_queued_age', 'last_update_walk_end_age', 'merge_count', 'neighbor_count', 'next_resume_version', 'nsr_version', 'parent_sub_group_id', 'parent_sub_group_index', 'pending_target_version', 'process_id', 'refresh_sub_group_count', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_default_route_sent', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_throttled', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                    class CreationTimestamp(Entity):
                                        """
                                        Creation time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                            self.yang_name = "creation-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "creation-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWalkEndTimestamp(Entity):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-walk-end-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstUpdateWalkStartTimestamp(Entity):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-update-walk-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastMergeTimestamp(Entity):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                            self.yang_name = "last-merge-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-merge-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-queued-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWalkEndTimestamp(Entity):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-walk-end-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateWalkStartTimestamp(Entity):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-walk-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGenerationUpdateGroups(Entity):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                    self.yang_name = "update-generation-update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-generation-update-group" : ("update_generation_update_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup)}

                                    self.update_generation_update_group = YList(self)
                                    self._segment_path = lambda: "update-generation-update-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                class UpdateGenerationUpdateGroup(Entity):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  <key>
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                        self.yang_name = "update-generation-update-group"
                                        self.yang_parent_name = "update-generation-update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-timer-delay-value" : ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue), "last-update-timer-expiry-timestamp" : ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp), "last-update-timer-remaining-value" : ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue), "last-update-timer-start-timestamp" : ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp), "last-update-timer-stop-timestamp" : ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.is_permanent = YLeaf(YType.boolean, "is-permanent")

                                        self.is_update_timer_running = YLeaf(YType.boolean, "is-update-timer-running")

                                        self.last_update_timer_expiry_age = YLeaf(YType.uint32, "last-update-timer-expiry-age")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.neighbor_leaving_count = YLeaf(YType.uint32, "neighbor-leaving-count")

                                        self.neighbor_session_af_name = YLeaf(YType.uint8, "neighbor-session-af-name")

                                        self.perm_pelem_allowed = YLeaf(YType.uint32, "perm-pelem-allowed")

                                        self.perm_pelem_encountered = YLeaf(YType.uint32, "perm-pelem-encountered")

                                        self.perm_pelem_exp_wdr = YLeaf(YType.uint32, "perm-pelem-exp-wdr")

                                        self.perm_pelem_not_allowed = YLeaf(YType.uint32, "perm-pelem-not-allowed")

                                        self.perm_pelem_spur_wdr = YLeaf(YType.uint32, "perm-pelem-spur-wdr")

                                        self.process_id = YLeaf(YType.uint32, "process-id")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                        self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                        self.update_generation_recovery_pending = YLeaf(YType.boolean, "update-generation-recovery-pending")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_flags2 = YLeaf(YType.uint32, "update-group-flags2")

                                        self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                        self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"
                                        self._children_yang_names.add("last-update-timer-delay-value")

                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"
                                        self._children_yang_names.add("last-update-timer-expiry-timestamp")

                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"
                                        self._children_yang_names.add("last-update-timer-remaining-value")

                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"
                                        self._children_yang_names.add("last-update-timer-start-timestamp")

                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"
                                        self._children_yang_names.add("last-update-timer-stop-timestamp")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + self.update_group_index.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', 'filter_group_count', 'is_permanent', 'is_update_timer_running', 'last_update_timer_expiry_age', 'neighbor_count', 'neighbor_leaving_count', 'neighbor_session_af_name', 'perm_pelem_allowed', 'perm_pelem_encountered', 'perm_pelem_exp_wdr', 'perm_pelem_not_allowed', 'perm_pelem_spur_wdr', 'process_id', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_generation_recovery_pending', 'update_group_af_name', 'update_group_flags2', 'update_group_index_xr', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_vrf_name'], name, value)


                                    class LastUpdateTimerDelayValue(Entity):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                            self.yang_name = "last-update-timer-delay-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-delay-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerExpiryTimestamp(Entity):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-expiry-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerRemainingValue(Entity):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                            self.yang_name = "last-update-timer-remaining-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-remaining-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerStartTimestamp(Entity):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-start-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-start-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastUpdateTimerStopTimestamp(Entity):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-stop-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-timer-stop-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateGroups(Entity):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups, self).__init__()

                                    self.yang_name = "update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"update-group" : ("update_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup)}

                                    self.update_group = YList(self)
                                    self._segment_path = lambda: "update-groups"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups, [], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\:  bool
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\:  str
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\:  bool
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\:  bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor), "update-sub-group" : ("update_sub_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup)}

                                        self.accepts_legacy_pe_rt_route = YLeaf(YType.boolean, "accepts-legacy-pe-rt-route")

                                        self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                        self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                        self.as_override = YLeaf(YType.boolean, "as-override")

                                        self.desync_count = YLeaf(YType.uint32, "desync-count")

                                        self.disable_def_vrf_imp_advertisement = YLeaf(YType.boolean, "disable-def-vrf-imp-advertisement")

                                        self.disable_native_advertisement = YLeaf(YType.boolean, "disable-native-advertisement")

                                        self.disable_vrf_re_imp_advertisement = YLeaf(YType.boolean, "disable-vrf-re-imp-advertisement")

                                        self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                        self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                        self.ext_nh_encoding = YLeaf(YType.boolean, "ext-nh-encoding")

                                        self.filter_group_id = YLeaf(YType.int32, "filter-group-id")

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")

                                        self.has_orf_receive_capability = YLeaf(YType.boolean, "has-orf-receive-capability")

                                        self.is4_byte_as_peer = YLeaf(YType.boolean, "is4-byte-as-peer")

                                        self.is_addpath_capable = YLeaf(YType.boolean, "is-addpath-capable")

                                        self.is_adv_capable = YLeaf(YType.boolean, "is-adv-capable")

                                        self.is_adv_perm_net_capable = YLeaf(YType.boolean, "is-adv-perm-net-capable")

                                        self.is_adv_reorg_capable = YLeaf(YType.boolean, "is-adv-reorg-capable")

                                        self.is_aigp_capable = YLeaf(YType.boolean, "is-aigp-capable")

                                        self.is_aigp_cost_community_capable = YLeaf(YType.boolean, "is-aigp-cost-community-capable")

                                        self.is_aigp_med_capable = YLeaf(YType.boolean, "is-aigp-med-capable")

                                        self.is_client_reflection_disabled = YLeaf(YType.boolean, "is-client-reflection-disabled")

                                        self.is_common_admin_peers = YLeaf(YType.boolean, "is-common-admin-peers")

                                        self.is_directly_connected_ebgp_v6_peers = YLeaf(YType.boolean, "is-directly-connected-ebgp-v6-peers")

                                        self.is_internal_peers = YLeaf(YType.boolean, "is-internal-peers")

                                        self.is_labeled_afi_enabled = YLeaf(YType.boolean, "is-labeled-afi-enabled")

                                        self.is_llgr_capable = YLeaf(YType.boolean, "is-llgr-capable")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_route_reflector_client = YLeaf(YType.boolean, "is-route-reflector-client")

                                        self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                        self.is_unlabeled_afi_enabled = YLeaf(YType.boolean, "is-unlabeled-afi-enabled")

                                        self.local_as = YLeaf(YType.uint32, "local-as")

                                        self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                        self.minimum_advertisement_interval = YLeaf(YType.uint32, "minimum-advertisement-interval")

                                        self.minimum_advertisement_interval_msecs = YLeaf(YType.uint32, "minimum-advertisement-interval-msecs")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                        self.refresh_subgrp_count = YLeaf(YType.uint32, "refresh-subgrp-count")

                                        self.remote_as = YLeaf(YType.uint32, "remote-as")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.session_af_name = YLeaf(YType.uint8, "session-af-name")

                                        self.should_remove_private_a_ss = YLeaf(YType.boolean, "should-remove-private-a-ss")

                                        self.should_remove_private_as_ent_path = YLeaf(YType.boolean, "should-remove-private-as-ent-path")

                                        self.should_send_communities = YLeaf(YType.boolean, "should-send-communities")

                                        self.should_send_ext_communities = YLeaf(YType.boolean, "should-send-ext-communities")

                                        self.should_send_gshut_community = YLeaf(YType.boolean, "should-send-gshut-community")

                                        self.should_send_stitching_rt = YLeaf(YType.boolean, "should-send-stitching-rt")

                                        self.soo_value = YLeaf(YType.str, "soo-value")

                                        self.split_horizon = YLeaf(YType.boolean, "split-horizon")

                                        self.subgrp_merge_count = YLeaf(YType.uint32, "subgrp-merge-count")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_group_id = YLeaf(YType.int32, "update-group-id")

                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                        self.updates_formatted = YLeaf(YType.uint32, "updates-formatted")

                                        self.updates_replicated = YLeaf(YType.uint32, "updates-replicated")

                                        self.updgrp_cluster_id = YLeaf(YType.uint32, "updgrp-cluster-id")

                                        self.updgrp_cluster_type = YLeaf(YType.uint8, "updgrp-cluster-type")

                                        self.use_next_hop_self = YLeaf(YType.boolean, "use-next-hop-self")

                                        self.use_next_hop_unchanged_mpath = YLeaf(YType.boolean, "use-next-hop-unchanged-mpath")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.neighbor = YList(self)
                                        self.update_sub_group = YList(self)
                                        self._segment_path = lambda: "update-group"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, ['accepts_legacy_pe_rt_route', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'as_override', 'desync_count', 'disable_def_vrf_imp_advertisement', 'disable_native_advertisement', 'disable_vrf_re_imp_advertisement', 'enable_label_stack', 'encapsulation_type', 'ext_nh_encoding', 'filter_group_id', 'gshut_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends', 'has_orf_receive_capability', 'is4_byte_as_peer', 'is_addpath_capable', 'is_adv_capable', 'is_adv_perm_net_capable', 'is_adv_reorg_capable', 'is_aigp_capable', 'is_aigp_cost_community_capable', 'is_aigp_med_capable', 'is_client_reflection_disabled', 'is_common_admin_peers', 'is_directly_connected_ebgp_v6_peers', 'is_internal_peers', 'is_labeled_afi_enabled', 'is_llgr_capable', 'is_orr_root_address_configured', 'is_route_reflector_client', 'is_send_mcast_attr_enabled', 'is_unlabeled_afi_enabled', 'local_as', 'local_as_replace_as', 'minimum_advertisement_interval', 'minimum_advertisement_interval_msecs', 'orr_group_index', 'orr_group_name', 'process_instance_id', 'refresh_subgrp_count', 'remote_as', 'route_policy_out', 'session_af_name', 'should_remove_private_a_ss', 'should_remove_private_as_ent_path', 'should_send_communities', 'should_send_ext_communities', 'should_send_gshut_community', 'should_send_stitching_rt', 'soo_value', 'split_horizon', 'subgrp_merge_count', 'update_group_af_name', 'update_group_id', 'update_group_number', 'updates_formatted', 'updates_replicated', 'updgrp_cluster_id', 'updgrp_cluster_type', 'use_next_hop_self', 'use_next_hop_unchanged_mpath'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                            self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                            self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                            self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                            self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                            self.updgen_timer_process_time = YLeaf(YType.uint64, "updgen-timer-process-time")

                                            self.updgen_timer_start_time = YLeaf(YType.uint64, "updgen-timer-start-time")

                                            self.updgen_timer_stop_time = YLeaf(YType.uint64, "updgen-timer-stop-time")
                                            self._segment_path = lambda: "performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, ['update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'updgen_timer_process_time', 'updgen_timer_start_time', 'updgen_timer_stop_time'], name, value)


                                    class UpdateSubGroup(Entity):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                            self.yang_name = "update-sub-group"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor), "update-filter-group" : ("update_filter_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)}

                                            self.filter_group = YLeaf(YType.uint16, "filter-group")

                                            self.update_sub_group_number = YLeaf(YType.uint32, "update-sub-group-number")

                                            self.wait_for_eo_rs = YLeaf(YType.boolean, "wait-for-eo-rs")

                                            self.neighbor = YList(self)
                                            self.update_filter_group = YList(self)
                                            self._segment_path = lambda: "update-sub-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, ['filter_group', 'update_sub_group_number', 'wait_for_eo_rs'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class UpdateFilterGroup(Entity):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                self.yang_name = "update-filter-group"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity), "neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor)}

                                                self.fgroup_advertised_prefixes = YLeaf(YType.uint32, "fgroup-advertised-prefixes")

                                                self.fgroup_created_message_elements = YLeaf(YType.uint32, "fgroup-created-message-elements")

                                                self.fgroup_deleted_message_elements = YLeaf(YType.uint32, "fgroup-deleted-message-elements")

                                                self.fgroup_flags = YLeaf(YType.uint8, "fgroup-flags")

                                                self.fgroup_neighbors = YLeaf(YType.uint16, "fgroup-neighbors")

                                                self.fgroup_queued_message_elements = YLeaf(YType.uint32, "fgroup-queued-message-elements")

                                                self.fgroup_skipped_prefixes = YLeaf(YType.uint32, "fgroup-skipped-prefixes")

                                                self.fgroup_suppressed_prefixes = YLeaf(YType.uint32, "fgroup-suppressed-prefixes")

                                                self.fgroup_total_advertised_prefixes = YLeaf(YType.uint32, "fgroup-total-advertised-prefixes")

                                                self.fgroup_total_non_optimised_prefixes = YLeaf(YType.uint32, "fgroup-total-non-optimised-prefixes")

                                                self.fgroup_total_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-total-withdrawn-prefixes")

                                                self.fgroup_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-withdrawn-prefixes")

                                                self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                self.rts = YLeaf(YType.uint32, "rts")

                                                self.update_filter_group_number = YLeaf(YType.uint32, "update-filter-group-number")

                                                self.extended_community = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-filter-group"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, ['fgroup_advertised_prefixes', 'fgroup_created_message_elements', 'fgroup_deleted_message_elements', 'fgroup_flags', 'fgroup_neighbors', 'fgroup_queued_message_elements', 'fgroup_skipped_prefixes', 'fgroup_suppressed_prefixes', 'fgroup_total_advertised_prefixes', 'fgroup_total_non_optimised_prefixes', 'fgroup_total_withdrawn_prefixes', 'fgroup_withdrawn_prefixes', 'is_rt_present', 'rts', 'update_filter_group_number'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, ['entry'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class Bmp(Entity):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp, self).__init__()

                            self.yang_name = "bmp"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"server-neighbors" : ("server_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors), "server-summaries" : ("server_summaries", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries)}
                            self._child_list_classes = {}

                            self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self._children_name_map["server_neighbors"] = "server-neighbors"
                            self._children_yang_names.add("server-neighbors")

                            self.server_summaries = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self
                            self._children_name_map["server_summaries"] = "server-summaries"
                            self._children_yang_names.add("server-summaries")
                            self._segment_path = lambda: "bmp"


                        class ServerNeighbors(Entity):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors, self).__init__()

                                self.yang_name = "server-neighbors"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"server-neighbor" : ("server_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor)}

                                self.server_neighbor = YList(self)
                                self._segment_path = lambda: "server-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors, [], name, value)


                            class ServerNeighbor(Entity):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                    self.yang_name = "server-neighbor"
                                    self.yang_parent_name = "server-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"monitored-neighbors" : ("monitored_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors)}
                                    self._child_list_classes = {}

                                    self.server_id = YLeaf(YType.uint32, "server-id")

                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self
                                    self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                    self._children_yang_names.add("monitored-neighbors")
                                    self._segment_path = lambda: "server-neighbor" + "[server-id='" + self.server_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                class MonitoredNeighbors(Entity):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                        self.yang_name = "monitored-neighbors"
                                        self.yang_parent_name = "server-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"monitored-neighbor" : ("monitored_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor)}

                                        self.monitored_neighbor = YList(self)
                                        self._segment_path = lambda: "monitored-neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                    class MonitoredNeighbor(Entity):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                        
                                        	Number of Route Monitor EOR Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                            self.yang_name = "monitored-neighbor"
                                            self.yang_parent_name = "monitored-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bmp-neighbor-address" : ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress)}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.bmp_neighbor_msg_dropped = YLeaf(YType.uint32, "bmp-neighbor-msg-dropped")

                                            self.bmp_neighbor_msg_pending = YLeaf(YType.uint32, "bmp-neighbor-msg-pending")

                                            self.bmp_neighbor_path_update_drop = YLeaf(YType.uint32, "bmp-neighbor-path-update-drop")

                                            self.bmp_neighbor_path_update_sent = YLeaf(YType.uint32, "bmp-neighbor-path-update-sent")

                                            self.bmp_neighbor_path_withdraw_drop = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-drop")

                                            self.bmp_neighbor_path_withdraw_sent = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-sent")

                                            self.bmp_neighbor_peer_down_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-down-sent")

                                            self.bmp_neighbor_peer_up_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-up-sent")

                                            self.bmp_neighbor_route_monitor_eor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-eor-sent")

                                            self.bmp_neighbor_route_monitor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-sent")

                                            self.bmp_neighbor_upd_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-upd-msg-sent")

                                            self.bmp_neighbor_wdraw_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-wdraw-msg-sent")

                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                            self._children_yang_names.add("bmp-neighbor-address")
                                            self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', 'bmp_neighbor_msg_dropped', 'bmp_neighbor_msg_pending', 'bmp_neighbor_path_update_drop', 'bmp_neighbor_path_update_sent', 'bmp_neighbor_path_withdraw_drop', 'bmp_neighbor_path_withdraw_sent', 'bmp_neighbor_peer_down_sent', 'bmp_neighbor_peer_up_sent', 'bmp_neighbor_route_monitor_eor_sent', 'bmp_neighbor_route_monitor_sent', 'bmp_neighbor_upd_msg_sent', 'bmp_neighbor_wdraw_msg_sent'], name, value)


                                        class BmpNeighborAddress(Entity):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-neighbor-address"
                                                self.yang_parent_name = "monitored-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "bmp-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class ServerSummaries(Entity):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries, self).__init__()

                                self.yang_name = "server-summaries"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"server-summary" : ("server_summary", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary)}

                                self.server_summary = YList(self)
                                self._segment_path = lambda: "server-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries, [], name, value)


                            class ServerSummary(Entity):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_maximum_buffer_size_route_mon
                                
                                	Buffer limit used for route mon
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_reset_walk_in_progress
                                
                                	Reset walk in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_rmon_cur_buffer_size
                                
                                	Current Buffer usage per BMP Route Mon
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\:  str
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\:  bool
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:   :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_server_up_count
                                
                                	Number of BMP server that are UP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_upd_gen_in_progress
                                
                                	Update generation in progress
                                	**type**\:  bool
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:   :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\:  str
                                
                                .. attribute:: bmpafi_info
                                
                                	AFI specific info for BMP server
                                	**type**\: list of    :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpr_mon_eo_rmessages
                                
                                	Total bmpQ EOR update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\:  str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                    self.yang_name = "server-summary"
                                    self.yang_parent_name = "server-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"bmp-server-last-discon-time" : ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime), "bmp-server-state-age" : ("bmp_server_state_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge), "bmp-server-state-time-spec" : ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec), "update-source-address" : ("update_source_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)}
                                    self._child_list_classes = {"bmpafi-info" : ("bmpafi_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo)}

                                    self.server_id = YLeaf(YType.uint32, "server-id")

                                    self.bmp_bytes_written_tcp = YLeaf(YType.uint64, "bmp-bytes-written-tcp")

                                    self.bmp_init_msg_count = YLeaf(YType.uint32, "bmp-init-msg-count")

                                    self.bmp_maximum_buffer_size_route_mon = YLeaf(YType.uint64, "bmp-maximum-buffer-size-route-mon")

                                    self.bmp_messages_wdraw_discarded = YLeaf(YType.uint32, "bmp-messages-wdraw-discarded")

                                    self.bmp_peer_msg_drop_count = YLeaf(YType.uint32, "bmp-peer-msg-drop-count")

                                    self.bmp_peer_msg_pending_count = YLeaf(YType.uint32, "bmp-peer-msg-pending-count")

                                    self.bmp_peer_msg_pending_count_hwts = YLeaf(YType.uint64, "bmp-peer-msg-pending-count-hwts")

                                    self.bmp_peer_msg_pending_count_max = YLeaf(YType.uint32, "bmp-peer-msg-pending-count-max")

                                    self.bmp_per_peer_msg_count = YLeaf(YType.uint32, "bmp-per-peer-msg-count")

                                    self.bmp_per_peer_msg_route_mon_count = YLeaf(YType.uint32, "bmp-per-peer-msg-route-mon-count")

                                    self.bmp_pfx_wdraw_discarded = YLeaf(YType.uint32, "bmp-pfx-wdraw-discarded")

                                    self.bmp_reset_walk_in_progress = YLeaf(YType.boolean, "bmp-reset-walk-in-progress")

                                    self.bmp_rmon_cur_buffer_size = YLeaf(YType.uint64, "bmp-rmon-cur-buffer-size")

                                    self.bmp_server_host_name = YLeaf(YType.str, "bmp-server-host-name")

                                    self.bmp_server_id = YLeaf(YType.uint8, "bmp-server-id")

                                    self.bmp_server_is_flapping = YLeaf(YType.boolean, "bmp-server-is-flapping")

                                    self.bmp_server_nbr_count = YLeaf(YType.uint32, "bmp-server-nbr-count")

                                    self.bmp_server_port = YLeaf(YType.uint32, "bmp-server-port")

                                    self.bmp_server_state = YLeaf(YType.enumeration, "bmp-server-state")

                                    self.bmp_server_up_count = YLeaf(YType.uint32, "bmp-server-up-count")

                                    self.bmp_status_report_count = YLeaf(YType.uint32, "bmp-status-report-count")

                                    self.bmp_termination_msg_count = YLeaf(YType.uint32, "bmp-termination-msg-count")

                                    self.bmp_upd_gen_in_progress = YLeaf(YType.boolean, "bmp-upd-gen-in-progress")

                                    self.bmp_update_mode = YLeaf(YType.enumeration, "bmp-update-mode")

                                    self.bmp_vrf_id = YLeaf(YType.uint32, "bmp-vrf-id")

                                    self.bmp_vrf_name = YLeaf(YType.str, "bmp-vrf-name")

                                    self.bmpq_last_all_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-all-write-pulse-sent-time")

                                    self.bmpq_last_write_pulse_cb_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-cb-time")

                                    self.bmpq_last_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-sent-time")

                                    self.bmpr_mon_eo_rmessages = YLeaf(YType.uint32, "bmpr-mon-eo-rmessages")

                                    self.bmpr_mon_upd_messages = YLeaf(YType.uint32, "bmpr-mon-upd-messages")

                                    self.bmpr_mon_update_gen_time = YLeaf(YType.uint32, "bmpr-mon-update-gen-time")

                                    self.bmpr_mon_wdraw_messages = YLeaf(YType.uint32, "bmpr-mon-wdraw-messages")

                                    self.path_update_count = YLeaf(YType.uint32, "path-update-count")

                                    self.path_update_drop = YLeaf(YType.uint32, "path-update-drop")

                                    self.path_withdraw_count = YLeaf(YType.uint32, "path-withdraw-count")

                                    self.path_withdraw_drop = YLeaf(YType.uint32, "path-withdraw-drop")

                                    self.tcp_keep_alive_interval = YLeaf(YType.uint32, "tcp-keep-alive-interval")

                                    self.tcp_last_write_cb_time = YLeaf(YType.uint64, "tcp-last-write-cb-time")

                                    self.tcp_last_write_result = YLeaf(YType.uint32, "tcp-last-write-result")

                                    self.tcp_last_write_time = YLeaf(YType.uint64, "tcp-last-write-time")

                                    self.tcp_maximum_segment_size = YLeaf(YType.uint32, "tcp-maximum-segment-size")

                                    self.tcp_write_cb_pending = YLeaf(YType.uint32, "tcp-write-cb-pending")

                                    self.tcp_write_time = YLeaf(YType.uint32, "tcp-write-time")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.update_source_interface_name = YLeaf(YType.str, "update-source-interface-name")

                                    self.update_source_vrf_id = YLeaf(YType.uint32, "update-source-vrf-id")

                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"
                                    self._children_yang_names.add("bmp-server-last-discon-time")

                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"
                                    self._children_yang_names.add("bmp-server-state-age")

                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"
                                    self._children_yang_names.add("bmp-server-state-time-spec")

                                    self.update_source_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self._children_name_map["update_source_address"] = "update-source-address"
                                    self._children_yang_names.add("update-source-address")

                                    self.bmpafi_info = YList(self)
                                    self._segment_path = lambda: "server-summary" + "[server-id='" + self.server_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary, ['server_id', 'bmp_bytes_written_tcp', 'bmp_init_msg_count', 'bmp_maximum_buffer_size_route_mon', 'bmp_messages_wdraw_discarded', 'bmp_peer_msg_drop_count', 'bmp_peer_msg_pending_count', 'bmp_peer_msg_pending_count_hwts', 'bmp_peer_msg_pending_count_max', 'bmp_per_peer_msg_count', 'bmp_per_peer_msg_route_mon_count', 'bmp_pfx_wdraw_discarded', 'bmp_reset_walk_in_progress', 'bmp_rmon_cur_buffer_size', 'bmp_server_host_name', 'bmp_server_id', 'bmp_server_is_flapping', 'bmp_server_nbr_count', 'bmp_server_port', 'bmp_server_state', 'bmp_server_up_count', 'bmp_status_report_count', 'bmp_termination_msg_count', 'bmp_upd_gen_in_progress', 'bmp_update_mode', 'bmp_vrf_id', 'bmp_vrf_name', 'bmpq_last_all_write_pulse_sent_time', 'bmpq_last_write_pulse_cb_time', 'bmpq_last_write_pulse_sent_time', 'bmpr_mon_eo_rmessages', 'bmpr_mon_upd_messages', 'bmpr_mon_update_gen_time', 'bmpr_mon_wdraw_messages', 'path_update_count', 'path_update_drop', 'path_withdraw_count', 'path_withdraw_drop', 'tcp_keep_alive_interval', 'tcp_last_write_cb_time', 'tcp_last_write_result', 'tcp_last_write_time', 'tcp_maximum_segment_size', 'tcp_write_cb_pending', 'tcp_write_time', 'tos_type', 'tos_value', 'update_source_interface_name', 'update_source_vrf_id'], name, value)


                                class BmpServerLastDisconTime(Entity):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                        self.yang_name = "bmp-server-last-discon-time"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-last-discon-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, ['nanoseconds', 'seconds'], name, value)


                                class BmpServerStateAge(Entity):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                        self.yang_name = "bmp-server-state-age"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-state-age"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, ['nanoseconds', 'seconds'], name, value)


                                class BmpServerStateTimeSpec(Entity):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                        self.yang_name = "bmp-server-state-time-spec"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "bmp-server-state-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpafiInfo(Entity):
                                    """
                                    AFI specific info for BMP server
                                    
                                    .. attribute:: bmp_filter_nbr_cnt
                                    
                                    	Filter nbr Count for this AFI
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_filter_neighbor_address
                                    
                                    	Filter Neighbor Address
                                    	**type**\:   :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                    
                                    .. attribute:: bmp_filter_neighbor_address_set
                                    
                                    	Filter Neighbor Address Set ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_init_eor_end_version
                                    
                                    	Version to reach to send EOR
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_eor_pending_cnt
                                    
                                    	Count for pending EOR
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_resume_prefix
                                    
                                    	BMP Resume prefix
                                    	**type**\:   :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                    
                                    .. attribute:: bmp_resume_prefix_len
                                    
                                    	BMP Resume prefix Len
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught upto
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_end_version
                                    
                                    	Update Gen ResumeWalk end version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_net_version
                                    
                                    	Update Gen ResumeWalk Net version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_start_version
                                    
                                    	Update Gen ResumeWalk start version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_count
                                    
                                    	Number of times Update Gen ran
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                    
                                    	Last Update Gen Run time stamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_count
                                    
                                    	Number of times Update Gen Stopped
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                    
                                    	Last Update Gen Stop time stamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stopped
                                    
                                    	Update Gen WalkStopped
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmpaf_name
                                    
                                    	BMP Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                        self.yang_name = "bmpafi-info"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-filter-neighbor-address" : ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress), "bmp-resume-prefix" : ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)}
                                        self._child_list_classes = {}

                                        self.bmp_filter_nbr_cnt = YLeaf(YType.uint32, "bmp-filter-nbr-cnt")

                                        self.bmp_filter_neighbor_address_set = YLeaf(YType.boolean, "bmp-filter-neighbor-address-set")

                                        self.bmp_init_eor_end_version = YLeaf(YType.uint32, "bmp-init-eor-end-version")

                                        self.bmp_init_eor_pending_cnt = YLeaf(YType.uint32, "bmp-init-eor-pending-cnt")

                                        self.bmp_resume_prefix_len = YLeaf(YType.uint32, "bmp-resume-prefix-len")

                                        self.bmp_send_version = YLeaf(YType.uint32, "bmp-send-version")

                                        self.bmp_upd_gen_resume_end_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-end-version")

                                        self.bmp_upd_gen_resume_net_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-net-version")

                                        self.bmp_upd_gen_resume_start_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-start-version")

                                        self.bmp_upd_gen_walk_run_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-count")

                                        self.bmp_upd_gen_walk_run_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-time-stamp")

                                        self.bmp_upd_gen_walk_stop_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-count")

                                        self.bmp_upd_gen_walk_stop_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-time-stamp")

                                        self.bmp_upd_gen_walk_stopped = YLeaf(YType.boolean, "bmp-upd-gen-walk-stopped")

                                        self.bmpaf_name = YLeaf(YType.enumeration, "bmpaf-name")

                                        self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                        self.bmp_filter_neighbor_address.parent = self
                                        self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                        self._children_yang_names.add("bmp-filter-neighbor-address")

                                        self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                        self.bmp_resume_prefix.parent = self
                                        self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"
                                        self._children_yang_names.add("bmp-resume-prefix")
                                        self._segment_path = lambda: "bmpafi-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, ['bmp_filter_nbr_cnt', 'bmp_filter_neighbor_address_set', 'bmp_init_eor_end_version', 'bmp_init_eor_pending_cnt', 'bmp_resume_prefix_len', 'bmp_send_version', 'bmp_upd_gen_resume_end_version', 'bmp_upd_gen_resume_net_version', 'bmp_upd_gen_resume_start_version', 'bmp_upd_gen_walk_run_count', 'bmp_upd_gen_walk_run_time_stamp', 'bmp_upd_gen_walk_stop_count', 'bmp_upd_gen_walk_stop_time_stamp', 'bmp_upd_gen_walk_stopped', 'bmpaf_name'], name, value)


                                    class BmpFilterNeighborAddress(Entity):
                                        """
                                        Filter Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                            self.yang_name = "bmp-filter-neighbor-address"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "bmp-filter-neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class BmpResumePrefix(Entity):
                                        """
                                        BMP Resume prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                            self.yang_name = "bmp-resume-prefix"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix)}
                                            self._child_list_classes = {}

                                            self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._children_yang_names.add("prefix")
                                            self._segment_path = lambda: "bmp-resume-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, ['prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bmp-resume-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateSourceAddress(Entity):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                        self.yang_name = "update-source-address"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-source-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class GlobalProcessInfo(Entity):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo, self).__init__()

                            self.yang_name = "global-process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf)}
                            self._child_list_classes = {}

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrfid = YLeaf(YType.uint32, "vrfid")

                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"
                            self._children_yang_names.add("global")

                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "global-process-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo, ['vrf_name', 'vrfid'], name, value)


                        class Global_(Entity):
                            """
                            Global information
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_cur_maximum_buffer_size
                            
                            	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                            
                            .. attribute:: color_id
                            
                            	All configured Color IDs
                            	**type**\: list of    :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ColorId>`
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\:  bool
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\:  str
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"cluster-id-entry" : ("cluster_id_entry", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry), "color-id" : ("color_id", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ColorId)}

                                self.asn_format = YLeaf(YType.uint32, "asn-format")

                                self.bmp_cur_maximum_buffer_size = YLeaf(YType.uint64, "bmp-cur-maximum-buffer-size")

                                self.bmp_current_buffer_size = YLeaf(YType.uint64, "bmp-current-buffer-size")

                                self.bmp_default_buffer_size = YLeaf(YType.uint64, "bmp-default-buffer-size")

                                self.bmp_maximum_buffer_size = YLeaf(YType.uint64, "bmp-maximum-buffer-size")

                                self.cluster_id = YLeaf(YType.uint32, "cluster-id")

                                self.confederation_id = YLeaf(YType.uint32, "confederation-id")

                                self.configured_cluster_id = YLeaf(YType.uint32, "configured-cluster-id")

                                self.generic_scan_period = YLeaf(YType.uint16, "generic-scan-period")

                                self.graceful_maint_all_nbrs = YLeaf(YType.boolean, "graceful-maint-all-nbrs")

                                self.graceful_maint_retain_routes = YLeaf(YType.boolean, "graceful-maint-retain-routes")

                                self.graceful_maintenance = YLeaf(YType.boolean, "graceful-maintenance")

                                self.in_standalone_mode = YLeaf(YType.boolean, "in-standalone-mode")

                                self.instance_name = YLeaf(YType.str, "instance-name")

                                self.is_cluster_id_specified_as_ip = YLeaf(YType.boolean, "is-cluster-id-specified-as-ip")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.process_rlimit = YLeaf(YType.uint64, "process-rlimit")

                                self.restart_count = YLeaf(YType.uint32, "restart-count")

                                self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                self.srgb_end_configured = YLeaf(YType.uint32, "srgb-end-configured")

                                self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                self.srgb_start_configured = YLeaf(YType.uint32, "srgb-start-configured")

                                self.update_delay = YLeaf(YType.uint32, "update-delay")

                                self.cluster_id_entry = YList(self)
                                self.color_id = YList(self)
                                self._segment_path = lambda: "global"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_, ['asn_format', 'bmp_cur_maximum_buffer_size', 'bmp_current_buffer_size', 'bmp_default_buffer_size', 'bmp_maximum_buffer_size', 'cluster_id', 'confederation_id', 'configured_cluster_id', 'generic_scan_period', 'graceful_maint_all_nbrs', 'graceful_maint_retain_routes', 'graceful_maintenance', 'in_standalone_mode', 'instance_name', 'is_cluster_id_specified_as_ip', 'local_as', 'process_rlimit', 'restart_count', 'srgb_end', 'srgb_end_configured', 'srgb_start', 'srgb_start_configured', 'update_delay'], name, value)


                            class ClusterIdEntry(Entity):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry, self).__init__()

                                    self.yang_name = "cluster-id-entry"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.cluster_id_type = YLeaf(YType.uint8, "cluster-id-type")

                                    self.cluster_id_val = YLeaf(YType.uint32, "cluster-id-val")
                                    self._segment_path = lambda: "cluster-id-entry"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry, ['cluster_id_type', 'cluster_id_val'], name, value)


                            class ColorId(Entity):
                                """
                                All configured Color IDs
                                
                                .. attribute:: color_id_val
                                
                                	Color ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ColorId, self).__init__()

                                    self.yang_name = "color-id"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.color_id_val = YLeaf(YType.uint32, "color-id-val")
                                    self._segment_path = lambda: "color-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ColorId, ['color_id_val'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\:  bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\:  bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.configured_router_id = YLeaf(YType.str, "configured-router-id")

                                self.default_local_preference = YLeaf(YType.uint32, "default-local-preference")

                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                self.hold_time = YLeaf(YType.uint16, "hold-time")

                                self.is_bestpath_aigp_ignore_enabled = YLeaf(YType.boolean, "is-bestpath-aigp-ignore-enabled")

                                self.is_bestpath_always_compare_med_enabled = YLeaf(YType.boolean, "is-bestpath-always-compare-med-enabled")

                                self.is_bestpath_as_path_mpath_relax_enabled = YLeaf(YType.boolean, "is-bestpath-as-path-mpath-relax-enabled")

                                self.is_bestpath_compare_med_from_confed_peer_enabled = YLeaf(YType.boolean, "is-bestpath-compare-med-from-confed-peer-enabled")

                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = YLeaf(YType.boolean, "is-bestpath-compare-router-id-for-ebgp-peers-enabled")

                                self.is_bestpath_ignore_as_path_enabled = YLeaf(YType.boolean, "is-bestpath-ignore-as-path-enabled")

                                self.is_bestpath_missing_med_is_worst_enabled = YLeaf(YType.boolean, "is-bestpath-missing-med-is-worst-enabled")

                                self.is_default_metric_configured = YLeaf(YType.boolean, "is-default-metric-configured")

                                self.is_default_originate_configured = YLeaf(YType.boolean, "is-default-originate-configured")

                                self.is_enforce_first_as_enabled = YLeaf(YType.boolean, "is-enforce-first-as-enabled")

                                self.is_fast_external_fallover_enabled = YLeaf(YType.boolean, "is-fast-external-fallover-enabled")

                                self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                                self.is_multipath_as_path_ignore_onwards_enabled = YLeaf(YType.boolean, "is-multipath-as-path-ignore-onwards-enabled")

                                self.is_neighbor_logging = YLeaf(YType.boolean, "is-neighbor-logging")

                                self.is_nsr = YLeaf(YType.boolean, "is-nsr")

                                self.is_redistribute_ibgp_to_ig_ps_enabled = YLeaf(YType.boolean, "is-redistribute-ibgp-to-ig-ps-enabled")

                                self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                self.min_acceptable_hold_time = YLeaf(YType.uint16, "min-acceptable-hold-time")

                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                self.rib_purge_timeout = YLeaf(YType.uint32, "rib-purge-timeout")

                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.stale_path_time = YLeaf(YType.uint32, "stale-path-time")

                                self.vrf_is_active = YLeaf(YType.boolean, "vrf-is-active")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf, ['configured_router_id', 'default_local_preference', 'default_metric', 'hold_time', 'is_bestpath_aigp_ignore_enabled', 'is_bestpath_always_compare_med_enabled', 'is_bestpath_as_path_mpath_relax_enabled', 'is_bestpath_compare_med_from_confed_peer_enabled', 'is_bestpath_compare_router_id_for_ebgp_peers_enabled', 'is_bestpath_ignore_as_path_enabled', 'is_bestpath_missing_med_is_worst_enabled', 'is_default_metric_configured', 'is_default_originate_configured', 'is_enforce_first_as_enabled', 'is_fast_external_fallover_enabled', 'is_graceful_restart', 'is_multipath_as_path_ignore_onwards_enabled', 'is_neighbor_logging', 'is_nsr', 'is_redistribute_ibgp_to_ig_ps_enabled', 'keep_alive_time', 'min_acceptable_hold_time', 'restart_time', 'rib_purge_timeout', 'route_distinguisher', 'router_id', 'stale_path_time', 'vrf_is_active'], name, value)


                    class Information(Entity):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")
                            self._segment_path = lambda: "information"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information, ['route_distinguisher'], name, value)


                    class MessageLogs(Entity):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs, self).__init__()

                            self.yang_name = "message-logs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"message-log" : ("message_log", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog)}

                            self.message_log = YList(self)
                            self._segment_path = lambda: "message-logs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs, [], name, value)


                        class MessageLog(Entity):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog, self).__init__()

                                self.yang_name = "message-log"
                                self.yang_parent_name = "message-logs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-message" : ("neighbor_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage)}

                                self.direction = YLeaf(YType.int32, "direction")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_message = YList(self)
                                self._segment_path = lambda: "message-log"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog, ['direction', 'neighbor_address'], name, value)


                            class NeighborMessage(Entity):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                    self.yang_name = "neighbor-message"
                                    self.yang_parent_name = "message-log"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"message-timestamp" : ("message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)}
                                    self._child_list_classes = {"logged-message-data" : ("logged_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData)}

                                    self.message_data_length = YLeaf(YType.uint16, "message-data-length")

                                    self.message_type_received = YLeaf(YType.uint8, "message-type-received")

                                    self.total_logged_message_count = YLeaf(YType.uint32, "total-logged-message-count")

                                    self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self._children_name_map["message_timestamp"] = "message-timestamp"
                                    self._children_yang_names.add("message-timestamp")

                                    self.logged_message_data = YList(self)
                                    self._segment_path = lambda: "neighbor-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, ['message_data_length', 'message_type_received', 'total_logged_message_count'], name, value)


                                class LoggedMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                        self.yang_name = "logged-message-data"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "logged-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, ['entry'], name, value)


                                class MessageTimestamp(Entity):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                        self.yang_name = "message-timestamp"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                    class NeighborRanges(Entity):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges, self).__init__()

                            self.yang_name = "neighbor-ranges"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-range" : ("neighbor_range", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange)}

                            self.neighbor_range = YList(self)
                            self._segment_path = lambda: "neighbor-ranges"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges, [], name, value)


                        class NeighborRange(Entity):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  <key>
                            
                            	Neighbor Range prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\:  bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\:  str
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\:  bool
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\:  bool
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\:  str
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\:  bool
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\:  bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange, self).__init__()

                                self.yang_name = "neighbor-range"
                                self.yang_parent_name = "neighbor-ranges"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"cfg-local-address" : ("cfg_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress), "connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance)}
                                self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData), "instance" : ("instance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance)}

                                self.neighbor_range_address = YLeaf(YType.str, "neighbor-range-address")

                                self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                self.addpath_receive_disable = YLeaf(YType.boolean, "addpath-receive-disable")

                                self.addpath_receive_enable = YLeaf(YType.boolean, "addpath-receive-enable")

                                self.addpath_send_disable = YLeaf(YType.boolean, "addpath-send-disable")

                                self.addpath_send_enable = YLeaf(YType.boolean, "addpath-send-enable")

                                self.attrf_group_name = YLeaf(YType.str, "attrf-group-name")

                                self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                self.current_peers = YLeaf(YType.uint32, "current-peers")

                                self.description = YLeaf(YType.str, "description")

                                self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                self.islocal_address_cfg = YLeaf(YType.boolean, "islocal-address-cfg")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                self.max_peers = YLeaf(YType.uint32, "max-peers")

                                self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                self.msg_bug_circular = YLeaf(YType.boolean, "msg-bug-circular")

                                self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                self.nbr_rcv_size = YLeaf(YType.uint32, "nbr-rcv-size")

                                self.nbr_send_size = YLeaf(YType.uint32, "nbr-send-size")

                                self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                self.neighbor_range_prefix_length = YLeaf(YType.uint8, "neighbor-range-prefix-length")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.oper_attrf_enable = YLeaf(YType.boolean, "oper-attrf-enable")

                                self.range_inst_error = YLeaf(YType.uint32, "range-inst-error")

                                self.range_max_drop = YLeaf(YType.uint32, "range-max-drop")

                                self.range_open_accepted = YLeaf(YType.uint32, "range-open-accepted")

                                self.range_open_match = YLeaf(YType.uint32, "range-open-match")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.remote_as_list_name = YLeaf(YType.str, "remote-as-list-name")

                                self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                self.syslog_enable = YLeaf(YType.boolean, "syslog-enable")

                                self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                self.tos_type = YLeaf(YType.uint8, "tos-type")

                                self.tos_value = YLeaf(YType.uint8, "tos-value")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.upd_errh_noreset = YLeaf(YType.boolean, "upd-errh-noreset")

                                self.update_source = YLeaf(YType.str, "update-source")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self._children_name_map["cfg_local_address"] = "cfg-local-address"
                                self._children_yang_names.add("cfg-local-address")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                self._children_yang_names.add("graceful-maintenance")

                                self.af_data = YList(self)
                                self.instance = YList(self)
                                self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + self.neighbor_range_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange, ['neighbor_range_address', 'active_bmp_servers', 'addpath_receive_disable', 'addpath_receive_enable', 'addpath_send_disable', 'addpath_send_enable', 'attrf_group_name', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_enable_mode', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'current_peers', 'description', 'discard_as4_path', 'dmz_link_bandwidth', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'idle_watch_time', 'ignore_connected', 'internal_vpn_client', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_passive_close', 'islocal_address_cfg', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'max_peers', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_buf_count', 'msg_bug_circular', 'msg_log_in', 'msg_log_out', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'nbr_rcv_size', 'nbr_send_size', 'neighbor_local_as', 'neighbor_range_prefix_length', 'nsr_enabled', 'oper_attrf_enable', 'range_inst_error', 'range_max_drop', 'range_open_accepted', 'range_open_match', 'remote_as', 'remote_as_list_name', 'remote_as_number', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'syslog_enable', 'tcp_session_open_mode', 'tcpmss', 'tos_type', 'tos_value', 'ttl_security_enabled', 'upd_errh_noreset', 'update_source', 'vrf_name'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby)}

                                    self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                    self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                    self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                    self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                    self.advertise_afi_local = YLeaf(YType.boolean, "advertise-afi-local")

                                    self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                    self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                    self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                    self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                    self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                    self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                    self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                    self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                    self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                    self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                    self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                    self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                    self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                    self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                    self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                    self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                    self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                    self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                    self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                    self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                    self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                    self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                    self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                    self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                    self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                    self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                    self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                    self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                    self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                    self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                    self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                    self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                    self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                    self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                    self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                    self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                    self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                    self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                    self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                    self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                    self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                    self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                    self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                    self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                    self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                    self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                    self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                    self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                    self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                    self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                    self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                    self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                    self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                    self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                    self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                    self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                    self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                    self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                    self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                    self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                    self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                    self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                    self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                    self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                    self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                    self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                    self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                    self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                    self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                    self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                    self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                    self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                    self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                    self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                    self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                    self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                    self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                    self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                    self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                    self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                    self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                    self.weight = YLeaf(YType.uint32, "weight")

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData, ['accept_own_enabled', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_disable', 'advertise_afi_local', 'advertise_afi_reorg', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'next_hop_unchanged', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, ['entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community-standby"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                            class CfgLocalAddress(Entity):
                                """
                                Configured local address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                    self.yang_name = "cfg-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "cfg-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                    self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                    self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                    self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                    self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                    self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                    self._segment_path = lambda: "graceful-maintenance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                            class Instance(Entity):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance, self).__init__()

                                    self.yang_name = "instance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"idle-watch-timer-remaining-value" : ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress), "neighbor-age" : ("neighbor_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge)}
                                    self._child_list_classes = {}

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.is_idle_watch_timer_running = YLeaf(YType.boolean, "is-idle-watch-timer-running")

                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                    self._children_yang_names.add("idle-watch-timer-remaining-value")

                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._children_yang_names.add("neighbor-address")

                                    self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge()
                                    self.neighbor_age.parent = self
                                    self._children_name_map["neighbor_age"] = "neighbor-age"
                                    self._children_yang_names.add("neighbor-age")
                                    self._segment_path = lambda: "instance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance, ['connection_state', 'is_idle_watch_timer_running'], name, value)


                                class IdleWatchTimerRemainingValue(Entity):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, self).__init__()

                                        self.yang_name = "idle-watch-timer-remaining-value"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "idle-watch-timer-remaining-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class NeighborAge(Entity):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge, self).__init__()

                                        self.yang_name = "neighbor-age"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "neighbor-age"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance.NeighborAge, ['nanoseconds', 'seconds'], name, value)


                    class Neighbors(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\:  bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\:  bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\:  bool
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\:  bool
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\:  bool
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)}
                                self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                self.description = YLeaf(YType.str, "description")

                                self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                self.hold_time = YLeaf(YType.uint16, "hold-time")

                                self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                self.io_armed = YLeaf(YType.boolean, "io-armed")

                                self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                self.messages_received = YLeaf(YType.uint32, "messages-received")

                                self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                self.read_armed = YLeaf(YType.boolean, "read-armed")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                self.tos_type = YLeaf(YType.uint8, "tos-type")

                                self.tos_value = YLeaf(YType.uint8, "tos-value")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.write_armed = YLeaf(YType.boolean, "write-armed")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                self._children_yang_names.add("graceful-maintenance")

                                self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self._children_name_map["message_statistics"] = "message-statistics"
                                self._children_yang_names.add("message-statistics")

                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._children_yang_names.add("performance-statistics")

                                self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self._children_name_map["received_notification_info"] = "received-notification-info"
                                self._children_yang_names.add("received-notification-info")

                                self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self._children_name_map["send_notification_info"] = "send-notification-info"
                                self._children_yang_names.add("send-notification-info")

                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                self._children_yang_names.add("tcp-init-sync-time-spec")

                                self.af_data = YList(self)
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with 
                                	**type**\:  bool
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\:  bool
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: outstanding_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby)}

                                    self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                    self.acked_version = YLeaf(YType.uint32, "acked-version")

                                    self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                    self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                    self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                    self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                    self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                    self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                    self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                    self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                    self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                    self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                    self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                    self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                    self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                    self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                    self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                    self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                    self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                    self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                    self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                    self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                    self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                    self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                    self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                    self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                    self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                    self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                    self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                    self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                    self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                    self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                    self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                    self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                    self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                    self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                    self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                    self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                    self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                    self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                    self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                    self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                    self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                    self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                    self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                    self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                    self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                    self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                    self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                    self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                    self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                    self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                    self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                    self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                    self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                    self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                    self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                    self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                    self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                    self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                    self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                    self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                    self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                    self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                    self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                    self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                    self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                    self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                    self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                    self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                    self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                    self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                    self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                    self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                    self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                    self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                    self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                    self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                    self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                    self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                    self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                    self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                    self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                    self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                    self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                    self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                    self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                    self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                    self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                    self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                    self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                    self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                    self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                    self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                    self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                    self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                    self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                    self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                    self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                    self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                    self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                    self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                    self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                    self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                    self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                    self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                    self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                    self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                    self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                    self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                    self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                    self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                    self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                    self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                    self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                    self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                    self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                    self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                    self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                    self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                    self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                    self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                    self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                    self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                    self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                    self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                    self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                    self.weight = YLeaf(YType.uint32, "weight")

                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                    self._children_yang_names.add("neighbor-af-performance-statistics")

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "extended-community-standby"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                class NeighborAfPerformanceStatistics(Entity):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                        self.yang_name = "neighbor-af-performance-statistics"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                        self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                        self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                        self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                        self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                        self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                        self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                        self._segment_path = lambda: "neighbor-af-performance-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                    self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                    self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                    self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                    self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                    self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                    self._segment_path = lambda: "graceful-maintenance"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                            class MessageStatistics(Entity):
                                """
                                Message statistics
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                    self.yang_name = "message-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update)}
                                    self._child_list_classes = {}

                                    self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self._children_name_map["keepalive"] = "keepalive"
                                    self._children_yang_names.add("keepalive")

                                    self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self._children_name_map["notification"] = "notification"
                                    self._children_yang_names.add("notification")

                                    self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self._children_name_map["open"] = "open"
                                    self._children_yang_names.add("open")

                                    self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self._children_name_map["route_refresh"] = "route-refresh"
                                    self._children_yang_names.add("route-refresh")

                                    self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                    self._children_yang_names.add("total")

                                    self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self
                                    self._children_name_map["update"] = "update"
                                    self._children_yang_names.add("update")
                                    self._segment_path = lambda: "message-statistics"


                                class Keepalive(Entity):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                        self.yang_name = "keepalive"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "keepalive"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Notification(Entity):
                                    """
                                    Notification
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                        self.yang_name = "notification"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "notification"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Open(Entity):
                                    """
                                    Open
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                        self.yang_name = "open"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "open"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class RouteRefresh(Entity):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                        self.yang_name = "route-refresh"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "route-refresh"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Total(Entity):
                                    """
                                    Total
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                        self.yang_name = "total"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "total"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class Update(Entity):
                                    """
                                    Update
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                        self.yang_name = "update"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)}
                                        self._child_list_classes = {}

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._children_yang_names.add("rx")

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"
                                        self._children_yang_names.add("tx")
                                        self._segment_path = lambda: "update"


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "rx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                            self._child_list_classes = {}

                                            self.count = YLeaf(YType.uint32, "count")

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._children_yang_names.add("last-time-spec")
                                            self._segment_path = lambda: "tx"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.active_collision = YLeaf(YType.uint32, "active-collision")

                                    self.actives = YLeaf(YType.uint32, "actives")

                                    self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                    self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                    self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                    self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                    self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                    self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                    self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                    self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                    self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                    self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                    self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                    self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                    self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                    self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                    self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                    self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                    self.network_status = YLeaf(YType.uint32, "network-status")

                                    self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                    self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                    self.passives = YLeaf(YType.uint32, "passives")

                                    self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                    self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                    self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                    self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                    self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                    self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                    self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                    self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                    self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                    self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                    self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                    self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                    self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                    self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                    self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                    self._segment_path = lambda: "performance-statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                            class ReceivedNotificationInfo(Entity):
                                """
                                Information on the last notification received
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                    self.yang_name = "received-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                    self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                    self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                    self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "received-notification-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "received-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "last-notification-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                            class SendNotificationInfo(Entity):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                    self.yang_name = "send-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData)}

                                    self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                    self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                    self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "send-notification-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "send-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "last-notification-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                            class TcpInitSyncDoneTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-done-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                            class TcpInitSyncTimeSpec(Entity):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "tcp-init-sync-time-spec"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                    class NextHopVrf(Entity):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf, self).__init__()

                            self.yang_name = "next-hop-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.last_notification_processing_time = YLeaf(YType.uint32, "last-notification-processing-time")

                            self.last_notificationication_time = YLeaf(YType.uint32, "last-notificationication-time")

                            self.max_notification_bestpath_changes = YLeaf(YType.uint32, "max-notification-bestpath-changes")

                            self.max_notification_bestpath_deletes = YLeaf(YType.uint32, "max-notification-bestpath-deletes")

                            self.max_proc_notification_time = YLeaf(YType.uint32, "max-proc-notification-time")

                            self.maximum_processing_time = YLeaf(YType.uint32, "maximum-processing-time")

                            self.total_processing_time = YLeaf(YType.uint32, "total-processing-time")
                            self._segment_path = lambda: "next-hop-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf, ['last_notification_processing_time', 'last_notificationication_time', 'max_notification_bestpath_changes', 'max_notification_bestpath_deletes', 'max_proc_notification_time', 'maximum_processing_time', 'total_processing_time'], name, value)


                    class Postits(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits, self).__init__()

                            self.yang_name = "postits"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"postit" : ("postit", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit)}

                            self.postit = YList(self)
                            self._segment_path = lambda: "postits"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits, [], name, value)


                        class Postit(Entity):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit, self).__init__()

                                self.yang_name = "postit"
                                self.yang_parent_name = "postits"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbors-address" : ("neighbors_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress)}
                                self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf), "postit-info" : ("postit_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.connect_state = YLeaf(YType.uint32, "connect-state")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.start_time = YLeaf(YType.uint32, "start-time")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self._children_name_map["neighbors_address"] = "neighbors-address"
                                self._children_yang_names.add("neighbors-address")

                                self.neighbor_af = YList(self)
                                self.postit_info = YList(self)
                                self._segment_path = lambda: "postit" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit, ['neighbor_address', 'connect_state', 'nsr_state', 'start_time', 'vrf_name'], name, value)


                            class NeighborAf(Entity):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf, self).__init__()

                                    self.yang_name = "neighbor-af"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.boolean, "entry")
                                    self._segment_path = lambda: "neighbor-af"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf, ['entry'], name, value)


                            class NeighborsAddress(Entity):
                                """
                                Neighbor Addr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress, self).__init__()

                                    self.yang_name = "neighbors-address"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "neighbors-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class PostitInfo(Entity):
                                """
                                Postit Info
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\:  str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo, self).__init__()

                                    self.yang_name = "postit-info"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"postit-notification" : ("postit_notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification)}
                                    self._child_list_classes = {}

                                    self.peer_id = YLeaf(YType.uint32, "peer-id")

                                    self.postit_af_name = YLeaf(YType.enumeration, "postit-af-name")

                                    self.postit_direction = YLeaf(YType.uint8, "postit-direction")

                                    self.postit_flags = YLeaf(YType.uint8, "postit-flags")

                                    self.postit_id = YLeaf(YType.uint32, "postit-id")

                                    self.postit_policy = YLeaf(YType.str, "postit-policy")

                                    self.postit_reset = YLeaf(YType.enumeration, "postit-reset")

                                    self.postit_subtype = YLeaf(YType.uint32, "postit-subtype")

                                    self.postit_ts = YLeaf(YType.uint64, "postit-ts")

                                    self.postit_type = YLeaf(YType.uint32, "postit-type")

                                    self.postit_notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self._children_name_map["postit_notification"] = "postit-notification"
                                    self._children_yang_names.add("postit-notification")
                                    self._segment_path = lambda: "postit-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo, ['peer_id', 'postit_af_name', 'postit_direction', 'postit_flags', 'postit_id', 'postit_policy', 'postit_reset', 'postit_subtype', 'postit_ts', 'postit_type'], name, value)


                                class PostitNotification(Entity):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                        self.yang_name = "postit-notification"
                                        self.yang_parent_name = "postit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "postit-notification"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "postit-notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, ['entry'], name, value)


                    class ProcessInfo(Entity):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo, self).__init__()

                            self.yang_name = "process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf)}
                            self._child_list_classes = {}

                            self.process_instance = YLeaf(YType.uint8, "process-instance")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"
                            self._children_yang_names.add("global")

                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self._children_name_map["performance_statistics"] = "performance-statistics"
                            self._children_yang_names.add("performance-statistics")

                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._children_yang_names.add("vrf")
                            self._segment_path = lambda: "process-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo, ['process_instance', 'vrf_name', 'vrf_totals'], name, value)


                        class Global_(Entity):
                            """
                            Global information
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize>`
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: large_community_entry_count
                            
                            	Number of large community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_memory
                            
                            	Memory (in bytes) used by large community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize>`
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount>`
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize>`
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\:  str
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"bmp-pool-alloc-count" : ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount), "bmp-pool-free-count" : ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount), "bmp-pool-size" : ("bmp_pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize), "msg-log-pool-alloc-count" : ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount), "msg-log-pool-free-count" : ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount), "msg-log-pool-size" : ("msg_log_pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize), "pool-alloc-count" : ("pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount), "pool-free-count" : ("pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount), "pool-size" : ("pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize)}

                                self.as_path_entries_memory = YLeaf(YType.uint32, "as-path-entries-memory")

                                self.as_path_entry_count = YLeaf(YType.uint32, "as-path-entry-count")

                                self.attr_set_entry_count = YLeaf(YType.uint32, "attr-set-entry-count")

                                self.attr_set_memory = YLeaf(YType.uint32, "attr-set-memory")

                                self.community_entry_count = YLeaf(YType.uint32, "community-entry-count")

                                self.community_memory = YLeaf(YType.uint32, "community-memory")

                                self.established_neighbors_count_total = YLeaf(YType.uint32, "established-neighbors-count-total")

                                self.extended_community_entry_count = YLeaf(YType.uint32, "extended-community-entry-count")

                                self.extended_community_memory = YLeaf(YType.uint32, "extended-community-memory")

                                self.large_community_entry_count = YLeaf(YType.uint32, "large-community-entry-count")

                                self.large_community_memory = YLeaf(YType.uint32, "large-community-memory")

                                self.lindex_entry_count = YLeaf(YType.uint32, "lindex-entry-count")

                                self.lindex_memory = YLeaf(YType.uint32, "lindex-memory")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.lsattr_entry_count = YLeaf(YType.uint32, "lsattr-entry-count")

                                self.lsattr_memory = YLeaf(YType.uint32, "lsattr-memory")

                                self.neighbors_count_total = YLeaf(YType.uint32, "neighbors-count-total")

                                self.nexthop_count = YLeaf(YType.uint32, "nexthop-count")

                                self.nexthop_memory = YLeaf(YType.uint32, "nexthop-memory")

                                self.path_attribute_memory = YLeaf(YType.uint32, "path-attribute-memory")

                                self.path_attributes_entry_count = YLeaf(YType.uint32, "path-attributes-entry-count")

                                self.pe_distinguisher_label_entry_count = YLeaf(YType.uint32, "pe-distinguisher-label-entry-count")

                                self.pe_distinguisher_label_memory = YLeaf(YType.uint32, "pe-distinguisher-label-memory")

                                self.ppmp_entry_count = YLeaf(YType.uint32, "ppmp-entry-count")

                                self.ppmp_memory = YLeaf(YType.uint32, "ppmp-memory")

                                self.process_instance_node = YLeaf(YType.str, "process-instance-node")

                                self.pta_entry_count = YLeaf(YType.uint32, "pta-entry-count")

                                self.pta_memory = YLeaf(YType.uint32, "pta-memory")

                                self.restart_count = YLeaf(YType.uint32, "restart-count")

                                self.ribrnh_entry_count = YLeaf(YType.uint32, "ribrnh-entry-count")

                                self.ribrnh_memory = YLeaf(YType.uint32, "ribrnh-memory")

                                self.route_reflector_memory = YLeaf(YType.uint32, "route-reflector-memory")

                                self.route_reflectors = YLeaf(YType.uint32, "route-reflectors")

                                self.sn_num_non_dflt_vrf_nbrs = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs")

                                self.sn_num_non_dflt_vrf_nbrs_estab = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs-estab")

                                self.total_vrf_count = YLeaf(YType.uint32, "total-vrf-count")

                                self.tunnel_encap_entry_count = YLeaf(YType.uint32, "tunnel-encap-entry-count")

                                self.tunnel_encap_memory = YLeaf(YType.uint32, "tunnel-encap-memory")

                                self.bmp_pool_alloc_count = YList(self)
                                self.bmp_pool_free_count = YList(self)
                                self.bmp_pool_size = YList(self)
                                self.msg_log_pool_alloc_count = YList(self)
                                self.msg_log_pool_free_count = YList(self)
                                self.msg_log_pool_size = YList(self)
                                self.pool_alloc_count = YList(self)
                                self.pool_free_count = YList(self)
                                self.pool_size = YList(self)
                                self._segment_path = lambda: "global"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_, ['as_path_entries_memory', 'as_path_entry_count', 'attr_set_entry_count', 'attr_set_memory', 'community_entry_count', 'community_memory', 'established_neighbors_count_total', 'extended_community_entry_count', 'extended_community_memory', 'large_community_entry_count', 'large_community_memory', 'lindex_entry_count', 'lindex_memory', 'local_as', 'lsattr_entry_count', 'lsattr_memory', 'neighbors_count_total', 'nexthop_count', 'nexthop_memory', 'path_attribute_memory', 'path_attributes_entry_count', 'pe_distinguisher_label_entry_count', 'pe_distinguisher_label_memory', 'ppmp_entry_count', 'ppmp_memory', 'process_instance_node', 'pta_entry_count', 'pta_memory', 'restart_count', 'ribrnh_entry_count', 'ribrnh_memory', 'route_reflector_memory', 'route_reflectors', 'sn_num_non_dflt_vrf_nbrs', 'sn_num_non_dflt_vrf_nbrs_estab', 'total_vrf_count', 'tunnel_encap_entry_count', 'tunnel_encap_memory'], name, value)


                            class BmpPoolAllocCount(Entity):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount, self).__init__()

                                    self.yang_name = "bmp-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount, ['entry'], name, value)


                            class BmpPoolFreeCount(Entity):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount, self).__init__()

                                    self.yang_name = "bmp-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount, ['entry'], name, value)


                            class BmpPoolSize(Entity):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize, self).__init__()

                                    self.yang_name = "bmp-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "bmp-pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize, ['entry'], name, value)


                            class MsgLogPoolAllocCount(Entity):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount, self).__init__()

                                    self.yang_name = "msg-log-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount, ['entry'], name, value)


                            class MsgLogPoolFreeCount(Entity):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount, self).__init__()

                                    self.yang_name = "msg-log-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount, ['entry'], name, value)


                            class MsgLogPoolSize(Entity):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize, self).__init__()

                                    self.yang_name = "msg-log-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "msg-log-pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize, ['entry'], name, value)


                            class PoolAllocCount(Entity):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount, self).__init__()

                                    self.yang_name = "pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-alloc-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount, ['entry'], name, value)


                            class PoolFreeCount(Entity):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount, self).__init__()

                                    self.yang_name = "pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-free-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount, ['entry'], name, value)


                            class PoolSize(Entity):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize, self).__init__()

                                    self.yang_name = "pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "pool-size"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize, ['entry'], name, value)


                        class PerformanceStatistics(Entity):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                self.yang_name = "performance-statistics"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf)}
                                self._child_list_classes = {}

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "performance-statistics"


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\:  bool
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\:  bool
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:   :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\:  bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\:  bool
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ds-npl" : ("ds_npl", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl), "ipv4rib-server" : ("ipv4rib_server", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer), "ipv6rib-server" : ("ipv6rib_server", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer), "lsd-connection" : ("lsd_connection", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection), "te-connection" : ("te_connection", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection)}
                                    self._child_list_classes = {"active-nsr-mode-enter-time" : ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime), "active-nsrfo-time" : ("active_nsrfo_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime), "issu-milestone" : ("issu_milestone", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone), "postit-count-info" : ("postit_count_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo), "standby-nsr-mode-enter-time" : ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime)}

                                    self.active_nsr_state = YLeaf(YType.uint32, "active-nsr-state")

                                    self.active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "active-nsrtcp-phase-two-enter-time")

                                    self.brib_api_input_bytes = YLeaf(YType.uint32, "brib-api-input-bytes")

                                    self.brib_api_input_messages = YLeaf(YType.uint32, "brib-api-input-messages")

                                    self.brib_api_input_prefixes_received = YLeaf(YType.uint32, "brib-api-input-prefixes-received")

                                    self.brib_api_input_processing_time = YLeaf(YType.uint32, "brib-api-input-processing-time")

                                    self.brib_api_input_withdrawn_prefixes = YLeaf(YType.uint32, "brib-api-input-withdrawn-prefixes")

                                    self.brib_api_output_bytes_generated = YLeaf(YType.uint32, "brib-api-output-bytes-generated")

                                    self.brib_api_output_bytes_sent = YLeaf(YType.uint32, "brib-api-output-bytes-sent")

                                    self.brib_api_output_calls = YLeaf(YType.uint32, "brib-api-output-calls")

                                    self.brib_api_output_generation_time = YLeaf(YType.uint32, "brib-api-output-generation-time")

                                    self.brib_api_output_messages_sent = YLeaf(YType.uint32, "brib-api-output-messages-sent")

                                    self.brib_api_output_prefixes_advertised = YLeaf(YType.uint32, "brib-api-output-prefixes-advertised")

                                    self.brib_api_output_prefixes_withdrawn = YLeaf(YType.uint32, "brib-api-output-prefixes-withdrawn")

                                    self.brib_api_output_sending_time = YLeaf(YType.uint32, "brib-api-output-sending-time")

                                    self.configuration_items_processed = YLeaf(YType.uint32, "configuration-items-processed")

                                    self.configuration_processing_time = YLeaf(YType.uint32, "configuration-processing-time")

                                    self.current_clock_time = YLeaf(YType.uint64, "current-clock-time")

                                    self.edm_processing_time = YLeaf(YType.uint32, "edm-processing-time")

                                    self.edm_requests_count = YLeaf(YType.uint32, "edm-requests-count")

                                    self.in_event_attach_calls = YLeaf(YType.uint32, "in-event-attach-calls")

                                    self.in_out_event_attach_calls = YLeaf(YType.uint32, "in-out-event-attach-calls")

                                    self.initial_sync_sessions_added = YLeaf(YType.boolean, "initial-sync-sessions-added")

                                    self.instance_node_role = YLeaf(YType.boolean, "instance-node-role")

                                    self.io_handler_tm = YLeaf(YType.uint64, "io-handler-tm")

                                    self.io_timer_id = YLeaf(YType.uint32, "io-timer-id")

                                    self.io_tree_timer_expiry = YLeaf(YType.uint64, "io-tree-timer-expiry")

                                    self.io_tree_timer_left = YLeaf(YType.uint64, "io-tree-timer-left")

                                    self.nsr_last_reset_reason = YLeaf(YType.uint8, "nsr-last-reset-reason")

                                    self.out_event_attach_calls = YLeaf(YType.uint32, "out-event-attach-calls")

                                    self.proc_scoped_sync_state = YLeaf(YType.enumeration, "proc-scoped-sync-state")

                                    self.qad_ac_ks_failure = YLeaf(YType.uint32, "qad-ac-ks-failure")

                                    self.qad_ac_ks_received = YLeaf(YType.uint32, "qad-ac-ks-received")

                                    self.qad_init_drops = YLeaf(YType.uint32, "qad-init-drops")

                                    self.qad_messages_received = YLeaf(YType.uint32, "qad-messages-received")

                                    self.qad_messages_sent = YLeaf(YType.uint32, "qad-messages-sent")

                                    self.qad_processed = YLeaf(YType.uint32, "qad-processed")

                                    self.qad_recv_drops = YLeaf(YType.uint32, "qad-recv-drops")

                                    self.qad_resumes = YLeaf(YType.uint32, "qad-resumes")

                                    self.qad_send_drops = YLeaf(YType.uint32, "qad-send-drops")

                                    self.qad_send_failure = YLeaf(YType.uint32, "qad-send-failure")

                                    self.qad_suspends = YLeaf(YType.uint32, "qad-suspends")

                                    self.qad_timeout_received = YLeaf(YType.uint32, "qad-timeout-received")

                                    self.qad_timeout_recvd = YLeaf(YType.uint32, "qad-timeout-recvd")

                                    self.qadack_sent = YLeaf(YType.uint32, "qadack-sent")

                                    self.qadoos_drops = YLeaf(YType.uint32, "qadoos-drops")

                                    self.redcon_nsr_ready = YLeaf(YType.boolean, "redcon-nsr-ready")

                                    self.redcon_state_time = YLeaf(YType.uint32, "redcon-state-time")

                                    self.sec_active_nsr_state = YLeaf(YType.uint32, "sec-active-nsr-state")

                                    self.sec_active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "sec-active-nsrtcp-phase-two-enter-time")

                                    self.tep2p_auto_tunnel_enabled = YLeaf(YType.boolean, "tep2p-auto-tunnel-enabled")

                                    self.total_neighbors_with_pending_postits = YLeaf(YType.uint32, "total-neighbors-with-pending-postits")

                                    self.total_outstanding_postits = YLeaf(YType.uint32, "total-outstanding-postits")

                                    self.updgen_handler_tm = YLeaf(YType.uint64, "updgen-handler-tm")

                                    self.updgen_timer_id = YLeaf(YType.uint32, "updgen-timer-id")

                                    self.updgen_tree_timer_expiry = YLeaf(YType.uint64, "updgen-tree-timer-expiry")

                                    self.updgen_tree_timer_left = YLeaf(YType.uint64, "updgen-tree-timer-left")

                                    self.ds_npl = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                    self.ds_npl.parent = self
                                    self._children_name_map["ds_npl"] = "ds-npl"
                                    self._children_yang_names.add("ds-npl")

                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                    self.ipv4rib_server.parent = self
                                    self._children_name_map["ipv4rib_server"] = "ipv4rib-server"
                                    self._children_yang_names.add("ipv4rib-server")

                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                    self.ipv6rib_server.parent = self
                                    self._children_name_map["ipv6rib_server"] = "ipv6rib-server"
                                    self._children_yang_names.add("ipv6rib-server")

                                    self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self._children_name_map["lsd_connection"] = "lsd-connection"
                                    self._children_yang_names.add("lsd-connection")

                                    self.te_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                    self.te_connection.parent = self
                                    self._children_name_map["te_connection"] = "te-connection"
                                    self._children_yang_names.add("te-connection")

                                    self.active_nsr_mode_enter_time = YList(self)
                                    self.active_nsrfo_time = YList(self)
                                    self.issu_milestone = YList(self)
                                    self.postit_count_info = YList(self)
                                    self.standby_nsr_mode_enter_time = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_, ['active_nsr_state', 'active_nsrtcp_phase_two_enter_time', 'brib_api_input_bytes', 'brib_api_input_messages', 'brib_api_input_prefixes_received', 'brib_api_input_processing_time', 'brib_api_input_withdrawn_prefixes', 'brib_api_output_bytes_generated', 'brib_api_output_bytes_sent', 'brib_api_output_calls', 'brib_api_output_generation_time', 'brib_api_output_messages_sent', 'brib_api_output_prefixes_advertised', 'brib_api_output_prefixes_withdrawn', 'brib_api_output_sending_time', 'configuration_items_processed', 'configuration_processing_time', 'current_clock_time', 'edm_processing_time', 'edm_requests_count', 'in_event_attach_calls', 'in_out_event_attach_calls', 'initial_sync_sessions_added', 'instance_node_role', 'io_handler_tm', 'io_timer_id', 'io_tree_timer_expiry', 'io_tree_timer_left', 'nsr_last_reset_reason', 'out_event_attach_calls', 'proc_scoped_sync_state', 'qad_ac_ks_failure', 'qad_ac_ks_received', 'qad_init_drops', 'qad_messages_received', 'qad_messages_sent', 'qad_processed', 'qad_recv_drops', 'qad_resumes', 'qad_send_drops', 'qad_send_failure', 'qad_suspends', 'qad_timeout_received', 'qad_timeout_recvd', 'qadack_sent', 'qadoos_drops', 'redcon_nsr_ready', 'redcon_state_time', 'sec_active_nsr_state', 'sec_active_nsrtcp_phase_two_enter_time', 'tep2p_auto_tunnel_enabled', 'total_neighbors_with_pending_postits', 'total_outstanding_postits', 'updgen_handler_tm', 'updgen_timer_id', 'updgen_tree_timer_expiry', 'updgen_tree_timer_left'], name, value)


                                class ActiveNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, self).__init__()

                                        self.yang_name = "active-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "active-nsr-mode-enter-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, ['entry'], name, value)


                                class ActiveNsrfoTime(Entity):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, self).__init__()

                                        self.yang_name = "active-nsrfo-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "active-nsrfo-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, ['entry'], name, value)


                                class DsNpl(Entity):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:   :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:   :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\:  str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\:  bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\:  str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, self).__init__()

                                        self.yang_name = "ds-npl"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"npl-endpoint" : ("npl_endpoint", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint), "npl-priority-statistic" : ("npl_priority_statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic)}

                                        self.dir_service_conn_state = YLeaf(YType.enumeration, "dir-service-conn-state")

                                        self.dsissu_status_flag = YLeaf(YType.uint32, "dsissu-status-flag")

                                        self.issu_mgr_conn_state = YLeaf(YType.enumeration, "issu-mgr-conn-state")

                                        self.issu_phase = YLeaf(YType.str, "issu-phase")

                                        self.issu_type_ng = YLeaf(YType.boolean, "issu-type-ng")

                                        self.issuha_option = YLeaf(YType.str, "issuha-option")

                                        self.local_ds_handle = YLeaf(YType.uint64, "local-ds-handle")

                                        self.service_name = YLeaf(YType.str, "service-name")

                                        self.npl_endpoint = YList(self)
                                        self.npl_priority_statistic = YList(self)
                                        self._segment_path = lambda: "ds-npl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, ['dir_service_conn_state', 'dsissu_status_flag', 'issu_mgr_conn_state', 'issu_phase', 'issu_type_ng', 'issuha_option', 'local_ds_handle', 'service_name'], name, value)


                                    class NplEndpoint(Entity):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\:  str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\:  str
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, self).__init__()

                                            self.yang_name = "npl-endpoint"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"endpoint" : ("endpoint", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint)}

                                            self.endpoint_active_flag = YLeaf(YType.boolean, "endpoint-active-flag")

                                            self.endpoint_handle = YLeaf(YType.uint64, "endpoint-handle")

                                            self.endpoint_issu_role = YLeaf(YType.str, "endpoint-issu-role")

                                            self.endpoint_name = YLeaf(YType.str, "endpoint-name")

                                            self.endpoint_stale_flag = YLeaf(YType.boolean, "endpoint-stale-flag")

                                            self.expected_sequence_num = YLeaf(YType.uint32, "expected-sequence-num")

                                            self.msg_size = YLeaf(YType.uint32, "msg-size")

                                            self.node_id = YLeaf(YType.str, "node-id")

                                            self.sync_group_name = YLeaf(YType.str, "sync-group-name")

                                            self.wheel_id = YLeaf(YType.uint32, "wheel-id")

                                            self.endpoint = YList(self)
                                            self._segment_path = lambda: "npl-endpoint"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, ['endpoint_active_flag', 'endpoint_handle', 'endpoint_issu_role', 'endpoint_name', 'endpoint_stale_flag', 'expected_sequence_num', 'msg_size', 'node_id', 'sync_group_name', 'wheel_id'], name, value)


                                        class Endpoint(Entity):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                self.yang_name = "endpoint"
                                                self.yang_parent_name = "npl-endpoint"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "endpoint"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, ['entry'], name, value)


                                    class NplPriorityStatistic(Entity):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, self).__init__()

                                            self.yang_name = "npl-priority-statistic"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"num-recv" : ("num_recv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv), "num-recv-drop" : ("num_recv_drop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop), "num-sent" : ("num_sent", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent), "num-sent-drop" : ("num_sent_drop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop)}

                                            self.num_recv = YList(self)
                                            self.num_recv_drop = YList(self)
                                            self.num_sent = YList(self)
                                            self.num_sent_drop = YList(self)
                                            self._segment_path = lambda: "npl-priority-statistic"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, [], name, value)


                                        class NumRecv(Entity):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                self.yang_name = "num-recv"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "num-recv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, ['entry'], name, value)


                                        class NumRecvDrop(Entity):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                self.yang_name = "num-recv-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray)}

                                                self.nsr_pl_recv_drop_array = YList(self)
                                                self._segment_path = lambda: "num-recv-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                            class NsrPlRecvDropArray(Entity):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-recv-drop-array"
                                                    self.yang_parent_name = "num-recv-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                                        class NumSent(Entity):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                self.yang_name = "num-sent"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "num-sent"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, ['entry'], name, value)


                                        class NumSentDrop(Entity):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                self.yang_name = "num-sent-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray)}

                                                self.nsr_pl_send_drop_array = YList(self)
                                                self._segment_path = lambda: "num-sent-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                            class NsrPlSendDropArray(Entity):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-send-drop-array"
                                                    self.yang_parent_name = "num-sent-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "nsr-pl-send-drop-array"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                                class Ipv4RibServer(Entity):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, self).__init__()

                                        self.yang_name = "ipv4rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                        self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                        self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                        self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                        self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                        self._children_yang_names.add("first-rib-connection-down-timestamp")

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                        self._children_yang_names.add("first-rib-connection-up-timestamp")

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._children_yang_names.add("last-rib-connection-down-timestamp")

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                        self._children_yang_names.add("last-rib-connection-up-timestamp")
                                        self._segment_path = lambda: "ipv4rib-server"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Ipv6RibServer(Entity):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, self).__init__()

                                        self.yang_name = "ipv6rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                        self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                        self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                        self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                        self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                        self._children_yang_names.add("first-rib-connection-down-timestamp")

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                        self._children_yang_names.add("first-rib-connection-up-timestamp")

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._children_yang_names.add("last-rib-connection-down-timestamp")

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                        self._children_yang_names.add("last-rib-connection-up-timestamp")
                                        self._segment_path = lambda: "ipv6rib-server"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class IssuMilestone(Entity):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\:  str
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, self).__init__()

                                        self.yang_name = "issu-milestone"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.milestone_met_timestamp = YLeaf(YType.uint32, "milestone-met-timestamp")

                                        self.milestone_name = YLeaf(YType.str, "milestone-name")

                                        self.milestone_start_timestamp = YLeaf(YType.uint32, "milestone-start-timestamp")
                                        self._segment_path = lambda: "issu-milestone"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, ['milestone_met_timestamp', 'milestone_name', 'milestone_start_timestamp'], name, value)


                                class LsdConnection(Entity):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, self).__init__()

                                        self.yang_name = "lsd-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                        self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                        self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                        self._children_yang_names.add("first-connection-down-timestamp")

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                        self._children_yang_names.add("first-connection-up-timestamp")

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._children_yang_names.add("last-connection-down-timestamp")

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                        self._children_yang_names.add("last-connection-up-timestamp")
                                        self._segment_path = lambda: "lsd-connection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class PostitCountInfo(Entity):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, self).__init__()

                                        self.yang_name = "postit-count-info"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress)}
                                        self._child_list_classes = {}

                                        self.postit_count = YLeaf(YType.uint32, "postit-count")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")
                                        self._segment_path = lambda: "postit-count-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, ['postit_count', 'vrf_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "postit-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class StandbyNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, self).__init__()

                                        self.yang_name = "standby-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "standby-nsr-mode-enter-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, ['entry'], name, value)


                                class TeConnection(Entity):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, self).__init__()

                                        self.yang_name = "te-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp)}
                                        self._child_list_classes = {}

                                        self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                        self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                        self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                        self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                        self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                        self._children_yang_names.add("first-connection-down-timestamp")

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                        self._children_yang_names.add("first-connection-up-timestamp")

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._children_yang_names.add("last-connection-down-timestamp")

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                        self._children_yang_names.add("last-connection-up-timestamp")
                                        self._segment_path = lambda: "te-connection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "first-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-down-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-connection-up-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                    self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                    self.high_throttled_read_count = YLeaf(YType.uint32, "high-throttled-read-count")

                                    self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                    self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                    self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                    self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                    self.low_throttled_read_count = YLeaf(YType.uint32, "low-throttled-read-count")

                                    self.lpts_calls = YLeaf(YType.uint32, "lpts-calls")

                                    self.lpts_set_up_time = YLeaf(YType.uint32, "lpts-set-up-time")

                                    self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                    self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                    self.read_throttles_count = YLeaf(YType.uint32, "read-throttles-count")

                                    self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                    self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                    self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                    self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                    self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                    self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                    self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, ['data_bytes_read', 'data_bytes_written', 'high_throttled_read_count', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'low_throttled_read_count', 'lpts_calls', 'lpts_set_up_time', 'read_calls_count', 'read_messages_count', 'read_throttles_count', 'subgroup_list_time', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.established_neighbors_count = YLeaf(YType.uint32, "established-neighbors-count")

                                self.neighbors_count = YLeaf(YType.uint32, "neighbors-count")

                                self.network_count = YLeaf(YType.uint32, "network-count")

                                self.notifications_received = YLeaf(YType.uint32, "notifications-received")

                                self.notifications_sent = YLeaf(YType.uint32, "notifications-sent")

                                self.path_count = YLeaf(YType.uint32, "path-count")

                                self.update_messages_received = YLeaf(YType.uint32, "update-messages-received")

                                self.update_messages_sent = YLeaf(YType.uint32, "update-messages-sent")
                                self._segment_path = lambda: "vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf, ['established_neighbors_count', 'neighbors_count', 'network_count', 'notifications_received', 'notifications_sent', 'path_count', 'update_messages_received', 'update_messages_sent'], name, value)


                    class Sessions(Entity):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions, self).__init__()

                            self.yang_name = "sessions"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"session" : ("session", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session)}

                            self.session = YList(self)
                            self._segment_path = lambda: "sessions"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions, [], name, value)


                        class Session(Entity):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\:  bool
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress)}
                                self._child_list_classes = {}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                self.description = YLeaf(YType.str, "description")

                                self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                self.local_as = YLeaf(YType.uint32, "local-as")

                                self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                self.postit_pending = YLeaf(YType.boolean, "postit-pending")

                                self.remote_as = YLeaf(YType.uint32, "remote-as")

                                self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"
                                self._children_yang_names.add("connection-local-address")

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._children_yang_names.add("connection-remote-address")
                                self._segment_path = lambda: "session" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session, ['neighbor_address', 'connection_state', 'description', 'is_local_address_configured', 'local_as', 'messages_queued_in', 'messages_queued_out', 'nsr_enabled', 'nsr_state', 'postit_pending', 'remote_as', 'speaker_id', 'vrf_name'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-local-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "connection-remote-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundErrorNeighbors(Entity):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors, self).__init__()

                            self.yang_name = "update-inbound-error-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update-inbound-error-neighbor" : ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor)}

                            self.update_inbound_error_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-error-neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors, [], name, value)


                        class UpdateInboundErrorNeighbor(Entity):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\:  bool
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                self.yang_name = "update-inbound-error-neighbor"
                                self.yang_parent_name = "update-inbound-error-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"first-update-error-handling-reset-timestamp" : ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp), "first-update-malformed-timestamp" : ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp), "first-update-memory-allocation-fail-timestamp" : ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp), "last-error-handling-reset-timestamp" : ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp), "last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)}
                                self._child_list_classes = {"establishment-action-count" : ("establishment_action_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount), "update-error-message" : ("update_error_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.establishment_total_update_message_count = YLeaf(YType.uint32, "establishment-total-update-message-count")

                                self.last_error_handling_reset_age = YLeaf(YType.uint32, "last-error-handling-reset-age")

                                self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                self.total_update_message_count = YLeaf(YType.uint32, "total-update-message-count")

                                self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                self.update_error_handling_avoid_reset = YLeaf(YType.boolean, "update-error-handling-avoid-reset")

                                self.update_error_handling_reset_count = YLeaf(YType.uint32, "update-error-handling-reset-count")

                                self.update_error_message_list_count = YLeaf(YType.uint32, "update-error-message-list-count")

                                self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"
                                self._children_yang_names.add("first-update-error-handling-reset-timestamp")

                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"
                                self._children_yang_names.add("first-update-malformed-timestamp")

                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"
                                self._children_yang_names.add("first-update-memory-allocation-fail-timestamp")

                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"
                                self._children_yang_names.add("last-error-handling-reset-timestamp")

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._children_yang_names.add("last-update-malformed-timestamp")

                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                self._children_yang_names.add("update-neighbor-address")

                                self.establishment_action_count = YList(self)
                                self.update_error_message = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', 'establishment_total_update_message_count', 'last_error_handling_reset_age', 'last_update_malformed_age', 'last_update_memory_allocation_fail_age', 'total_update_message_count', 'update_attribute_discard_count', 'update_error_handling_avoid_reset', 'update_error_handling_reset_count', 'update_error_message_list_count', 'update_malformed_message_count', 'update_memory_allocation_fail_count', 'update_vrf_name'], name, value)


                            class EstablishmentActionCount(Entity):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                    self.yang_name = "establishment-action-count"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "establishment-action-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, ['entry'], name, value)


                            class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "first-update-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-error-handling-reset-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class FirstUpdateMalformedTimestamp(Entity):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "first-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastErrorHandlingResetTimestamp(Entity):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "last-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-error-handling-reset-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateErrorMessage(Entity):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                    self.yang_name = "update-error-message"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-message-reset-data" : ("update_message_reset_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData), "update-message-timestamp" : ("update_message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)}
                                    self._child_list_classes = {"update-error-element" : ("update_error_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement), "update-message-data" : ("update_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)}

                                    self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                    self.update_error_final_action = YLeaf(YType.enumeration, "update-error-final-action")

                                    self.update_error_nlri_address_family = YLeaf(YType.enumeration, "update-error-nlri-address-family")

                                    self.update_error_nlri_string = YLeaf(YType.str, "update-error-nlri-string")

                                    self.update_error_nlri_string_truncated = YLeaf(YType.boolean, "update-error-nlri-string-truncated")

                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self._children_name_map["update_message_reset_data"] = "update-message-reset-data"
                                    self._children_yang_names.add("update-message-reset-data")

                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self
                                    self._children_name_map["update_message_timestamp"] = "update-message-timestamp"
                                    self._children_yang_names.add("update-message-timestamp")

                                    self.update_error_element = YList(self)
                                    self.update_message_data = YList(self)
                                    self._segment_path = lambda: "update-error-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, ['update_attribute_discard_count', 'update_error_final_action', 'update_error_nlri_address_family', 'update_error_nlri_string', 'update_error_nlri_string_truncated'], name, value)


                                class UpdateErrorElement(Entity):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                        self.yang_name = "update-error-element"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                        self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                        self.update_attribute_length = YLeaf(YType.uint16, "update-attribute-length")

                                        self.update_error_action = YLeaf(YType.enumeration, "update-error-action")

                                        self.update_error_data = YLeaf(YType.str, "update-error-data")

                                        self.update_error_data_length = YLeaf(YType.uint16, "update-error-data-length")
                                        self._segment_path = lambda: "update-error-element"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, ['update_attribute_code', 'update_attribute_flags', 'update_attribute_length', 'update_error_action', 'update_error_data', 'update_error_data_length'], name, value)


                                class UpdateMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                        self.yang_name = "update-message-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "update-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, ['entry'], name, value)


                                class UpdateMessageResetData(Entity):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                        self.yang_name = "update-message-reset-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_error_reset_notification_code = YLeaf(YType.uint8, "update-error-reset-notification-code")

                                        self.update_error_reset_notification_data = YLeaf(YType.str, "update-error-reset-notification-data")

                                        self.update_error_reset_notification_data_length = YLeaf(YType.uint16, "update-error-reset-notification-data-length")

                                        self.update_error_reset_notification_sub_code = YLeaf(YType.uint16, "update-error-reset-notification-sub-code")

                                        self.update_error_reset_reason = YLeaf(YType.enumeration, "update-error-reset-reason")
                                        self._segment_path = lambda: "update-message-reset-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, ['update_error_reset_notification_code', 'update_error_reset_notification_data', 'update_error_reset_notification_data_length', 'update_error_reset_notification_sub_code', 'update_error_reset_reason'], name, value)


                                class UpdateMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                        self.yang_name = "update-message-timestamp"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "update-message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "update-neighbor-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundErrorVrf(Entity):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf, self).__init__()

                            self.yang_name = "update-inbound-error-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                            self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                            self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                            self._children_yang_names.add("last-update-malformed-timestamp")
                            self._segment_path = lambda: "update-inbound-error-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf, ['last_update_malformed_age', 'update_malformed_message_count', 'update_malformed_neighbor_count', 'update_vrf_name'], name, value)


                        class LastUpdateMalformedTimestamp(Entity):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                self.yang_name = "last-update-malformed-timestamp"
                                self.yang_parent_name = "update-inbound-error-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-malformed-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                    class UpdateInboundFilterNeighbors(Entity):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors, self).__init__()

                            self.yang_name = "update-inbound-filter-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update-inbound-filter-neighbor" : ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor)}

                            self.update_inbound_filter_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-filter-neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors, [], name, value)


                        class UpdateInboundFilterNeighbor(Entity):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbor"
                                self.yang_parent_name = "update-inbound-filter-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"first-update-filtered-timestamp" : ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp), "last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)}
                                self._child_list_classes = {"update-attribute-filter-attributes" : ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes), "update-filter-message" : ("update_filter_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage)}

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.configured_update_filter_message_buffer_count = YLeaf(YType.uint32, "configured-update-filter-message-buffer-count")

                                self.establishment_total_filter_update_message_count = YLeaf(YType.uint32, "establishment-total-filter-update-message-count")

                                self.establishment_update_filtered_message_count = YLeaf(YType.uint32, "establishment-update-filtered-message-count")

                                self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                self.message_update_attribute_filtering_enabled = YLeaf(YType.boolean, "message-update-attribute-filtering-enabled")

                                self.operational_update_attribute_filtering_enabled = YLeaf(YType.boolean, "operational-update-attribute-filtering-enabled")

                                self.operational_update_filter_message_buffer_count = YLeaf(YType.uint32, "operational-update-filter-message-buffer-count")

                                self.total_filter_update_message_count = YLeaf(YType.uint32, "total-filter-update-message-count")

                                self.update_attribute_filter_group_name = YLeaf(YType.str, "update-attribute-filter-group-name")

                                self.update_filter_logging_enabled = YLeaf(YType.boolean, "update-filter-logging-enabled")

                                self.update_filter_message_buffer_circular = YLeaf(YType.boolean, "update-filter-message-buffer-circular")

                                self.update_filter_message_list_count = YLeaf(YType.uint32, "update-filter-message-list-count")

                                self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"
                                self._children_yang_names.add("first-update-filtered-timestamp")

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._children_yang_names.add("last-update-filtered-timestamp")

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                self._children_yang_names.add("update-neighbor-address")

                                self.update_attribute_filter_attributes = YList(self)
                                self.update_filter_message = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', 'configured_update_filter_message_buffer_count', 'establishment_total_filter_update_message_count', 'establishment_update_filtered_message_count', 'last_update_filtered_age', 'message_update_attribute_filtering_enabled', 'operational_update_attribute_filtering_enabled', 'operational_update_filter_message_buffer_count', 'total_filter_update_message_count', 'update_attribute_filter_group_name', 'update_filter_logging_enabled', 'update_filter_message_buffer_circular', 'update_filter_message_list_count', 'update_filtered_message_count', 'update_vrf_name'], name, value)


                            class FirstUpdateFilteredTimestamp(Entity):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "first-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "first-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateAttributeFilterAttributes(Entity):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                    self.yang_name = "update-attribute-filter-attributes"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"last-update-filter-match-timestamp" : ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp)}
                                    self._child_list_classes = {}

                                    self.establishment_update_filter_match_count = YLeaf(YType.uint32, "establishment-update-filter-match-count")

                                    self.last_update_filter_match_age = YLeaf(YType.uint32, "last-update-filter-match-age")

                                    self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")

                                    self.update_filter_match_count = YLeaf(YType.uint32, "update-filter-match-count")

                                    self.update_internal_attribute_code = YLeaf(YType.uint32, "update-internal-attribute-code")

                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                    self._children_yang_names.add("last-update-filter-match-timestamp")
                                    self._segment_path = lambda: "update-attribute-filter-attributes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, ['establishment_update_filter_match_count', 'last_update_filter_match_age', 'update_filter_action', 'update_filter_match_count', 'update_internal_attribute_code'], name, value)


                                class LastUpdateFilterMatchTimestamp(Entity):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                        self.yang_name = "last-update-filter-match-timestamp"
                                        self.yang_parent_name = "update-attribute-filter-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-filter-match-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateFilterMessage(Entity):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                    self.yang_name = "update-filter-message"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"update-filter-message-timestamp" : ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)}
                                    self._child_list_classes = {"update-filter-element" : ("update_filter_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement), "update-filter-message-data" : ("update_filter_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)}

                                    self.update_filter_final_action = YLeaf(YType.enumeration, "update-filter-final-action")

                                    self.update_filter_nlri_address_family = YLeaf(YType.enumeration, "update-filter-nlri-address-family")

                                    self.update_filter_nlri_string = YLeaf(YType.str, "update-filter-nlri-string")

                                    self.update_filter_nlri_string_truncated = YLeaf(YType.boolean, "update-filter-nlri-string-truncated")

                                    self.update_filtered_attribute_count = YLeaf(YType.uint32, "update-filtered-attribute-count")

                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"
                                    self._children_yang_names.add("update-filter-message-timestamp")

                                    self.update_filter_element = YList(self)
                                    self.update_filter_message_data = YList(self)
                                    self._segment_path = lambda: "update-filter-message"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, ['update_filter_final_action', 'update_filter_nlri_address_family', 'update_filter_nlri_string', 'update_filter_nlri_string_truncated', 'update_filtered_attribute_count'], name, value)


                                class UpdateFilterElement(Entity):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                        self.yang_name = "update-filter-element"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                        self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                        self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")
                                        self._segment_path = lambda: "update-filter-element"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, ['update_attribute_code', 'update_attribute_flags', 'update_filter_action'], name, value)


                                class UpdateFilterMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                        self.yang_name = "update-filter-message-data"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint8, "entry")
                                        self._segment_path = lambda: "update-filter-message-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, ['entry'], name, value)


                                class UpdateFilterMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                        self.yang_name = "update-filter-message-timestamp"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "update-filter-message-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                    self._child_list_classes = {}

                                    self.afi = YLeaf(YType.enumeration, "afi")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                    self._children_yang_names.add("l2vpn-mspw-address")

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                    self._children_yang_names.add("l2vpn-vpls-address")
                                    self._segment_path = lambda: "update-neighbor-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                class L2VpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                class L2VpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                    class UpdateInboundFilterVrf(Entity):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf, self).__init__()

                            self.yang_name = "update-inbound-filter-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                            self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                            self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                            self._children_yang_names.add("last-update-filtered-timestamp")
                            self._segment_path = lambda: "update-inbound-filter-vrf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count', 'update_vrf_name'], name, value)


                        class LastUpdateFilteredTimestamp(Entity):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                self.yang_name = "last-update-filtered-timestamp"
                                self.yang_parent_name = "update-inbound-filter-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-filtered-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                class RpkiRefreshAfs(Entity):
                    """
                    RPKI Refresh Table (per AF)
                    
                    .. attribute:: rpki_refresh_af
                    
                    	RPKI Refresh List
                    	**type**\: list of    :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs, self).__init__()

                        self.yang_name = "rpki-refresh-afs"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-refresh-af" : ("rpki_refresh_af", Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf)}

                        self.rpki_refresh_af = YList(self)
                        self._segment_path = lambda: "rpki-refresh-afs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs, [], name, value)


                    class RpkiRefreshAf(Entity):
                        """
                        RPKI Refresh List
                        
                        .. attribute:: af_name  <key>
                        
                        	Adress family
                        	**type**\:   :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: refresh_entry
                        
                        	Array of refresh entries
                        	**type**\: list of    :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf, self).__init__()

                            self.yang_name = "rpki-refresh-af"
                            self.yang_parent_name = "rpki-refresh-afs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"refresh-entry" : ("refresh_entry", Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry)}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.refresh_entry = YList(self)
                            self._segment_path = lambda: "rpki-refresh-af" + "[af-name='" + self.af_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf, ['af_name'], name, value)


                        class RefreshEntry(Entity):
                            """
                            Array of refresh entries
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: drop
                            
                            	BGP paths were dropped
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	BGP neighbor
                            	**type**\:  str
                            
                            .. attribute:: paths
                            
                            	Number of BGP paths modified or dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: policy
                            
                            	Route Policy
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry, self).__init__()

                                self.yang_name = "refresh-entry"
                                self.yang_parent_name = "rpki-refresh-af"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.drop = YLeaf(YType.boolean, "drop")

                                self.neighbor = YLeaf(YType.str, "neighbor")

                                self.paths = YLeaf(YType.uint32, "paths")

                                self.policy = YLeaf(YType.str, "policy")
                                self._segment_path = lambda: "refresh-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry, ['af_name', 'drop', 'neighbor', 'paths', 'policy'], name, value)


                class RpkiRoutes(Entity):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes, self).__init__()

                        self.yang_name = "rpki-routes"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-route" : ("rpki_route", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute)}

                        self.rpki_route = YList(self)
                        self._segment_path = lambda: "rpki-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes, [], name, value)


                    class RpkiRoute(Entity):
                        """
                        RPKI Path Group
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute, self).__init__()

                            self.yang_name = "rpki-route"
                            self.yang_parent_name = "rpki-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"rpki-route" : ("rpki_route", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute)}

                            self.address = YLeaf(YType.str, "address")

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.maximum = YLeaf(YType.int32, "maximum")

                            self.minimum = YLeaf(YType.int32, "minimum")

                            self.rpki_route = YList(self)
                            self._segment_path = lambda: "rpki-route"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute, ['address', 'af_name', 'maximum', 'minimum'], name, value)


                        class RpkiRoute(Entity):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\:  str
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\:  str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute, self).__init__()

                                self.yang_name = "rpki-route"
                                self.yang_parent_name = "rpki-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address = YLeaf(YType.str, "address")

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.as_ = YLeaf(YType.uint32, "as")

                                self.max_prefix_len = YLeaf(YType.uint8, "max-prefix-len")

                                self.min_prefix_len = YLeaf(YType.uint8, "min-prefix-len")

                                self.refcount = YLeaf(YType.uint16, "refcount")

                                self.server = YLeaf(YType.str, "server")

                                self.stale = YLeaf(YType.boolean, "stale")
                                self._segment_path = lambda: "rpki-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute, ['address', 'af_name', 'as_', 'max_prefix_len', 'min_prefix_len', 'refcount', 'server', 'stale'], name, value)


                class RpkiServerList(Entity):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiServerList, self).__init__()

                        self.yang_name = "rpki-server-list"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rpki-server" : ("rpki_server", Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer)}

                        self.rpki_server = YList(self)
                        self._segment_path = lambda: "rpki-server-list"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiServerList, [], name, value)


                    class RpkiServer(Entity):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:   :py:class:`BgpRpkiCreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreason>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\:  str
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\:  str
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:   :py:class:`BgpRpkiPerror <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerror>`
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:   :py:class:`BgpRpkiPstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstate>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:   :py:class:`BgpRpkiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiState>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\:  str
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer, self).__init__()

                            self.yang_name = "rpki-server"
                            self.yang_parent_name = "rpki-server-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.close_reason = YLeaf(YType.enumeration, "close-reason")

                            self.close_time = YLeaf(YType.uint32, "close-time")

                            self.close_time_real = YLeaf(YType.uint32, "close-time-real")

                            self.ipv4roa = YLeaf(YType.uint32, "ipv4roa")

                            self.ipv4roa_announce = YLeaf(YType.uint32, "ipv4roa-announce")

                            self.ipv4roa_withdraw = YLeaf(YType.uint32, "ipv4roa-withdraw")

                            self.ipv6roa = YLeaf(YType.uint32, "ipv6roa")

                            self.ipv6roa_announce = YLeaf(YType.uint32, "ipv6roa-announce")

                            self.ipv6roa_withdraw = YLeaf(YType.uint32, "ipv6roa-withdraw")

                            self.name = YLeaf(YType.str, "name")

                            self.nonce = YLeaf(YType.uint32, "nonce")

                            self.password = YLeaf(YType.str, "password")

                            self.port = YLeaf(YType.uint32, "port")

                            self.preference = YLeaf(YType.uint32, "preference")

                            self.proto_error = YLeaf(YType.enumeration, "proto-error")

                            self.proto_state = YLeaf(YType.enumeration, "proto-state")

                            self.proto_state_time = YLeaf(YType.uint32, "proto-state-time")

                            self.purge_time = YLeaf(YType.int32, "purge-time")

                            self.read_bytes = YLeaf(YType.uint32, "read-bytes")

                            self.refresh_time = YLeaf(YType.int32, "refresh-time")

                            self.response_time = YLeaf(YType.int32, "response-time")

                            self.retries = YLeaf(YType.uint32, "retries")

                            self.serial = YLeaf(YType.uint32, "serial")

                            self.shutdown = YLeaf(YType.boolean, "shutdown")

                            self.sshpid = YLeaf(YType.uint32, "sshpid")

                            self.state = YLeaf(YType.enumeration, "state")

                            self.state_time = YLeaf(YType.uint32, "state-time")

                            self.transport = YLeaf(YType.uint32, "transport")

                            self.username = YLeaf(YType.str, "username")

                            self.write_bytes = YLeaf(YType.uint32, "write-bytes")
                            self._segment_path = lambda: "rpki-server"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer, ['close_reason', 'close_time', 'close_time_real', 'ipv4roa', 'ipv4roa_announce', 'ipv4roa_withdraw', 'ipv6roa', 'ipv6roa_announce', 'ipv6roa_withdraw', 'name', 'nonce', 'password', 'port', 'preference', 'proto_error', 'proto_state', 'proto_state_time', 'purge_time', 'read_bytes', 'refresh_time', 'response_time', 'retries', 'serial', 'shutdown', 'sshpid', 'state', 'state_time', 'transport', 'username', 'write_bytes'], name, value)


                class RpkiSummary(Entity):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpki_allow_invalid
                    
                    	Allow invalid paths
                    	**type**\:  bool
                    
                    .. attribute:: rpki_disabled
                    
                    	RPKI Knob disabled
                    	**type**\:  bool
                    
                    .. attribute:: rpki_signal_ibgp
                    
                    	Signal RPKI validity to iBGP peers
                    	**type**\:  bool
                    
                    .. attribute:: rpki_use_validity
                    
                    	Use RPKI validity for bestpath calculation
                    	**type**\:  bool
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiSummary, self).__init__()

                        self.yang_name = "rpki-summary"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.ipv4roa_nets = YLeaf(YType.uint32, "ipv4roa-nets")

                        self.ipv4roa_paths = YLeaf(YType.uint32, "ipv4roa-paths")

                        self.ipv6roa_nets = YLeaf(YType.uint32, "ipv6roa-nets")

                        self.ipv6roa_paths = YLeaf(YType.uint32, "ipv6roa-paths")

                        self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                        self.rpki_disabled = YLeaf(YType.boolean, "rpki-disabled")

                        self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                        self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                        self.servers = YLeaf(YType.uint32, "servers")
                        self._segment_path = lambda: "rpki-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiSummary, ['ipv4roa_nets', 'ipv4roa_paths', 'ipv6roa_nets', 'ipv6roa_paths', 'rpki_allow_invalid', 'rpki_disabled', 'rpki_signal_ibgp', 'rpki_use_validity', 'servers'], name, value)


                class RtEntries(Entity):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of    :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RtEntries, self).__init__()

                        self.yang_name = "rt-entries"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"rt-entry" : ("rt_entry", Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry)}

                        self.rt_entry = YList(self)
                        self._segment_path = lambda: "rt-entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries, [], name, value)


                    class RtEntry(Entity):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\:  str
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:   :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry, self).__init__()

                            self.yang_name = "rt-entry"
                            self.yang_parent_name = "rt-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"rt" : ("rt", Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt)}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.afs = YLeaf(YType.str, "afs")

                            self.request_id = YLeaf(YType.int32, "request-id")

                            self.route_target_lower_bytes = YLeaf(YType.int32, "route-target-lower-bytes")

                            self.route_target_upper_bytes = YLeaf(YType.int32, "route-target-upper-bytes")

                            self.rt = Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt()
                            self.rt.parent = self
                            self._children_name_map["rt"] = "rt"
                            self._children_yang_names.add("rt")
                            self._segment_path = lambda: "rt-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry, ['af_name', 'afs', 'request_id', 'route_target_lower_bytes', 'route_target_upper_bytes'], name, value)


                        class Rt(Entity):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt, self).__init__()

                                self.yang_name = "rt"
                                self.yang_parent_name = "rt-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_target = YLeaf(YType.str, "route-target")
                                self._segment_path = lambda: "rt"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt, ['route_target'], name, value)


                class UpdateGenerationProcess(Entity):
                    """
                    Update generation for the process
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of    :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\:  bool
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess, self).__init__()

                        self.yang_name = "update-generation-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics)}
                        self._child_list_classes = {"update-address-family" : ("update_address_family", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily)}

                        self.configured_update_limit_process = YLeaf(YType.uint32, "configured-update-limit-process")

                        self.current_update_limit_process = YLeaf(YType.uint32, "current-update-limit-process")

                        self.update_out_logging = YLeaf(YType.boolean, "update-out-logging")

                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self._children_name_map["update_statistics"] = "update-statistics"
                        self._children_yang_names.add("update-statistics")

                        self.update_address_family = YList(self)
                        self._segment_path = lambda: "update-generation-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess, ['configured_update_limit_process', 'current_update_limit_process', 'update_out_logging', 'update_out_queue_messages', 'update_out_queue_size', 'update_throttled'], name, value)


                    class UpdateAddressFamily(Entity):
                        """
                        List of address\-families
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\:  bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily, self).__init__()

                            self.yang_name = "update-address-family"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                            self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                            self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                            self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                            self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                            self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")
                            self._segment_path = lambda: "update-address-family"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily, ['current_update_limit_af', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_group_af_name', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_throttled', 'update_update_group_count'], name, value)


                    class UpdateStatistics(Entity):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics, self).__init__()

                            self.yang_name = "update-statistics"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp)}
                            self._child_list_classes = {}

                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                            self._children_yang_names.add("last-update-cleared-timestamp")

                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                            self._children_yang_names.add("last-update-discard-timestamp")

                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                            self._children_yang_names.add("last-update-recovery-timestamp")

                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                            self._children_yang_names.add("last-update-throttle-timestamp")
                            self._segment_path = lambda: "update-statistics"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                        class LastUpdateClearedTimestamp(Entity):
                            """
                            Last Cleared time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                self.yang_name = "last-update-cleared-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-cleared-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateDiscardTimestamp(Entity):
                            """
                            Last Discarded time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                self.yang_name = "last-update-discard-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-discard-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateRecoveryTimestamp(Entity):
                            """
                            Last Recovery time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                self.yang_name = "last-update-recovery-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-recovery-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class LastUpdateThrottleTimestamp(Entity):
                            """
                            Last Throttled time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                self.yang_name = "last-update-throttle-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")
                                self._segment_path = lambda: "last-update-throttle-timestamp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                class UpdateInboundErrorProcess(Entity):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess, self).__init__()

                        self.yang_name = "update-inbound-error-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp)}
                        self._child_list_classes = {}

                        self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                        self.update_error_handling_basic_ebgp = YLeaf(YType.boolean, "update-error-handling-basic-ebgp")

                        self.update_error_handling_basic_ibgp = YLeaf(YType.boolean, "update-error-handling-basic-ibgp")

                        self.update_error_handling_extended_ebgp = YLeaf(YType.boolean, "update-error-handling-extended-ebgp")

                        self.update_error_handling_extended_ibgp = YLeaf(YType.boolean, "update-error-handling-extended-ibgp")

                        self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                        self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                        self._children_yang_names.add("last-update-malformed-timestamp")
                        self._segment_path = lambda: "update-inbound-error-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess, ['last_update_malformed_age', 'update_error_handling_basic_ebgp', 'update_error_handling_basic_ibgp', 'update_error_handling_extended_ebgp', 'update_error_handling_extended_ibgp', 'update_malformed_message_count', 'update_malformed_neighbor_count'], name, value)


                    class LastUpdateMalformedTimestamp(Entity):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, self).__init__()

                            self.yang_name = "last-update-malformed-timestamp"
                            self.yang_parent_name = "update-inbound-error-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")
                            self._segment_path = lambda: "last-update-malformed-timestamp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                class UpdateInboundFilterProcess(Entity):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess, self).__init__()

                        self.yang_name = "update-inbound-filter-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp)}
                        self._child_list_classes = {}

                        self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                        self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                        self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                        self._children_yang_names.add("last-update-filtered-timestamp")
                        self._segment_path = lambda: "update-inbound-filter-process"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count'], name, value)


                    class LastUpdateFilteredTimestamp(Entity):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, self).__init__()

                            self.yang_name = "last-update-filtered-timestamp"
                            self.yang_parent_name = "update-inbound-filter-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")
                            self._segment_path = lambda: "last-update-filtered-timestamp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                class Vrfs(Entity):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf)}

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs, [], name, value)


                    class Vrf(Entity):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  <key>
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"afs" : ("afs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs), "bmp" : ("bmp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp), "global-process-info" : ("global_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo), "information" : ("information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information), "message-logs" : ("message_logs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs), "neighbor-ranges" : ("neighbor_ranges", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges), "neighbors" : ("neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors), "next-hop-vrf" : ("next_hop_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf), "postits" : ("postits", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits), "process-info" : ("process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo), "sessions" : ("sessions", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions), "update-inbound-error-neighbors" : ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors), "update-inbound-error-vrf" : ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf), "update-inbound-filter-neighbors" : ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors), "update-inbound-filter-vrf" : ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf)}
                            self._child_list_classes = {}

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self._children_name_map["afs"] = "afs"
                            self._children_yang_names.add("afs")

                            self.bmp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self._children_name_map["bmp"] = "bmp"
                            self._children_yang_names.add("bmp")

                            self.global_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self._children_name_map["global_process_info"] = "global-process-info"
                            self._children_yang_names.add("global-process-info")

                            self.information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"
                            self._children_yang_names.add("information")

                            self.message_logs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self._children_name_map["message_logs"] = "message-logs"
                            self._children_yang_names.add("message-logs")

                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self._children_name_map["neighbor_ranges"] = "neighbor-ranges"
                            self._children_yang_names.add("neighbor-ranges")

                            self.neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self._children_name_map["next_hop_vrf"] = "next-hop-vrf"
                            self._children_yang_names.add("next-hop-vrf")

                            self.postits = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self._children_name_map["postits"] = "postits"
                            self._children_yang_names.add("postits")

                            self.process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self._children_name_map["process_info"] = "process-info"
                            self._children_yang_names.add("process-info")

                            self.sessions = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"
                            self._children_yang_names.add("sessions")

                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"
                            self._children_yang_names.add("update-inbound-error-neighbors")

                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"
                            self._children_yang_names.add("update-inbound-error-vrf")

                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"
                            self._children_yang_names.add("update-inbound-filter-neighbors")

                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self
                            self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"
                            self._children_yang_names.add("update-inbound-filter-vrf")
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf, ['vrf_name'], name, value)


                        class Afs(Entity):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs, self).__init__()

                                self.yang_name = "afs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"af" : ("af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af)}

                                self.af = YList(self)
                                self._segment_path = lambda: "afs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs, [], name, value)


                            class Af(Entity):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                .. attribute:: bmp_path_table_generic
                                
                                	Summary Info about BMP Table
                                	**type**\:   :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: network_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds>`
                                
                                .. attribute:: network_lookup_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds>`
                                
                                .. attribute:: network_prefixes
                                
                                	The BGP Network Lookup table
                                	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af, self).__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertised-path-counts" : ("advertised_path_counts", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts), "advertised-path-xr" : ("advertised_path_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr), "advertised-paths" : ("advertised_paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths), "af-process-info" : ("af_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo), "attributes" : ("attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes), "bmp-path-table-generic" : ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric), "bmp-paths" : ("bmp_paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths), "convergence" : ("convergence", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence), "dampenings" : ("dampenings", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings), "epes" : ("epes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes), "global-af-process-info" : ("global_af_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo), "neighbor-af-table" : ("neighbor_af_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable), "network-all-rds" : ("network_all_rds", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds), "network-lookup-all-rds" : ("network_lookup_all_rds", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds), "network-prefixes" : ("network_prefixes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes), "networks" : ("networks", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks), "next-hop-address-families" : ("next_hop_address_families", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies), "path-labeled-table" : ("path_labeled_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable), "path-table" : ("path_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable), "path-used-table" : ("path_used_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable), "policies" : ("policies", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies), "prefix-filters" : ("prefix_filters", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters), "rpc-sets" : ("rpc_sets", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets), "rt-set-counters" : ("rt_set_counters", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters), "sourced-networks" : ("sourced_networks", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks), "update-generation-address-family" : ("update_generation_address_family", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily), "update-generation-filter-groups" : ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups), "update-generation-neighbors" : ("update_generation_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors), "update-generation-sub-groups" : ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups), "update-generation-update-groups" : ("update_generation_update_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups), "update-groups" : ("update_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self._children_name_map["advertised_path_counts"] = "advertised-path-counts"
                                    self._children_yang_names.add("advertised-path-counts")

                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self._children_name_map["advertised_path_xr"] = "advertised-path-xr"
                                    self._children_yang_names.add("advertised-path-xr")

                                    self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self._children_name_map["advertised_paths"] = "advertised-paths"
                                    self._children_yang_names.add("advertised-paths")

                                    self.af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self._children_name_map["af_process_info"] = "af-process-info"
                                    self._children_yang_names.add("af-process-info")

                                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self._children_name_map["attributes"] = "attributes"
                                    self._children_yang_names.add("attributes")

                                    self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric()
                                    self.bmp_path_table_generic.parent = self
                                    self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"
                                    self._children_yang_names.add("bmp-path-table-generic")

                                    self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self._children_name_map["bmp_paths"] = "bmp-paths"
                                    self._children_yang_names.add("bmp-paths")

                                    self.convergence = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self._children_name_map["convergence"] = "convergence"
                                    self._children_yang_names.add("convergence")

                                    self.dampenings = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self._children_name_map["dampenings"] = "dampenings"
                                    self._children_yang_names.add("dampenings")

                                    self.epes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self._children_name_map["epes"] = "epes"
                                    self._children_yang_names.add("epes")

                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self._children_name_map["global_af_process_info"] = "global-af-process-info"
                                    self._children_yang_names.add("global-af-process-info")

                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self._children_name_map["neighbor_af_table"] = "neighbor-af-table"
                                    self._children_yang_names.add("neighbor-af-table")

                                    self.network_all_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds()
                                    self.network_all_rds.parent = self
                                    self._children_name_map["network_all_rds"] = "network-all-rds"
                                    self._children_yang_names.add("network-all-rds")

                                    self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds()
                                    self.network_lookup_all_rds.parent = self
                                    self._children_name_map["network_lookup_all_rds"] = "network-lookup-all-rds"
                                    self._children_yang_names.add("network-lookup-all-rds")

                                    self.network_prefixes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes()
                                    self.network_prefixes.parent = self
                                    self._children_name_map["network_prefixes"] = "network-prefixes"
                                    self._children_yang_names.add("network-prefixes")

                                    self.networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self._children_name_map["networks"] = "networks"
                                    self._children_yang_names.add("networks")

                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self._children_name_map["next_hop_address_families"] = "next-hop-address-families"
                                    self._children_yang_names.add("next-hop-address-families")

                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self._children_name_map["path_labeled_table"] = "path-labeled-table"
                                    self._children_yang_names.add("path-labeled-table")

                                    self.path_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self._children_name_map["path_table"] = "path-table"
                                    self._children_yang_names.add("path-table")

                                    self.path_used_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self._children_name_map["path_used_table"] = "path-used-table"
                                    self._children_yang_names.add("path-used-table")

                                    self.policies = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self._children_name_map["policies"] = "policies"
                                    self._children_yang_names.add("policies")

                                    self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self._children_name_map["prefix_filters"] = "prefix-filters"
                                    self._children_yang_names.add("prefix-filters")

                                    self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self._children_name_map["rpc_sets"] = "rpc-sets"
                                    self._children_yang_names.add("rpc-sets")

                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self._children_name_map["rt_set_counters"] = "rt-set-counters"
                                    self._children_yang_names.add("rt-set-counters")

                                    self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"
                                    self._children_yang_names.add("sourced-networks")

                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self._children_name_map["update_generation_address_family"] = "update-generation-address-family"
                                    self._children_yang_names.add("update-generation-address-family")

                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"
                                    self._children_yang_names.add("update-generation-filter-groups")

                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"
                                    self._children_yang_names.add("update-generation-neighbors")

                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"
                                    self._children_yang_names.add("update-generation-sub-groups")

                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"
                                    self._children_yang_names.add("update-generation-update-groups")

                                    self.update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self
                                    self._children_name_map["update_groups"] = "update-groups"
                                    self._children_yang_names.add("update-groups")
                                    self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                                class AdvertisedPathCounts(Entity):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                        self.yang_name = "advertised-path-counts"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path-count" : ("advertised_path_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount)}

                                        self.advertised_path_count = YList(self)
                                        self._segment_path = lambda: "advertised-path-counts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                    class AdvertisedPathCount(Entity):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                            self.yang_name = "advertised-path-count"
                                            self.yang_parent_name = "advertised-path-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.max_prefix_advertisedcount = YLeaf(YType.uint32, "max-prefix-advertisedcount")
                                            self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', 'max_prefix_advertisedcount'], name, value)


                                class AdvertisedPathXr(Entity):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                        self.yang_name = "advertised-path-xr"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath)}

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-path-xr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-path-xr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "advertised-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AdvertisedPaths(Entity):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths, self).__init__()

                                        self.yang_name = "advertised-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"advertised-path" : ("advertised_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath)}

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-paths"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"adv-path-info" : ("adv_path_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo), "paths" : ("paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.adv_path_info = YList(self)
                                            self.paths = YList(self)
                                            self._segment_path = lambda: "advertised-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['neighbor_address', 'network', 'prefix_length', 'rd'], name, value)


                                        class AdvPathInfo(Entity):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                                self.yang_name = "adv-path-info"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                                self._children_yang_names.add("attributes-after-policy-out")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                                self._children_yang_names.add("path-info-after-policy-in")

                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                                self._children_yang_names.add("path-info-after-policy-out")
                                                self._segment_path = lambda: "adv-path-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, ['af_name', 'no_path', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class AttributesAfterPolicyOut(Entity):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                    self.yang_name = "attributes-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-out"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInfoAfterPolicyIn(Entity):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                    self.yang_name = "path-info-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInfoAfterPolicyOut(Entity):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                    self.yang_name = "path-info-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-out"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class Paths(Entity):
                                            """
                                            paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "paths"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class AfProcessInfo(Entity):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo, self).__init__()

                                        self.yang_name = "af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.process_instance = YLeaf(YType.uint8, "process-instance")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._children_yang_names.add("performance-statistics")

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "af-process-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo, ['af_name', 'process_instance', 'vrf_name', 'vrf_totals'], name, value)


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v4_next_hop
                                        
                                        	Max supported label stack depth for IPv4 Nexthop
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v6_next_hop
                                        
                                        	Max supported label stack depth for IPv6 Nexthop
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_bgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:   :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall), "trigger-import" : ("trigger_import", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport), "trigger-label" : ("trigger_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel), "trigger-rib" : ("trigger_rib", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib), "trigger-update" : ("trigger_update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate), "version-wrap-done-time-spec" : ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec), "version-wrap-start-time-spec" : ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec), "version-wrap-time-spec" : ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec)}
                                            self._child_list_classes = {}

                                            self.freed_rd_count = YLeaf(YType.uint32, "freed-rd-count")

                                            self.import_bgp_version = YLeaf(YType.uint32, "import-bgp-version")

                                            self.import_last_trigger = YLeaf(YType.uint64, "import-last-trigger")

                                            self.import_triggers = YLeaf(YType.uint32, "import-triggers")

                                            self.import_version = YLeaf(YType.uint32, "import-version")

                                            self.imported_paths_memory = YLeaf(YType.uint32, "imported-paths-memory")

                                            self.imported_paths_num = YLeaf(YType.uint32, "imported-paths-num")

                                            self.label_bgp_version = YLeaf(YType.uint32, "label-bgp-version")

                                            self.label_last_trigger = YLeaf(YType.uint64, "label-last-trigger")

                                            self.label_triggers = YLeaf(YType.uint32, "label-triggers")

                                            self.label_version = YLeaf(YType.uint32, "label-version")

                                            self.last_import_version = YLeaf(YType.uint32, "last-import-version")

                                            self.last_label_version = YLeaf(YType.uint32, "last-label-version")

                                            self.last_rib_version = YLeaf(YType.uint32, "last-rib-version")

                                            self.local_networks_freed_num = YLeaf(YType.uint32, "local-networks-freed-num")

                                            self.local_networks_malloced_num = YLeaf(YType.uint32, "local-networks-malloced-num")

                                            self.local_networks_memory = YLeaf(YType.uint32, "local-networks-memory")

                                            self.local_networks_num = YLeaf(YType.uint32, "local-networks-num")

                                            self.local_paths_freed_num = YLeaf(YType.uint32, "local-paths-freed-num")

                                            self.local_paths_malloced_num = YLeaf(YType.uint32, "local-paths-malloced-num")

                                            self.local_paths_memory = YLeaf(YType.uint32, "local-paths-memory")

                                            self.local_paths_num = YLeaf(YType.uint32, "local-paths-num")

                                            self.malloced_rd_count = YLeaf(YType.uint32, "malloced-rd-count")

                                            self.max_active_pelem_version = YLeaf(YType.uint32, "max-active-pelem-version")

                                            self.max_label_stack_depth_v4_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v4-next-hop")

                                            self.max_label_stack_depth_v6_next_hop = YLeaf(YType.uint32, "max-label-stack-depth-v6-next-hop")

                                            self.merged_table_version = YLeaf(YType.uint32, "merged-table-version")

                                            self.multipath_network_entry_count = YLeaf(YType.uint32, "multipath-network-entry-count")

                                            self.multipath_network_entry_memory = YLeaf(YType.uint32, "multipath-network-entry-memory")

                                            self.multipath_paths_count = YLeaf(YType.uint32, "multipath-paths-count")

                                            self.multipath_paths_memory = YLeaf(YType.uint32, "multipath-paths-memory")

                                            self.networks_freed_num = YLeaf(YType.uint32, "networks-freed-num")

                                            self.networks_malloced_num = YLeaf(YType.uint32, "networks-malloced-num")

                                            self.networks_memory = YLeaf(YType.uint32, "networks-memory")

                                            self.networks_num = YLeaf(YType.uint32, "networks-num")

                                            self.num_init_sync_pfx = YLeaf(YType.uint32, "num-init-sync-pfx")

                                            self.path_elems_freed_num = YLeaf(YType.uint32, "path-elems-freed-num")

                                            self.path_elems_malloced_num = YLeaf(YType.uint32, "path-elems-malloced-num")

                                            self.path_elems_memory = YLeaf(YType.uint32, "path-elems-memory")

                                            self.path_elems_num = YLeaf(YType.uint32, "path-elems-num")

                                            self.paths_freed_num = YLeaf(YType.uint32, "paths-freed-num")

                                            self.paths_malloced_num = YLeaf(YType.uint32, "paths-malloced-num")

                                            self.paths_memory = YLeaf(YType.uint32, "paths-memory")

                                            self.paths_num = YLeaf(YType.uint32, "paths-num")

                                            self.rd_memory = YLeaf(YType.uint32, "rd-memory")

                                            self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                            self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                            self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                            self.rib_bgp_version = YLeaf(YType.uint32, "rib-bgp-version")

                                            self.rib_brib_received_version = YLeaf(YType.uint32, "rib-brib-received-version")

                                            self.rib_last_trigger = YLeaf(YType.uint64, "rib-last-trigger")

                                            self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                            self.rib_triggers = YLeaf(YType.uint32, "rib-triggers")

                                            self.route_download_go_active_done_pending = YLeaf(YType.uint32, "route-download-go-active-done-pending")

                                            self.router_state = YLeaf(YType.enumeration, "router-state")

                                            self.send_version = YLeaf(YType.uint32, "send-version")

                                            self.standby_version = YLeaf(YType.uint32, "standby-version")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.total_r_ds_num = YLeaf(YType.uint32, "total-r-ds-num")

                                            self.total_remote_r_ds_num = YLeaf(YType.uint32, "total-remote-r-ds-num")

                                            self.total_same_r_ds_num = YLeaf(YType.uint32, "total-same-r-ds-num")

                                            self.update_gen_bgp_version = YLeaf(YType.uint32, "update-gen-bgp-version")

                                            self.update_gen_last_trigger = YLeaf(YType.uint64, "update-gen-last-trigger")

                                            self.update_triggers = YLeaf(YType.uint32, "update-triggers")

                                            self.update_wait_install_enabled = YLeaf(YType.uint32, "update-wait-install-enabled")

                                            self.version_wrapped = YLeaf(YType.uint32, "version-wrapped")

                                            self.version_wrapped_tid = YLeaf(YType.uint32, "version-wrapped-tid")

                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._children_yang_names.add("rib-install")

                                            self.trigger_import = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                            self.trigger_import.parent = self
                                            self._children_name_map["trigger_import"] = "trigger-import"
                                            self._children_yang_names.add("trigger-import")

                                            self.trigger_label = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self._children_name_map["trigger_label"] = "trigger-label"
                                            self._children_yang_names.add("trigger-label")

                                            self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self._children_name_map["trigger_rib"] = "trigger-rib"
                                            self._children_yang_names.add("trigger-rib")

                                            self.trigger_update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self._children_name_map["trigger_update"] = "trigger-update"
                                            self._children_yang_names.add("trigger-update")

                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"
                                            self._children_yang_names.add("version-wrap-done-time-spec")

                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"
                                            self._children_yang_names.add("version-wrap-start-time-spec")

                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"
                                            self._children_yang_names.add("version-wrap-time-spec")
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_, ['freed_rd_count', 'import_bgp_version', 'import_last_trigger', 'import_triggers', 'import_version', 'imported_paths_memory', 'imported_paths_num', 'label_bgp_version', 'label_last_trigger', 'label_triggers', 'label_version', 'last_import_version', 'last_label_version', 'last_rib_version', 'local_networks_freed_num', 'local_networks_malloced_num', 'local_networks_memory', 'local_networks_num', 'local_paths_freed_num', 'local_paths_malloced_num', 'local_paths_memory', 'local_paths_num', 'malloced_rd_count', 'max_active_pelem_version', 'max_label_stack_depth_v4_next_hop', 'max_label_stack_depth_v6_next_hop', 'merged_table_version', 'multipath_network_entry_count', 'multipath_network_entry_memory', 'multipath_paths_count', 'multipath_paths_memory', 'networks_freed_num', 'networks_malloced_num', 'networks_memory', 'networks_num', 'num_init_sync_pfx', 'path_elems_freed_num', 'path_elems_malloced_num', 'path_elems_memory', 'path_elems_num', 'paths_freed_num', 'paths_malloced_num', 'paths_memory', 'paths_num', 'rd_memory', 'rib_ack_requests', 'rib_acked_table_version', 'rib_acks_received', 'rib_bgp_version', 'rib_brib_received_version', 'rib_last_trigger', 'rib_slow_acks', 'rib_triggers', 'route_download_go_active_done_pending', 'router_state', 'send_version', 'standby_version', 'table_brib_version', 'table_version', 'total_r_ds_num', 'total_remote_r_ds_num', 'total_same_r_ds_num', 'update_gen_bgp_version', 'update_gen_last_trigger', 'update_triggers', 'update_wait_install_enabled', 'version_wrapped', 'version_wrapped_tid'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime)}
                                                self._child_list_classes = {}

                                                self.installed_count = YLeaf(YType.uint32, "installed-count")

                                                self.modified_count = YLeaf(YType.uint32, "modified-count")

                                                self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                                self.start_version = YLeaf(YType.uint32, "start-version")

                                                self.target_version = YLeaf(YType.uint32, "target-version")

                                                self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._children_yang_names.add("install-time")

                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"
                                                self._children_yang_names.add("update-time")
                                                self._segment_path = lambda: "rib-install"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "install-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerImport(Entity):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, self).__init__()

                                                self.yang_name = "trigger-import"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerLabel(Entity):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, self).__init__()

                                                self.yang_name = "trigger-label"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-label"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-label"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerRib(Entity):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, self).__init__()

                                                self.yang_name = "trigger-rib"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-rib"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-rib"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TriggerUpdate(Entity):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, self).__init__()

                                                self.yang_name = "trigger-update"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"statistic" : ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic)}

                                                self.triggers = YLeaf(YType.uint32, "triggers")

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-update"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate, ['triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"trigger-time-spec" : ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec)}
                                                    self._child_list_classes = {}

                                                    self.trigger_table_version = YLeaf(YType.uint32, "trigger-table-version")

                                                    self.trigger_version = YLeaf(YType.uint32, "trigger-version")

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._children_yang_names.add("trigger-time-spec")
                                                    self._segment_path = lambda: "statistic"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic, ['trigger_table_version', 'trigger_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "trigger-time-spec"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapDoneTimeSpec(Entity):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-done-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-done-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapStartTimeSpec(Entity):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-start-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-start-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class VersionWrapTimeSpec(Entity):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-wrap-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf)}
                                            self._child_list_classes = {}

                                            self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                            self.global_.parent = self
                                            self._children_name_map["global_"] = "global"
                                            self._children_yang_names.add("global")

                                            self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._children_yang_names.add("vrf")
                                            self._segment_path = lambda: "performance-statistics"


                                        class Global_(Entity):
                                            """
                                            Global information
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\:  bool
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                                self.yang_name = "global"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mode-enter-time" : ("mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime), "total-pim-callback-add" : ("total_pim_callback_add", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd), "total-pim-callback-add-local" : ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal), "total-pim-callback-del" : ("total_pim_callback_del", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel), "total-pim-callback-del-local" : ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal), "total-pim-install-add" : ("total_pim_install_add", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd), "total-pim-install-del" : ("total_pim_install_del", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel)}

                                                self.first_nbr_up_time = YLeaf(YType.uint32, "first-nbr-up-time")

                                                self.has_converged = YLeaf(YType.boolean, "has-converged")

                                                self.total_pim_callback_batch = YLeaf(YType.uint32, "total-pim-callback-batch")

                                                self.total_pim_callbacks = YLeaf(YType.uint32, "total-pim-callbacks")

                                                self.total_pim_install = YLeaf(YType.uint32, "total-pim-install")

                                                self.mode_enter_time = YList(self)
                                                self.total_pim_callback_add = YList(self)
                                                self.total_pim_callback_add_local = YList(self)
                                                self.total_pim_callback_del = YList(self)
                                                self.total_pim_callback_del_local = YList(self)
                                                self.total_pim_install_add = YList(self)
                                                self.total_pim_install_del = YList(self)
                                                self._segment_path = lambda: "global"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_, ['first_nbr_up_time', 'has_converged', 'total_pim_callback_batch', 'total_pim_callbacks', 'total_pim_install'], name, value)


                                            class ModeEnterTime(Entity):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, self).__init__()

                                                    self.yang_name = "mode-enter-time"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "mode-enter-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime, ['entry'], name, value)


                                            class TotalPimCallbackAdd(Entity):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, self).__init__()

                                                    self.yang_name = "total-pim-callback-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-add"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd, ['entry'], name, value)


                                            class TotalPimCallbackAddLocal(Entity):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-add-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-add-local"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal, ['entry'], name, value)


                                            class TotalPimCallbackDel(Entity):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, self).__init__()

                                                    self.yang_name = "total-pim-callback-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-del"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel, ['entry'], name, value)


                                            class TotalPimCallbackDelLocal(Entity):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-del-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-callback-del-local"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal, ['entry'], name, value)


                                            class TotalPimInstallAdd(Entity):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, self).__init__()

                                                    self.yang_name = "total-pim-install-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-install-add"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd, ['entry'], name, value)


                                            class TotalPimInstallDel(Entity):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, self).__init__()

                                                    self.yang_name = "total-pim-install-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "total-pim-install-del"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel, ['entry'], name, value)


                                        class Vrf(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_not_sent_to_rib
                                            
                                            	No. of prefixes not sent to RIB due to unsupported label stack size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"first-rib-table-full-timestamp" : ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp), "first-rib-table-has-space-timestamp" : ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp), "last-rib-table-full-timestamp" : ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp), "last-rib-table-has-space-timestamp" : ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp), "time-label-retain" : ("time_label_retain", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain), "time-rib-coverged" : ("time_rib_coverged", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged), "time-rib-down" : ("time_rib_down", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)}
                                                self._child_list_classes = {}

                                                self.attributes_recover_from_rib = YLeaf(YType.uint32, "attributes-recover-from-rib")

                                                self.attributes_removed_from_rib = YLeaf(YType.uint32, "attributes-removed-from-rib")

                                                self.attributes_sent_to_rib = YLeaf(YType.uint32, "attributes-sent-to-rib")

                                                self.first_rib_table_full_version = YLeaf(YType.uint32, "first-rib-table-full-version")

                                                self.first_rib_table_has_space_version = YLeaf(YType.uint32, "first-rib-table-has-space-version")

                                                self.import_added_path_count = YLeaf(YType.uint32, "import-added-path-count")

                                                self.import_calls = YLeaf(YType.uint32, "import-calls")

                                                self.import_dest_net_processed_count = YLeaf(YType.uint32, "import-dest-net-processed-count")

                                                self.import_removed_path_count = YLeaf(YType.uint32, "import-removed-path-count")

                                                self.import_replaced_path_count = YLeaf(YType.uint32, "import-replaced-path-count")

                                                self.import_src_net_processed_count = YLeaf(YType.uint32, "import-src-net-processed-count")

                                                self.import_time = YLeaf(YType.uint32, "import-time")

                                                self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                                self.label_added_count = YLeaf(YType.uint32, "label-added-count")

                                                self.label_calls = YLeaf(YType.uint32, "label-calls")

                                                self.label_release_count = YLeaf(YType.uint32, "label-release-count")

                                                self.label_rewrite_count = YLeaf(YType.uint32, "label-rewrite-count")

                                                self.label_time = YLeaf(YType.uint32, "label-time")

                                                self.last_rib_table_full_age = YLeaf(YType.uint32, "last-rib-table-full-age")

                                                self.last_rib_table_full_version = YLeaf(YType.uint32, "last-rib-table-full-version")

                                                self.last_rib_table_has_space_age = YLeaf(YType.uint32, "last-rib-table-has-space-age")

                                                self.last_rib_table_has_space_version = YLeaf(YType.uint32, "last-rib-table-has-space-version")

                                                self.prefixes_not_sent_to_rib = YLeaf(YType.uint32, "prefixes-not-sent-to-rib")

                                                self.prefixes_removed_from_rib = YLeaf(YType.uint32, "prefixes-removed-from-rib")

                                                self.prefixes_resent_to_rib = YLeaf(YType.uint32, "prefixes-resent-to-rib")

                                                self.prefixes_sent_to_rib = YLeaf(YType.uint32, "prefixes-sent-to-rib")

                                                self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                                self.rib_tbl_del_calls = YLeaf(YType.uint32, "rib-tbl-del-calls")

                                                self.rib_tbl_invalid_calls = YLeaf(YType.uint32, "rib-tbl-invalid-calls")

                                                self.rib_tbl_local_label = YLeaf(YType.uint32, "rib-tbl-local-label")

                                                self.rib_tbl_retry = YLeaf(YType.uint32, "rib-tbl-retry")

                                                self.rib_tbl_skip_calls = YLeaf(YType.uint32, "rib-tbl-skip-calls")

                                                self.rib_trigger = YLeaf(YType.boolean, "rib-trigger")

                                                self.rib_update_calls = YLeaf(YType.uint32, "rib-update-calls")

                                                self.rib_update_time = YLeaf(YType.uint32, "rib-update-time")

                                                self.scanner_runs = YLeaf(YType.uint32, "scanner-runs")

                                                self.scanner_time = YLeaf(YType.uint32, "scanner-time")

                                                self.subgroup_count = YLeaf(YType.uint32, "subgroup-count")

                                                self.time_last_update_sent = YLeaf(YType.uint32, "time-last-update-sent")

                                                self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                                self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                                self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                                self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                                self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                                self.update_group_count = YLeaf(YType.uint32, "update-group-count")

                                                self.vrf_flags = YLeaf(YType.uint32, "vrf-flags")

                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"
                                                self._children_yang_names.add("first-rib-table-full-timestamp")

                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"
                                                self._children_yang_names.add("first-rib-table-has-space-timestamp")

                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"
                                                self._children_yang_names.add("last-rib-table-full-timestamp")

                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"
                                                self._children_yang_names.add("last-rib-table-has-space-timestamp")

                                                self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self._children_name_map["time_label_retain"] = "time-label-retain"
                                                self._children_yang_names.add("time-label-retain")

                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self._children_name_map["time_rib_coverged"] = "time-rib-coverged"
                                                self._children_yang_names.add("time-rib-coverged")

                                                self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self._children_name_map["time_rib_down"] = "time-rib-down"
                                                self._children_yang_names.add("time-rib-down")
                                                self._segment_path = lambda: "vrf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, ['attributes_recover_from_rib', 'attributes_removed_from_rib', 'attributes_sent_to_rib', 'first_rib_table_full_version', 'first_rib_table_has_space_version', 'import_added_path_count', 'import_calls', 'import_dest_net_processed_count', 'import_removed_path_count', 'import_replaced_path_count', 'import_src_net_processed_count', 'import_time', 'is_rib_table_full', 'label_added_count', 'label_calls', 'label_release_count', 'label_rewrite_count', 'label_time', 'last_rib_table_full_age', 'last_rib_table_full_version', 'last_rib_table_has_space_age', 'last_rib_table_has_space_version', 'prefixes_not_sent_to_rib', 'prefixes_removed_from_rib', 'prefixes_resent_to_rib', 'prefixes_sent_to_rib', 'rib_table_full_version', 'rib_tbl_del_calls', 'rib_tbl_invalid_calls', 'rib_tbl_local_label', 'rib_tbl_retry', 'rib_tbl_skip_calls', 'rib_trigger', 'rib_update_calls', 'rib_update_time', 'scanner_runs', 'scanner_time', 'subgroup_count', 'time_last_update_sent', 'update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'update_group_count', 'vrf_flags'], name, value)


                                            class FirstRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "first-rib-table-full-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class FirstRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "first-rib-table-has-space-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-rib-table-full-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-rib-table-has-space-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class TimeLabelRetain(Entity):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                    self.yang_name = "time-label-retain"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-label-retain"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, ['nanoseconds', 'seconds'], name, value)


                                            class TimeRibCoverged(Entity):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                    self.yang_name = "time-rib-coverged"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-rib-coverged"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, ['nanoseconds', 'seconds'], name, value)


                                            class TimeRibDown(Entity):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                    self.yang_name = "time-rib-down"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "time-rib-down"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, ['nanoseconds', 'seconds'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\:  bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.add_path_install_disable = YLeaf(YType.boolean, "add-path-install-disable")

                                            self.add_path_install_enable = YLeaf(YType.boolean, "add-path-install-enable")

                                            self.any_ebgp_neighbor_missing_policy = YLeaf(YType.boolean, "any-ebgp-neighbor-missing-policy")

                                            self.asbr = YLeaf(YType.boolean, "asbr")

                                            self.attribute_download = YLeaf(YType.boolean, "attribute-download")

                                            self.best_external = YLeaf(YType.boolean, "best-external")

                                            self.best_external_disable = YLeaf(YType.boolean, "best-external-disable")

                                            self.bmp_network_entry_count = YLeaf(YType.uint32, "bmp-network-entry-count")

                                            self.bmp_path_memory = YLeaf(YType.uint32, "bmp-path-memory")

                                            self.bmp_paths_count = YLeaf(YType.uint32, "bmp-paths-count")

                                            self.bmp_prefix_memory = YLeaf(YType.uint32, "bmp-prefix-memory")

                                            self.damped_path_count = YLeaf(YType.uint32, "damped-path-count")

                                            self.freed_path_count = YLeaf(YType.uint32, "freed-path-count")

                                            self.freed_path_elem_count = YLeaf(YType.uint32, "freed-path-elem-count")

                                            self.freed_prefix_count = YLeaf(YType.uint32, "freed-prefix-count")

                                            self.history_path_count = YLeaf(YType.uint32, "history-path-count")

                                            self.ibgp_nexthop_self_count = YLeaf(YType.uint32, "ibgp-nexthop-self-count")

                                            self.imported_path_memory = YLeaf(YType.uint32, "imported-path-memory")

                                            self.imported_paths = YLeaf(YType.uint32, "imported-paths")

                                            self.is_route_reflector = YLeaf(YType.boolean, "is-route-reflector")

                                            self.label_retain = YLeaf(YType.boolean, "label-retain")

                                            self.label_retainvalue = YLeaf(YType.uint32, "label-retainvalue")

                                            self.local_path_memory = YLeaf(YType.uint32, "local-path-memory")

                                            self.local_paths = YLeaf(YType.uint32, "local-paths")

                                            self.malloced_path_count = YLeaf(YType.uint32, "malloced-path-count")

                                            self.malloced_path_elem_count = YLeaf(YType.uint32, "malloced-path-elem-count")

                                            self.malloced_prefix_count = YLeaf(YType.uint32, "malloced-prefix-count")

                                            self.network_entry_count = YLeaf(YType.uint32, "network-entry-count")

                                            self.path_elem_memory = YLeaf(YType.uint32, "path-elem-memory")

                                            self.path_elems_count = YLeaf(YType.uint32, "path-elems-count")

                                            self.path_memory = YLeaf(YType.uint32, "path-memory")

                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                            self.prefix_memory = YLeaf(YType.uint32, "prefix-memory")

                                            self.received_path_count = YLeaf(YType.uint32, "received-path-count")

                                            self.retain_rt_all = YLeaf(YType.boolean, "retain-rt-all")

                                            self.route_target_download = YLeaf(YType.boolean, "route-target-download")

                                            self.tbl_bitf_size = YLeaf(YType.uint16, "tbl-bitf-size")

                                            self.tbl_chunk_bitf_size = YLeaf(YType.uint16, "tbl-chunk-bitf-size")

                                            self.use_igpsr_label = YLeaf(YType.boolean, "use-igpsr-label")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf, ['add_path_install_disable', 'add_path_install_enable', 'any_ebgp_neighbor_missing_policy', 'asbr', 'attribute_download', 'best_external', 'best_external_disable', 'bmp_network_entry_count', 'bmp_path_memory', 'bmp_paths_count', 'bmp_prefix_memory', 'damped_path_count', 'freed_path_count', 'freed_path_elem_count', 'freed_prefix_count', 'history_path_count', 'ibgp_nexthop_self_count', 'imported_path_memory', 'imported_paths', 'is_route_reflector', 'label_retain', 'label_retainvalue', 'local_path_memory', 'local_paths', 'malloced_path_count', 'malloced_path_elem_count', 'malloced_prefix_count', 'network_entry_count', 'path_elem_memory', 'path_elems_count', 'path_memory', 'paths_count', 'prefix_memory', 'received_path_count', 'retain_rt_all', 'route_target_download', 'tbl_bitf_size', 'tbl_chunk_bitf_size', 'use_igpsr_label'], name, value)


                                class Attributes(Entity):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes, self).__init__()

                                        self.yang_name = "attributes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"attribute" : ("attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute)}

                                        self.attribute = YList(self)
                                        self._segment_path = lambda: "attributes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes, [], name, value)


                                    class Attribute(Entity):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute, self).__init__()

                                            self.yang_name = "attribute"
                                            self.yang_parent_name = "attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attribute-info" : ("attribute_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo)}
                                            self._child_list_classes = {}

                                            self.attribute_cache_bucket = YLeaf(YType.int32, "attribute-cache-bucket")

                                            self.attribute_cache_id = YLeaf(YType.int32, "attribute-cache-id")

                                            self.attribute_iid = YLeaf(YType.int32, "attribute-iid")

                                            self.attribute_instance_id = YLeaf(YType.uint8, "attribute-instance-id")

                                            self.attribute_structure_hash_value = YLeaf(YType.uint32, "attribute-structure-hash-value")

                                            self.attribute_structure_id = YLeaf(YType.uint32, "attribute-structure-id")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.reference_count = YLeaf(YType.uint32, "reference-count")

                                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self._children_name_map["attribute_info"] = "attribute-info"
                                            self._children_yang_names.add("attribute-info")
                                            self._segment_path = lambda: "attribute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute, ['attribute_cache_bucket', 'attribute_cache_id', 'attribute_iid', 'attribute_instance_id', 'attribute_structure_hash_value', 'attribute_structure_id', 'process_instance_id', 'reference_count'], name, value)


                                        class AttributeInfo(Entity):
                                            """
                                            Attributes
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                                self.yang_name = "attribute-info"
                                                self.yang_parent_name = "attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attribute-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                class BmpPathTableGeneric(Entity):
                                    """
                                    Summary Info about BMP Table
                                    
                                    .. attribute:: bmp_route_monitoringe_enabled
                                    
                                    	Is Route Monitoring mode enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_incremented
                                    
                                    	Is Version being incremented
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_version_inprogress
                                    
                                    	Is Version wrap in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrapped
                                    
                                    	Number of times Table Version Wrapped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped_tid
                                    
                                    	Version Wrapped trigger thread id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_count
                                    
                                    	Number of nets in the table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_count
                                    
                                    	Number of paths in the table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                        self.yang_name = "bmp-path-table-generic"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-version-wrap-done-time-spec" : ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec), "bmp-version-wrap-start-time-spec" : ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec), "bmp-version-wrap-time-spec" : ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)}
                                        self._child_list_classes = {}

                                        self.bmp_route_monitoringe_enabled = YLeaf(YType.boolean, "bmp-route-monitoringe-enabled")

                                        self.bmp_table_version = YLeaf(YType.uint32, "bmp-table-version")

                                        self.bmp_version_incremented = YLeaf(YType.boolean, "bmp-version-incremented")

                                        self.bmp_version_inprogress = YLeaf(YType.boolean, "bmp-version-inprogress")

                                        self.bmp_version_wrapped = YLeaf(YType.uint32, "bmp-version-wrapped")

                                        self.bmp_version_wrapped_tid = YLeaf(YType.uint32, "bmp-version-wrapped-tid")

                                        self.network_count = YLeaf(YType.uint32, "network-count")

                                        self.path_count = YLeaf(YType.uint32, "path-count")

                                        self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                        self.bmp_version_wrap_done_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-done-time-spec")

                                        self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                        self.bmp_version_wrap_start_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-start-time-spec")

                                        self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                        self.bmp_version_wrap_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"
                                        self._children_yang_names.add("bmp-version-wrap-time-spec")
                                        self._segment_path = lambda: "bmp-path-table-generic"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, ['bmp_route_monitoringe_enabled', 'bmp_table_version', 'bmp_version_incremented', 'bmp_version_inprogress', 'bmp_version_wrapped', 'bmp_version_wrapped_tid', 'network_count', 'path_count'], name, value)


                                    class BmpVersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-done-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-done-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpVersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-start-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-start-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpVersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-version-wrap-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class BmpPaths(Entity):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths, self).__init__()

                                        self.yang_name = "bmp-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath)}

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-paths"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths, [], name, value)


                                    class BmpPath(Entity):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath>`
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)}
                                            self._child_list_classes = {"bmp-path" : ("bmp_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath)}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bmp_net_flags = YLeaf(YType.uint32, "bmp-net-flags")

                                            self.bmp_net_version = YLeaf(YType.uint32, "bmp-net-version")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.network = YLeaf(YType.str, "network")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.bmp_path = YList(self)
                                            self._segment_path = lambda: "bmp-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, ['af_name', 'bmp_net_flags', 'bmp_net_version', 'has_local_label', 'net_local_label', 'network', 'num_of_path', 'prefix_length'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BmpPath(Entity):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress>`
                                            
                                            .. attribute:: received_label
                                            
                                            	Label received from peer
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath, self).__init__()

                                                self.yang_name = "bmp-path"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.bmp_nbr_bit_map = YLeaf(YType.uint32, "bmp-nbr-bit-map")

                                                self.bmp_path_adv_bit_map = YLeaf(YType.uint16, "bmp-path-adv-bit-map")

                                                self.bmp_path_flags = YLeaf(YType.uint32, "bmp-path-flags")

                                                self.bmp_path_snd_bit_map = YLeaf(YType.uint16, "bmp-path-snd-bit-map")

                                                self.bpath_pointer = YLeaf(YType.uint64, "bpath-pointer")

                                                self.local_path = YLeaf(YType.boolean, "local-path")

                                                self.received_label = YLeaf(YType.uint32, "received-label")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "bmp-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath, ['bmp_nbr_bit_map', 'bmp_path_adv_bit_map', 'bmp_path_flags', 'bmp_path_snd_bit_map', 'bpath_pointer', 'local_path', 'received_label'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Convergence(Entity):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence, self).__init__()

                                        self.yang_name = "convergence"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.are_write_queues_empty = YLeaf(YType.boolean, "are-write-queues-empty")

                                        self.has_converged = YLeaf(YType.boolean, "has-converged")
                                        self._segment_path = lambda: "convergence"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence, ['af_name', 'are_write_queues_empty', 'has_converged'], name, value)


                                class Dampenings(Entity):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings, self).__init__()

                                        self.yang_name = "dampenings"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"dampening" : ("dampening", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening)}

                                        self.dampening = YList(self)
                                        self._segment_path = lambda: "dampenings"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "dampenings"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.length = YLeaf(YType.int32, "length")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.reuse = YLeaf(YType.int32, "reuse")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.version = YLeaf(YType.int32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "dampening"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'length', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_version', 'process_instance_id', 'rd', 'reuse', 'route_distinguisher', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'version', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class Epes(Entity):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes, self).__init__()

                                        self.yang_name = "epes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"epe" : ("epe", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe)}

                                        self.epe = YList(self)
                                        self._segment_path = lambda: "epes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes, [], name, value)


                                    class Epe(Entity):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe, self).__init__()

                                            self.yang_name = "epe"
                                            self.yang_parent_name = "epes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"epe-local-address" : ("epe_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress), "epe-next-hop" : ("epe_next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop)}
                                            self._child_list_classes = {"epe-key" : ("epe_key", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey), "first-hop" : ("first_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop), "ifhandle" : ("ifhandle", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle), "nexthop-id" : ("nexthop_id", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId)}

                                            self.epe_flags = YLeaf(YType.uint8, "epe-flags")

                                            self.epe_key_length = YLeaf(YType.int32, "epe-key-length")

                                            self.epe_key_length_xr = YLeaf(YType.uint8, "epe-key-length-xr")

                                            self.epe_local_asn = YLeaf(YType.uint32, "epe-local-asn")

                                            self.epe_local_router_id = YLeaf(YType.uint32, "epe-local-router-id")

                                            self.epe_remote_asn = YLeaf(YType.uint32, "epe-remote-asn")

                                            self.epe_remote_router_id = YLeaf(YType.uint32, "epe-remote-router-id")

                                            self.epe_set_key = YLeaf(YType.str, "epe-set-key")

                                            self.epe_version = YLeaf(YType.uint32, "epe-version")

                                            self.label = YLeaf(YType.uint32, "label")

                                            self.ref_count = YLeaf(YType.uint32, "ref-count")

                                            self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self._children_name_map["epe_local_address"] = "epe-local-address"
                                            self._children_yang_names.add("epe-local-address")

                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self._children_name_map["epe_next_hop"] = "epe-next-hop"
                                            self._children_yang_names.add("epe-next-hop")

                                            self.epe_key = YList(self)
                                            self.first_hop = YList(self)
                                            self.ifhandle = YList(self)
                                            self.nexthop_id = YList(self)
                                            self._segment_path = lambda: "epe"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe, ['epe_flags', 'epe_key_length', 'epe_key_length_xr', 'epe_local_asn', 'epe_local_router_id', 'epe_remote_asn', 'epe_remote_router_id', 'epe_set_key', 'epe_version', 'label', 'ref_count'], name, value)


                                        class EpeKey(Entity):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                                self.yang_name = "epe-key"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "epe-key"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, ['entry'], name, value)


                                        class EpeLocalAddress(Entity):
                                            """
                                            Local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                                self.yang_name = "epe-local-address"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "epe-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class EpeNextHop(Entity):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                                self.yang_name = "epe-next-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "epe-next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class FirstHop(Entity):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                                self.yang_name = "first-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "first-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class Ifhandle(Entity):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                                self.yang_name = "ifhandle"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ifhandle"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, ['entry'], name, value)


                                        class NexthopId(Entity):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                                self.yang_name = "nexthop-id"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "nexthop-id"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, ['entry'], name, value)


                                class GlobalAfProcessInfo(Entity):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                        self.yang_name = "global-af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.is_nsr_enabled = YLeaf(YType.boolean, "is-nsr-enabled")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"
                                        self._children_yang_names.add("global")

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._children_yang_names.add("vrf")
                                        self._segment_path = lambda: "global-af-process-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, ['af_name', 'is_nsr_enabled', 'vrf_name'], name, value)


                                    class Global_(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rib-install" : ("rib_install", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall)}
                                            self._child_list_classes = {"syncgrp-version" : ("syncgrp_version", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion)}

                                            self.gblafrpki_allow_invalid = YLeaf(YType.boolean, "gblafrpki-allow-invalid")

                                            self.gblafrpki_disable = YLeaf(YType.boolean, "gblafrpki-disable")

                                            self.gblafrpki_signal_ibgp = YLeaf(YType.boolean, "gblafrpki-signal-ibgp")

                                            self.gblafrpki_use_validity = YLeaf(YType.boolean, "gblafrpki-use-validity")

                                            self.global_mcast_enabled = YLeaf(YType.boolean, "global-mcast-enabled")

                                            self.inter_as_install_enabled = YLeaf(YType.boolean, "inter-as-install-enabled")

                                            self.is_perm_net_cfg = YLeaf(YType.boolean, "is-perm-net-cfg")

                                            self.nh_tunnel_version = YLeaf(YType.uint32, "nh-tunnel-version")

                                            self.perm_nbr_count = YLeaf(YType.uint16, "perm-nbr-count")

                                            self.perm_net_del_count = YLeaf(YType.uint16, "perm-net-del-count")

                                            self.perm_net_existing_count = YLeaf(YType.uint16, "perm-net-existing-count")

                                            self.perm_net_insert_count = YLeaf(YType.uint16, "perm-net-insert-count")

                                            self.perm_net_rpl_process_count = YLeaf(YType.uint16, "perm-net-rpl-process-count")

                                            self.perm_net_rpl_query_count = YLeaf(YType.uint16, "perm-net-rpl-query-count")

                                            self.perm_net_stale_del_count = YLeaf(YType.uint16, "perm-net-stale-del-count")

                                            self.perm_net_stale_mark_count = YLeaf(YType.uint16, "perm-net-stale-mark-count")

                                            self.perm_path_refresh_count = YLeaf(YType.uint16, "perm-path-refresh-count")

                                            self.perm_pelem_all_bump_count = YLeaf(YType.uint16, "perm-pelem-all-bump-count")

                                            self.perm_pelem_bump_count = YLeaf(YType.uint16, "perm-pelem-bump-count")

                                            self.perm_pelem_free_count = YLeaf(YType.uint16, "perm-pelem-free-count")

                                            self.rib_ack_requests = YLeaf(YType.uint32, "rib-ack-requests")

                                            self.rib_acks_received = YLeaf(YType.uint32, "rib-acks-received")

                                            self.rib_perm_path_found_count = YLeaf(YType.uint16, "rib-perm-path-found-count")

                                            self.rib_perm_path_not_found_count = YLeaf(YType.uint16, "rib-perm-path-not-found-count")

                                            self.rib_perm_pelem_found_count = YLeaf(YType.uint16, "rib-perm-pelem-found-count")

                                            self.rib_perm_pelem_not_found_count = YLeaf(YType.uint16, "rib-perm-pelem-not-found-count")

                                            self.rib_reg_path_found_count = YLeaf(YType.uint16, "rib-reg-path-found-count")

                                            self.rib_slow_acks = YLeaf(YType.uint32, "rib-slow-acks")

                                            self.scan_prefixes = YLeaf(YType.uint32, "scan-prefixes")

                                            self.scan_segment_prefixes = YLeaf(YType.uint32, "scan-segment-prefixes")

                                            self.scan_segments = YLeaf(YType.uint8, "scan-segments")

                                            self.scanner_period = YLeaf(YType.uint16, "scanner-period")

                                            self.segmented_mcast_enabled = YLeaf(YType.boolean, "segmented-mcast-enabled")

                                            self.update_wait_install_enabled = YLeaf(YType.boolean, "update-wait-install-enabled")

                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._children_yang_names.add("rib-install")

                                            self.syncgrp_version = YList(self)
                                            self._segment_path = lambda: "global"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_, ['gblafrpki_allow_invalid', 'gblafrpki_disable', 'gblafrpki_signal_ibgp', 'gblafrpki_use_validity', 'global_mcast_enabled', 'inter_as_install_enabled', 'is_perm_net_cfg', 'nh_tunnel_version', 'perm_nbr_count', 'perm_net_del_count', 'perm_net_existing_count', 'perm_net_insert_count', 'perm_net_rpl_process_count', 'perm_net_rpl_query_count', 'perm_net_stale_del_count', 'perm_net_stale_mark_count', 'perm_path_refresh_count', 'perm_pelem_all_bump_count', 'perm_pelem_bump_count', 'perm_pelem_free_count', 'rib_ack_requests', 'rib_acks_received', 'rib_perm_path_found_count', 'rib_perm_path_not_found_count', 'rib_perm_pelem_found_count', 'rib_perm_pelem_not_found_count', 'rib_reg_path_found_count', 'rib_slow_acks', 'scan_prefixes', 'scan_segment_prefixes', 'scan_segments', 'scanner_period', 'segmented_mcast_enabled', 'update_wait_install_enabled'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"install-time" : ("install_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime), "update-time" : ("update_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime)}
                                                self._child_list_classes = {}

                                                self.installed_count = YLeaf(YType.uint32, "installed-count")

                                                self.modified_count = YLeaf(YType.uint32, "modified-count")

                                                self.skipped_count = YLeaf(YType.uint32, "skipped-count")

                                                self.start_version = YLeaf(YType.uint32, "start-version")

                                                self.target_version = YLeaf(YType.uint32, "target-version")

                                                self.withdrawn_count = YLeaf(YType.uint32, "withdrawn-count")

                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._children_yang_names.add("install-time")

                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"
                                                self._children_yang_names.add("update-time")
                                                self._segment_path = lambda: "rib-install"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall, ['installed_count', 'modified_count', 'skipped_count', 'start_version', 'target_version', 'withdrawn_count'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "install-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime, ['nanoseconds', 'seconds'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime, ['nanoseconds', 'seconds'], name, value)


                                        class SyncgrpVersion(Entity):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, self).__init__()

                                                self.yang_name = "syncgrp-version"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "syncgrp-version"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion, ['entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.aggregates_distance = YLeaf(YType.uint16, "aggregates-distance")

                                            self.client_reflection_enabled = YLeaf(YType.boolean, "client-reflection-enabled")

                                            self.dampening_enabled = YLeaf(YType.boolean, "dampening-enabled")

                                            self.dynamic_med_enabled = YLeaf(YType.boolean, "dynamic-med-enabled")

                                            self.dynamic_med_interval = YLeaf(YType.uint16, "dynamic-med-interval")

                                            self.dynamic_med_periodic_timer_running = YLeaf(YType.boolean, "dynamic-med-periodic-timer-running")

                                            self.dynamic_med_periodic_timer_value = YLeaf(YType.uint16, "dynamic-med-periodic-timer-value")

                                            self.dynamic_med_timer_running = YLeaf(YType.boolean, "dynamic-med-timer-running")

                                            self.dynamic_med_timer_value = YLeaf(YType.uint16, "dynamic-med-timer-value")

                                            self.ebgp_distance = YLeaf(YType.uint16, "ebgp-distance")

                                            self.ibgp_distance = YLeaf(YType.uint16, "ibgp-distance")

                                            self.is_rib_table_full = YLeaf(YType.boolean, "is-rib-table-full")

                                            self.nexthop_resolution_minimum_prefix_length = YLeaf(YType.uint32, "nexthop-resolution-minimum-prefix-length")

                                            self.nexthop_resolution_minimum_prefix_length_configured = YLeaf(YType.boolean, "nexthop-resolution-minimum-prefix-length-configured")

                                            self.nsr_conv_version = YLeaf(YType.uint32, "nsr-conv-version")

                                            self.nsr_is_conv = YLeaf(YType.boolean, "nsr-is-conv")

                                            self.rd_version = YLeaf(YType.uint32, "rd-version")

                                            self.rib_acked_table_version = YLeaf(YType.uint32, "rib-acked-table-version")

                                            self.rib_convergence_version = YLeaf(YType.uint32, "rib-convergence-version")

                                            self.rib_has_converged = YLeaf(YType.boolean, "rib-has-converged")

                                            self.rib_table_full_version = YLeaf(YType.uint32, "rib-table-full-version")

                                            self.rib_version = YLeaf(YType.uint32, "rib-version")

                                            self.selective_ebgp_multipath_enabled = YLeaf(YType.boolean, "selective-ebgp-multipath-enabled")

                                            self.selective_eibgp_multipath_enabled = YLeaf(YType.boolean, "selective-eibgp-multipath-enabled")

                                            self.selective_ibgp_multipath_enabled = YLeaf(YType.boolean, "selective-ibgp-multipath-enabled")

                                            self.table_id = YLeaf(YType.uint32, "table-id")

                                            self.table_is_active = YLeaf(YType.boolean, "table-is-active")

                                            self.table_version = YLeaf(YType.uint32, "table-version")
                                            self._segment_path = lambda: "vrf"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf, ['aggregates_distance', 'client_reflection_enabled', 'dampening_enabled', 'dynamic_med_enabled', 'dynamic_med_interval', 'dynamic_med_periodic_timer_running', 'dynamic_med_periodic_timer_value', 'dynamic_med_timer_running', 'dynamic_med_timer_value', 'ebgp_distance', 'ibgp_distance', 'is_rib_table_full', 'nexthop_resolution_minimum_prefix_length', 'nexthop_resolution_minimum_prefix_length_configured', 'nsr_conv_version', 'nsr_is_conv', 'rd_version', 'rib_acked_table_version', 'rib_convergence_version', 'rib_has_converged', 'rib_table_full_version', 'rib_version', 'selective_ebgp_multipath_enabled', 'selective_eibgp_multipath_enabled', 'selective_ibgp_multipath_enabled', 'table_id', 'table_is_active', 'table_version'], name, value)


                                class NeighborAfTable(Entity):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable, self).__init__()

                                        self.yang_name = "neighbor-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbor-af-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\:  str
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\:  bool
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\:  bool
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbor-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)}
                                            self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData)}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                            self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                            self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                            self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                            self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                            self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                            self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                            self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                            self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                            self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                            self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                            self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                            self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                            self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                            self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                            self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                            self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                            self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                            self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                            self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                            self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                            self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                            self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                            self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                            self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                            self.description = YLeaf(YType.str, "description")

                                            self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                            self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                            self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                            self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                            self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                            self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                            self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                            self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                            self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                            self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                            self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                            self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                            self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                            self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                            self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                            self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                            self.hold_time = YLeaf(YType.uint16, "hold-time")

                                            self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                            self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                            self.io_armed = YLeaf(YType.boolean, "io-armed")

                                            self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                            self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                            self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                            self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                            self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                            self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                            self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                            self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                            self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                            self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                            self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                            self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                            self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                            self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                            self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                            self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                            self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                            self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                            self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                            self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                            self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                            self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                            self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                            self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                            self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                            self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                            self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                            self.local_as = YLeaf(YType.uint32, "local-as")

                                            self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                            self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                            self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                            self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                            self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                            self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                            self.messages_received = YLeaf(YType.uint32, "messages-received")

                                            self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                            self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                            self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                            self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                            self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                            self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                            self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                            self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                            self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                            self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                            self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                            self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                            self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                            self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                            self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                            self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                            self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                            self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                            self.read_armed = YLeaf(YType.boolean, "read-armed")

                                            self.remote_as = YLeaf(YType.uint32, "remote-as")

                                            self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                            self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                            self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                            self.router_id = YLeaf(YType.str, "router-id")

                                            self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                            self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                            self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                            self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                            self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                            self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                            self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                            self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                            self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                            self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                            self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                            self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                            self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                            self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                            self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                            self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                            self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                            self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                            self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                            self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                            self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                            self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                            self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                            self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                            self.tos_type = YLeaf(YType.uint8, "tos-type")

                                            self.tos_value = YLeaf(YType.uint8, "tos-value")

                                            self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                            self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                            self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                            self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.write_armed = YLeaf(YType.boolean, "write-armed")

                                            self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self._children_name_map["connection_local_address"] = "connection-local-address"
                                            self._children_yang_names.add("connection-local-address")

                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                            self._children_yang_names.add("connection-remote-address")

                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                            self._children_yang_names.add("graceful-maintenance")

                                            self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self._children_name_map["message_statistics"] = "message-statistics"
                                            self._children_yang_names.add("message-statistics")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")

                                            self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self._children_name_map["received_notification_info"] = "received-notification-info"
                                            self._children_yang_names.add("received-notification-info")

                                            self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self._children_name_map["send_notification_info"] = "send-notification-info"
                                            self._children_yang_names.add("send-notification-info")

                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                            self._children_yang_names.add("tcp-init-sync-time-spec")

                                            self.af_data = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                        class AfData(Entity):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with 
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\:  bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\:  bool
                                            
                                            .. attribute:: enable_label_stack
                                            
                                            	Enable label stack
                                            	**type**\:  bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\:  bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\:  str
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\:  str
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                                self.yang_name = "af-data"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                                self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby)}

                                                self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                                self.acked_version = YLeaf(YType.uint32, "acked-version")

                                                self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                                self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                                self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                                self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                                self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                                self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                                self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                                self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                                self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                                self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                                self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                                self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                                self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                                self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                                self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                                self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                                self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                                self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                                self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                                self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                                self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                                self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                                self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                                self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                                self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                                self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                                self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                                self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                                self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                                self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                                self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                                self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                                self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                                self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                                self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                                self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                                self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                                self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                                self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                                self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                                self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                                self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                                self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                                self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                                self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                                self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                                self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                                self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                                self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                                self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                                self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                                self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                                self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                                self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                                self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                                self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                                self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                                self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                                self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                                self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                                self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                                self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                                self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                                self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                                self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                                self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                                self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                                self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                                self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                                self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                                self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                                self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                                self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                                self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                                self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                                self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                                self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                                self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                                self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                                self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                                self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                                self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                                self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                                self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                                self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                                self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                                self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                                self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                                self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                                self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                                self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                                self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                                self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                                self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                                self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                                self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                                self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                                self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                                self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                                self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                                self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                                self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                                self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                                self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                                self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                                self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                                self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                                self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                                self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                                self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                                self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                                self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                                self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                                self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                                self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                                self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                                self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                                self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                                self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                                self._children_yang_names.add("neighbor-af-performance-statistics")

                                                self.extended_community = YList(self)
                                                self.extended_community_standby = YList(self)
                                                self._segment_path = lambda: "af-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                            class ExtendedCommunityStandby(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                    self.yang_name = "extended-community-standby"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community-standby"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                            class NeighborAfPerformanceStatistics(Entity):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                    self.yang_name = "neighbor-af-performance-statistics"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                                    self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                                    self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                                    self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                                    self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                                    self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                                    self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                                    self._segment_path = lambda: "neighbor-af-performance-statistics"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                        class ConnectionLocalAddress(Entity):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                                self.yang_name = "connection-local-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "connection-local-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ConnectionRemoteAddress(Entity):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                                self.yang_name = "connection-remote-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "connection-remote-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class GracefulMaintenance(Entity):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                                self.yang_name = "graceful-maintenance"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                                self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                                self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                                self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                                self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                                self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                                self._segment_path = lambda: "graceful-maintenance"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                        class MessageStatistics(Entity):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                                self.yang_name = "message-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)}
                                                self._child_list_classes = {}

                                                self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self._children_name_map["keepalive"] = "keepalive"
                                                self._children_yang_names.add("keepalive")

                                                self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self._children_name_map["notification"] = "notification"
                                                self._children_yang_names.add("notification")

                                                self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self._children_name_map["open"] = "open"
                                                self._children_yang_names.add("open")

                                                self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self._children_name_map["route_refresh"] = "route-refresh"
                                                self._children_yang_names.add("route-refresh")

                                                self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self._children_name_map["total"] = "total"
                                                self._children_yang_names.add("total")

                                                self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self
                                                self._children_name_map["update"] = "update"
                                                self._children_yang_names.add("update")
                                                self._segment_path = lambda: "message-statistics"


                                            class Keepalive(Entity):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                    self.yang_name = "keepalive"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "keepalive"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Notification(Entity):
                                                """
                                                Notification
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                    self.yang_name = "notification"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "notification"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Open(Entity):
                                                """
                                                Open
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                    self.yang_name = "open"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "open"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class RouteRefresh(Entity):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                    self.yang_name = "route-refresh"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "route-refresh"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Total(Entity):
                                                """
                                                Total
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                    self.yang_name = "total"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "total"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                            class Update(Entity):
                                                """
                                                Update
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                    self.yang_name = "update"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)}
                                                    self._child_list_classes = {}

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._children_yang_names.add("rx")

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"
                                                    self._children_yang_names.add("tx")
                                                    self._segment_path = lambda: "update"


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "rx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                        self._child_list_classes = {}

                                                        self.count = YLeaf(YType.uint32, "count")

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._children_yang_names.add("last-time-spec")
                                                        self._segment_path = lambda: "tx"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                                            self._segment_path = lambda: "last-time-spec"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.active_collision = YLeaf(YType.uint32, "active-collision")

                                                self.actives = YLeaf(YType.uint32, "actives")

                                                self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                                self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                                self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                                self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                                self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                                self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                                self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                                self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                                self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                                self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                                self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                                self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                                self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                                self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                                self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                                self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                                self.network_status = YLeaf(YType.uint32, "network-status")

                                                self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                                self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                                self.passives = YLeaf(YType.uint32, "passives")

                                                self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                                self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                                self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                                self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                                self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                                self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                                self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                                self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                                self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                                self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                                self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                                self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                                self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                                self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                                self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                        class ReceivedNotificationInfo(Entity):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                                self.yang_name = "received-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                                self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                                self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                                self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "received-notification-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "received-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "last-notification-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                        class SendNotificationInfo(Entity):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                                self.yang_name = "send-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData)}

                                                self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                                self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                                self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "send-notification-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "send-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "last-notification-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                        class TcpInitSyncDoneTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-done-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class TcpInitSyncTimeSpec(Entity):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "tcp-init-sync-time-spec"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class NetworkAllRds(Entity):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds, self).__init__()

                                        self.yang_name = "network-all-rds"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-all-rd" : ("network_all_rd", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd)}

                                        self.network_all_rd = YList(self)
                                        self._segment_path = lambda: "network-all-rds"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds, [], name, value)


                                    class NetworkAllRd(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: network_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd, self).__init__()

                                            self.yang_name = "network-all-rd"
                                            self.yang_parent_name = "network-all-rds"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"network-rds" : ("network_rds", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds)}
                                            self._child_list_classes = {}

                                            self.network = YLeaf(YType.str, "network")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.network_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                            self.network_rds.parent = self
                                            self._children_name_map["network_rds"] = "network-rds"
                                            self._children_yang_names.add("network-rds")
                                            self._segment_path = lambda: "network-all-rd"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd, ['network', 'prefix_length'], name, value)


                                        class NetworkRds(Entity):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, self).__init__()

                                                self.yang_name = "network-rds"
                                                self.yang_parent_name = "network-all-rd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"network-rd" : ("network_rd", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd)}

                                                self.network_rd = YList(self)
                                                self._segment_path = lambda: "network-rds"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds, [], name, value)


                                            class NetworkRd(Entity):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, self).__init__()

                                                    self.yang_name = "network-rd"
                                                    self.yang_parent_name = "network-rds"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp)}
                                                    self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo)}

                                                    self.rd = YLeaf(YType.str, "rd")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.bit = YLeaf(YType.uint16, "bit")

                                                    self.flags = YLeaf(YType.uint8, "flags")

                                                    self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                    self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                    self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                    self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                    self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                    self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                    self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                    self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                    self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                    self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                    self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                    self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                    self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                    self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                    self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                    self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                    self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                    self.table_version = YLeaf(YType.uint32, "table-version")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self._children_name_map["version_age"] = "version-age"
                                                    self._children_yang_names.add("version-age")

                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self._children_name_map["version_timestamp"] = "version-timestamp"
                                                    self._children_yang_names.add("version-timestamp")

                                                    self.active_path_element = YList(self)
                                                    self.active_process_instance_path = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.local_path_element = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.local_process_instance_path = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self._segment_path = lambda: "network-rd" + "[rd='" + self.rd.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                                class ActivePathElement(Entity):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, self).__init__()

                                                        self.yang_name = "active-path-element"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "active-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ActiveProcessInstancePath(Entity):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, self).__init__()

                                                        self.yang_name = "active-process-instance-path"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "active-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPathElement(Entity):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, self).__init__()

                                                        self.yang_name = "local-path-element"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "local-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalProcessInstancePath(Entity):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, self).__init__()

                                                        self.yang_name = "local-process-instance-path"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "local-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class VersionAge(Entity):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, self).__init__()

                                                        self.yang_name = "version-age"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-age"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                                class VersionTimestamp(Entity):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, self).__init__()

                                                        self.yang_name = "version-timestamp"
                                                        self.yang_parent_name = "network-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-timestamp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NetworkLookupAllRds(Entity):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_lookup_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds, self).__init__()

                                        self.yang_name = "network-lookup-all-rds"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-lookup-all-rd" : ("network_lookup_all_rd", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd)}

                                        self.network_lookup_all_rd = YList(self)
                                        self._segment_path = lambda: "network-lookup-all-rds"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds, [], name, value)


                                    class NetworkLookupAllRd(Entity):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_lookup_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, self).__init__()

                                            self.yang_name = "network-lookup-all-rd"
                                            self.yang_parent_name = "network-lookup-all-rds"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"network-lookup-rds" : ("network_lookup_rds", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds)}
                                            self._child_list_classes = {}

                                            self.network_prefix = YLeaf(YType.str, "network-prefix")

                                            self.network_lookup_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                            self.network_lookup_rds.parent = self
                                            self._children_name_map["network_lookup_rds"] = "network-lookup-rds"
                                            self._children_yang_names.add("network-lookup-rds")
                                            self._segment_path = lambda: "network-lookup-all-rd" + "[network-prefix='" + self.network_prefix.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd, ['network_prefix'], name, value)


                                        class NetworkLookupRds(Entity):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_lookup_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, self).__init__()

                                                self.yang_name = "network-lookup-rds"
                                                self.yang_parent_name = "network-lookup-all-rd"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"network-lookup-rd" : ("network_lookup_rd", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd)}

                                                self.network_lookup_rd = YList(self)
                                                self._segment_path = lambda: "network-lookup-rds"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds, [], name, value)


                                            class NetworkLookupRd(Entity):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, self).__init__()

                                                    self.yang_name = "network-lookup-rd"
                                                    self.yang_parent_name = "network-lookup-rds"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp)}
                                                    self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo)}

                                                    self.rd = YLeaf(YType.str, "rd")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.bit = YLeaf(YType.uint16, "bit")

                                                    self.flags = YLeaf(YType.uint8, "flags")

                                                    self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                                    self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                                    self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                                    self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                                    self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                                    self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                                    self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                                    self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                                    self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                                    self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                                    self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                                    self.net_flags = YLeaf(YType.uint32, "net-flags")

                                                    self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                                    self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                                    self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                                    self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                                    self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                                    self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                    self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                                    self.table_version = YLeaf(YType.uint32, "table-version")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self._children_name_map["version_age"] = "version-age"
                                                    self._children_yang_names.add("version-age")

                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self._children_name_map["version_timestamp"] = "version-timestamp"
                                                    self._children_yang_names.add("version-timestamp")

                                                    self.active_path_element = YList(self)
                                                    self.active_process_instance_path = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.local_path_element = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.local_process_instance_path = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self._segment_path = lambda: "network-lookup-rd" + "[rd='" + self.rd.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd, ['rd', 'advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'num_of_path', 'process_instance_id', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                                class ActivePathElement(Entity):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, self).__init__()

                                                        self.yang_name = "active-path-element"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "active-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "active-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ActiveProcessInstancePath(Entity):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, self).__init__()

                                                        self.yang_name = "active-process-instance-path"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "active-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "active-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPathElement(Entity):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nh_tunnel
                                                    
                                                    	NH tunnel information
                                                    	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, self).__init__()

                                                        self.yang_name = "local-path-element"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop)}
                                                        self._child_list_classes = {}

                                                        self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                        self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                        self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                        self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                        self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                        self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                        self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                        self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                        self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                        self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                        self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                        self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel()
                                                        self.nh_tunnel.parent = self
                                                        self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                        self._children_yang_names.add("nh-tunnel")

                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                        self._children_yang_names.add("pelem-path-neighbor-addr")

                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                        self._children_yang_names.add("pelem-path-nexthop")
                                                        self._segment_path = lambda: "local-path-element"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                                    class NhTunnel(Entity):
                                                        """
                                                        NH tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last tunnel update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	Tunnel name attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	Nexthop Tunnel Type
                                                        	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, self).__init__()

                                                            self.yang_name = "nh-tunnel"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                            self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                            self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                            self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                            self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                            self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                            self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                            self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                            self._segment_path = lambda: "nh-tunnel"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                    class PelemPathNeighborAddr(Entity):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                            self.yang_name = "pelem-path-neighbor-addr"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-neighbor-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PelemPathNexthop(Entity):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, self).__init__()

                                                            self.yang_name = "pelem-path-nexthop"
                                                            self.yang_parent_name = "local-path-element"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "pelem-path-nexthop"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "pelem-path-nexthop"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class LocalProcessInstancePath(Entity):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, self).__init__()

                                                        self.yang_name = "local-process-instance-path"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation)}
                                                        self._child_list_classes = {}

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                        self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                        self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                        self.no_path = YLeaf(YType.boolean, "no-path")

                                                        self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                        self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                        self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                        self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                        self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                        self._children_yang_names.add("attributes-after-policy-in")

                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                        self._children_yang_names.add("neighbor-address-xr")

                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self._children_name_map["path_information"] = "path-information"
                                                        self._children_yang_names.add("path-information")
                                                        self._segment_path = lambda: "local-process-instance-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                                    class AttributesAfterPolicyIn(Entity):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                            self.yang_name = "attributes-after-policy-in"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                            self._child_list_classes = {}

                                                            self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                            self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                            self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                            self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                            self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                            self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                            self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                            self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                            self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                            self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                            self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                            self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                            self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                            self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                            self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                            self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                            self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                            self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                            self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                            self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                            self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                            self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                            self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self._children_name_map["attr_set"] = "attr-set"
                                                            self._children_yang_names.add("attr-set")

                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self._children_name_map["common_attributes"] = "common-attributes"
                                                            self._children_yang_names.add("common-attributes")

                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                            self._children_yang_names.add("ribrnh-ip")

                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self._children_name_map["rnh_addr"] = "rnh-addr"
                                                            self._children_yang_names.add("rnh-addr")
                                                            self._segment_path = lambda: "attributes-after-policy-in"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                        class AttrSet(Entity):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                                self.yang_name = "attr-set"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "attr-set"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "attr-set"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                        class CommonAttributes(Entity):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_large_community_present
                                                            
                                                            	Large Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: large_community
                                                            
                                                            	Large Community attribute
                                                            	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap
                                                            
                                                            	Tunnel Encapsulation attribute
                                                            	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                                self.yang_name = "common-attributes"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                                self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                                self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                                self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                                self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                                self.as_path = YLeaf(YType.str, "as-path")

                                                                self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                                self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                                self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                                self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                                self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                                self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                                self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                                self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                                self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                                self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                                self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                                self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                                self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                                self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                                self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                                self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                                self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                                self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                                self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                                self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                                self.metric = YLeaf(YType.uint32, "metric")

                                                                self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                                self.origin = YLeaf(YType.uint16, "origin")

                                                                self.originator = YLeaf(YType.str, "originator")

                                                                self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                                self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                                self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                                self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                                self.tunnel_encap.parent = self
                                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                                self._children_yang_names.add("tunnel-encap")

                                                                self.cluster = YList(self)
                                                                self.community = YList(self)
                                                                self.connector_value = YList(self)
                                                                self.extended_community = YList(self)
                                                                self.l2tpv3_cookie = YList(self)
                                                                self.label_index_attr = YList(self)
                                                                self.large_community = YList(self)
                                                                self.ls_attr = YList(self)
                                                                self.pe_distinguisher_label = YList(self)
                                                                self.pmsi_value = YList(self)
                                                                self.unknown_attribute = YList(self)
                                                                self._segment_path = lambda: "common-attributes"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                            class Cluster(Entity):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                                    self.yang_name = "cluster"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "cluster"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                            class Community(Entity):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                                    self.yang_name = "community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                                    self._segment_path = lambda: "community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                            class ConnectorValue(Entity):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                                    self.yang_name = "connector-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "connector-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                            class ExtendedCommunity(Entity):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                                    self.yang_name = "extended-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "extended-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                            class L2Tpv3Cookie(Entity):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                                    self.yang_name = "l2tpv3-cookie"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "l2tpv3-cookie"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                            class LabelIndexAttr(Entity):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                                    self.yang_name = "label-index-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "label-index-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                            class LargeCommunity(Entity):
                                                                """
                                                                Large Community attribute
                                                                
                                                                .. attribute:: global_admin
                                                                
                                                                	Global Administrator
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data1
                                                                
                                                                	Local Data 1
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: local_data2
                                                                
                                                                	Local Data 2
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                                    self.yang_name = "large-community"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                                    self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                                    self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                                    self._segment_path = lambda: "large-community"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                            class LsAttr(Entity):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                                    self.yang_name = "ls-attr"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "ls-attr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                            class PeDistinguisherLabel(Entity):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                                    self.yang_name = "pe-distinguisher-label"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.pe_address = YLeaf(YType.str, "pe-address")
                                                                    self._segment_path = lambda: "pe-distinguisher-label"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                            class PmsiValue(Entity):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                                    self.yang_name = "pmsi-value"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "pmsi-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                            class TunnelEncap(Entity):
                                                                """
                                                                Tunnel Encapsulation attribute
                                                                
                                                                .. attribute:: sr_policy
                                                                
                                                                	Tunnel encap type SR policy
                                                                	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                                    self.yang_name = "tunnel-encap"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                                    self._child_list_classes = {}

                                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                                    self.sr_policy.parent = self
                                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                                    self._children_yang_names.add("sr-policy")
                                                                    self._segment_path = lambda: "tunnel-encap"


                                                                class SrPolicy(Entity):
                                                                    """
                                                                    Tunnel encap type SR policy
                                                                    
                                                                    .. attribute:: allocated_binding_sid
                                                                    
                                                                    	SR Policy allocated Binding sid by the router
                                                                    	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                                    
                                                                    .. attribute:: binding_sid
                                                                    
                                                                    	SR Policy incoming Binding sid
                                                                    	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                                    
                                                                    .. attribute:: preference
                                                                    
                                                                    	SR Policy Preference
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: request_state
                                                                    
                                                                    	SR Policy programming Status
                                                                    	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                                    
                                                                    .. attribute:: segment_list
                                                                    
                                                                    	SR Policy Segment Lists
                                                                    	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	SR Policy active state in forwarding
                                                                    	**type**\:  bool
                                                                    
                                                                    .. attribute:: tunnel_encap_type
                                                                    
                                                                    	Tunnel Encapsulation Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                        self.yang_name = "sr-policy"
                                                                        self.yang_parent_name = "tunnel-encap"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                        self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                        self.preference = YLeaf(YType.uint32, "preference")

                                                                        self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                        self.state = YLeaf(YType.boolean, "state")

                                                                        self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                        self.allocated_binding_sid.parent = self
                                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                        self._children_yang_names.add("allocated-binding-sid")

                                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                        self.binding_sid.parent = self
                                                                        self._children_name_map["binding_sid"] = "binding-sid"
                                                                        self._children_yang_names.add("binding-sid")

                                                                        self.segment_list = YList(self)
                                                                        self._segment_path = lambda: "sr-policy"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                                    class AllocatedBindingSid(Entity):
                                                                        """
                                                                        SR Policy allocated Binding sid by the router
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                            self.yang_name = "allocated-binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "allocated-binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class BindingSid(Entity):
                                                                        """
                                                                        SR Policy incoming Binding sid
                                                                        
                                                                        .. attribute:: ipv6_address
                                                                        
                                                                        	IPv6 Addr
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                        
                                                                        .. attribute:: label
                                                                        
                                                                        	MPLS Label
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	Type
                                                                        	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                            self.yang_name = "binding-sid"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                            self.label = YLeaf(YType.uint32, "label")

                                                                            self.type = YLeaf(YType.enumeration, "type")
                                                                            self._segment_path = lambda: "binding-sid"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                                    class SegmentList(Entity):
                                                                        """
                                                                        SR Policy Segment Lists
                                                                        
                                                                        .. attribute:: segment
                                                                        
                                                                        	Segments in segment list
                                                                        	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                        
                                                                        .. attribute:: weight
                                                                        
                                                                        	Weight of segment list
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-bgp-oper'
                                                                        _revision = '2017-06-26'

                                                                        def __init__(self):
                                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                            self.yang_name = "segment-list"
                                                                            self.yang_parent_name = "sr-policy"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                            self.weight = YLeaf(YType.uint8, "weight")

                                                                            self.segment = YList(self)
                                                                            self._segment_path = lambda: "segment-list"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                        class Segment(Entity):
                                                                            """
                                                                            Segments in segment list
                                                                            
                                                                            .. attribute:: ipv4_address
                                                                            
                                                                            	IPv4 Address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: ipv6_address
                                                                            
                                                                            	IPv6 address value
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	MPLS Label value
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	Type
                                                                            	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-bgp-oper'
                                                                            _revision = '2017-06-26'

                                                                            def __init__(self):
                                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                                self.yang_name = "segment"
                                                                                self.yang_parent_name = "segment-list"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                                self.label = YLeaf(YType.uint32, "label")

                                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                                self._segment_path = lambda: "segment"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                            class UnknownAttribute(Entity):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                                    self.yang_name = "unknown-attribute"
                                                                    self.yang_parent_name = "common-attributes"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                                    self._segment_path = lambda: "unknown-attribute"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                        class RibrnhIp(Entity):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                                self.yang_name = "ribrnh-ip"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "ribrnh-ip"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "ribrnh-ip"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RnhAddr(Entity):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                                self.yang_name = "rnh-addr"
                                                                self.yang_parent_name = "attributes-after-policy-in"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")

                                                                self.mac_address = YLeaf(YType.str, "mac-address")
                                                                self._segment_path = lambda: "rnh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                                    class NeighborAddressXr(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                            self.yang_name = "neighbor-address-xr"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address-xr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address-xr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class PathInformation(Entity):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: af_name
                                                        
                                                        	Original Source Address family identifier
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_nh_addr
                                                        
                                                        	Path has next\-hop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_vpn_nexthop_addr
                                                        
                                                        	Path has VPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_orig_src_rd_present
                                                        
                                                        	Original Source RD  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebgps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nh_addr
                                                        
                                                        	Path next\-hop Address
                                                        	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                        
                                                        .. attribute:: nh_tunnel
                                                        
                                                        	NH tunnel information
                                                        	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label stack
                                                        	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                        
                                                        .. attribute:: rcvd_label_count
                                                        
                                                        	Path received label count
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_distinguisher
                                                        
                                                        	Original Source Route Distinguisher
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: vpn_nexthop_addr
                                                        
                                                        	Vpn nexthop Address for the path
                                                        	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                        
                                                        .. attribute:: vpn_path_flags
                                                        
                                                        	Vpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, self).__init__()

                                                            self.yang_name = "path-information"
                                                            self.yang_parent_name = "local-process-instance-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                            self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                            self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                            self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                                            self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                            self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                            self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                            self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                            self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                            self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                            self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                            self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                            self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                            self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                            self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                            self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                            self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                            self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                            self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                            self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                            self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                            self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                            self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                            self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                            self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                            self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                            self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                            self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                            self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                            self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                            self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                            self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                            self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                            self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                            self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                            self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                            self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                            self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                            self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                            self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                            self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                            self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                            self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                            self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                            self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                            self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                            self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                            self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                            self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                            self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                            self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                            self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                            self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                            self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                            self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                            self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                            self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                            self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                            self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                            self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                            self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                            self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                            self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                            self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                            self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                            self.local_label = YLeaf(YType.uint32, "local-label")

                                                            self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                            self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                            self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                            self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                            self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                            self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                            self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                            self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                            self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                            self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                            self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                            self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                            self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                            self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                            self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                            self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                            self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                            self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                            self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                                            self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                            self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                            self.second_label = YLeaf(YType.uint32, "second-label")

                                                            self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                            self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                            self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                            self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                            self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                            self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                            self._children_yang_names.add("best-path-comp-winner")

                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                            self._children_yang_names.add("bgp-prefix")

                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self._children_name_map["gw_addr"] = "gw-addr"
                                                            self._children_yang_names.add("gw-addr")

                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                            self._children_yang_names.add("mdt-group-addr")

                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                            self._children_yang_names.add("mvpn-nbr-addr")

                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                            self._children_yang_names.add("mvpn-nexthop-addr")

                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                                            self._children_yang_names.add("neighbor-address")

                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self._children_name_map["next_hop"] = "next-hop"
                                                            self._children_yang_names.add("next-hop")

                                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr()
                                                            self.nh_addr.parent = self
                                                            self._children_name_map["nh_addr"] = "nh-addr"
                                                            self._children_yang_names.add("nh-addr")

                                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                            self.nh_tunnel.parent = self
                                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                            self._children_yang_names.add("nh-tunnel")

                                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                            self.vpn_nexthop_addr.parent = self
                                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                            self._children_yang_names.add("vpn-nexthop-addr")

                                                            self.add_path_orr_bitfield = YList(self)
                                                            self.best_path_orr_bitfield = YList(self)
                                                            self.extended_community = YList(self)
                                                            self.l2vpn_circuit_status_value = YList(self)
                                                            self.local_peers_advertised_to = YList(self)
                                                            self.mvpn_pmsi_value = YList(self)
                                                            self.pe_peers_advertised_to = YList(self)
                                                            self.rcvd_label = YList(self)
                                                            self._segment_path = lambda: "path-information"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                        class AddPathOrrBitfield(Entity):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                                self.yang_name = "add-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathCompWinner(Entity):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                                self.yang_name = "best-path-comp-winner"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "best-path-comp-winner"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "best-path-comp-winner"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BestPathOrrBitfield(Entity):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                                self.yang_name = "best-path-orr-bitfield"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class BgpPrefix(Entity):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                                self.yang_name = "bgp-prefix"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                                self._child_list_classes = {}

                                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self._children_name_map["prefix"] = "prefix"
                                                                self._children_yang_names.add("prefix")
                                                                self._segment_path = lambda: "bgp-prefix"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                            class Prefix(Entity):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                                    self.yang_name = "prefix"
                                                                    self.yang_parent_name = "bgp-prefix"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "prefix"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "prefix"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class ExtendedCommunity(Entity):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                                self.yang_name = "extended-community"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "extended-community"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                        class GwAddr(Entity):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                                self.yang_name = "gw-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "gw-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class L2VpnCircuitStatusValue(Entity):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                                self.yang_name = "l2vpn-circuit-status-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                        class LocalPeersAdvertisedTo(Entity):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "local-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "local-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MdtGroupAddr(Entity):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                                self.yang_name = "mdt-group-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mdt-group-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mdt-group-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNbrAddr(Entity):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                                self.yang_name = "mvpn-nbr-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nbr-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnNexthopAddr(Entity):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                                self.yang_name = "mvpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "mvpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class MvpnPmsiValue(Entity):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                                self.yang_name = "mvpn-pmsi-value"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint8, "entry")
                                                                self._segment_path = lambda: "mvpn-pmsi-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                        class NeighborAddress(Entity):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                                self.yang_name = "neighbor-address"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "neighbor-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "neighbor-address"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NextHop(Entity):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                                self.yang_name = "next-hop"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "next-hop"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "next-hop"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class NhAddr(Entity):
                                                            """
                                                            Path next\-hop Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                                self.yang_name = "nh-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.len = YLeaf(YType.enumeration, "len")
                                                                self._segment_path = lambda: "nh-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                        class NhTunnel(Entity):
                                                            """
                                                            NH tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last tunnel update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	Tunnel name attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	Nexthop Tunnel Type
                                                            	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                                self.yang_name = "nh-tunnel"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                                self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                                self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                                self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                                self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                                self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                                self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                                self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                                self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                                self._segment_path = lambda: "nh-tunnel"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                        class PePeersAdvertisedTo(Entity):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                                self.yang_name = "pe-peers-advertised-to"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                                self._child_list_classes = {}

                                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                                self._children_yang_names.add("neighbor-address")
                                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                            class NeighborAddress(Entity):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4_sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpn_vpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                                    self.yang_name = "neighbor-address"
                                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                                    self._child_list_classes = {}

                                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6_sr_policy_address.parent = self
                                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                                    self.l2vpn_vpls_address.parent = self
                                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                                    self._segment_path = lambda: "neighbor-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                                class Ipv4SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv4-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                                class Ipv6SrPolicyAddress(Entity):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                        self.yang_name = "ipv6-sr-policy-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                                class L2VpnMspwAddress(Entity):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-mspw-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                                class L2VpnVplsAddress(Entity):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                        self.yang_name = "l2vpn-vpls-address"
                                                                        self.yang_parent_name = "neighbor-address"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                        class RcvdLabel(Entity):
                                                            """
                                                            Path received label stack
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                                self.yang_name = "rcvd-label"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "rcvd-label"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                        class VpnNexthopAddr(Entity):
                                                            """
                                                            Vpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4_sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpn_vpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                                self.yang_name = "vpn-nexthop-addr"
                                                                self.yang_parent_name = "path-information"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                                self._child_list_classes = {}

                                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4_sr_policy_address.parent = self
                                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6_sr_policy_address.parent = self
                                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                                self.l2vpn_vpls_address.parent = self
                                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                                self._segment_path = lambda: "vpn-nexthop-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                            class Ipv4SrPolicyAddress(Entity):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv4-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                            class Ipv6SrPolicyAddress(Entity):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                                    self.yang_name = "ipv6-sr-policy-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                            class L2VpnMspwAddress(Entity):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-mspw-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                            class L2VpnVplsAddress(Entity):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                                    self.yang_name = "l2vpn-vpls-address"
                                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class VersionAge(Entity):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, self).__init__()

                                                        self.yang_name = "version-age"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-age"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                                class VersionTimestamp(Entity):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, self).__init__()

                                                        self.yang_name = "version-timestamp"
                                                        self.yang_parent_name = "network-lookup-rd"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                                        self._segment_path = lambda: "version-timestamp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NetworkPrefixes(Entity):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix
                                    
                                    	A BGP Network Lookup prefix entry
                                    	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes, self).__init__()

                                        self.yang_name = "network-prefixes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network-prefix" : ("network_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix)}

                                        self.network_prefix = YList(self)
                                        self._segment_path = lambda: "network-prefixes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes, [], name, value)


                                    class NetworkPrefix(Entity):
                                        """
                                        A BGP Network Lookup prefix entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network_prefix
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix, self).__init__()

                                            self.yang_name = "network-prefix"
                                            self.yang_parent_name = "network-prefixes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp)}
                                            self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo)}

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bit = YLeaf(YType.uint16, "bit")

                                            self.flags = YLeaf(YType.uint8, "flags")

                                            self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                            self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                            self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                            self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                            self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                            self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                            self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                            self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                            self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                            self.net_flags = YLeaf(YType.uint32, "net-flags")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                            self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                            self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                            self.network_prefix = YLeaf(YType.str, "network-prefix")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.active_path_element = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.local_path_element = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self._segment_path = lambda: "network-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network_prefix', 'num_of_path', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "active-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "active-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "local-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "local-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Networks(Entity):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks, self).__init__()

                                        self.yang_name = "networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"network" : ("network", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network)}

                                        self.network = YList(self)
                                        self._segment_path = lambda: "networks"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks, [], name, value)


                                    class Network(Entity):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix), "version-age" : ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge), "version-timestamp" : ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp)}
                                            self._child_list_classes = {"active-path-element" : ("active_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement), "active-process-instance-path" : ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath), "add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield), "local-path-element" : ("local_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo), "local-process-instance-path" : ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)}

                                            self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.bit = YLeaf(YType.uint16, "bit")

                                            self.flags = YLeaf(YType.uint8, "flags")

                                            self.gateway_array = YLeaf(YType.uint32, "gateway-array")

                                            self.has_inconsistent_paths = YLeaf(YType.boolean, "has-inconsistent-paths")

                                            self.has_lbl_retained = YLeaf(YType.boolean, "has-lbl-retained")

                                            self.has_local_label = YLeaf(YType.boolean, "has-local-label")

                                            self.is_net_aggregation_suppressed = YLeaf(YType.boolean, "is-net-aggregation-suppressed")

                                            self.is_net_ldp_signaled = YLeaf(YType.boolean, "is-net-ldp-signaled")

                                            self.is_permanent_network = YLeaf(YType.boolean, "is-permanent-network")

                                            self.net_backup_available = YLeaf(YType.boolean, "net-backup-available")

                                            self.net_backup_label_rewrite_available = YLeaf(YType.boolean, "net-backup-label-rewrite-available")

                                            self.net_eibgp_multipath = YLeaf(YType.boolean, "net-eibgp-multipath")

                                            self.net_extended_flags = YLeaf(YType.uint32, "net-extended-flags")

                                            self.net_flags = YLeaf(YType.uint32, "net-flags")

                                            self.net_local_label = YLeaf(YType.uint32, "net-local-label")

                                            self.net_local_label_rewrite = YLeaf(YType.boolean, "net-local-label-rewrite")

                                            self.net_local_label_srgb = YLeaf(YType.boolean, "net-local-label-srgb")

                                            self.net_multipath = YLeaf(YType.boolean, "net-multipath")

                                            self.network = YLeaf(YType.str, "network")

                                            self.num_of_path = YLeaf(YType.uint32, "num-of-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.resilient_nexthop_set = YLeaf(YType.uint32, "resilient-nexthop-set")

                                            self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.table_brib_version = YLeaf(YType.uint32, "table-brib-version")

                                            self.table_version = YLeaf(YType.uint32, "table-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                            self._children_yang_names.add("bgp-prefix")

                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"
                                            self._children_yang_names.add("version-age")

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"
                                            self._children_yang_names.add("version-timestamp")

                                            self.active_path_element = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.local_path_element = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self._segment_path = lambda: "network"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network, ['advertisedto_pe', 'af_name', 'bit', 'flags', 'gateway_array', 'has_inconsistent_paths', 'has_lbl_retained', 'has_local_label', 'is_net_aggregation_suppressed', 'is_net_ldp_signaled', 'is_permanent_network', 'net_backup_available', 'net_backup_label_rewrite_available', 'net_eibgp_multipath', 'net_extended_flags', 'net_flags', 'net_local_label', 'net_local_label_rewrite', 'net_local_label_srgb', 'net_multipath', 'network', 'num_of_path', 'prefix_length', 'process_instance_id', 'rd', 'resilient_nexthop_set', 'rib_failed', 'route_distinguisher', 'table_brib_version', 'table_version', 'version', 'vrf_name'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "active-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "active-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "add-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "best-path-orr-bitfield"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bgp-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel), "pelem-path-neighbor-addr" : ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr), "pelem-path-nexthop" : ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)}
                                                self._child_list_classes = {}

                                                self.is_perm_path_pelem = YLeaf(YType.boolean, "is-perm-path-pelem")

                                                self.pelem_flags = YLeaf(YType.uint32, "pelem-flags")

                                                self.pelem_gw_metric = YLeaf(YType.uint32, "pelem-gw-metric")

                                                self.pelem_no_addpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-addpath-table-attr-version")

                                                self.pelem_no_bestpath_table_attr_version = YLeaf(YType.uint32, "pelem-no-bestpath-table-attr-version")

                                                self.pelem_path_flags = YLeaf(YType.uint64, "pelem-path-flags")

                                                self.pelem_path_id = YLeaf(YType.uint32, "pelem-path-id")

                                                self.pelem_path_peer_path_id = YLeaf(YType.uint32, "pelem-path-peer-path-id")

                                                self.pelem_path_table_attr_version = YLeaf(YType.uint32, "pelem-path-table-attr-version")

                                                self.pelem_table_attr_version = YLeaf(YType.uint32, "pelem-table-attr-version")

                                                self.pelem_version = YLeaf(YType.uint32, "pelem-version")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._children_yang_names.add("pelem-path-neighbor-addr")

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"
                                                self._children_yang_names.add("pelem-path-nexthop")
                                                self._segment_path = lambda: "local-path-element"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, ['is_perm_path_pelem', 'pelem_flags', 'pelem_gw_metric', 'pelem_no_addpath_table_attr_version', 'pelem_no_bestpath_table_attr_version', 'pelem_path_flags', 'pelem_path_id', 'pelem_path_peer_path_id', 'pelem_path_table_attr_version', 'pelem_table_attr_version', 'pelem_version'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "pelem-path-nexthop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "local-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.label_fail = YLeaf(YType.boolean, "label-fail")

                                                self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                                self.label_oor = YLeaf(YType.boolean, "label-oor")

                                                self.no_path = YLeaf(YType.boolean, "no-path")

                                                self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                                self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                                self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                                self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._children_yang_names.add("attributes-after-policy-in")

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                                self._children_yang_names.add("neighbor-address-xr")

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"
                                                self._children_yang_names.add("path-information")
                                                self._segment_path = lambda: "local-process-instance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'no_path', 'prefix_version', 'process_instance_id', 'route_distinguisher', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)}
                                                    self._child_list_classes = {}

                                                    self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                    self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                    self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                    self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                    self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                    self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                    self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                    self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                    self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                    self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                    self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                    self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                    self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                    self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                    self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                    self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                    self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                    self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                    self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                    self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                    self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                    self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                    self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"
                                                    self._children_yang_names.add("attr-set")

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"
                                                    self._children_yang_names.add("common-attributes")

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._children_yang_names.add("ribrnh-ip")

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"
                                                    self._children_yang_names.add("rnh-addr")
                                                    self._segment_path = lambda: "attributes-after-policy-in"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "attr-set"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                        self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                        self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                        self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                        self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                        self.as_path = YLeaf(YType.str, "as-path")

                                                        self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                        self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                        self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                        self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                        self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                        self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                        self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                        self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                        self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                        self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                        self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                        self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                        self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                        self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                        self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                        self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                        self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                        self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                        self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                        self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                        self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                        self.origin = YLeaf(YType.uint16, "origin")

                                                        self.originator = YLeaf(YType.str, "originator")

                                                        self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                        self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                        self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                        self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                        self._children_yang_names.add("tunnel-encap")

                                                        self.cluster = YList(self)
                                                        self.community = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.label_index_attr = YList(self)
                                                        self.large_community = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self._segment_path = lambda: "common-attributes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "cluster"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "connector-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "extended-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                    class L2Tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "l2tpv3-cookie"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                    class LabelIndexAttr(Entity):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                            self.yang_name = "label-index-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "label-index-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                            self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                            self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                            self._segment_path = lambda: "large-community"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "ls-attr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.label = YLeaf(YType.uint32, "label")

                                                            self.pe_address = YLeaf(YType.str, "pe-address")
                                                            self._segment_path = lambda: "pe-distinguisher-label"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "pmsi-value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                            self._child_list_classes = {}

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._children_yang_names.add("sr-policy")
                                                            self._segment_path = lambda: "tunnel-encap"


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                                self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                                self.preference = YLeaf(YType.uint32, "preference")

                                                                self.request_state = YLeaf(YType.enumeration, "request-state")

                                                                self.state = YLeaf(YType.boolean, "state")

                                                                self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                                self._children_yang_names.add("allocated-binding-sid")

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"
                                                                self._children_yang_names.add("binding-sid")

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "allocated-binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "binding-sid"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                    self.weight = YLeaf(YType.uint8, "weight")

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-06-26'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                        self.label = YLeaf(YType.uint32, "label")

                                                                        self.type = YLeaf(YType.enumeration, "type")
                                                                        self._segment_path = lambda: "segment"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint8, "entry")
                                                            self._segment_path = lambda: "unknown-attribute"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "ribrnh-ip"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")

                                                        self.mac_address = YLeaf(YType.str, "mac-address")
                                                        self._segment_path = lambda: "rnh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address-xr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:  str
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: rcvd_label_count
                                                
                                                	Path received label count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_path_flags
                                                
                                                	Vpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)}
                                                    self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)}

                                                    self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                    self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                    self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                    self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                    self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                    self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                    self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                    self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                    self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                    self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                    self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                    self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                    self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                    self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                    self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                    self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                    self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                    self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                    self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                    self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                    self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                    self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                    self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                    self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                    self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                    self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                    self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                    self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                    self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                    self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                    self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                    self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                    self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                    self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                    self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                    self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                    self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                    self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                    self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                    self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                    self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                    self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                    self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                    self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                    self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                    self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                    self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                    self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                    self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                    self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                    self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                    self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                    self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                    self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                    self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                    self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                    self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                    self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                    self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                    self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                    self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                    self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                    self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                    self.local_label = YLeaf(YType.uint32, "local-label")

                                                    self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                    self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                    self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                    self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                    self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                    self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                    self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                    self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                    self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                    self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                    self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                    self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                    self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                    self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                    self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                    self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                    self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                    self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                    self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                    self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                                    self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                    self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                    self.second_label = YLeaf(YType.uint32, "second-label")

                                                    self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                    self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                    self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                    self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                    self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                    self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                    self._children_yang_names.add("best-path-comp-winner")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"
                                                    self._children_yang_names.add("gw-addr")

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                    self._children_yang_names.add("mdt-group-addr")

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                    self._children_yang_names.add("mvpn-nbr-addr")

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                    self._children_yang_names.add("mvpn-nexthop-addr")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"
                                                    self._children_yang_names.add("next-hop")

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"
                                                    self._children_yang_names.add("nh-addr")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                    self._children_yang_names.add("vpn-nexthop-addr")

                                                    self.add_path_orr_bitfield = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.rcvd_label = YList(self)
                                                    self._segment_path = lambda: "path-information"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "add-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "best-path-comp-winner"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "best-path-orr-bitfield"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "gw-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class L2VpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "local-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mdt-group-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nbr-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "mvpn-pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "next-hop"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.len = YLeaf(YType.enumeration, "len")
                                                        self._segment_path = lambda: "nh-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                        self._child_list_classes = {}

                                                        self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._children_yang_names.add("neighbor-address")
                                                        self._segment_path = lambda: "pe-peers-advertised-to"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "neighbor-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "rcvd-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, ['entry'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "vpn-nexthop-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress)}
                                                self._child_list_classes = {}

                                                self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")
                                                self._segment_path = lambda: "pe-peers-advertised-to"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-age"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, ['nanoseconds', 'seconds'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "version-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class NextHopAddressFamilies(Entity):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                        self.yang_name = "next-hop-address-families"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"next-hop-address-family" : ("next_hop_address_family", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily)}

                                        self.next_hop_address_family = YList(self)
                                        self._segment_path = lambda: "next-hop-address-families"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                    class NextHopAddressFamily(Entity):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  <key>
                                        
                                        	Address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                            self.yang_name = "next-hop-address-family"
                                            self.yang_parent_name = "next-hop-address-families"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-af-vrf-af" : ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf), "next-hop-afs" : ("next_hop_afs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs)}
                                            self._child_list_classes = {}

                                            self.next_hop_af_name = YLeaf(YType.enumeration, "next-hop-af-name")

                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"
                                            self._children_yang_names.add("next-hop-af-vrf-af")

                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self
                                            self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                            self._children_yang_names.add("next-hop-afs")
                                            self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + self.next_hop_af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                        class NextHopAfVrfAf(Entity):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                                self.yang_name = "next-hop-af-vrf-af"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics)}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.critical_trigger_delay = YLeaf(YType.uint32, "critical-trigger-delay")

                                                self.epe_downloaded_version = YLeaf(YType.uint32, "epe-downloaded-version")

                                                self.epe_label_version = YLeaf(YType.uint32, "epe-label-version")

                                                self.epe_standby_version = YLeaf(YType.uint32, "epe-standby-version")

                                                self.epe_table_version = YLeaf(YType.uint32, "epe-table-version")

                                                self.gwaf_name = YLeaf(YType.enumeration, "gwaf-name")

                                                self.nh_nexthop_version = YLeaf(YType.uint32, "nh-nexthop-version")

                                                self.nh_rib_up = YLeaf(YType.boolean, "nh-rib-up")

                                                self.nh_rib_version = YLeaf(YType.uint32, "nh-rib-version")

                                                self.nh_table_id = YLeaf(YType.uint32, "nh-table-id")

                                                self.non_critical_trigger_delay = YLeaf(YType.uint32, "non-critical-trigger-delay")

                                                self.table_active = YLeaf(YType.boolean, "table-active")

                                                self.total_nexthops = YLeaf(YType.uint32, "total-nexthops")

                                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                                self._children_yang_names.add("performance-statistics")
                                                self._segment_path = lambda: "next-hop-af-vrf-af"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, ['af_name', 'critical_trigger_delay', 'epe_downloaded_version', 'epe_label_version', 'epe_standby_version', 'epe_table_version', 'gwaf_name', 'nh_nexthop_version', 'nh_rib_up', 'nh_rib_version', 'nh_table_id', 'non_critical_trigger_delay', 'table_active', 'total_nexthops'], name, value)


                                            class PerformanceStatistics(Entity):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                    self.yang_name = "performance-statistics"
                                                    self.yang_parent_name = "next-hop-af-vrf-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.critical_notf_count = YLeaf(YType.uint32, "critical-notf-count")

                                                    self.last_notf_bestpath_changes = YLeaf(YType.uint32, "last-notf-bestpath-changes")

                                                    self.last_notf_bestpath_deletes = YLeaf(YType.uint32, "last-notf-bestpath-deletes")

                                                    self.nexthops_removed_from_rib = YLeaf(YType.uint32, "nexthops-removed-from-rib")

                                                    self.nexthops_resent_to_rib = YLeaf(YType.uint32, "nexthops-resent-to-rib")

                                                    self.nexthops_sent_to_rib = YLeaf(YType.uint32, "nexthops-sent-to-rib")

                                                    self.nh_batch_finish_calls = YLeaf(YType.uint32, "nh-batch-finish-calls")

                                                    self.nh_flush_timer_calls = YLeaf(YType.uint32, "nh-flush-timer-calls")

                                                    self.nh_last_a_sync_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-reg-ts")

                                                    self.nh_last_a_sync_un_reg_ts = YLeaf(YType.uint32, "nh-last-a-sync-un-reg-ts")

                                                    self.nh_last_batch_finish_ts = YLeaf(YType.uint32, "nh-last-batch-finish-ts")

                                                    self.nh_last_flush_timer_ts = YLeaf(YType.uint32, "nh-last-flush-timer-ts")

                                                    self.nh_last_sync_reg_ts = YLeaf(YType.uint32, "nh-last-sync-reg-ts")

                                                    self.nh_peak_registrations = YLeaf(YType.uint32, "nh-peak-registrations")

                                                    self.nh_pending_registrations = YLeaf(YType.uint32, "nh-pending-registrations")

                                                    self.nh_sync_reg_calls = YLeaf(YType.uint32, "nh-sync-reg-calls")

                                                    self.nha_sync_reg_calls = YLeaf(YType.uint32, "nha-sync-reg-calls")

                                                    self.nha_sync_un_reg_calls = YLeaf(YType.uint32, "nha-sync-un-reg-calls")

                                                    self.nhrib_update_calls = YLeaf(YType.uint32, "nhrib-update-calls")

                                                    self.nhrib_update_time = YLeaf(YType.uint32, "nhrib-update-time")

                                                    self.noncritical_notf_count = YLeaf(YType.uint32, "noncritical-notf-count")

                                                    self.rib_sync_registers_failed = YLeaf(YType.uint32, "rib-sync-registers-failed")

                                                    self.riba_sync_registers_failed = YLeaf(YType.uint32, "riba-sync-registers-failed")

                                                    self.ribnh_reg_failed_for_no_rib_conn = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-rib-conn")

                                                    self.ribnh_reg_failed_for_no_tbl_id = YLeaf(YType.uint32, "ribnh-reg-failed-for-no-tbl-id")

                                                    self.tunnel_walk_backup_creates = YLeaf(YType.uint32, "tunnel-walk-backup-creates")

                                                    self.tunnel_walk_gw_not_found = YLeaf(YType.uint32, "tunnel-walk-gw-not-found")

                                                    self.tunnel_walk_nh_not_found = YLeaf(YType.uint32, "tunnel-walk-nh-not-found")
                                                    self._segment_path = lambda: "performance-statistics"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, ['critical_notf_count', 'last_notf_bestpath_changes', 'last_notf_bestpath_deletes', 'nexthops_removed_from_rib', 'nexthops_resent_to_rib', 'nexthops_sent_to_rib', 'nh_batch_finish_calls', 'nh_flush_timer_calls', 'nh_last_a_sync_reg_ts', 'nh_last_a_sync_un_reg_ts', 'nh_last_batch_finish_ts', 'nh_last_flush_timer_ts', 'nh_last_sync_reg_ts', 'nh_peak_registrations', 'nh_pending_registrations', 'nh_sync_reg_calls', 'nha_sync_reg_calls', 'nha_sync_un_reg_calls', 'nhrib_update_calls', 'nhrib_update_time', 'noncritical_notf_count', 'rib_sync_registers_failed', 'riba_sync_registers_failed', 'ribnh_reg_failed_for_no_rib_conn', 'ribnh_reg_failed_for_no_tbl_id', 'tunnel_walk_backup_creates', 'tunnel_walk_gw_not_found', 'tunnel_walk_nh_not_found'], name, value)


                                        class NextHopAfs(Entity):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                                self.yang_name = "next-hop-afs"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"next-hop-af" : ("next_hop_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf)}

                                                self.next_hop_af = YList(self)
                                                self._segment_path = lambda: "next-hop-afs"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                            class NextHopAf(Entity):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                    self.yang_name = "next-hop-af"
                                                    self.yang_parent_name = "next-hop-afs"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress), "nexthop-internal-info" : ("nexthop_internal_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)}
                                                    self._child_list_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress), "nexthop-gateway-info" : ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)}

                                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                                    self.attribute_set = YLeaf(YType.str, "attribute-set")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.nexthop_aigp_metric = YLeaf(YType.uint32, "nexthop-aigp-metric")

                                                    self.nexthop_gateway_prefix_connected = YLeaf(YType.boolean, "nexthop-gateway-prefix-connected")

                                                    self.nexthop_gateway_prefix_length = YLeaf(YType.uint32, "nexthop-gateway-prefix-length")

                                                    self.nexthop_gateway_reachable = YLeaf(YType.boolean, "nexthop-gateway-reachable")

                                                    self.nexthop_pending_registration = YLeaf(YType.uint8, "nexthop-pending-registration")

                                                    self.nexthop_reference_count = YLeaf(YType.uint32, "nexthop-reference-count")

                                                    self.nh_first_hop_if_handle = YLeaf(YType.str, "nh-first-hop-if-handle")

                                                    self.nh_reference_count_total = YLeaf(YType.uint32, "nh-reference-count-total")

                                                    self.rib_nexthop_id = YLeaf(YType.uint32, "rib-nexthop-id")

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"
                                                    self._children_yang_names.add("nexthop-address")

                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"
                                                    self._children_yang_names.add("nexthop-internal-info")

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                    self._children_yang_names.add("nh-tunnel")

                                                    self.neighbor_address = YList(self)
                                                    self.nexthop_gateway_info = YList(self)
                                                    self._segment_path = lambda: "next-hop-af"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['af_name', 'attribute_set', 'next_hop_address', 'nexthop_aigp_metric', 'nexthop_gateway_prefix_connected', 'nexthop_gateway_prefix_length', 'nexthop_gateway_reachable', 'nexthop_pending_registration', 'nexthop_reference_count', 'nh_first_hop_if_handle', 'nh_reference_count_total', 'rib_nexthop_id'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "nexthop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopGatewayInfo(Entity):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:   :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:   :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-route" : ("nexthop_route", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)}
                                                        self._child_list_classes = {"nexthop-route-path" : ("nexthop_route_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath)}

                                                        self.critical_events = YLeaf(YType.uint32, "critical-events")

                                                        self.last_event_since = YLeaf(YType.uint32, "last-event-since")

                                                        self.last_event_type = YLeaf(YType.enumeration, "last-event-type")

                                                        self.last_rib_update = YLeaf(YType.uint32, "last-rib-update")

                                                        self.last_update_type = YLeaf(YType.enumeration, "last-update-type")

                                                        self.nexthop_af_invalid_bits = YLeaf(YType.uint16, "nexthop-af-invalid-bits")

                                                        self.nexthop_metric = YLeaf(YType.uint32, "nexthop-metric")

                                                        self.nexthop_mpls_enabled = YLeaf(YType.boolean, "nexthop-mpls-enabled")

                                                        self.nexthop_mpls_interfaces = YLeaf(YType.uint32, "nexthop-mpls-interfaces")

                                                        self.nexthop_mpls_label = YLeaf(YType.uint32, "nexthop-mpls-label")

                                                        self.nexthop_route_path_count = YLeaf(YType.uint32, "nexthop-route-path-count")

                                                        self.nexthop_route_prefix_length = YLeaf(YType.uint8, "nexthop-route-prefix-length")

                                                        self.nexthop_route_protocol = YLeaf(YType.str, "nexthop-route-protocol")

                                                        self.nexthop_status = YLeaf(YType.uint8, "nexthop-status")

                                                        self.nexthop_tableid = YLeaf(YType.uint64, "nexthop-tableid")

                                                        self.non_critical_events = YLeaf(YType.uint32, "non-critical-events")

                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self._children_name_map["nexthop_route"] = "nexthop-route"
                                                        self._children_yang_names.add("nexthop-route")

                                                        self.nexthop_route_path = YList(self)
                                                        self._segment_path = lambda: "nexthop-gateway-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, ['critical_events', 'last_event_since', 'last_event_type', 'last_rib_update', 'last_update_type', 'nexthop_af_invalid_bits', 'nexthop_metric', 'nexthop_mpls_enabled', 'nexthop_mpls_interfaces', 'nexthop_mpls_label', 'nexthop_route_path_count', 'nexthop_route_prefix_length', 'nexthop_route_protocol', 'nexthop_status', 'nexthop_tableid', 'non_critical_events'], name, value)


                                                    class NexthopRoute(Entity):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                            self.yang_name = "nexthop-route"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NexthopRoutePath(Entity):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                            self.yang_name = "nexthop-route-path"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-route-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                class NexthopInternalInfo(Entity):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-internal-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"nexthop-address" : ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)}
                                                        self._child_list_classes = {"nexthop-gateway-internal-info" : ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo), "nexthop-metrice" : ("nexthop_metrice", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice), "nexthop-refcount" : ("nexthop_refcount", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)}

                                                        self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                        self.nexthop_af_user_bits = YLeaf(YType.uint32, "nexthop-af-user-bits")

                                                        self.nexthop_flags = YLeaf(YType.uint32, "nexthop-flags")

                                                        self.nexthop_id = YLeaf(YType.uint32, "nexthop-id")

                                                        self.nexthop_if_handle = YLeaf(YType.uint32, "nexthop-if-handle")

                                                        self.nexthop_label = YLeaf(YType.uint32, "nexthop-label")

                                                        self.nexthop_version = YLeaf(YType.uint32, "nexthop-version")

                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self._children_name_map["nexthop_address"] = "nexthop-address"
                                                        self._children_yang_names.add("nexthop-address")

                                                        self.nexthop_gateway_internal_info = YList(self)
                                                        self.nexthop_metrice = YList(self)
                                                        self.nexthop_refcount = YList(self)
                                                        self._segment_path = lambda: "nexthop-internal-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, ['gateway_flags', 'nexthop_af_user_bits', 'nexthop_flags', 'nexthop_id', 'nexthop_if_handle', 'nexthop_label', 'nexthop_version'], name, value)


                                                    class NexthopAddress(Entity):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                            self.yang_name = "nexthop-address"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "nexthop-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                                    class NexthopGatewayInternalInfo(Entity):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:   :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                            self.yang_name = "nexthop-gateway-internal-info"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.gateway_flags = YLeaf(YType.uint32, "gateway-flags")

                                                            self.registration_since = YLeaf(YType.uint32, "registration-since")

                                                            self.registration_type = YLeaf(YType.enumeration, "registration-type")
                                                            self._segment_path = lambda: "nexthop-gateway-internal-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, ['gateway_flags', 'registration_since', 'registration_type'], name, value)


                                                    class NexthopMetrice(Entity):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                            self.yang_name = "nexthop-metrice"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "nexthop-metrice"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, ['entry'], name, value)


                                                    class NexthopRefcount(Entity):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                            self.yang_name = "nexthop-refcount"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "nexthop-refcount"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, ['entry'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                        self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                        self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                        self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                        self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                        self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                        self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                        self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                        self._segment_path = lambda: "nh-tunnel"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                class PathLabeledTable(Entity):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable, self).__init__()

                                        self.yang_name = "path-labeled-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-labeled-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-labeled-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PathTable(Entity):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable, self).__init__()

                                        self.yang_name = "path-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PathUsedTable(Entity):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable, self).__init__()

                                        self.yang_name = "path-used-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"path" : ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path)}

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-used-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-used-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr), "path-information" : ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.label_fail = YLeaf(YType.boolean, "label-fail")

                                            self.label_o_or_version = YLeaf(YType.uint32, "label-o-or-version")

                                            self.label_oor = YLeaf(YType.boolean, "label-oor")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.path_id = YLeaf(YType.int32, "path-id")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.prefix_version = YLeaf(YType.uint32, "prefix-version")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.source_rd = YLeaf(YType.str, "source-rd")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.source_vrf_name = YLeaf(YType.str, "source-vrf-name")

                                            self.srcaf_name = YLeaf(YType.enumeration, "srcaf-name")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"
                                            self._children_yang_names.add("path-information")
                                            self._segment_path = lambda: "path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, ['af_name', 'label_fail', 'label_o_or_version', 'label_oor', 'neighbor_address', 'network', 'no_path', 'path_id', 'prefix_length', 'prefix_version', 'process_instance_id', 'rd', 'route_distinguisher', 'route_type', 'source_rd', 'source_route_distinguisher', 'source_vrf_name', 'srcaf_name', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class Policies(Entity):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies, self).__init__()

                                        self.yang_name = "policies"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"policy" : ("policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy)}

                                        self.policy = YList(self)
                                        self._segment_path = lambda: "policies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies, [], name, value)


                                    class Policy(Entity):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy, self).__init__()

                                            self.yang_name = "policy"
                                            self.yang_parent_name = "policies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"attributes-after-policy-in" : ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn), "attributes-after-policy-out" : ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut), "neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr), "path-info-after-policy-in" : ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn), "path-info-after-policy-out" : ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.network = YLeaf(YType.str, "network")

                                            self.no_path = YLeaf(YType.boolean, "no-path")

                                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                            self.rd = YLeaf(YType.str, "rd")

                                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                            self.source_route_distinguisher = YLeaf(YType.str, "source-route-distinguisher")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._children_yang_names.add("attributes-after-policy-in")

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._children_yang_names.add("attributes-after-policy-out")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"
                                            self._children_yang_names.add("path-info-after-policy-in")

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"
                                            self._children_yang_names.add("path-info-after-policy-out")
                                            self._segment_path = lambda: "policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy, ['af_name', 'neighbor_address', 'network', 'no_path', 'prefix_length', 'rd', 'route_distinguisher', 'source_route_distinguisher', 'vrf_name'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"attr-set" : ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet), "common-attributes" : ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes), "ribrnh-ip" : ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp), "rnh-addr" : ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)}
                                                self._child_list_classes = {}

                                                self.attribute_key_number = YLeaf(YType.uint32, "attribute-key-number")

                                                self.attribute_reuse_id_config = YLeaf(YType.boolean, "attribute-reuse-id-config")

                                                self.attribute_reuse_id_current = YLeaf(YType.uint32, "attribute-reuse-id-current")

                                                self.attribute_reuse_id_keys = YLeaf(YType.uint32, "attribute-reuse-id-keys")

                                                self.attribute_reuse_id_max_id = YLeaf(YType.uint32, "attribute-reuse-id-max-id")

                                                self.attribute_reuse_id_node = YLeaf(YType.uint32, "attribute-reuse-id-node")

                                                self.attribute_reuse_id_recover_sec = YLeaf(YType.uint32, "attribute-reuse-id-recover-sec")

                                                self.is_application_gateway_present = YLeaf(YType.boolean, "is-application-gateway-present")

                                                self.is_as_path2_byte = YLeaf(YType.boolean, "is-as-path2-byte")

                                                self.is_attr_set_present = YLeaf(YType.boolean, "is-attr-set-present")

                                                self.is_ribrnh_present = YLeaf(YType.boolean, "is-ribrnh-present")

                                                self.is_rnh_present = YLeaf(YType.boolean, "is-rnh-present")

                                                self.ribrnh_encap = YLeaf(YType.uint8, "ribrnh-encap")

                                                self.ribrnh_mac = YLeaf(YType.str, "ribrnh-mac")

                                                self.ribrnh_table = YLeaf(YType.uint32, "ribrnh-table")

                                                self.ribrnh_vni = YLeaf(YType.uint32, "ribrnh-vni")

                                                self.ribrnhip_table = YLeaf(YType.uint32, "ribrnhip-table")

                                                self.rnh_addr_len = YLeaf(YType.uint32, "rnh-addr-len")

                                                self.rnh_len = YLeaf(YType.uint8, "rnh-len")

                                                self.rnh_type = YLeaf(YType.uint16, "rnh-type")

                                                self.set_aigp_inbound_igp = YLeaf(YType.boolean, "set-aigp-inbound-igp")

                                                self.set_aigp_inbound_metric = YLeaf(YType.boolean, "set-aigp-inbound-metric")

                                                self.vpn_distinguisher = YLeaf(YType.uint32, "vpn-distinguisher")

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"
                                                self._children_yang_names.add("attr-set")

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"
                                                self._children_yang_names.add("common-attributes")

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._children_yang_names.add("ribrnh-ip")

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"
                                                self._children_yang_names.add("rnh-addr")
                                                self._segment_path = lambda: "attributes-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, ['attribute_key_number', 'attribute_reuse_id_config', 'attribute_reuse_id_current', 'attribute_reuse_id_keys', 'attribute_reuse_id_max_id', 'attribute_reuse_id_node', 'attribute_reuse_id_recover_sec', 'is_application_gateway_present', 'is_as_path2_byte', 'is_attr_set_present', 'is_ribrnh_present', 'is_rnh_present', 'ribrnh_encap', 'ribrnh_mac', 'ribrnh_table', 'ribrnh_vni', 'ribrnhip_table', 'rnh_addr_len', 'rnh_len', 'rnh_type', 'set_aigp_inbound_igp', 'set_aigp_inbound_metric', 'vpn_distinguisher'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "attr-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, ['entry'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of    :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:   :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tunnel-encap" : ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)}
                                                    self._child_list_classes = {"cluster" : ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster), "community" : ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community), "connector-value" : ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity), "l2tpv3-cookie" : ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie), "label-index-attr" : ("label_index_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr), "large-community" : ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity), "ls-attr" : ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr), "pe-distinguisher-label" : ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel), "pmsi-value" : ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue), "unknown-attribute" : ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)}

                                                    self.aggregator_address = YLeaf(YType.str, "aggregator-address")

                                                    self.aggregator_as = YLeaf(YType.uint32, "aggregator-as")

                                                    self.aigp_metric_value = YLeaf(YType.uint64, "aigp-metric-value")

                                                    self.as_path = YLeaf(YType.str, "as-path")

                                                    self.connector_type = YLeaf(YType.uint16, "connector-type")

                                                    self.extended_community_flags = YLeaf(YType.uint8, "extended-community-flags")

                                                    self.is_aggregator_present = YLeaf(YType.boolean, "is-aggregator-present")

                                                    self.is_aigp_present = YLeaf(YType.boolean, "is-aigp-present")

                                                    self.is_as_path_present = YLeaf(YType.boolean, "is-as-path-present")

                                                    self.is_atomic_aggregate_present = YLeaf(YType.boolean, "is-atomic-aggregate-present")

                                                    self.is_community_present = YLeaf(YType.boolean, "is-community-present")

                                                    self.is_connector_present = YLeaf(YType.boolean, "is-connector-present")

                                                    self.is_extended_community_present = YLeaf(YType.boolean, "is-extended-community-present")

                                                    self.is_label_index_present = YLeaf(YType.boolean, "is-label-index-present")

                                                    self.is_large_community_present = YLeaf(YType.boolean, "is-large-community-present")

                                                    self.is_local_pref_present = YLeaf(YType.boolean, "is-local-pref-present")

                                                    self.is_ls_attribute_present = YLeaf(YType.boolean, "is-ls-attribute-present")

                                                    self.is_metric_present = YLeaf(YType.boolean, "is-metric-present")

                                                    self.is_origin_present = YLeaf(YType.boolean, "is-origin-present")

                                                    self.is_pe_distinguisher_label_present = YLeaf(YType.boolean, "is-pe-distinguisher-label-present")

                                                    self.is_pmsi_present = YLeaf(YType.boolean, "is-pmsi-present")

                                                    self.is_pppmp_present = YLeaf(YType.boolean, "is-pppmp-present")

                                                    self.is_ssa_present = YLeaf(YType.boolean, "is-ssa-present")

                                                    self.l2tpv3_session_id = YLeaf(YType.uint32, "l2tpv3-session-id")

                                                    self.local_preference = YLeaf(YType.uint32, "local-preference")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.neighbor_as = YLeaf(YType.uint32, "neighbor-as")

                                                    self.origin = YLeaf(YType.uint16, "origin")

                                                    self.originator = YLeaf(YType.str, "originator")

                                                    self.pmsi_flags = YLeaf(YType.uint8, "pmsi-flags")

                                                    self.pmsi_label = YLeaf(YType.uint32, "pmsi-label")

                                                    self.pmsi_type = YLeaf(YType.uint16, "pmsi-type")

                                                    self.ppm_pvalue = YLeaf(YType.uint32, "ppm-pvalue")

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"
                                                    self._children_yang_names.add("tunnel-encap")

                                                    self.cluster = YList(self)
                                                    self.community = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.label_index_attr = YList(self)
                                                    self.large_community = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self._segment_path = lambda: "common-attributes"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, ['aggregator_address', 'aggregator_as', 'aigp_metric_value', 'as_path', 'connector_type', 'extended_community_flags', 'is_aggregator_present', 'is_aigp_present', 'is_as_path_present', 'is_atomic_aggregate_present', 'is_community_present', 'is_connector_present', 'is_extended_community_present', 'is_label_index_present', 'is_large_community_present', 'is_local_pref_present', 'is_ls_attribute_present', 'is_metric_present', 'is_origin_present', 'is_pe_distinguisher_label_present', 'is_pmsi_present', 'is_pppmp_present', 'is_ssa_present', 'l2tpv3_session_id', 'local_preference', 'metric', 'neighbor_as', 'origin', 'originator', 'pmsi_flags', 'pmsi_label', 'pmsi_type', 'ppm_pvalue'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "cluster"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, ['entry'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, ['entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "connector-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, ['entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, ['entry'], name, value)


                                                class L2Tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "l2tpv3-cookie"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie, ['entry'], name, value)


                                                class LabelIndexAttr(Entity):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, self).__init__()

                                                        self.yang_name = "label-index-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "label-index-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr, ['entry'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.global_admin = YLeaf(YType.uint32, "global-admin")

                                                        self.local_data1 = YLeaf(YType.uint32, "local-data1")

                                                        self.local_data2 = YLeaf(YType.uint32, "local-data2")
                                                        self._segment_path = lambda: "large-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, ['global_admin', 'local_data1', 'local_data2'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "ls-attr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, ['entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.label = YLeaf(YType.uint32, "label")

                                                        self.pe_address = YLeaf(YType.str, "pe-address")
                                                        self._segment_path = lambda: "pe-distinguisher-label"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, ['label', 'pe_address'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "pmsi-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, ['entry'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:   :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sr-policy" : ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy)}
                                                        self._child_list_classes = {}

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._children_yang_names.add("sr-policy")
                                                        self._segment_path = lambda: "tunnel-encap"


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:   :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:   :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of    :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"allocated-binding-sid" : ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid), "binding-sid" : ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)}
                                                            self._child_list_classes = {"segment-list" : ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList)}

                                                            self.preference = YLeaf(YType.uint32, "preference")

                                                            self.request_state = YLeaf(YType.enumeration, "request-state")

                                                            self.state = YLeaf(YType.boolean, "state")

                                                            self.tunnel_encap_type = YLeaf(YType.uint16, "tunnel-encap-type")

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"
                                                            self._children_yang_names.add("allocated-binding-sid")

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"
                                                            self._children_yang_names.add("binding-sid")

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, ['preference', 'request_state', 'state', 'tunnel_encap_type'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "allocated-binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                self.label = YLeaf(YType.uint32, "label")

                                                                self.type = YLeaf(YType.enumeration, "type")
                                                                self._segment_path = lambda: "binding-sid"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, ['ipv6_address', 'label', 'type'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of    :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"segment" : ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment)}

                                                                self.weight = YLeaf(YType.uint8, "weight")

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, ['weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-06-26'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                                    self.label = YLeaf(YType.uint32, "label")

                                                                    self.type = YLeaf(YType.enumeration, "type")
                                                                    self._segment_path = lambda: "segment"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, ['ipv4_address', 'ipv6_address', 'label', 'type'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "unknown-attribute"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, ['entry'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "ribrnh-ip"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")

                                                    self.mac_address = YLeaf(YType.str, "mac-address")
                                                    self._segment_path = lambda: "rnh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, ['ipv4_address', 'ipv6_address', 'len', 'mac_address'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:  str
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:   :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:   :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of    :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: rcvd_label_count
                                            
                                            	Path received label count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:   :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_path_flags
                                            
                                            	Vpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"best-path-comp-winner" : ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner), "bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix), "gw-addr" : ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr), "mdt-group-addr" : ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr), "mvpn-nbr-addr" : ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr), "mvpn-nexthop-addr" : ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress), "next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop), "nh-addr" : ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr), "nh-tunnel" : ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel), "vpn-nexthop-addr" : ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)}
                                                self._child_list_classes = {"add-path-orr-bitfield" : ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield), "best-path-orr-bitfield" : ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield), "extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity), "l2vpn-circuit-status-value" : ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue), "local-peers-advertised-to" : ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo), "mvpn-pmsi-value" : ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue), "pe-peers-advertised-to" : ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo), "rcvd-label" : ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)}

                                                self.accept_own_path = YLeaf(YType.boolean, "accept-own-path")

                                                self.accept_own_self_originated_p_ath = YLeaf(YType.boolean, "accept-own-self-originated-p-ath")

                                                self.advertisedto_pe = YLeaf(YType.boolean, "advertisedto-pe")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.aigp_metric = YLeaf(YType.uint64, "aigp-metric")

                                                self.best_path_comp_stage = YLeaf(YType.enumeration, "best-path-comp-stage")

                                                self.best_path_id = YLeaf(YType.uint32, "best-path-id")

                                                self.best_path_id_comp_winner = YLeaf(YType.uint32, "best-path-id-comp-winner")

                                                self.dampen_penalty = YLeaf(YType.uint32, "dampen-penalty")

                                                self.fspec_invalid_path = YLeaf(YType.boolean, "fspec-invalid-path")

                                                self.graceful_shutdown = YLeaf(YType.boolean, "graceful-shutdown")

                                                self.halflife_time = YLeaf(YType.uint32, "halflife-time")

                                                self.has_gw_addr = YLeaf(YType.boolean, "has-gw-addr")

                                                self.has_local_net_label = YLeaf(YType.boolean, "has-local-net-label")

                                                self.has_mdt_group_addr = YLeaf(YType.boolean, "has-mdt-group-addr")

                                                self.has_mvpn_extcomm = YLeaf(YType.boolean, "has-mvpn-extcomm")

                                                self.has_mvpn_nbr_addr = YLeaf(YType.boolean, "has-mvpn-nbr-addr")

                                                self.has_mvpn_nexthop_addr = YLeaf(YType.boolean, "has-mvpn-nexthop-addr")

                                                self.has_mvpn_pmsi = YLeaf(YType.boolean, "has-mvpn-pmsi")

                                                self.has_nh_addr = YLeaf(YType.boolean, "has-nh-addr")

                                                self.has_second_label = YLeaf(YType.boolean, "has-second-label")

                                                self.has_vpn_nexthop_addr = YLeaf(YType.boolean, "has-vpn-nexthop-addr")

                                                self.ibgp_signaled_validity = YLeaf(YType.boolean, "ibgp-signaled-validity")

                                                self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                                self.is_aggregation_suppressed = YLeaf(YType.boolean, "is-aggregation-suppressed")

                                                self.is_as_best = YLeaf(YType.boolean, "is-as-best")

                                                self.is_best_path = YLeaf(YType.boolean, "is-best-path")

                                                self.is_import_dampened = YLeaf(YType.boolean, "is-import-dampened")

                                                self.is_import_suspect = YLeaf(YType.boolean, "is-import-suspect")

                                                self.is_internal_path = YLeaf(YType.boolean, "is-internal-path")

                                                self.is_orig_src_rd_present = YLeaf(YType.boolean, "is-orig-src-rd-present")

                                                self.is_partial_best = YLeaf(YType.boolean, "is-partial-best")

                                                self.is_path_additional_path = YLeaf(YType.boolean, "is-path-additional-path")

                                                self.is_path_advertised_local_as_only = YLeaf(YType.boolean, "is-path-advertised-local-as-only")

                                                self.is_path_af_install_eligible = YLeaf(YType.boolean, "is-path-af-install-eligible")

                                                self.is_path_backup = YLeaf(YType.boolean, "is-path-backup")

                                                self.is_path_backup_protect_multipath = YLeaf(YType.boolean, "is-path-backup-protect-multipath")

                                                self.is_path_best_external = YLeaf(YType.boolean, "is-path-best-external")

                                                self.is_path_damped = YLeaf(YType.boolean, "is-path-damped")

                                                self.is_path_from_confederation_peer = YLeaf(YType.boolean, "is-path-from-confederation-peer")

                                                self.is_path_from_network_command = YLeaf(YType.boolean, "is-path-from-network-command")

                                                self.is_path_from_redistribute_command = YLeaf(YType.boolean, "is-path-from-redistribute-command")

                                                self.is_path_from_route_reflector = YLeaf(YType.boolean, "is-path-from-route-reflector")

                                                self.is_path_history_held = YLeaf(YType.boolean, "is-path-history-held")

                                                self.is_path_imp_candidate = YLeaf(YType.boolean, "is-path-imp-candidate")

                                                self.is_path_imported = YLeaf(YType.boolean, "is-path-imported")

                                                self.is_path_local_aggregate = YLeaf(YType.boolean, "is-path-local-aggregate")

                                                self.is_path_locally_sourced = YLeaf(YType.boolean, "is-path-locally-sourced")

                                                self.is_path_long_lived_stale = YLeaf(YType.boolean, "is-path-long-lived-stale")

                                                self.is_path_multipath = YLeaf(YType.boolean, "is-path-multipath")

                                                self.is_path_nexthop_discarded = YLeaf(YType.boolean, "is-path-nexthop-discarded")

                                                self.is_path_not_advertised = YLeaf(YType.boolean, "is-path-not-advertised")

                                                self.is_path_not_advertised_to_ebgps = YLeaf(YType.boolean, "is-path-not-advertised-to-ebgps")

                                                self.is_path_received_only = YLeaf(YType.boolean, "is-path-received-only")

                                                self.is_path_reoriginated = YLeaf(YType.boolean, "is-path-reoriginated")

                                                self.is_path_reoriginated_stitching = YLeaf(YType.boolean, "is-path-reoriginated-stitching")

                                                self.is_path_stale = YLeaf(YType.boolean, "is-path-stale")

                                                self.is_path_synced_with_igp = YLeaf(YType.boolean, "is-path-synced-with-igp")

                                                self.is_path_valid = YLeaf(YType.boolean, "is-path-valid")

                                                self.is_path_vpn_only = YLeaf(YType.boolean, "is-path-vpn-only")

                                                self.is_permanent_path = YLeaf(YType.boolean, "is-permanent-path")

                                                self.is_received_path_not_modified = YLeaf(YType.boolean, "is-received-path-not-modified")

                                                self.is_spkr_as_best = YLeaf(YType.boolean, "is-spkr-as-best")

                                                self.l2vpn_evpn_esi = YLeaf(YType.str, "l2vpn-evpn-esi")

                                                self.l2vpn_size = YLeaf(YType.uint32, "l2vpn-size")

                                                self.labeled_unicast_safi_path = YLeaf(YType.boolean, "labeled-unicast-safi-path")

                                                self.local_label = YLeaf(YType.uint32, "local-label")

                                                self.local_nh = YLeaf(YType.boolean, "local-nh")

                                                self.local_path_id = YLeaf(YType.uint32, "local-path-id")

                                                self.maximum_suppress_time = YLeaf(YType.uint32, "maximum-suppress-time")

                                                self.mvpn_path_flags = YLeaf(YType.uint16, "mvpn-path-flags")

                                                self.mvpn_pmsi_flags = YLeaf(YType.uint8, "mvpn-pmsi-flags")

                                                self.mvpn_pmsi_label = YLeaf(YType.uint32, "mvpn-pmsi-label")

                                                self.mvpn_pmsi_type = YLeaf(YType.uint16, "mvpn-pmsi-type")

                                                self.mvpn_sfs_path = YLeaf(YType.boolean, "mvpn-sfs-path")

                                                self.neighbor_router_id = YLeaf(YType.str, "neighbor-router-id")

                                                self.path_flags = YLeaf(YType.uint64, "path-flags")

                                                self.path_flap_count = YLeaf(YType.uint32, "path-flap-count")

                                                self.path_import_flags = YLeaf(YType.uint32, "path-import-flags")

                                                self.path_rt_set_id = YLeaf(YType.uint32, "path-rt-set-id")

                                                self.path_rt_set_route_count = YLeaf(YType.uint32, "path-rt-set-route-count")

                                                self.path_table_version = YLeaf(YType.uint32, "path-table-version")

                                                self.path_weight = YLeaf(YType.uint16, "path-weight")

                                                self.rcvd_label_count = YLeaf(YType.uint32, "rcvd-label-count")

                                                self.rcvd_path_id = YLeaf(YType.uint32, "rcvd-path-id")

                                                self.reuse_value = YLeaf(YType.uint32, "reuse-value")

                                                self.rib_failed = YLeaf(YType.boolean, "rib-failed")

                                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                                self.rpki_origin_as_validation_disabled = YLeaf(YType.boolean, "rpki-origin-as-validation-disabled")

                                                self.rt_set_limit_enabled = YLeaf(YType.boolean, "rt-set-limit-enabled")

                                                self.second_label = YLeaf(YType.uint32, "second-label")

                                                self.seconds_since_first_flap = YLeaf(YType.uint32, "seconds-since-first-flap")

                                                self.show_rpki_origin_as_validity = YLeaf(YType.boolean, "show-rpki-origin-as-validity")

                                                self.sn_rpki_origin_as_validity = YLeaf(YType.uint8, "sn-rpki-origin-as-validity")

                                                self.suppress_penalty = YLeaf(YType.uint32, "suppress-penalty")

                                                self.time_to_unsuppress = YLeaf(YType.uint32, "time-to-unsuppress")

                                                self.vpn_path_flags = YLeaf(YType.uint8, "vpn-path-flags")

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"
                                                self._children_yang_names.add("best-path-comp-winner")

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._children_yang_names.add("bgp-prefix")

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"
                                                self._children_yang_names.add("gw-addr")

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"
                                                self._children_yang_names.add("mdt-group-addr")

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"
                                                self._children_yang_names.add("mvpn-nbr-addr")

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"
                                                self._children_yang_names.add("mvpn-nexthop-addr")

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._children_yang_names.add("neighbor-address")

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"
                                                self._children_yang_names.add("next-hop")

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"
                                                self._children_yang_names.add("nh-addr")

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"
                                                self._children_yang_names.add("nh-tunnel")

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"
                                                self._children_yang_names.add("vpn-nexthop-addr")

                                                self.add_path_orr_bitfield = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.extended_community = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.rcvd_label = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, ['accept_own_path', 'accept_own_self_originated_p_ath', 'advertisedto_pe', 'af_name', 'aigp_metric', 'best_path_comp_stage', 'best_path_id', 'best_path_id_comp_winner', 'dampen_penalty', 'fspec_invalid_path', 'graceful_shutdown', 'halflife_time', 'has_gw_addr', 'has_local_net_label', 'has_mdt_group_addr', 'has_mvpn_extcomm', 'has_mvpn_nbr_addr', 'has_mvpn_nexthop_addr', 'has_mvpn_pmsi', 'has_nh_addr', 'has_second_label', 'has_vpn_nexthop_addr', 'ibgp_signaled_validity', 'igp_metric', 'is_aggregation_suppressed', 'is_as_best', 'is_best_path', 'is_import_dampened', 'is_import_suspect', 'is_internal_path', 'is_orig_src_rd_present', 'is_partial_best', 'is_path_additional_path', 'is_path_advertised_local_as_only', 'is_path_af_install_eligible', 'is_path_backup', 'is_path_backup_protect_multipath', 'is_path_best_external', 'is_path_damped', 'is_path_from_confederation_peer', 'is_path_from_network_command', 'is_path_from_redistribute_command', 'is_path_from_route_reflector', 'is_path_history_held', 'is_path_imp_candidate', 'is_path_imported', 'is_path_local_aggregate', 'is_path_locally_sourced', 'is_path_long_lived_stale', 'is_path_multipath', 'is_path_nexthop_discarded', 'is_path_not_advertised', 'is_path_not_advertised_to_ebgps', 'is_path_received_only', 'is_path_reoriginated', 'is_path_reoriginated_stitching', 'is_path_stale', 'is_path_synced_with_igp', 'is_path_valid', 'is_path_vpn_only', 'is_permanent_path', 'is_received_path_not_modified', 'is_spkr_as_best', 'l2vpn_evpn_esi', 'l2vpn_size', 'labeled_unicast_safi_path', 'local_label', 'local_nh', 'local_path_id', 'maximum_suppress_time', 'mvpn_path_flags', 'mvpn_pmsi_flags', 'mvpn_pmsi_label', 'mvpn_pmsi_type', 'mvpn_sfs_path', 'neighbor_router_id', 'path_flags', 'path_flap_count', 'path_import_flags', 'path_rt_set_id', 'path_rt_set_route_count', 'path_table_version', 'path_weight', 'rcvd_label_count', 'rcvd_path_id', 'reuse_value', 'rib_failed', 'route_distinguisher', 'route_type', 'rpki_origin_as_validation_disabled', 'rt_set_limit_enabled', 'second_label', 'seconds_since_first_flap', 'show_rpki_origin_as_validity', 'sn_rpki_origin_as_validity', 'suppress_penalty', 'time_to_unsuppress', 'vpn_path_flags'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "add-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "best-path-comp-winner"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "best-path-orr-bitfield"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix)}
                                                    self._child_list_classes = {}

                                                    self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._children_yang_names.add("prefix")
                                                    self._segment_path = lambda: "bgp-prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, ['prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "extended-community"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, ['entry'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "gw-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class L2VpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue, ['entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "local-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mdt-group-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nbr-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "mvpn-pmsi-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, ['entry'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "next-hop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.len = YLeaf(YType.enumeration, "len")
                                                    self._segment_path = lambda: "nh-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, ['ipv4_address', 'ipv6_address', 'len'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:   :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                    self.is_tunnel_info_stale = YLeaf(YType.boolean, "is-tunnel-info-stale")

                                                    self.is_tunnel_registered = YLeaf(YType.boolean, "is-tunnel-registered")

                                                    self.is_tunnel_up = YLeaf(YType.boolean, "is-tunnel-up")

                                                    self.last_tunnel_update = YLeaf(YType.uint32, "last-tunnel-update")

                                                    self.tunnel_if_handle = YLeaf(YType.uint32, "tunnel-if-handle")

                                                    self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                                                    self.tunnel_type = YLeaf(YType.enumeration, "tunnel-type")

                                                    self.tunnel_v6_enabled = YLeaf(YType.boolean, "tunnel-v6-enabled")

                                                    self.tunnel_v6_required = YLeaf(YType.boolean, "tunnel-v6-required")
                                                    self._segment_path = lambda: "nh-tunnel"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, ['binding_label', 'is_tunnel_info_stale', 'is_tunnel_registered', 'is_tunnel_up', 'last_tunnel_update', 'tunnel_if_handle', 'tunnel_name', 'tunnel_type', 'tunnel_v6_enabled', 'tunnel_v6_required'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress)}
                                                    self._child_list_classes = {}

                                                    self.is_neighbor = YLeaf(YType.boolean, "is-neighbor")

                                                    self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._children_yang_names.add("neighbor-address")
                                                    self._segment_path = lambda: "pe-peers-advertised-to"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, ['is_neighbor', 'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "rcvd-label"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, ['entry'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "vpn-nexthop-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PrefixFilters(Entity):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters, self).__init__()

                                        self.yang_name = "prefix-filters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"prefix-filter" : ("prefix_filter", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter)}

                                        self.prefix_filter = YList(self)
                                        self._segment_path = lambda: "prefix-filters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters, [], name, value)


                                    class PrefixFilter(Entity):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                            self.yang_name = "prefix-filter"
                                            self.yang_parent_name = "prefix-filters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address-xr" : ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr), "prefix-list-info" : ("prefix_list_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo)}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"
                                            self._children_yang_names.add("neighbor-address-xr")

                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self
                                            self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                            self._children_yang_names.add("prefix-list-info")
                                            self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', 'af_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address-xr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PrefixListInfo(Entity):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                                self.yang_name = "prefix-list-info"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bgp-pfxlst" : ("bgp_pfxlst", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst)}

                                                self.bgp_pfxlst = YList(self)
                                                self._segment_path = lambda: "prefix-list-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                            class BgpPfxlst(Entity):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\:  bool
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                    self.yang_name = "bgp-pfxlst"
                                                    self.yang_parent_name = "prefix-list-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bgp-prefix" : ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix)}
                                                    self._child_list_classes = {}

                                                    self.is_prefix_grant = YLeaf(YType.boolean, "is-prefix-grant")

                                                    self.max_prefix_length = YLeaf(YType.uint8, "max-prefix-length")

                                                    self.min_prefix_length = YLeaf(YType.uint8, "min-prefix-length")

                                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._children_yang_names.add("bgp-prefix")
                                                    self._segment_path = lambda: "bgp-pfxlst"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, ['is_prefix_grant', 'max_prefix_length', 'min_prefix_length', 'sequence_number'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "bgp-pfxlst"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix)}
                                                        self._child_list_classes = {}

                                                        self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._children_yang_names.add("prefix")
                                                        self._segment_path = lambda: "bgp-prefix"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, ['prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress)}
                                                            self._child_list_classes = {}

                                                            self.afi = YLeaf(YType.enumeration, "afi")

                                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                            self._children_yang_names.add("l2vpn-mspw-address")

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                            self._children_yang_names.add("l2vpn-vpls-address")
                                                            self._segment_path = lambda: "prefix"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                        class L2VpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                        class L2VpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-06-26'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RpcSets(Entity):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets, self).__init__()

                                        self.yang_name = "rpc-sets"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"rpc-set" : ("rpc_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet)}

                                        self.rpc_set = YList(self)
                                        self._segment_path = lambda: "rpc-sets"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets, [], name, value)


                                    class RpcSet(Entity):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  <key>
                                        
                                        	Nexthop set index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                            self.yang_name = "rpc-set"
                                            self.yang_parent_name = "rpc-sets"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"next-hop" : ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop)}

                                            self.rpc_set_index = YLeaf(YType.int32, "rpc-set-index")

                                            self.label = YLeaf(YType.uint32, "label")

                                            self.next_hop_xr = YLeaf(YType.uint32, "next-hop-xr")

                                            self.ref_count = YLeaf(YType.uint32, "ref-count")

                                            self.next_hop = YList(self)
                                            self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + self.rpc_set_index.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', 'label', 'next_hop_xr', 'ref_count'], name, value)


                                        class NextHop(Entity):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "rpc-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "next-hop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class RtSetCounters(Entity):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters, self).__init__()

                                        self.yang_name = "rt-set-counters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"rt-set-counter" : ("rt_set_counter", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter)}

                                        self.rt_set_counter = YList(self)
                                        self._segment_path = lambda: "rt-set-counters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters, [], name, value)


                                    class RtSetCounter(Entity):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  <key>
                                        
                                        	RTSet ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                            self.yang_name = "rt-set-counter"
                                            self.yang_parent_name = "rt-set-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-target-set" : ("route_target_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet)}
                                            self._child_list_classes = {}

                                            self.rt_set_id = YLeaf(YType.int32, "rt-set-id")

                                            self.route_target_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self
                                            self._children_name_map["route_target_set"] = "route-target-set"
                                            self._children_yang_names.add("route-target-set")
                                            self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + self.rt_set_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                        class RouteTargetSet(Entity):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                                self.yang_name = "route-target-set"
                                                self.yang_parent_name = "rt-set-counter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"rt-set" : ("rt_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet)}

                                                self.rt_set_id = YLeaf(YType.uint32, "rt-set-id")

                                                self.rt_set_len = YLeaf(YType.uint8, "rt-set-len")

                                                self.rt_set_net_count = YLeaf(YType.uint32, "rt-set-net-count")

                                                self.rt_set = YList(self)
                                                self._segment_path = lambda: "route-target-set"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, ['rt_set_id', 'rt_set_len', 'rt_set_net_count'], name, value)


                                            class RtSet(Entity):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                    self.yang_name = "rt-set"
                                                    self.yang_parent_name = "route-target-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "rt-set"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, ['entry'], name, value)


                                class SourcedNetworks(Entity):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork)}

                                        self.sourced_network = YList(self)
                                        self._segment_path = lambda: "sourced-networks"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks, [], name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  <key>
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\:  bool
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sourced-prefix" : ("sourced_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix)}
                                            self._child_list_classes = {}

                                            self.network = YLeaf(YType.str, "network")

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.is_backdoor = YLeaf(YType.boolean, "is-backdoor")

                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self
                                            self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                            self._children_yang_names.add("sourced-prefix")
                                            self._segment_path = lambda: "sourced-network" + "[network='" + self.network.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', 'af_name', 'is_backdoor'], name, value)


                                        class SourcedPrefix(Entity):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                                self.yang_name = "sourced-prefix"
                                                self.yang_parent_name = "sourced-network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "sourced-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "sourced-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class UpdateGenerationAddressFamily(Entity):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                        self.yang_name = "update-generation-address-family"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics)}
                                        self._child_list_classes = {}

                                        self.configured_update_limit_af = YLeaf(YType.uint32, "configured-update-limit-af")

                                        self.configured_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "configured-update-limit-sub-group-ibgp")

                                        self.configured_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "configured-update-limit-subgrp-ebgp")

                                        self.current_update_limit_af = YLeaf(YType.uint32, "current-update-limit-af")

                                        self.current_update_limit_sub_group_ibgp = YLeaf(YType.uint32, "current-update-limit-sub-group-ibgp")

                                        self.current_update_limit_subgrp_ebgp = YLeaf(YType.uint32, "current-update-limit-subgrp-ebgp")

                                        self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                        self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                        self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                        self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                        self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                        self.table_neighbor_count = YLeaf(YType.uint32, "table-neighbor-count")

                                        self.table_refresh_sub_group_count = YLeaf(YType.uint32, "table-refresh-sub-group-count")

                                        self.table_refresh_sub_group_throttled_count = YLeaf(YType.uint32, "table-refresh-sub-group-throttled-count")

                                        self.table_sub_group_throttled_count = YLeaf(YType.uint32, "table-sub-group-throttled-count")

                                        self.table_update_group_count = YLeaf(YType.uint32, "table-update-group-count")

                                        self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                        self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                        self.update_min_neighbor_version = YLeaf(YType.uint32, "update-min-neighbor-version")

                                        self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                        self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                        self.update_rib_version = YLeaf(YType.uint32, "update-rib-version")

                                        self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                        self.update_table_filter_group_count = YLeaf(YType.uint32, "update-table-filter-group-count")

                                        self.update_table_sub_group_count = YLeaf(YType.uint32, "update-table-sub-group-count")

                                        self.update_table_vrf_name = YLeaf(YType.str, "update-table-vrf-name")

                                        self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                        self.update_update_group_count = YLeaf(YType.uint32, "update-update-group-count")

                                        self.update_vrf_rd_version = YLeaf(YType.uint32, "update-vrf-rd-version")

                                        self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                        self.update_vrfaf_name = YLeaf(YType.uint32, "update-vrfaf-name")

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._children_yang_names.add("update-statistics")
                                        self._segment_path = lambda: "update-generation-address-family"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, ['configured_update_limit_af', 'configured_update_limit_sub_group_ibgp', 'configured_update_limit_subgrp_ebgp', 'current_update_limit_af', 'current_update_limit_sub_group_ibgp', 'current_update_limit_subgrp_ebgp', 'filter_group_count', 'neighbor_count', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'table_neighbor_count', 'table_refresh_sub_group_count', 'table_refresh_sub_group_throttled_count', 'table_sub_group_throttled_count', 'table_update_group_count', 'update_group_af_name', 'update_main_table_version', 'update_min_neighbor_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_rib_version', 'update_sub_group_count', 'update_table_filter_group_count', 'update_table_sub_group_count', 'update_table_vrf_name', 'update_throttled', 'update_update_group_count', 'update_vrf_rd_version', 'update_vrf_table_rib_version', 'update_vrfaf_name'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                            self._child_list_classes = {}

                                            self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                            self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                            self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                            self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                            self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                            self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                            self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                            self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                            self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                            self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                            self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                            self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                            self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                            self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                            self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                            self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                            self._children_yang_names.add("last-update-cleared-timestamp")

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                            self._children_yang_names.add("last-update-discard-timestamp")

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                            self._children_yang_names.add("last-update-recovery-timestamp")

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                            self._children_yang_names.add("last-update-throttle-timestamp")
                                            self._segment_path = lambda: "update-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-cleared-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-discard-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-recovery-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-throttle-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationFilterGroups(Entity):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                        self.yang_name = "update-generation-filter-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-filter-group" : ("update_generation_filter_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup)}

                                        self.update_generation_filter_group = YList(self)
                                        self._segment_path = lambda: "update-generation-filter-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                    class UpdateGenerationFilterGroup(Entity):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                            self.yang_name = "update-generation-filter-group"
                                            self.yang_parent_name = "update-generation-filter-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.parent_filter_group_index = YLeaf(YType.uint32, "parent-filter-group-index")

                                            self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                            self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")
                                            self._segment_path = lambda: "update-generation-filter-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['filter_group_index', 'neighbor_count', 'parent_filter_group_index', 'parent_sub_group_id', 'parent_sub_group_index', 'process_id', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_filter_group_index', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_vrf_name'], name, value)


                                class UpdateGenerationNeighbors(Entity):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                        self.yang_name = "update-generation-neighbors"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-neighbor" : ("update_generation_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor)}

                                        self.update_generation_neighbor = YList(self)
                                        self._segment_path = lambda: "update-generation-neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                    class UpdateGenerationNeighbor(Entity):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                            self.yang_name = "update-generation-neighbor"
                                            self.yang_parent_name = "update-generation-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-default-originate-timestamp" : ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp), "first-update-queued-timestamp" : ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp), "first-update-write-timestamp" : ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp), "last-default-originate-timestamp" : ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp), "last-filter-group-add-timestamp" : ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp), "last-filter-group-remove-timestamp" : ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp), "last-refresh-update-queued-timestamp" : ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp), "last-refresh-update-write-timestamp" : ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp), "last-sub-group-add-timestamp" : ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp), "last-sub-group-remove-timestamp" : ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp), "last-update-group-expiry-timestamp" : ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp), "last-update-group-start-timestamp" : ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp), "last-update-write-timestamp" : ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.ack_version = YLeaf(YType.uint32, "ack-version")

                                            self.current_update_group_af_name = YLeaf(YType.enumeration, "current-update-group-af-name")

                                            self.default_originate_internal_context = YLeaf(YType.int32, "default-originate-internal-context")

                                            self.default_originate_state = YLeaf(YType.int32, "default-originate-state")

                                            self.filter_group_index = YLeaf(YType.int32, "filter-group-index")

                                            self.inbound_refresh_count = YLeaf(YType.uint32, "inbound-refresh-count")

                                            self.is_eor_outstanding = YLeaf(YType.boolean, "is-eor-outstanding")

                                            self.is_update_group_timer_running = YLeaf(YType.boolean, "is-update-group-timer-running")

                                            self.last_default_originate_age = YLeaf(YType.uint32, "last-default-originate-age")

                                            self.last_refresh_update_queued_age = YLeaf(YType.uint32, "last-refresh-update-queued-age")

                                            self.last_refresh_update_write_age = YLeaf(YType.uint32, "last-refresh-update-write-age")

                                            self.last_update_group_af_name = YLeaf(YType.enumeration, "last-update-group-af-name")

                                            self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                            self.last_update_write_age = YLeaf(YType.uint32, "last-update-write-age")

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                            self.outbound_refresh_count = YLeaf(YType.uint32, "outbound-refresh-count")

                                            self.outstanding_version_count = YLeaf(YType.uint32, "outstanding-version-count")

                                            self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_ack_version = YLeaf(YType.uint32, "refresh-ack-version")

                                            self.refresh_filter_group_index = YLeaf(YType.uint32, "refresh-filter-group-index")

                                            self.refresh_next_resume_version = YLeaf(YType.uint32, "refresh-next-resume-version")

                                            self.refresh_pending_target_version = YLeaf(YType.uint32, "refresh-pending-target-version")

                                            self.refresh_requested_target_version = YLeaf(YType.uint32, "refresh-requested-target-version")

                                            self.refresh_sub_group_id = YLeaf(YType.uint32, "refresh-sub-group-id")

                                            self.refresh_sub_group_index = YLeaf(YType.uint32, "refresh-sub-group-index")

                                            self.refresh_update_out_queue_messages = YLeaf(YType.uint32, "refresh-update-out-queue-messages")

                                            self.refresh_update_out_queue_size = YLeaf(YType.uint32, "refresh-update-out-queue-size")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.synced_ack_version = YLeaf(YType.uint32, "synced-ack-version")

                                            self.update_filter_group_index = YLeaf(YType.uint32, "update-filter-group-index")

                                            self.update_filter_group_messages = YLeaf(YType.uint32, "update-filter-group-messages")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                            self.update_refresh_version = YLeaf(YType.uint32, "update-refresh-version")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"
                                            self._children_yang_names.add("first-default-originate-timestamp")

                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"
                                            self._children_yang_names.add("first-update-queued-timestamp")

                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"
                                            self._children_yang_names.add("first-update-write-timestamp")

                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"
                                            self._children_yang_names.add("last-default-originate-timestamp")

                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"
                                            self._children_yang_names.add("last-filter-group-add-timestamp")

                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"
                                            self._children_yang_names.add("last-filter-group-remove-timestamp")

                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"
                                            self._children_yang_names.add("last-refresh-update-queued-timestamp")

                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"
                                            self._children_yang_names.add("last-refresh-update-write-timestamp")

                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"
                                            self._children_yang_names.add("last-sub-group-add-timestamp")

                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"
                                            self._children_yang_names.add("last-sub-group-remove-timestamp")

                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"
                                            self._children_yang_names.add("last-update-group-expiry-timestamp")

                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"
                                            self._children_yang_names.add("last-update-group-start-timestamp")

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                            self._children_yang_names.add("last-update-queued-timestamp")

                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"
                                            self._children_yang_names.add("last-update-write-timestamp")

                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                            self._children_yang_names.add("update-neighbor-address")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['ack_version', 'current_update_group_af_name', 'default_originate_internal_context', 'default_originate_state', 'filter_group_index', 'inbound_refresh_count', 'is_eor_outstanding', 'is_update_group_timer_running', 'last_default_originate_age', 'last_refresh_update_queued_age', 'last_refresh_update_write_age', 'last_update_group_af_name', 'last_update_queued_age', 'last_update_write_age', 'neighbor_address', 'next_resume_version', 'outbound_refresh_count', 'outstanding_version_count', 'pending_target_version', 'process_id', 'refresh_ack_version', 'refresh_filter_group_index', 'refresh_next_resume_version', 'refresh_pending_target_version', 'refresh_requested_target_version', 'refresh_sub_group_id', 'refresh_sub_group_index', 'refresh_update_out_queue_messages', 'refresh_update_out_queue_size', 'sub_group_id', 'sub_group_index', 'sub_group_index_xr', 'synced_ack_version', 'update_filter_group_index', 'update_filter_group_messages', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_refresh_version', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                        class FirstDefaultOriginateTimestamp(Entity):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "first-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-default-originate-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateQueuedTimestamp(Entity):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "first-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWriteTimestamp(Entity):
                                            """
                                            First update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "first-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastDefaultOriginateTimestamp(Entity):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "last-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-default-originate-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastFilterGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-filter-group-add-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastFilterGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-filter-group-remove-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRefreshUpdateQueuedTimestamp(Entity):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-refresh-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRefreshUpdateWriteTimestamp(Entity):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-refresh-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastSubGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-sub-group-add-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastSubGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-sub-group-remove-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateGroupExpiryTimestamp(Entity):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-group-expiry-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateGroupStartTimestamp(Entity):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-start-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-group-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWriteTimestamp(Entity):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-write-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateNeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                                self.yang_name = "update-neighbor-address"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "update-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationSubGroups(Entity):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                        self.yang_name = "update-generation-sub-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-sub-group" : ("update_generation_sub_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup)}

                                        self.update_generation_sub_group = YList(self)
                                        self._segment_path = lambda: "update-generation-sub-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                    class UpdateGenerationSubGroup(Entity):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                            self.yang_name = "update-generation-sub-group"
                                            self.yang_parent_name = "update-generation-sub-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"creation-timestamp" : ("creation_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp), "first-update-walk-end-timestamp" : ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp), "first-update-walk-start-timestamp" : ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp), "last-merge-timestamp" : ("last_merge_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp), "last-update-queued-timestamp" : ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp), "last-update-walk-end-timestamp" : ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp), "last-update-walk-start-timestamp" : ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.configured_update_limit_sub_group = YLeaf(YType.uint32, "configured-update-limit-sub-group")

                                            self.current_update_limit_sub_group = YLeaf(YType.uint32, "current-update-limit-sub-group")

                                            self.eo_r_attempted = YLeaf(YType.boolean, "eo-r-attempted")

                                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                            self.io_write_event_pending = YLeaf(YType.boolean, "io-write-event-pending")

                                            self.last_merged_sub_group_index = YLeaf(YType.uint32, "last-merged-sub-group-index")

                                            self.last_update_queued_age = YLeaf(YType.uint32, "last-update-queued-age")

                                            self.last_update_walk_end_age = YLeaf(YType.uint32, "last-update-walk-end-age")

                                            self.merge_count = YLeaf(YType.uint32, "merge-count")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.next_resume_version = YLeaf(YType.uint32, "next-resume-version")

                                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                            self.parent_sub_group_id = YLeaf(YType.uint32, "parent-sub-group-id")

                                            self.parent_sub_group_index = YLeaf(YType.uint32, "parent-sub-group-index")

                                            self.pending_target_version = YLeaf(YType.uint32, "pending-target-version")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                            self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                                            self.sub_group_id_xr = YLeaf(YType.uint32, "sub-group-id-xr")

                                            self.sub_group_index = YLeaf(YType.int32, "sub-group-index")

                                            self.sub_group_index_xr = YLeaf(YType.uint32, "sub-group-index-xr")

                                            self.update_default_route_sent = YLeaf(YType.boolean, "update-default-route-sent")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_main_table_version = YLeaf(YType.uint32, "update-main-table-version")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_refresh_target_version = YLeaf(YType.uint32, "update-refresh-target-version")

                                            self.update_throttled = YLeaf(YType.boolean, "update-throttled")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.update_vrf_table_rib_version = YLeaf(YType.uint32, "update-vrf-table-rib-version")

                                            self.version = YLeaf(YType.uint32, "version")

                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self._children_name_map["creation_timestamp"] = "creation-timestamp"
                                            self._children_yang_names.add("creation-timestamp")

                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"
                                            self._children_yang_names.add("first-update-walk-end-timestamp")

                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"
                                            self._children_yang_names.add("first-update-walk-start-timestamp")

                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"
                                            self._children_yang_names.add("last-merge-timestamp")

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"
                                            self._children_yang_names.add("last-update-queued-timestamp")

                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"
                                            self._children_yang_names.add("last-update-walk-end-timestamp")

                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"
                                            self._children_yang_names.add("last-update-walk-start-timestamp")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-sub-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['configured_update_limit_sub_group', 'current_update_limit_sub_group', 'eo_r_attempted', 'filter_group_count', 'io_write_event_pending', 'last_merged_sub_group_index', 'last_update_queued_age', 'last_update_walk_end_age', 'merge_count', 'neighbor_count', 'next_resume_version', 'nsr_version', 'parent_sub_group_id', 'parent_sub_group_index', 'pending_target_version', 'process_id', 'refresh_sub_group_count', 'sub_group_id', 'sub_group_id_xr', 'sub_group_index', 'sub_group_index_xr', 'update_default_route_sent', 'update_group_af_name', 'update_group_index', 'update_group_index_xr', 'update_main_table_version', 'update_out_queue_messages', 'update_out_queue_size', 'update_refresh_target_version', 'update_throttled', 'update_vrf_name', 'update_vrf_table_rib_version', 'version'], name, value)


                                        class CreationTimestamp(Entity):
                                            """
                                            Creation time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                                self.yang_name = "creation-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "creation-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWalkEndTimestamp(Entity):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-walk-end-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstUpdateWalkStartTimestamp(Entity):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-update-walk-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastMergeTimestamp(Entity):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                                self.yang_name = "last-merge-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-merge-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-queued-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWalkEndTimestamp(Entity):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-walk-end-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateWalkStartTimestamp(Entity):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-walk-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGenerationUpdateGroups(Entity):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                        self.yang_name = "update-generation-update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-generation-update-group" : ("update_generation_update_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup)}

                                        self.update_generation_update_group = YList(self)
                                        self._segment_path = lambda: "update-generation-update-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                    class UpdateGenerationUpdateGroup(Entity):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  <key>
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                            self.yang_name = "update-generation-update-group"
                                            self.yang_parent_name = "update-generation-update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"last-update-timer-delay-value" : ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue), "last-update-timer-expiry-timestamp" : ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp), "last-update-timer-remaining-value" : ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue), "last-update-timer-start-timestamp" : ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp), "last-update-timer-stop-timestamp" : ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp), "update-statistics" : ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics)}
                                            self._child_list_classes = {}

                                            self.update_group_index = YLeaf(YType.int32, "update-group-index")

                                            self.filter_group_count = YLeaf(YType.uint32, "filter-group-count")

                                            self.is_permanent = YLeaf(YType.boolean, "is-permanent")

                                            self.is_update_timer_running = YLeaf(YType.boolean, "is-update-timer-running")

                                            self.last_update_timer_expiry_age = YLeaf(YType.uint32, "last-update-timer-expiry-age")

                                            self.neighbor_count = YLeaf(YType.uint32, "neighbor-count")

                                            self.neighbor_leaving_count = YLeaf(YType.uint32, "neighbor-leaving-count")

                                            self.neighbor_session_af_name = YLeaf(YType.uint8, "neighbor-session-af-name")

                                            self.perm_pelem_allowed = YLeaf(YType.uint32, "perm-pelem-allowed")

                                            self.perm_pelem_encountered = YLeaf(YType.uint32, "perm-pelem-encountered")

                                            self.perm_pelem_exp_wdr = YLeaf(YType.uint32, "perm-pelem-exp-wdr")

                                            self.perm_pelem_not_allowed = YLeaf(YType.uint32, "perm-pelem-not-allowed")

                                            self.perm_pelem_spur_wdr = YLeaf(YType.uint32, "perm-pelem-spur-wdr")

                                            self.process_id = YLeaf(YType.uint32, "process-id")

                                            self.refresh_sub_group_count = YLeaf(YType.uint32, "refresh-sub-group-count")

                                            self.refresh_sub_group_throttled_count = YLeaf(YType.uint32, "refresh-sub-group-throttled-count")

                                            self.sub_group_throttled_count = YLeaf(YType.uint32, "sub-group-throttled-count")

                                            self.update_generation_recovery_pending = YLeaf(YType.boolean, "update-generation-recovery-pending")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_flags2 = YLeaf(YType.uint32, "update-group-flags2")

                                            self.update_group_index_xr = YLeaf(YType.uint32, "update-group-index-xr")

                                            self.update_out_queue_messages = YLeaf(YType.uint32, "update-out-queue-messages")

                                            self.update_out_queue_size = YLeaf(YType.uint32, "update-out-queue-size")

                                            self.update_sub_group_count = YLeaf(YType.uint32, "update-sub-group-count")

                                            self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"
                                            self._children_yang_names.add("last-update-timer-delay-value")

                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"
                                            self._children_yang_names.add("last-update-timer-expiry-timestamp")

                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"
                                            self._children_yang_names.add("last-update-timer-remaining-value")

                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"
                                            self._children_yang_names.add("last-update-timer-start-timestamp")

                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"
                                            self._children_yang_names.add("last-update-timer-stop-timestamp")

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._children_yang_names.add("update-statistics")
                                            self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + self.update_group_index.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', 'filter_group_count', 'is_permanent', 'is_update_timer_running', 'last_update_timer_expiry_age', 'neighbor_count', 'neighbor_leaving_count', 'neighbor_session_af_name', 'perm_pelem_allowed', 'perm_pelem_encountered', 'perm_pelem_exp_wdr', 'perm_pelem_not_allowed', 'perm_pelem_spur_wdr', 'process_id', 'refresh_sub_group_count', 'refresh_sub_group_throttled_count', 'sub_group_throttled_count', 'update_generation_recovery_pending', 'update_group_af_name', 'update_group_flags2', 'update_group_index_xr', 'update_out_queue_messages', 'update_out_queue_size', 'update_sub_group_count', 'update_vrf_name'], name, value)


                                        class LastUpdateTimerDelayValue(Entity):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                                self.yang_name = "last-update-timer-delay-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-delay-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerExpiryTimestamp(Entity):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-expiry-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerRemainingValue(Entity):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                                self.yang_name = "last-update-timer-remaining-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-remaining-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerStartTimestamp(Entity):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-start-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-start-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastUpdateTimerStopTimestamp(Entity):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-stop-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-update-timer-stop-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-update-cleared-timestamp" : ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp), "last-update-discard-timestamp" : ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp), "last-update-recovery-timestamp" : ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp), "last-update-throttle-timestamp" : ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)}
                                                self._child_list_classes = {}

                                                self.last_update_cleard_age = YLeaf(YType.uint32, "last-update-cleard-age")

                                                self.last_update_discard_age = YLeaf(YType.uint32, "last-update-discard-age")

                                                self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                                self.last_update_recovery_age = YLeaf(YType.uint32, "last-update-recovery-age")

                                                self.last_update_throttle_age = YLeaf(YType.uint32, "last-update-throttle-age")

                                                self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                                self.update_out_queue_messages_cleared = YLeaf(YType.uint32, "update-out-queue-messages-cleared")

                                                self.update_out_queue_messages_cumulative = YLeaf(YType.uint32, "update-out-queue-messages-cumulative")

                                                self.update_out_queue_messages_discarded = YLeaf(YType.uint32, "update-out-queue-messages-discarded")

                                                self.update_out_queue_messages_high = YLeaf(YType.uint32, "update-out-queue-messages-high")

                                                self.update_out_queue_size_cleared = YLeaf(YType.uint64, "update-out-queue-size-cleared")

                                                self.update_out_queue_size_cumulative = YLeaf(YType.uint64, "update-out-queue-size-cumulative")

                                                self.update_out_queue_size_discarded = YLeaf(YType.uint64, "update-out-queue-size-discarded")

                                                self.update_out_queue_size_high = YLeaf(YType.uint32, "update-out-queue-size-high")

                                                self.update_recovery_count = YLeaf(YType.uint32, "update-recovery-count")

                                                self.update_throttle_count = YLeaf(YType.uint32, "update-throttle-count")

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"
                                                self._children_yang_names.add("last-update-cleared-timestamp")

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"
                                                self._children_yang_names.add("last-update-discard-timestamp")

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"
                                                self._children_yang_names.add("last-update-recovery-timestamp")

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"
                                                self._children_yang_names.add("last-update-throttle-timestamp")
                                                self._segment_path = lambda: "update-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, ['last_update_cleard_age', 'last_update_discard_age', 'last_update_memory_allocation_fail_age', 'last_update_recovery_age', 'last_update_throttle_age', 'update_memory_allocation_fail_count', 'update_out_queue_messages_cleared', 'update_out_queue_messages_cumulative', 'update_out_queue_messages_discarded', 'update_out_queue_messages_high', 'update_out_queue_size_cleared', 'update_out_queue_size_cumulative', 'update_out_queue_size_discarded', 'update_out_queue_size_high', 'update_recovery_count', 'update_throttle_count'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-discard-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, ['nanoseconds', 'seconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateGroups(Entity):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups, self).__init__()

                                        self.yang_name = "update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"update-group" : ("update_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup)}

                                        self.update_group = YList(self)
                                        self._segment_path = lambda: "update-groups"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups, [], name, value)


                                    class UpdateGroup(Entity):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\:  bool
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\:  str
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\:  bool
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\:  bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                            self.yang_name = "update-group"
                                            self.yang_parent_name = "update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor), "update-sub-group" : ("update_sub_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup)}

                                            self.accepts_legacy_pe_rt_route = YLeaf(YType.boolean, "accepts-legacy-pe-rt-route")

                                            self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                            self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.desync_count = YLeaf(YType.uint32, "desync-count")

                                            self.disable_def_vrf_imp_advertisement = YLeaf(YType.boolean, "disable-def-vrf-imp-advertisement")

                                            self.disable_native_advertisement = YLeaf(YType.boolean, "disable-native-advertisement")

                                            self.disable_vrf_re_imp_advertisement = YLeaf(YType.boolean, "disable-vrf-re-imp-advertisement")

                                            self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                            self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                            self.ext_nh_encoding = YLeaf(YType.boolean, "ext-nh-encoding")

                                            self.filter_group_id = YLeaf(YType.int32, "filter-group-id")

                                            self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                            self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                            self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                            self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")

                                            self.has_orf_receive_capability = YLeaf(YType.boolean, "has-orf-receive-capability")

                                            self.is4_byte_as_peer = YLeaf(YType.boolean, "is4-byte-as-peer")

                                            self.is_addpath_capable = YLeaf(YType.boolean, "is-addpath-capable")

                                            self.is_adv_capable = YLeaf(YType.boolean, "is-adv-capable")

                                            self.is_adv_perm_net_capable = YLeaf(YType.boolean, "is-adv-perm-net-capable")

                                            self.is_adv_reorg_capable = YLeaf(YType.boolean, "is-adv-reorg-capable")

                                            self.is_aigp_capable = YLeaf(YType.boolean, "is-aigp-capable")

                                            self.is_aigp_cost_community_capable = YLeaf(YType.boolean, "is-aigp-cost-community-capable")

                                            self.is_aigp_med_capable = YLeaf(YType.boolean, "is-aigp-med-capable")

                                            self.is_client_reflection_disabled = YLeaf(YType.boolean, "is-client-reflection-disabled")

                                            self.is_common_admin_peers = YLeaf(YType.boolean, "is-common-admin-peers")

                                            self.is_directly_connected_ebgp_v6_peers = YLeaf(YType.boolean, "is-directly-connected-ebgp-v6-peers")

                                            self.is_internal_peers = YLeaf(YType.boolean, "is-internal-peers")

                                            self.is_labeled_afi_enabled = YLeaf(YType.boolean, "is-labeled-afi-enabled")

                                            self.is_llgr_capable = YLeaf(YType.boolean, "is-llgr-capable")

                                            self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                            self.is_route_reflector_client = YLeaf(YType.boolean, "is-route-reflector-client")

                                            self.is_send_mcast_attr_enabled = YLeaf(YType.boolean, "is-send-mcast-attr-enabled")

                                            self.is_unlabeled_afi_enabled = YLeaf(YType.boolean, "is-unlabeled-afi-enabled")

                                            self.local_as = YLeaf(YType.uint32, "local-as")

                                            self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                            self.minimum_advertisement_interval = YLeaf(YType.uint32, "minimum-advertisement-interval")

                                            self.minimum_advertisement_interval_msecs = YLeaf(YType.uint32, "minimum-advertisement-interval-msecs")

                                            self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                            self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                            self.process_instance_id = YLeaf(YType.uint8, "process-instance-id")

                                            self.refresh_subgrp_count = YLeaf(YType.uint32, "refresh-subgrp-count")

                                            self.remote_as = YLeaf(YType.uint32, "remote-as")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.session_af_name = YLeaf(YType.uint8, "session-af-name")

                                            self.should_remove_private_a_ss = YLeaf(YType.boolean, "should-remove-private-a-ss")

                                            self.should_remove_private_as_ent_path = YLeaf(YType.boolean, "should-remove-private-as-ent-path")

                                            self.should_send_communities = YLeaf(YType.boolean, "should-send-communities")

                                            self.should_send_ext_communities = YLeaf(YType.boolean, "should-send-ext-communities")

                                            self.should_send_gshut_community = YLeaf(YType.boolean, "should-send-gshut-community")

                                            self.should_send_stitching_rt = YLeaf(YType.boolean, "should-send-stitching-rt")

                                            self.soo_value = YLeaf(YType.str, "soo-value")

                                            self.split_horizon = YLeaf(YType.boolean, "split-horizon")

                                            self.subgrp_merge_count = YLeaf(YType.uint32, "subgrp-merge-count")

                                            self.update_group_af_name = YLeaf(YType.enumeration, "update-group-af-name")

                                            self.update_group_id = YLeaf(YType.int32, "update-group-id")

                                            self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                            self.updates_formatted = YLeaf(YType.uint32, "updates-formatted")

                                            self.updates_replicated = YLeaf(YType.uint32, "updates-replicated")

                                            self.updgrp_cluster_id = YLeaf(YType.uint32, "updgrp-cluster-id")

                                            self.updgrp_cluster_type = YLeaf(YType.uint8, "updgrp-cluster-type")

                                            self.use_next_hop_self = YLeaf(YType.boolean, "use-next-hop-self")

                                            self.use_next_hop_unchanged_mpath = YLeaf(YType.boolean, "use-next-hop-unchanged-mpath")

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._children_yang_names.add("performance-statistics")

                                            self.neighbor = YList(self)
                                            self.update_sub_group = YList(self)
                                            self._segment_path = lambda: "update-group"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, ['accepts_legacy_pe_rt_route', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'as_override', 'desync_count', 'disable_def_vrf_imp_advertisement', 'disable_native_advertisement', 'disable_vrf_re_imp_advertisement', 'enable_label_stack', 'encapsulation_type', 'ext_nh_encoding', 'filter_group_id', 'gshut_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends', 'has_orf_receive_capability', 'is4_byte_as_peer', 'is_addpath_capable', 'is_adv_capable', 'is_adv_perm_net_capable', 'is_adv_reorg_capable', 'is_aigp_capable', 'is_aigp_cost_community_capable', 'is_aigp_med_capable', 'is_client_reflection_disabled', 'is_common_admin_peers', 'is_directly_connected_ebgp_v6_peers', 'is_internal_peers', 'is_labeled_afi_enabled', 'is_llgr_capable', 'is_orr_root_address_configured', 'is_route_reflector_client', 'is_send_mcast_attr_enabled', 'is_unlabeled_afi_enabled', 'local_as', 'local_as_replace_as', 'minimum_advertisement_interval', 'minimum_advertisement_interval_msecs', 'orr_group_index', 'orr_group_name', 'process_instance_id', 'refresh_subgrp_count', 'remote_as', 'route_policy_out', 'session_af_name', 'should_remove_private_a_ss', 'should_remove_private_as_ent_path', 'should_send_communities', 'should_send_ext_communities', 'should_send_gshut_community', 'should_send_stitching_rt', 'soo_value', 'split_horizon', 'subgrp_merge_count', 'update_group_af_name', 'update_group_id', 'update_group_number', 'updates_formatted', 'updates_replicated', 'updgrp_cluster_id', 'updgrp_cluster_type', 'use_next_hop_self', 'use_next_hop_unchanged_mpath'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.update_generation_be_prefixes_count = YLeaf(YType.uint32, "update-generation-be-prefixes-count")

                                                self.update_generation_calls = YLeaf(YType.uint32, "update-generation-calls")

                                                self.update_generation_messages_count = YLeaf(YType.uint32, "update-generation-messages-count")

                                                self.update_generation_prefixes_count = YLeaf(YType.uint32, "update-generation-prefixes-count")

                                                self.update_generation_time = YLeaf(YType.uint32, "update-generation-time")

                                                self.updgen_timer_process_time = YLeaf(YType.uint64, "updgen-timer-process-time")

                                                self.updgen_timer_start_time = YLeaf(YType.uint64, "updgen-timer-start-time")

                                                self.updgen_timer_stop_time = YLeaf(YType.uint64, "updgen-timer-stop-time")
                                                self._segment_path = lambda: "performance-statistics"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, ['update_generation_be_prefixes_count', 'update_generation_calls', 'update_generation_messages_count', 'update_generation_prefixes_count', 'update_generation_time', 'updgen_timer_process_time', 'updgen_timer_start_time', 'updgen_timer_stop_time'], name, value)


                                        class UpdateSubGroup(Entity):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                                self.yang_name = "update-sub-group"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor), "update-filter-group" : ("update_filter_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)}

                                                self.filter_group = YLeaf(YType.uint16, "filter-group")

                                                self.update_sub_group_number = YLeaf(YType.uint32, "update-sub-group-number")

                                                self.wait_for_eo_rs = YLeaf(YType.boolean, "wait-for-eo-rs")

                                                self.neighbor = YList(self)
                                                self.update_filter_group = YList(self)
                                                self._segment_path = lambda: "update-sub-group"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, ['filter_group', 'update_sub_group_number', 'wait_for_eo_rs'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "neighbor"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                            class UpdateFilterGroup(Entity):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                    self.yang_name = "update-filter-group"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity), "neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor)}

                                                    self.fgroup_advertised_prefixes = YLeaf(YType.uint32, "fgroup-advertised-prefixes")

                                                    self.fgroup_created_message_elements = YLeaf(YType.uint32, "fgroup-created-message-elements")

                                                    self.fgroup_deleted_message_elements = YLeaf(YType.uint32, "fgroup-deleted-message-elements")

                                                    self.fgroup_flags = YLeaf(YType.uint8, "fgroup-flags")

                                                    self.fgroup_neighbors = YLeaf(YType.uint16, "fgroup-neighbors")

                                                    self.fgroup_queued_message_elements = YLeaf(YType.uint32, "fgroup-queued-message-elements")

                                                    self.fgroup_skipped_prefixes = YLeaf(YType.uint32, "fgroup-skipped-prefixes")

                                                    self.fgroup_suppressed_prefixes = YLeaf(YType.uint32, "fgroup-suppressed-prefixes")

                                                    self.fgroup_total_advertised_prefixes = YLeaf(YType.uint32, "fgroup-total-advertised-prefixes")

                                                    self.fgroup_total_non_optimised_prefixes = YLeaf(YType.uint32, "fgroup-total-non-optimised-prefixes")

                                                    self.fgroup_total_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-total-withdrawn-prefixes")

                                                    self.fgroup_withdrawn_prefixes = YLeaf(YType.uint32, "fgroup-withdrawn-prefixes")

                                                    self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                                    self.rts = YLeaf(YType.uint32, "rts")

                                                    self.update_filter_group_number = YLeaf(YType.uint32, "update-filter-group-number")

                                                    self.extended_community = YList(self)
                                                    self.neighbor = YList(self)
                                                    self._segment_path = lambda: "update-filter-group"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, ['fgroup_advertised_prefixes', 'fgroup_created_message_elements', 'fgroup_deleted_message_elements', 'fgroup_flags', 'fgroup_neighbors', 'fgroup_queued_message_elements', 'fgroup_skipped_prefixes', 'fgroup_suppressed_prefixes', 'fgroup_total_advertised_prefixes', 'fgroup_total_non_optimised_prefixes', 'fgroup_total_withdrawn_prefixes', 'fgroup_withdrawn_prefixes', 'is_rt_present', 'rts', 'update_filter_group_number'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint8, "entry")
                                                        self._segment_path = lambda: "extended-community"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, ['entry'], name, value)


                                                class Neighbor(Entity):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                        self.yang_name = "neighbor"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress)}
                                                        self._child_list_classes = {}

                                                        self.afi = YLeaf(YType.enumeration, "afi")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                        self._children_yang_names.add("l2vpn-mspw-address")

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                        self._children_yang_names.add("l2vpn-vpls-address")
                                                        self._segment_path = lambda: "neighbor"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                    class L2VpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                    class L2VpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-06-26'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class Bmp(Entity):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp, self).__init__()

                                self.yang_name = "bmp"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"server-neighbors" : ("server_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors), "server-summaries" : ("server_summaries", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries)}
                                self._child_list_classes = {}

                                self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self._children_name_map["server_neighbors"] = "server-neighbors"
                                self._children_yang_names.add("server-neighbors")

                                self.server_summaries = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self
                                self._children_name_map["server_summaries"] = "server-summaries"
                                self._children_yang_names.add("server-summaries")
                                self._segment_path = lambda: "bmp"


                            class ServerNeighbors(Entity):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors, self).__init__()

                                    self.yang_name = "server-neighbors"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"server-neighbor" : ("server_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor)}

                                    self.server_neighbor = YList(self)
                                    self._segment_path = lambda: "server-neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors, [], name, value)


                                class ServerNeighbor(Entity):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                        self.yang_name = "server-neighbor"
                                        self.yang_parent_name = "server-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"monitored-neighbors" : ("monitored_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors)}
                                        self._child_list_classes = {}

                                        self.server_id = YLeaf(YType.uint32, "server-id")

                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self
                                        self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                        self._children_yang_names.add("monitored-neighbors")
                                        self._segment_path = lambda: "server-neighbor" + "[server-id='" + self.server_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                    class MonitoredNeighbors(Entity):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                            self.yang_name = "monitored-neighbors"
                                            self.yang_parent_name = "server-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"monitored-neighbor" : ("monitored_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor)}

                                            self.monitored_neighbor = YList(self)
                                            self._segment_path = lambda: "monitored-neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                        class MonitoredNeighbor(Entity):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                            
                                            	Number of Route Monitor EOR Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                                self.yang_name = "monitored-neighbor"
                                                self.yang_parent_name = "monitored-neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bmp-neighbor-address" : ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress)}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.bmp_neighbor_msg_dropped = YLeaf(YType.uint32, "bmp-neighbor-msg-dropped")

                                                self.bmp_neighbor_msg_pending = YLeaf(YType.uint32, "bmp-neighbor-msg-pending")

                                                self.bmp_neighbor_path_update_drop = YLeaf(YType.uint32, "bmp-neighbor-path-update-drop")

                                                self.bmp_neighbor_path_update_sent = YLeaf(YType.uint32, "bmp-neighbor-path-update-sent")

                                                self.bmp_neighbor_path_withdraw_drop = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-drop")

                                                self.bmp_neighbor_path_withdraw_sent = YLeaf(YType.uint32, "bmp-neighbor-path-withdraw-sent")

                                                self.bmp_neighbor_peer_down_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-down-sent")

                                                self.bmp_neighbor_peer_up_sent = YLeaf(YType.uint32, "bmp-neighbor-peer-up-sent")

                                                self.bmp_neighbor_route_monitor_eor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-eor-sent")

                                                self.bmp_neighbor_route_monitor_sent = YLeaf(YType.uint32, "bmp-neighbor-route-monitor-sent")

                                                self.bmp_neighbor_upd_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-upd-msg-sent")

                                                self.bmp_neighbor_wdraw_msg_sent = YLeaf(YType.uint32, "bmp-neighbor-wdraw-msg-sent")

                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                                self._children_yang_names.add("bmp-neighbor-address")
                                                self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', 'bmp_neighbor_msg_dropped', 'bmp_neighbor_msg_pending', 'bmp_neighbor_path_update_drop', 'bmp_neighbor_path_update_sent', 'bmp_neighbor_path_withdraw_drop', 'bmp_neighbor_path_withdraw_sent', 'bmp_neighbor_peer_down_sent', 'bmp_neighbor_peer_up_sent', 'bmp_neighbor_route_monitor_eor_sent', 'bmp_neighbor_route_monitor_sent', 'bmp_neighbor_upd_msg_sent', 'bmp_neighbor_wdraw_msg_sent'], name, value)


                                            class BmpNeighborAddress(Entity):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                    self.yang_name = "bmp-neighbor-address"
                                                    self.yang_parent_name = "monitored-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "bmp-neighbor-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                            class ServerSummaries(Entity):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries, self).__init__()

                                    self.yang_name = "server-summaries"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"server-summary" : ("server_summary", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary)}

                                    self.server_summary = YList(self)
                                    self._segment_path = lambda: "server-summaries"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries, [], name, value)


                                class ServerSummary(Entity):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_maximum_buffer_size_route_mon
                                    
                                    	Buffer limit used for route mon
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_reset_walk_in_progress
                                    
                                    	Reset walk in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_rmon_cur_buffer_size
                                    
                                    	Current Buffer usage per BMP Route Mon
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\:  str
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:   :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_server_up_count
                                    
                                    	Number of BMP server that are UP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_in_progress
                                    
                                    	Update generation in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:   :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\:  str
                                    
                                    .. attribute:: bmpafi_info
                                    
                                    	AFI specific info for BMP server
                                    	**type**\: list of    :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpr_mon_eo_rmessages
                                    
                                    	Total bmpQ EOR update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\:  str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                        self.yang_name = "server-summary"
                                        self.yang_parent_name = "server-summaries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"bmp-server-last-discon-time" : ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime), "bmp-server-state-age" : ("bmp_server_state_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge), "bmp-server-state-time-spec" : ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec), "update-source-address" : ("update_source_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)}
                                        self._child_list_classes = {"bmpafi-info" : ("bmpafi_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo)}

                                        self.server_id = YLeaf(YType.uint32, "server-id")

                                        self.bmp_bytes_written_tcp = YLeaf(YType.uint64, "bmp-bytes-written-tcp")

                                        self.bmp_init_msg_count = YLeaf(YType.uint32, "bmp-init-msg-count")

                                        self.bmp_maximum_buffer_size_route_mon = YLeaf(YType.uint64, "bmp-maximum-buffer-size-route-mon")

                                        self.bmp_messages_wdraw_discarded = YLeaf(YType.uint32, "bmp-messages-wdraw-discarded")

                                        self.bmp_peer_msg_drop_count = YLeaf(YType.uint32, "bmp-peer-msg-drop-count")

                                        self.bmp_peer_msg_pending_count = YLeaf(YType.uint32, "bmp-peer-msg-pending-count")

                                        self.bmp_peer_msg_pending_count_hwts = YLeaf(YType.uint64, "bmp-peer-msg-pending-count-hwts")

                                        self.bmp_peer_msg_pending_count_max = YLeaf(YType.uint32, "bmp-peer-msg-pending-count-max")

                                        self.bmp_per_peer_msg_count = YLeaf(YType.uint32, "bmp-per-peer-msg-count")

                                        self.bmp_per_peer_msg_route_mon_count = YLeaf(YType.uint32, "bmp-per-peer-msg-route-mon-count")

                                        self.bmp_pfx_wdraw_discarded = YLeaf(YType.uint32, "bmp-pfx-wdraw-discarded")

                                        self.bmp_reset_walk_in_progress = YLeaf(YType.boolean, "bmp-reset-walk-in-progress")

                                        self.bmp_rmon_cur_buffer_size = YLeaf(YType.uint64, "bmp-rmon-cur-buffer-size")

                                        self.bmp_server_host_name = YLeaf(YType.str, "bmp-server-host-name")

                                        self.bmp_server_id = YLeaf(YType.uint8, "bmp-server-id")

                                        self.bmp_server_is_flapping = YLeaf(YType.boolean, "bmp-server-is-flapping")

                                        self.bmp_server_nbr_count = YLeaf(YType.uint32, "bmp-server-nbr-count")

                                        self.bmp_server_port = YLeaf(YType.uint32, "bmp-server-port")

                                        self.bmp_server_state = YLeaf(YType.enumeration, "bmp-server-state")

                                        self.bmp_server_up_count = YLeaf(YType.uint32, "bmp-server-up-count")

                                        self.bmp_status_report_count = YLeaf(YType.uint32, "bmp-status-report-count")

                                        self.bmp_termination_msg_count = YLeaf(YType.uint32, "bmp-termination-msg-count")

                                        self.bmp_upd_gen_in_progress = YLeaf(YType.boolean, "bmp-upd-gen-in-progress")

                                        self.bmp_update_mode = YLeaf(YType.enumeration, "bmp-update-mode")

                                        self.bmp_vrf_id = YLeaf(YType.uint32, "bmp-vrf-id")

                                        self.bmp_vrf_name = YLeaf(YType.str, "bmp-vrf-name")

                                        self.bmpq_last_all_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-all-write-pulse-sent-time")

                                        self.bmpq_last_write_pulse_cb_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-cb-time")

                                        self.bmpq_last_write_pulse_sent_time = YLeaf(YType.uint64, "bmpq-last-write-pulse-sent-time")

                                        self.bmpr_mon_eo_rmessages = YLeaf(YType.uint32, "bmpr-mon-eo-rmessages")

                                        self.bmpr_mon_upd_messages = YLeaf(YType.uint32, "bmpr-mon-upd-messages")

                                        self.bmpr_mon_update_gen_time = YLeaf(YType.uint32, "bmpr-mon-update-gen-time")

                                        self.bmpr_mon_wdraw_messages = YLeaf(YType.uint32, "bmpr-mon-wdraw-messages")

                                        self.path_update_count = YLeaf(YType.uint32, "path-update-count")

                                        self.path_update_drop = YLeaf(YType.uint32, "path-update-drop")

                                        self.path_withdraw_count = YLeaf(YType.uint32, "path-withdraw-count")

                                        self.path_withdraw_drop = YLeaf(YType.uint32, "path-withdraw-drop")

                                        self.tcp_keep_alive_interval = YLeaf(YType.uint32, "tcp-keep-alive-interval")

                                        self.tcp_last_write_cb_time = YLeaf(YType.uint64, "tcp-last-write-cb-time")

                                        self.tcp_last_write_result = YLeaf(YType.uint32, "tcp-last-write-result")

                                        self.tcp_last_write_time = YLeaf(YType.uint64, "tcp-last-write-time")

                                        self.tcp_maximum_segment_size = YLeaf(YType.uint32, "tcp-maximum-segment-size")

                                        self.tcp_write_cb_pending = YLeaf(YType.uint32, "tcp-write-cb-pending")

                                        self.tcp_write_time = YLeaf(YType.uint32, "tcp-write-time")

                                        self.tos_type = YLeaf(YType.uint8, "tos-type")

                                        self.tos_value = YLeaf(YType.uint8, "tos-value")

                                        self.update_source_interface_name = YLeaf(YType.str, "update-source-interface-name")

                                        self.update_source_vrf_id = YLeaf(YType.uint32, "update-source-vrf-id")

                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"
                                        self._children_yang_names.add("bmp-server-last-discon-time")

                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"
                                        self._children_yang_names.add("bmp-server-state-age")

                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"
                                        self._children_yang_names.add("bmp-server-state-time-spec")

                                        self.update_source_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self._children_name_map["update_source_address"] = "update-source-address"
                                        self._children_yang_names.add("update-source-address")

                                        self.bmpafi_info = YList(self)
                                        self._segment_path = lambda: "server-summary" + "[server-id='" + self.server_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, ['server_id', 'bmp_bytes_written_tcp', 'bmp_init_msg_count', 'bmp_maximum_buffer_size_route_mon', 'bmp_messages_wdraw_discarded', 'bmp_peer_msg_drop_count', 'bmp_peer_msg_pending_count', 'bmp_peer_msg_pending_count_hwts', 'bmp_peer_msg_pending_count_max', 'bmp_per_peer_msg_count', 'bmp_per_peer_msg_route_mon_count', 'bmp_pfx_wdraw_discarded', 'bmp_reset_walk_in_progress', 'bmp_rmon_cur_buffer_size', 'bmp_server_host_name', 'bmp_server_id', 'bmp_server_is_flapping', 'bmp_server_nbr_count', 'bmp_server_port', 'bmp_server_state', 'bmp_server_up_count', 'bmp_status_report_count', 'bmp_termination_msg_count', 'bmp_upd_gen_in_progress', 'bmp_update_mode', 'bmp_vrf_id', 'bmp_vrf_name', 'bmpq_last_all_write_pulse_sent_time', 'bmpq_last_write_pulse_cb_time', 'bmpq_last_write_pulse_sent_time', 'bmpr_mon_eo_rmessages', 'bmpr_mon_upd_messages', 'bmpr_mon_update_gen_time', 'bmpr_mon_wdraw_messages', 'path_update_count', 'path_update_drop', 'path_withdraw_count', 'path_withdraw_drop', 'tcp_keep_alive_interval', 'tcp_last_write_cb_time', 'tcp_last_write_result', 'tcp_last_write_time', 'tcp_maximum_segment_size', 'tcp_write_cb_pending', 'tcp_write_time', 'tos_type', 'tos_value', 'update_source_interface_name', 'update_source_vrf_id'], name, value)


                                    class BmpServerLastDisconTime(Entity):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                            self.yang_name = "bmp-server-last-discon-time"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-last-discon-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, ['nanoseconds', 'seconds'], name, value)


                                    class BmpServerStateAge(Entity):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                            self.yang_name = "bmp-server-state-age"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-state-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, ['nanoseconds', 'seconds'], name, value)


                                    class BmpServerStateTimeSpec(Entity):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                            self.yang_name = "bmp-server-state-time-spec"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "bmp-server-state-time-spec"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class BmpafiInfo(Entity):
                                        """
                                        AFI specific info for BMP server
                                        
                                        .. attribute:: bmp_filter_nbr_cnt
                                        
                                        	Filter nbr Count for this AFI
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_filter_neighbor_address
                                        
                                        	Filter Neighbor Address
                                        	**type**\:   :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                        
                                        .. attribute:: bmp_filter_neighbor_address_set
                                        
                                        	Filter Neighbor Address Set ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_init_eor_end_version
                                        
                                        	Version to reach to send EOR
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_init_eor_pending_cnt
                                        
                                        	Count for pending EOR
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_resume_prefix
                                        
                                        	BMP Resume prefix
                                        	**type**\:   :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                        
                                        .. attribute:: bmp_resume_prefix_len
                                        
                                        	BMP Resume prefix Len
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_send_version
                                        
                                        	Table Version that this BMP server has caught upto
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_end_version
                                        
                                        	Update Gen ResumeWalk end version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_net_version
                                        
                                        	Update Gen ResumeWalk Net version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_start_version
                                        
                                        	Update Gen ResumeWalk start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_count
                                        
                                        	Number of times Update Gen ran
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                        
                                        	Last Update Gen Run time stamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_count
                                        
                                        	Number of times Update Gen Stopped
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                        
                                        	Last Update Gen Stop time stamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stopped
                                        
                                        	Update Gen WalkStopped
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmpaf_name
                                        
                                        	BMP Address family identifier
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                            self.yang_name = "bmpafi-info"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bmp-filter-neighbor-address" : ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress), "bmp-resume-prefix" : ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)}
                                            self._child_list_classes = {}

                                            self.bmp_filter_nbr_cnt = YLeaf(YType.uint32, "bmp-filter-nbr-cnt")

                                            self.bmp_filter_neighbor_address_set = YLeaf(YType.boolean, "bmp-filter-neighbor-address-set")

                                            self.bmp_init_eor_end_version = YLeaf(YType.uint32, "bmp-init-eor-end-version")

                                            self.bmp_init_eor_pending_cnt = YLeaf(YType.uint32, "bmp-init-eor-pending-cnt")

                                            self.bmp_resume_prefix_len = YLeaf(YType.uint32, "bmp-resume-prefix-len")

                                            self.bmp_send_version = YLeaf(YType.uint32, "bmp-send-version")

                                            self.bmp_upd_gen_resume_end_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-end-version")

                                            self.bmp_upd_gen_resume_net_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-net-version")

                                            self.bmp_upd_gen_resume_start_version = YLeaf(YType.uint32, "bmp-upd-gen-resume-start-version")

                                            self.bmp_upd_gen_walk_run_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-count")

                                            self.bmp_upd_gen_walk_run_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-run-time-stamp")

                                            self.bmp_upd_gen_walk_stop_count = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-count")

                                            self.bmp_upd_gen_walk_stop_time_stamp = YLeaf(YType.uint64, "bmp-upd-gen-walk-stop-time-stamp")

                                            self.bmp_upd_gen_walk_stopped = YLeaf(YType.boolean, "bmp-upd-gen-walk-stopped")

                                            self.bmpaf_name = YLeaf(YType.enumeration, "bmpaf-name")

                                            self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                            self.bmp_filter_neighbor_address.parent = self
                                            self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                            self._children_yang_names.add("bmp-filter-neighbor-address")

                                            self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                            self.bmp_resume_prefix.parent = self
                                            self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"
                                            self._children_yang_names.add("bmp-resume-prefix")
                                            self._segment_path = lambda: "bmpafi-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, ['bmp_filter_nbr_cnt', 'bmp_filter_neighbor_address_set', 'bmp_init_eor_end_version', 'bmp_init_eor_pending_cnt', 'bmp_resume_prefix_len', 'bmp_send_version', 'bmp_upd_gen_resume_end_version', 'bmp_upd_gen_resume_net_version', 'bmp_upd_gen_resume_start_version', 'bmp_upd_gen_walk_run_count', 'bmp_upd_gen_walk_run_time_stamp', 'bmp_upd_gen_walk_stop_count', 'bmp_upd_gen_walk_stop_time_stamp', 'bmp_upd_gen_walk_stopped', 'bmpaf_name'], name, value)


                                        class BmpFilterNeighborAddress(Entity):
                                            """
                                            Filter Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-filter-neighbor-address"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "bmp-filter-neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                        class BmpResumePrefix(Entity):
                                            """
                                            BMP Resume prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                                self.yang_name = "bmp-resume-prefix"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"prefix" : ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix)}
                                                self._child_list_classes = {}

                                                self.prefix_length = YLeaf(YType.uint16, "prefix-length")

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._children_yang_names.add("prefix")
                                                self._segment_path = lambda: "bmp-resume-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, ['prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bmp-resume-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress)}
                                                    self._child_list_classes = {}

                                                    self.afi = YLeaf(YType.enumeration, "afi")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                    self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                    self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                    self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                    self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                    self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                    self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                    self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                    self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                    self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                    self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                    self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                    self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                    self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                    self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                    self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                    self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                    self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                    self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                    self._children_yang_names.add("ipv4-sr-policy-address")

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._children_yang_names.add("ipv6-sr-policy-address")

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                    self._children_yang_names.add("l2vpn-mspw-address")

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                    self._children_yang_names.add("l2vpn-vpls-address")
                                                    self._segment_path = lambda: "prefix"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                                class L2VpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-mspw-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                                class L2VpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                        self._segment_path = lambda: "l2vpn-vpls-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class UpdateSourceAddress(Entity):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                            self.yang_name = "update-source-address"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "update-source-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class GlobalProcessInfo(Entity):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo, self).__init__()

                                self.yang_name = "global-process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf)}
                                self._child_list_classes = {}

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.vrfid = YLeaf(YType.uint32, "vrfid")

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "global-process-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo, ['vrf_name', 'vrfid'], name, value)


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_cur_maximum_buffer_size
                                
                                	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                                
                                .. attribute:: color_id
                                
                                	All configured Color IDs
                                	**type**\: list of    :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId>`
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\:  bool
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\:  str
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"cluster-id-entry" : ("cluster_id_entry", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry), "color-id" : ("color_id", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId)}

                                    self.asn_format = YLeaf(YType.uint32, "asn-format")

                                    self.bmp_cur_maximum_buffer_size = YLeaf(YType.uint64, "bmp-cur-maximum-buffer-size")

                                    self.bmp_current_buffer_size = YLeaf(YType.uint64, "bmp-current-buffer-size")

                                    self.bmp_default_buffer_size = YLeaf(YType.uint64, "bmp-default-buffer-size")

                                    self.bmp_maximum_buffer_size = YLeaf(YType.uint64, "bmp-maximum-buffer-size")

                                    self.cluster_id = YLeaf(YType.uint32, "cluster-id")

                                    self.confederation_id = YLeaf(YType.uint32, "confederation-id")

                                    self.configured_cluster_id = YLeaf(YType.uint32, "configured-cluster-id")

                                    self.generic_scan_period = YLeaf(YType.uint16, "generic-scan-period")

                                    self.graceful_maint_all_nbrs = YLeaf(YType.boolean, "graceful-maint-all-nbrs")

                                    self.graceful_maint_retain_routes = YLeaf(YType.boolean, "graceful-maint-retain-routes")

                                    self.graceful_maintenance = YLeaf(YType.boolean, "graceful-maintenance")

                                    self.in_standalone_mode = YLeaf(YType.boolean, "in-standalone-mode")

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.is_cluster_id_specified_as_ip = YLeaf(YType.boolean, "is-cluster-id-specified-as-ip")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.process_rlimit = YLeaf(YType.uint64, "process-rlimit")

                                    self.restart_count = YLeaf(YType.uint32, "restart-count")

                                    self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                    self.srgb_end_configured = YLeaf(YType.uint32, "srgb-end-configured")

                                    self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                    self.srgb_start_configured = YLeaf(YType.uint32, "srgb-start-configured")

                                    self.update_delay = YLeaf(YType.uint32, "update-delay")

                                    self.cluster_id_entry = YList(self)
                                    self.color_id = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_, ['asn_format', 'bmp_cur_maximum_buffer_size', 'bmp_current_buffer_size', 'bmp_default_buffer_size', 'bmp_maximum_buffer_size', 'cluster_id', 'confederation_id', 'configured_cluster_id', 'generic_scan_period', 'graceful_maint_all_nbrs', 'graceful_maint_retain_routes', 'graceful_maintenance', 'in_standalone_mode', 'instance_name', 'is_cluster_id_specified_as_ip', 'local_as', 'process_rlimit', 'restart_count', 'srgb_end', 'srgb_end_configured', 'srgb_start', 'srgb_start_configured', 'update_delay'], name, value)


                                class ClusterIdEntry(Entity):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry, self).__init__()

                                        self.yang_name = "cluster-id-entry"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_type = YLeaf(YType.uint8, "cluster-id-type")

                                        self.cluster_id_val = YLeaf(YType.uint32, "cluster-id-val")
                                        self._segment_path = lambda: "cluster-id-entry"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry, ['cluster_id_type', 'cluster_id_val'], name, value)


                                class ColorId(Entity):
                                    """
                                    All configured Color IDs
                                    
                                    .. attribute:: color_id_val
                                    
                                    	Color ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId, self).__init__()

                                        self.yang_name = "color-id"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.color_id_val = YLeaf(YType.uint32, "color-id-val")
                                        self._segment_path = lambda: "color-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ColorId, ['color_id_val'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\:  bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\:  bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.configured_router_id = YLeaf(YType.str, "configured-router-id")

                                    self.default_local_preference = YLeaf(YType.uint32, "default-local-preference")

                                    self.default_metric = YLeaf(YType.uint32, "default-metric")

                                    self.hold_time = YLeaf(YType.uint16, "hold-time")

                                    self.is_bestpath_aigp_ignore_enabled = YLeaf(YType.boolean, "is-bestpath-aigp-ignore-enabled")

                                    self.is_bestpath_always_compare_med_enabled = YLeaf(YType.boolean, "is-bestpath-always-compare-med-enabled")

                                    self.is_bestpath_as_path_mpath_relax_enabled = YLeaf(YType.boolean, "is-bestpath-as-path-mpath-relax-enabled")

                                    self.is_bestpath_compare_med_from_confed_peer_enabled = YLeaf(YType.boolean, "is-bestpath-compare-med-from-confed-peer-enabled")

                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = YLeaf(YType.boolean, "is-bestpath-compare-router-id-for-ebgp-peers-enabled")

                                    self.is_bestpath_ignore_as_path_enabled = YLeaf(YType.boolean, "is-bestpath-ignore-as-path-enabled")

                                    self.is_bestpath_missing_med_is_worst_enabled = YLeaf(YType.boolean, "is-bestpath-missing-med-is-worst-enabled")

                                    self.is_default_metric_configured = YLeaf(YType.boolean, "is-default-metric-configured")

                                    self.is_default_originate_configured = YLeaf(YType.boolean, "is-default-originate-configured")

                                    self.is_enforce_first_as_enabled = YLeaf(YType.boolean, "is-enforce-first-as-enabled")

                                    self.is_fast_external_fallover_enabled = YLeaf(YType.boolean, "is-fast-external-fallover-enabled")

                                    self.is_graceful_restart = YLeaf(YType.boolean, "is-graceful-restart")

                                    self.is_multipath_as_path_ignore_onwards_enabled = YLeaf(YType.boolean, "is-multipath-as-path-ignore-onwards-enabled")

                                    self.is_neighbor_logging = YLeaf(YType.boolean, "is-neighbor-logging")

                                    self.is_nsr = YLeaf(YType.boolean, "is-nsr")

                                    self.is_redistribute_ibgp_to_ig_ps_enabled = YLeaf(YType.boolean, "is-redistribute-ibgp-to-ig-ps-enabled")

                                    self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                    self.min_acceptable_hold_time = YLeaf(YType.uint16, "min-acceptable-hold-time")

                                    self.restart_time = YLeaf(YType.uint32, "restart-time")

                                    self.rib_purge_timeout = YLeaf(YType.uint32, "rib-purge-timeout")

                                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.stale_path_time = YLeaf(YType.uint32, "stale-path-time")

                                    self.vrf_is_active = YLeaf(YType.boolean, "vrf-is-active")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf, ['configured_router_id', 'default_local_preference', 'default_metric', 'hold_time', 'is_bestpath_aigp_ignore_enabled', 'is_bestpath_always_compare_med_enabled', 'is_bestpath_as_path_mpath_relax_enabled', 'is_bestpath_compare_med_from_confed_peer_enabled', 'is_bestpath_compare_router_id_for_ebgp_peers_enabled', 'is_bestpath_ignore_as_path_enabled', 'is_bestpath_missing_med_is_worst_enabled', 'is_default_metric_configured', 'is_default_originate_configured', 'is_enforce_first_as_enabled', 'is_fast_external_fallover_enabled', 'is_graceful_restart', 'is_multipath_as_path_ignore_onwards_enabled', 'is_neighbor_logging', 'is_nsr', 'is_redistribute_ibgp_to_ig_ps_enabled', 'keep_alive_time', 'min_acceptable_hold_time', 'restart_time', 'rib_purge_timeout', 'route_distinguisher', 'router_id', 'stale_path_time', 'vrf_is_active'], name, value)


                        class Information(Entity):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")
                                self._segment_path = lambda: "information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information, ['route_distinguisher'], name, value)


                        class MessageLogs(Entity):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs, self).__init__()

                                self.yang_name = "message-logs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"message-log" : ("message_log", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog)}

                                self.message_log = YList(self)
                                self._segment_path = lambda: "message-logs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs, [], name, value)


                            class MessageLog(Entity):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog, self).__init__()

                                    self.yang_name = "message-log"
                                    self.yang_parent_name = "message-logs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor-message" : ("neighbor_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage)}

                                    self.direction = YLeaf(YType.int32, "direction")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_message = YList(self)
                                    self._segment_path = lambda: "message-log"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog, ['direction', 'neighbor_address'], name, value)


                                class NeighborMessage(Entity):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                        self.yang_name = "neighbor-message"
                                        self.yang_parent_name = "message-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-timestamp" : ("message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)}
                                        self._child_list_classes = {"logged-message-data" : ("logged_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData)}

                                        self.message_data_length = YLeaf(YType.uint16, "message-data-length")

                                        self.message_type_received = YLeaf(YType.uint8, "message-type-received")

                                        self.total_logged_message_count = YLeaf(YType.uint32, "total-logged-message-count")

                                        self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self._children_name_map["message_timestamp"] = "message-timestamp"
                                        self._children_yang_names.add("message-timestamp")

                                        self.logged_message_data = YList(self)
                                        self._segment_path = lambda: "neighbor-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, ['message_data_length', 'message_type_received', 'total_logged_message_count'], name, value)


                                    class LoggedMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                            self.yang_name = "logged-message-data"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "logged-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, ['entry'], name, value)


                                    class MessageTimestamp(Entity):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                            self.yang_name = "message-timestamp"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class NeighborRanges(Entity):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges, self).__init__()

                                self.yang_name = "neighbor-ranges"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-range" : ("neighbor_range", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange)}

                                self.neighbor_range = YList(self)
                                self._segment_path = lambda: "neighbor-ranges"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges, [], name, value)


                            class NeighborRange(Entity):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  <key>
                                
                                	Neighbor Range prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\:  bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\:  str
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\:  bool
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\:  bool
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\:  str
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\:  bool
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\:  bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\:  str
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange, self).__init__()

                                    self.yang_name = "neighbor-range"
                                    self.yang_parent_name = "neighbor-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"cfg-local-address" : ("cfg_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress), "connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance)}
                                    self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData), "instance" : ("instance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance)}

                                    self.neighbor_range_address = YLeaf(YType.str, "neighbor-range-address")

                                    self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                    self.addpath_receive_disable = YLeaf(YType.boolean, "addpath-receive-disable")

                                    self.addpath_receive_enable = YLeaf(YType.boolean, "addpath-receive-enable")

                                    self.addpath_send_disable = YLeaf(YType.boolean, "addpath-send-disable")

                                    self.addpath_send_enable = YLeaf(YType.boolean, "addpath-send-enable")

                                    self.attrf_group_name = YLeaf(YType.str, "attrf-group-name")

                                    self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                    self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                    self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                    self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                    self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                    self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                    self.current_peers = YLeaf(YType.uint32, "current-peers")

                                    self.description = YLeaf(YType.str, "description")

                                    self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                    self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                    self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                    self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                    self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                    self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                    self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                    self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                    self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                    self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                    self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                    self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                    self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                    self.islocal_address_cfg = YLeaf(YType.boolean, "islocal-address-cfg")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                    self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                    self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                    self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                    self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                    self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                    self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                    self.msg_bug_circular = YLeaf(YType.boolean, "msg-bug-circular")

                                    self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                    self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                    self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                    self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                    self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                    self.nbr_rcv_size = YLeaf(YType.uint32, "nbr-rcv-size")

                                    self.nbr_send_size = YLeaf(YType.uint32, "nbr-send-size")

                                    self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                    self.neighbor_range_prefix_length = YLeaf(YType.uint8, "neighbor-range-prefix-length")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.oper_attrf_enable = YLeaf(YType.boolean, "oper-attrf-enable")

                                    self.range_inst_error = YLeaf(YType.uint32, "range-inst-error")

                                    self.range_max_drop = YLeaf(YType.uint32, "range-max-drop")

                                    self.range_open_accepted = YLeaf(YType.uint32, "range-open-accepted")

                                    self.range_open_match = YLeaf(YType.uint32, "range-open-match")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.remote_as_list_name = YLeaf(YType.str, "remote-as-list-name")

                                    self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                    self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                    self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                    self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                    self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                    self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                    self.syslog_enable = YLeaf(YType.boolean, "syslog-enable")

                                    self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                    self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.upd_errh_noreset = YLeaf(YType.boolean, "upd-errh-noreset")

                                    self.update_source = YLeaf(YType.str, "update-source")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self._children_name_map["cfg_local_address"] = "cfg-local-address"
                                    self._children_yang_names.add("cfg-local-address")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.af_data = YList(self)
                                    self.instance = YList(self)
                                    self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + self.neighbor_range_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange, ['neighbor_range_address', 'active_bmp_servers', 'addpath_receive_disable', 'addpath_receive_enable', 'addpath_send_disable', 'addpath_send_enable', 'attrf_group_name', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_enable_mode', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'current_peers', 'description', 'discard_as4_path', 'dmz_link_bandwidth', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'idle_watch_time', 'ignore_connected', 'internal_vpn_client', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_passive_close', 'islocal_address_cfg', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'max_peers', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_buf_count', 'msg_bug_circular', 'msg_log_in', 'msg_log_out', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'nbr_rcv_size', 'nbr_send_size', 'neighbor_local_as', 'neighbor_range_prefix_length', 'nsr_enabled', 'oper_attrf_enable', 'range_inst_error', 'range_max_drop', 'range_open_accepted', 'range_open_match', 'remote_as', 'remote_as_list_name', 'remote_as_number', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'syslog_enable', 'tcp_session_open_mode', 'tcpmss', 'tos_type', 'tos_value', 'ttl_security_enabled', 'upd_errh_noreset', 'update_source', 'vrf_name'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby)}

                                        self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                        self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                        self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                        self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                        self.advertise_afi_local = YLeaf(YType.boolean, "advertise-afi-local")

                                        self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                        self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                        self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                        self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                        self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                        self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                        self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                        self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                        self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                        self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                        self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                        self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                        self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                        self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                        self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                        self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                        self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                        self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                        self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                        self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                        self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                        self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                        self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                        self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                        self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                        self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                        self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                        self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                        self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                        self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                        self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                        self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                        self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                        self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                        self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                        self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                        self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                        self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                        self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                        self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                        self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                        self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                        self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                        self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                        self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                        self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                        self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                        self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                        self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                        self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                        self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                        self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                        self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                        self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                        self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                        self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                        self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                        self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                        self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                        self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                        self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                        self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                        self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                        self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                        self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                        self.restart_time = YLeaf(YType.uint32, "restart-time")

                                        self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                        self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                        self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                        self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                        self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                        self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                        self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                        self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                        self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                        self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                        self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                        self.weight = YLeaf(YType.uint32, "weight")

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, ['accept_own_enabled', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_disable', 'advertise_afi_local', 'advertise_afi_reorg', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'next_hop_unchanged', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, ['entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community-standby"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                class CfgLocalAddress(Entity):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                        self.yang_name = "cfg-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "cfg-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                        self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                class Instance(Entity):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance, self).__init__()

                                        self.yang_name = "instance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"idle-watch-timer-remaining-value" : ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue), "neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress), "neighbor-age" : ("neighbor_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge)}
                                        self._child_list_classes = {}

                                        self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                        self.is_idle_watch_timer_running = YLeaf(YType.boolean, "is-idle-watch-timer-running")

                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                        self._children_yang_names.add("idle-watch-timer-remaining-value")

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._children_yang_names.add("neighbor-address")

                                        self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge()
                                        self.neighbor_age.parent = self
                                        self._children_name_map["neighbor_age"] = "neighbor-age"
                                        self._children_yang_names.add("neighbor-age")
                                        self._segment_path = lambda: "instance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance, ['connection_state', 'is_idle_watch_timer_running'], name, value)


                                    class IdleWatchTimerRemainingValue(Entity):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, self).__init__()

                                            self.yang_name = "idle-watch-timer-remaining-value"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "idle-watch-timer-remaining-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.IdleWatchTimerRemainingValue, ['nanoseconds', 'seconds'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress)}
                                            self._child_list_classes = {}

                                            self.afi = YLeaf(YType.enumeration, "afi")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                            self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                            self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                            self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                            self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                            self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                            self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                            self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                            self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                            self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                            self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                            self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                            self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                            self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                            self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                            self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                            self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                            self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                            self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                            self._children_yang_names.add("ipv4-sr-policy-address")

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._children_yang_names.add("ipv6-sr-policy-address")

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                            self._children_yang_names.add("l2vpn-mspw-address")

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                            self._children_yang_names.add("l2vpn-vpls-address")
                                            self._segment_path = lambda: "neighbor-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                self._segment_path = lambda: "ipv4-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                self._segment_path = lambda: "ipv6-sr-policy-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                        class L2VpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-mspw-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                        class L2VpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                self._segment_path = lambda: "l2vpn-vpls-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class NeighborAge(Entity):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge, self).__init__()

                                            self.yang_name = "neighbor-age"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "neighbor-age"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance.NeighborAge, ['nanoseconds', 'seconds'], name, value)


                        class Neighbors(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor)}

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\:  bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\:  bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\:  bool
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:   :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:   :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\:  bool
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\:  bool
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance), "message-statistics" : ("message_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics), "received-notification-info" : ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo), "send-notification-info" : ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo), "tcp-init-sync-done-time-spec" : ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec), "tcp-init-sync-phase-two-time-spec" : ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec), "tcp-init-sync-time-spec" : ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)}
                                    self._child_list_classes = {"af-data" : ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.active_bmp_servers = YLeaf(YType.uint8, "active-bmp-servers")

                                    self.actual_last_write_bytes = YLeaf(YType.uint32, "actual-last-write-bytes")

                                    self.actual_last_write_reset_bytes = YLeaf(YType.uint32, "actual-last-write-reset-bytes")

                                    self.actual_second_last_write_bytes = YLeaf(YType.uint32, "actual-second-last-write-bytes")

                                    self.actual_second_last_write_reset_bytes = YLeaf(YType.uint32, "actual-second-last-write-reset-bytes")

                                    self.attempted_last_write_bytes = YLeaf(YType.uint32, "attempted-last-write-bytes")

                                    self.attempted_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-last-write-reset-bytes")

                                    self.attempted_second_last_write_bytes = YLeaf(YType.uint32, "attempted-second-last-write-bytes")

                                    self.attempted_second_last_write_reset_bytes = YLeaf(YType.uint32, "attempted-second-last-write-reset-bytes")

                                    self.bfd_minintervalval = YLeaf(YType.uint32, "bfd-minintervalval")

                                    self.bfd_multiplierval = YLeaf(YType.uint32, "bfd-multiplierval")

                                    self.bfd_session_created_state = YLeaf(YType.enumeration, "bfd-session-created-state")

                                    self.bfd_session_enable_mode = YLeaf(YType.enumeration, "bfd-session-enable-mode")

                                    self.bfd_session_state = YLeaf(YType.enumeration, "bfd-session-state")

                                    self.bfd_state_ts = YLeaf(YType.uint64, "bfd-state-ts")

                                    self.bytes_read = YLeaf(YType.uint32, "bytes-read")

                                    self.bytes_written = YLeaf(YType.uint32, "bytes-written")

                                    self.configured_hold_time = YLeaf(YType.uint16, "configured-hold-time")

                                    self.configured_keepalive = YLeaf(YType.uint16, "configured-keepalive")

                                    self.configured_min_acc_hold_time = YLeaf(YType.uint16, "configured-min-acc-hold-time")

                                    self.connect_retry_interval = YLeaf(YType.uint16, "connect-retry-interval")

                                    self.connection_admin_status = YLeaf(YType.uint32, "connection-admin-status")

                                    self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                    self.connection_established_time = YLeaf(YType.uint32, "connection-established-time")

                                    self.connection_local_port = YLeaf(YType.uint32, "connection-local-port")

                                    self.connection_remote_port = YLeaf(YType.uint32, "connection-remote-port")

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                    self.count_last_write = YLeaf(YType.uint32, "count-last-write")

                                    self.description = YLeaf(YType.str, "description")

                                    self.discard_as4_path = YLeaf(YType.uint32, "discard-as4-path")

                                    self.discard_data_bytes = YLeaf(YType.uint32, "discard-data-bytes")

                                    self.dmz_link_bandwidth = YLeaf(YType.uint32, "dmz-link-bandwidth")

                                    self.dynamic_neighbor = YLeaf(YType.boolean, "dynamic-neighbor")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_mode = YLeaf(YType.enumeration, "ebgp-send-dmz-mode")

                                    self.ebgp_time_to_live = YLeaf(YType.uint32, "ebgp-time-to-live")

                                    self.egress_peer_engineering_enabled = YLeaf(YType.boolean, "egress-peer-engineering-enabled")

                                    self.error_notifies_received = YLeaf(YType.uint32, "error-notifies-received")

                                    self.error_notifies_sent = YLeaf(YType.uint32, "error-notifies-sent")

                                    self.fpbsn_offset = YLeaf(YType.uint32, "fpbsn-offset")

                                    self.fssn_offset = YLeaf(YType.uint32, "fssn-offset")

                                    self.gr_restart_time = YLeaf(YType.uint32, "gr-restart-time")

                                    self.gr_stale_path_time = YLeaf(YType.uint32, "gr-stale-path-time")

                                    self.graceful_restart_enabled_nbr = YLeaf(YType.boolean, "graceful-restart-enabled-nbr")

                                    self.has_internal_link = YLeaf(YType.boolean, "has-internal-link")

                                    self.hold_time = YLeaf(YType.uint16, "hold-time")

                                    self.ignore_connected = YLeaf(YType.boolean, "ignore-connected")

                                    self.internal_vpn_client = YLeaf(YType.boolean, "internal-vpn-client")

                                    self.io_armed = YLeaf(YType.boolean, "io-armed")

                                    self.is4_byte_as_capability_received = YLeaf(YType.boolean, "is4-byte-as-capability-received")

                                    self.is4_byte_as_capability_sent = YLeaf(YType.boolean, "is4-byte-as-capability-sent")

                                    self.is_administratively_shut_down = YLeaf(YType.boolean, "is-administratively-shut-down")

                                    self.is_capability_negotiation_performed = YLeaf(YType.boolean, "is-capability-negotiation-performed")

                                    self.is_capability_negotiation_suppressed = YLeaf(YType.boolean, "is-capability-negotiation-suppressed")

                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = YLeaf(YType.boolean, "is-ebgp-multihop-bgp-mpls-forwarding-disabled")

                                    self.is_ebgp_peer_as_league = YLeaf(YType.boolean, "is-ebgp-peer-as-league")

                                    self.is_ebgp_peer_common_admin = YLeaf(YType.boolean, "is-ebgp-peer-common-admin")

                                    self.is_external_neighbor_not_directly_connected = YLeaf(YType.boolean, "is-external-neighbor-not-directly-connected")

                                    self.is_gr_aware = YLeaf(YType.boolean, "is-gr-aware")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.is_neighbor_max_prefix_shutdown = YLeaf(YType.boolean, "is-neighbor-max-prefix-shutdown")

                                    self.is_out_of_memory_forced_up = YLeaf(YType.boolean, "is-out-of-memory-forced-up")

                                    self.is_out_of_memory_shutdown = YLeaf(YType.boolean, "is-out-of-memory-shutdown")

                                    self.is_passive_close = YLeaf(YType.boolean, "is-passive-close")

                                    self.is_read_disabled = YLeaf(YType.boolean, "is-read-disabled")

                                    self.is_route_refresh_capability_received = YLeaf(YType.boolean, "is-route-refresh-capability-received")

                                    self.is_route_refresh_old_capability_received = YLeaf(YType.boolean, "is-route-refresh-old-capability-received")

                                    self.keep_alive_time = YLeaf(YType.uint16, "keep-alive-time")

                                    self.last_ackd_seq_no = YLeaf(YType.uint32, "last-ackd-seq-no")

                                    self.last_k_aerror_reset = YLeaf(YType.uint32, "last-k-aerror-reset")

                                    self.last_k_aexpiry_reset = YLeaf(YType.uint32, "last-k-aexpiry-reset")

                                    self.last_k_anotsent_reset = YLeaf(YType.uint32, "last-k-anotsent-reset")

                                    self.last_k_astart_reset = YLeaf(YType.uint32, "last-k-astart-reset")

                                    self.last_notify_error_code = YLeaf(YType.uint8, "last-notify-error-code")

                                    self.last_notify_error_subcode = YLeaf(YType.uint8, "last-notify-error-subcode")

                                    self.last_write_event = YLeaf(YType.uint32, "last-write-event")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.local_as_dual_as = YLeaf(YType.boolean, "local-as-dual-as")

                                    self.local_as_dual_as_mode_native = YLeaf(YType.boolean, "local-as-dual-as-mode-native")

                                    self.local_as_no_prepend = YLeaf(YType.boolean, "local-as-no-prepend")

                                    self.local_as_replace_as = YLeaf(YType.boolean, "local-as-replace-as")

                                    self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                    self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                    self.messages_received = YLeaf(YType.uint32, "messages-received")

                                    self.messages_sent = YLeaf(YType.uint32, "messages-sent")

                                    self.min_advertise_interval = YLeaf(YType.uint32, "min-advertise-interval")

                                    self.min_advertise_interval_msecs = YLeaf(YType.uint32, "min-advertise-interval-msecs")

                                    self.min_origination_interval = YLeaf(YType.uint16, "min-origination-interval")

                                    self.msg_log_in = YLeaf(YType.uint32, "msg-log-in")

                                    self.msg_log_out = YLeaf(YType.uint32, "msg-log-out")

                                    self.multi_protocol_capability_received = YLeaf(YType.boolean, "multi-protocol-capability-received")

                                    self.nbr_cluster_id = YLeaf(YType.uint32, "nbr-cluster-id")

                                    self.nbr_enforce_first_as = YLeaf(YType.boolean, "nbr-enforce-first-as")

                                    self.nbr_in_cluster = YLeaf(YType.uint8, "nbr-in-cluster")

                                    self.negotiated_protocol_version = YLeaf(YType.uint16, "negotiated-protocol-version")

                                    self.neighbor_interface_handle = YLeaf(YType.uint32, "neighbor-interface-handle")

                                    self.neighbor_local_as = YLeaf(YType.uint32, "neighbor-local-as")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.open_check_error_code = YLeaf(YType.enumeration, "open-check-error-code")

                                    self.peer_error_code = YLeaf(YType.uint32, "peer-error-code")

                                    self.peer_reset_reason = YLeaf(YType.enumeration, "peer-reset-reason")

                                    self.previous_connection_state = YLeaf(YType.uint32, "previous-connection-state")

                                    self.read_armed = YLeaf(YType.boolean, "read-armed")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.remote_as_number = YLeaf(YType.uint32, "remote-as-number")

                                    self.reset_notification_sent = YLeaf(YType.boolean, "reset-notification-sent")

                                    self.reset_reason = YLeaf(YType.enumeration, "reset-reason")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.rpki_allow_invalid = YLeaf(YType.boolean, "rpki-allow-invalid")

                                    self.rpki_disable = YLeaf(YType.boolean, "rpki-disable")

                                    self.rpki_signal_ibgp = YLeaf(YType.boolean, "rpki-signal-ibgp")

                                    self.rpki_use_validity = YLeaf(YType.boolean, "rpki-use-validity")

                                    self.second_last_k_aexpiry_reset = YLeaf(YType.uint32, "second-last-k-aexpiry-reset")

                                    self.second_last_k_astart_reset = YLeaf(YType.uint32, "second-last-k-astart-reset")

                                    self.second_last_write_event = YLeaf(YType.uint32, "second-last-write-event")

                                    self.socket_read_bytes = YLeaf(YType.uint32, "socket-read-bytes")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.standby_rp = YLeaf(YType.boolean, "standby-rp")

                                    self.suppress4_byte_as = YLeaf(YType.boolean, "suppress4-byte-as")

                                    self.tcp_session_open_mode = YLeaf(YType.enumeration, "tcp-session-open-mode")

                                    self.tcpmss = YLeaf(YType.uint32, "tcpmss")

                                    self.time_last_cb = YLeaf(YType.uint64, "time-last-cb")

                                    self.time_last_cb_reset = YLeaf(YType.uint32, "time-last-cb-reset")

                                    self.time_last_fb = YLeaf(YType.uint64, "time-last-fb")

                                    self.time_since_connection_last_dropped = YLeaf(YType.uint32, "time-since-connection-last-dropped")

                                    self.time_since_last_read = YLeaf(YType.uint32, "time-since-last-read")

                                    self.time_since_last_read_reset = YLeaf(YType.uint32, "time-since-last-read-reset")

                                    self.time_since_last_update = YLeaf(YType.uint32, "time-since-last-update")

                                    self.time_since_last_write = YLeaf(YType.uint32, "time-since-last-write")

                                    self.time_since_last_write_reset = YLeaf(YType.uint32, "time-since-last-write-reset")

                                    self.time_since_second_last_write = YLeaf(YType.uint32, "time-since-second-last-write")

                                    self.time_since_second_last_write_reset = YLeaf(YType.uint32, "time-since-second-last-write-reset")

                                    self.tos_type = YLeaf(YType.uint8, "tos-type")

                                    self.tos_value = YLeaf(YType.uint8, "tos-value")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.update_bytes_read = YLeaf(YType.uint32, "update-bytes-read")

                                    self.update_messages_in = YLeaf(YType.uint32, "update-messages-in")

                                    self.update_messages_out = YLeaf(YType.uint32, "update-messages-out")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.write_armed = YLeaf(YType.boolean, "write-armed")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self._children_name_map["message_statistics"] = "message-statistics"
                                    self._children_yang_names.add("message-statistics")

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._children_yang_names.add("performance-statistics")

                                    self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self._children_name_map["received_notification_info"] = "received-notification-info"
                                    self._children_yang_names.add("received-notification-info")

                                    self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self._children_name_map["send_notification_info"] = "send-notification-info"
                                    self._children_yang_names.add("send-notification-info")

                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-done-time-spec")

                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-phase-two-time-spec")

                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"
                                    self._children_yang_names.add("tcp-init-sync-time-spec")

                                    self.af_data = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor, ['neighbor_address', 'active_bmp_servers', 'actual_last_write_bytes', 'actual_last_write_reset_bytes', 'actual_second_last_write_bytes', 'actual_second_last_write_reset_bytes', 'attempted_last_write_bytes', 'attempted_last_write_reset_bytes', 'attempted_second_last_write_bytes', 'attempted_second_last_write_reset_bytes', 'bfd_minintervalval', 'bfd_multiplierval', 'bfd_session_created_state', 'bfd_session_enable_mode', 'bfd_session_state', 'bfd_state_ts', 'bytes_read', 'bytes_written', 'configured_hold_time', 'configured_keepalive', 'configured_min_acc_hold_time', 'connect_retry_interval', 'connection_admin_status', 'connection_down_count', 'connection_established_time', 'connection_local_port', 'connection_remote_port', 'connection_state', 'connection_up_count', 'count_last_write', 'description', 'discard_as4_path', 'discard_data_bytes', 'dmz_link_bandwidth', 'dynamic_neighbor', 'ebgp_recv_dmz', 'ebgp_send_dmz_mode', 'ebgp_time_to_live', 'egress_peer_engineering_enabled', 'error_notifies_received', 'error_notifies_sent', 'fpbsn_offset', 'fssn_offset', 'gr_restart_time', 'gr_stale_path_time', 'graceful_restart_enabled_nbr', 'has_internal_link', 'hold_time', 'ignore_connected', 'internal_vpn_client', 'io_armed', 'is4_byte_as_capability_received', 'is4_byte_as_capability_sent', 'is_administratively_shut_down', 'is_capability_negotiation_performed', 'is_capability_negotiation_suppressed', 'is_ebgp_multihop_bgp_mpls_forwarding_disabled', 'is_ebgp_peer_as_league', 'is_ebgp_peer_common_admin', 'is_external_neighbor_not_directly_connected', 'is_gr_aware', 'is_local_address_configured', 'is_neighbor_max_prefix_shutdown', 'is_out_of_memory_forced_up', 'is_out_of_memory_shutdown', 'is_passive_close', 'is_read_disabled', 'is_route_refresh_capability_received', 'is_route_refresh_old_capability_received', 'keep_alive_time', 'last_ackd_seq_no', 'last_k_aerror_reset', 'last_k_aexpiry_reset', 'last_k_anotsent_reset', 'last_k_astart_reset', 'last_notify_error_code', 'last_notify_error_subcode', 'last_write_event', 'local_as', 'local_as_dual_as', 'local_as_dual_as_mode_native', 'local_as_no_prepend', 'local_as_replace_as', 'messages_queued_in', 'messages_queued_out', 'messages_received', 'messages_sent', 'min_advertise_interval', 'min_advertise_interval_msecs', 'min_origination_interval', 'msg_log_in', 'msg_log_out', 'multi_protocol_capability_received', 'nbr_cluster_id', 'nbr_enforce_first_as', 'nbr_in_cluster', 'negotiated_protocol_version', 'neighbor_interface_handle', 'neighbor_local_as', 'nsr_enabled', 'nsr_state', 'open_check_error_code', 'peer_error_code', 'peer_reset_reason', 'previous_connection_state', 'read_armed', 'remote_as', 'remote_as_number', 'reset_notification_sent', 'reset_reason', 'router_id', 'rpki_allow_invalid', 'rpki_disable', 'rpki_signal_ibgp', 'rpki_use_validity', 'second_last_k_aexpiry_reset', 'second_last_k_astart_reset', 'second_last_write_event', 'socket_read_bytes', 'speaker_id', 'standby_rp', 'suppress4_byte_as', 'tcp_session_open_mode', 'tcpmss', 'time_last_cb', 'time_last_cb_reset', 'time_last_fb', 'time_since_connection_last_dropped', 'time_since_last_read', 'time_since_last_read_reset', 'time_since_last_update', 'time_since_last_write', 'time_since_last_write_reset', 'time_since_second_last_write', 'time_since_second_last_write_reset', 'tos_type', 'tos_value', 'ttl_security_enabled', 'update_bytes_read', 'update_messages_in', 'update_messages_out', 'vrf_name', 'write_armed'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with 
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-af-performance-statistics" : ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)}
                                        self._child_list_classes = {"extended-community" : ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity), "extended-community-standby" : ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby)}

                                        self.accept_own_enabled = YLeaf(YType.boolean, "accept-own-enabled")

                                        self.acked_version = YLeaf(YType.uint32, "acked-version")

                                        self.address_family_long_lived_time = YLeaf(YType.uint32, "address-family-long-lived-time")

                                        self.advertise_afi = YLeaf(YType.boolean, "advertise-afi")

                                        self.advertise_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-afi-def-vrf-imp-disable")

                                        self.advertise_afi_disable = YLeaf(YType.boolean, "advertise-afi-disable")

                                        self.advertise_afi_eo_r_ready = YLeaf(YType.boolean, "advertise-afi-eo-r-ready")

                                        self.advertise_afi_reorg = YLeaf(YType.boolean, "advertise-afi-reorg")

                                        self.advertise_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-afi-vrf-re-imp-disable")

                                        self.advertise_evpnv4_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-def-vrf-imp-disable")

                                        self.advertise_evpnv4_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv4-afi-vrf-re-imp-disable")

                                        self.advertise_evpnv6_afi_def_vrf_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-def-vrf-imp-disable")

                                        self.advertise_evpnv6_afi_vrf_re_imp_disable = YLeaf(YType.boolean, "advertise-evpnv6-afi-vrf-re-imp-disable")

                                        self.advertise_local_labeled_route_unicast = YLeaf(YType.boolean, "advertise-local-labeled-route-unicast")

                                        self.advertise_rt_type = YLeaf(YType.uint8, "advertise-rt-type")

                                        self.advertise_v4_flags = YLeaf(YType.uint32, "advertise-v4-flags")

                                        self.advertise_v6_flags = YLeaf(YType.uint32, "advertise-v6-flags")

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.afrpki_allow_invalid = YLeaf(YType.boolean, "afrpki-allow-invalid")

                                        self.afrpki_disable = YLeaf(YType.boolean, "afrpki-disable")

                                        self.afrpki_signal_ibgp = YLeaf(YType.boolean, "afrpki-signal-ibgp")

                                        self.afrpki_use_validity = YLeaf(YType.boolean, "afrpki-use-validity")

                                        self.allow_as_in_count = YLeaf(YType.uint32, "allow-as-in-count")

                                        self.always_use_next_hop_local = YLeaf(YType.boolean, "always-use-next-hop-local")

                                        self.enable_label_stack = YLeaf(YType.boolean, "enable-label-stack")

                                        self.encapsulation_type = YLeaf(YType.uint32, "encapsulation-type")

                                        self.eo_r_received_in_read_only = YLeaf(YType.boolean, "eo-r-received-in-read-only")

                                        self.filter_group_index = YLeaf(YType.uint32, "filter-group-index")

                                        self.flowspec_redirect_validation_d_isable = YLeaf(YType.boolean, "flowspec-redirect-validation-d-isable")

                                        self.flowspec_validation_d_isable = YLeaf(YType.boolean, "flowspec-validation-d-isable")

                                        self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                        self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                        self.import_stitching = YLeaf(YType.boolean, "import-stitching")

                                        self.is_add_path_receive_capability_advertised = YLeaf(YType.boolean, "is-add-path-receive-capability-advertised")

                                        self.is_add_path_receive_capability_received = YLeaf(YType.boolean, "is-add-path-receive-capability-received")

                                        self.is_add_path_send_capability_advertised = YLeaf(YType.boolean, "is-add-path-send-capability-advertised")

                                        self.is_add_path_send_capability_received = YLeaf(YType.boolean, "is-add-path-send-capability-received")

                                        self.is_addpath_receive_operational = YLeaf(YType.boolean, "is-addpath-receive-operational")

                                        self.is_addpath_send_operational = YLeaf(YType.boolean, "is-addpath-send-operational")

                                        self.is_advertise_permanent_network = YLeaf(YType.boolean, "is-advertise-permanent-network")

                                        self.is_advertised_graceful_restart = YLeaf(YType.boolean, "is-advertised-graceful-restart")

                                        self.is_advertised_orf_receive = YLeaf(YType.boolean, "is-advertised-orf-receive")

                                        self.is_advertised_orf_send = YLeaf(YType.boolean, "is-advertised-orf-send")

                                        self.is_aigp_set = YLeaf(YType.boolean, "is-aigp-set")

                                        self.is_allow_as_in_set = YLeaf(YType.boolean, "is-allow-as-in-set")

                                        self.is_as_override_set = YLeaf(YType.boolean, "is-as-override-set")

                                        self.is_default_originate_sent = YLeaf(YType.boolean, "is-default-originate-sent")

                                        self.is_ext_nh_encoding_capability_received = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-received")

                                        self.is_ext_nh_encoding_capability_sent = YLeaf(YType.boolean, "is-ext-nh-encoding-capability-sent")

                                        self.is_graceful_restart_state_flag = YLeaf(YType.boolean, "is-graceful-restart-state-flag")

                                        self.is_legacy_pe_rt = YLeaf(YType.boolean, "is-legacy-pe-rt")

                                        self.is_neighbor_af_capable = YLeaf(YType.boolean, "is-neighbor-af-capable")

                                        self.is_neighbor_ebgp_without_inbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-inbound-policy")

                                        self.is_neighbor_ebgp_without_outbound_policy = YLeaf(YType.boolean, "is-neighbor-ebgp-without-outbound-policy")

                                        self.is_neighbor_route_reflector_client = YLeaf(YType.boolean, "is-neighbor-route-reflector-client")

                                        self.is_orf_send_scheduled = YLeaf(YType.boolean, "is-orf-send-scheduled")

                                        self.is_orf_sent = YLeaf(YType.boolean, "is-orf-sent")

                                        self.is_orr_root_address_configured = YLeaf(YType.boolean, "is-orr-root-address-configured")

                                        self.is_peer_orf_capable = YLeaf(YType.boolean, "is-peer-orf-capable")

                                        self.is_prefix_orf_present = YLeaf(YType.boolean, "is-prefix-orf-present")

                                        self.is_received_graceful_restart_capable = YLeaf(YType.boolean, "is-received-graceful-restart-capable")

                                        self.is_received_orf_receive_capable = YLeaf(YType.boolean, "is-received-orf-receive-capable")

                                        self.is_received_orf_send_capable = YLeaf(YType.boolean, "is-received-orf-send-capable")

                                        self.is_rt_present = YLeaf(YType.boolean, "is-rt-present")

                                        self.is_rt_present_standby = YLeaf(YType.boolean, "is-rt-present-standby")

                                        self.is_send_mcast_attr = YLeaf(YType.boolean, "is-send-mcast-attr")

                                        self.is_soft_reconfiguration_inbound_allowed = YLeaf(YType.boolean, "is-soft-reconfiguration-inbound-allowed")

                                        self.is_update_deferred = YLeaf(YType.boolean, "is-update-deferred")

                                        self.is_update_leaving = YLeaf(YType.boolean, "is-update-leaving")

                                        self.is_update_throttled = YLeaf(YType.boolean, "is-update-throttled")

                                        self.is_use_soft_reconfiguration_always_on = YLeaf(YType.boolean, "is-use-soft-reconfiguration-always-on")

                                        self.local_restart_time = YLeaf(YType.uint32, "local-restart-time")

                                        self.long_lived_graceful_restart_capability_received = YLeaf(YType.boolean, "long-lived-graceful-restart-capability-received")

                                        self.long_lived_graceful_restart_stale_time_accept = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-accept")

                                        self.long_lived_graceful_restart_stale_time_configured = YLeaf(YType.boolean, "long-lived-graceful-restart-stale-time-configured")

                                        self.long_lived_graceful_restart_stale_time_received = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-received")

                                        self.long_lived_graceful_restart_stale_time_sent = YLeaf(YType.uint32, "long-lived-graceful-restart-stale-time-sent")

                                        self.max_prefix_discard_extra_paths = YLeaf(YType.boolean, "max-prefix-discard-extra-paths")

                                        self.max_prefix_exceed_discard_paths = YLeaf(YType.boolean, "max-prefix-exceed-discard-paths")

                                        self.max_prefix_limit = YLeaf(YType.uint32, "max-prefix-limit")

                                        self.max_prefix_restart_time = YLeaf(YType.uint16, "max-prefix-restart-time")

                                        self.max_prefix_threshold_percent = YLeaf(YType.uint8, "max-prefix-threshold-percent")

                                        self.neighbor_default_originate = YLeaf(YType.boolean, "neighbor-default-originate")

                                        self.neighbor_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-long-lived-graceful-restart-capable")

                                        self.neighbor_long_lived_graceful_restart_time_remaining = YLeaf(YType.uint32, "neighbor-long-lived-graceful-restart-time-remaining")

                                        self.neighbor_preserved_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-forwarding-state")

                                        self.neighbor_preserved_long_lived_forwarding_state = YLeaf(YType.boolean, "neighbor-preserved-long-lived-forwarding-state")

                                        self.neighbor_version = YLeaf(YType.uint32, "neighbor-version")

                                        self.number_of_best_externalpaths = YLeaf(YType.uint32, "number-of-best-externalpaths")

                                        self.number_of_bestpaths = YLeaf(YType.uint32, "number-of-bestpaths")

                                        self.orf_entries_received = YLeaf(YType.uint32, "orf-entries-received")

                                        self.orr_group_index = YLeaf(YType.uint32, "orr-group-index")

                                        self.orr_group_name = YLeaf(YType.str, "orr-group-name")

                                        self.outstanding_version = YLeaf(YType.uint32, "outstanding-version")

                                        self.outstanding_version_max = YLeaf(YType.uint32, "outstanding-version-max")

                                        self.prefixes_accepted = YLeaf(YType.uint32, "prefixes-accepted")

                                        self.prefixes_advertised = YLeaf(YType.uint32, "prefixes-advertised")

                                        self.prefixes_be_advertised = YLeaf(YType.uint32, "prefixes-be-advertised")

                                        self.prefixes_denied = YLeaf(YType.uint32, "prefixes-denied")

                                        self.prefixes_denied_no_policy = YLeaf(YType.uint32, "prefixes-denied-no-policy")

                                        self.prefixes_denied_non_cumulative = YLeaf(YType.uint32, "prefixes-denied-non-cumulative")

                                        self.prefixes_denied_orf_policy = YLeaf(YType.uint32, "prefixes-denied-orf-policy")

                                        self.prefixes_denied_policy = YLeaf(YType.uint32, "prefixes-denied-policy")

                                        self.prefixes_denied_rt_permit = YLeaf(YType.uint32, "prefixes-denied-rt-permit")

                                        self.prefixes_suppressed = YLeaf(YType.uint32, "prefixes-suppressed")

                                        self.prefixes_synced = YLeaf(YType.uint32, "prefixes-synced")

                                        self.prefixes_withdrawn = YLeaf(YType.uint32, "prefixes-withdrawn")

                                        self.prefixes_withdrawn_not_found = YLeaf(YType.uint32, "prefixes-withdrawn-not-found")

                                        self.refresh_acked_version = YLeaf(YType.uint32, "refresh-acked-version")

                                        self.refresh_target_version = YLeaf(YType.uint32, "refresh-target-version")

                                        self.refresh_version = YLeaf(YType.uint32, "refresh-version")

                                        self.remove_private_as_entire_aspath_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-inbound-updates")

                                        self.remove_private_as_entire_aspath_from_updates = YLeaf(YType.boolean, "remove-private-as-entire-aspath-from-updates")

                                        self.remove_private_as_from_inbound_updates = YLeaf(YType.boolean, "remove-private-as-from-inbound-updates")

                                        self.remove_private_as_from_updates = YLeaf(YType.boolean, "remove-private-as-from-updates")

                                        self.restart_time = YLeaf(YType.uint32, "restart-time")

                                        self.rib_purge_timeout_value = YLeaf(YType.uint32, "rib-purge-timeout-value")

                                        self.route_policy_default_originate = YLeaf(YType.str, "route-policy-default-originate")

                                        self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                        self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                        self.route_policy_prefix_orf = YLeaf(YType.str, "route-policy-prefix-orf")

                                        self.route_refreshes_received = YLeaf(YType.uint32, "route-refreshes-received")

                                        self.route_refreshes_sent = YLeaf(YType.uint32, "route-refreshes-sent")

                                        self.selective_multipath_eligible = YLeaf(YType.boolean, "selective-multipath-eligible")

                                        self.sent_community_to_neighbor = YLeaf(YType.boolean, "sent-community-to-neighbor")

                                        self.sent_extended_community_to_neighbor = YLeaf(YType.boolean, "sent-extended-community-to-neighbor")

                                        self.sent_gshut_community_to_neighbor = YLeaf(YType.boolean, "sent-gshut-community-to-neighbor")

                                        self.stale_path_timeout = YLeaf(YType.uint32, "stale-path-timeout")

                                        self.synced_acked_version = YLeaf(YType.uint32, "synced-acked-version")

                                        self.update_group_number = YLeaf(YType.uint32, "update-group-number")

                                        self.use_max_prefix_warning_only = YLeaf(YType.boolean, "use-max-prefix-warning-only")

                                        self.vpn_update_gen_enabled = YLeaf(YType.boolean, "vpn-update-gen-enabled")

                                        self.vpn_update_gen_trigger_enabled = YLeaf(YType.boolean, "vpn-update-gen-trigger-enabled")

                                        self.weight = YLeaf(YType.uint32, "weight")

                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"
                                        self._children_yang_names.add("neighbor-af-performance-statistics")

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData, ['accept_own_enabled', 'acked_version', 'address_family_long_lived_time', 'advertise_afi', 'advertise_afi_def_vrf_imp_disable', 'advertise_afi_disable', 'advertise_afi_eo_r_ready', 'advertise_afi_reorg', 'advertise_afi_vrf_re_imp_disable', 'advertise_evpnv4_afi_def_vrf_imp_disable', 'advertise_evpnv4_afi_vrf_re_imp_disable', 'advertise_evpnv6_afi_def_vrf_imp_disable', 'advertise_evpnv6_afi_vrf_re_imp_disable', 'advertise_local_labeled_route_unicast', 'advertise_rt_type', 'advertise_v4_flags', 'advertise_v6_flags', 'af_name', 'afrpki_allow_invalid', 'afrpki_disable', 'afrpki_signal_ibgp', 'afrpki_use_validity', 'allow_as_in_count', 'always_use_next_hop_local', 'enable_label_stack', 'encapsulation_type', 'eo_r_received_in_read_only', 'filter_group_index', 'flowspec_redirect_validation_d_isable', 'flowspec_validation_d_isable', 'import_reoriginate', 'import_reoriginate_stitching', 'import_stitching', 'is_add_path_receive_capability_advertised', 'is_add_path_receive_capability_received', 'is_add_path_send_capability_advertised', 'is_add_path_send_capability_received', 'is_addpath_receive_operational', 'is_addpath_send_operational', 'is_advertise_permanent_network', 'is_advertised_graceful_restart', 'is_advertised_orf_receive', 'is_advertised_orf_send', 'is_aigp_set', 'is_allow_as_in_set', 'is_as_override_set', 'is_default_originate_sent', 'is_ext_nh_encoding_capability_received', 'is_ext_nh_encoding_capability_sent', 'is_graceful_restart_state_flag', 'is_legacy_pe_rt', 'is_neighbor_af_capable', 'is_neighbor_ebgp_without_inbound_policy', 'is_neighbor_ebgp_without_outbound_policy', 'is_neighbor_route_reflector_client', 'is_orf_send_scheduled', 'is_orf_sent', 'is_orr_root_address_configured', 'is_peer_orf_capable', 'is_prefix_orf_present', 'is_received_graceful_restart_capable', 'is_received_orf_receive_capable', 'is_received_orf_send_capable', 'is_rt_present', 'is_rt_present_standby', 'is_send_mcast_attr', 'is_soft_reconfiguration_inbound_allowed', 'is_update_deferred', 'is_update_leaving', 'is_update_throttled', 'is_use_soft_reconfiguration_always_on', 'local_restart_time', 'long_lived_graceful_restart_capability_received', 'long_lived_graceful_restart_stale_time_accept', 'long_lived_graceful_restart_stale_time_configured', 'long_lived_graceful_restart_stale_time_received', 'long_lived_graceful_restart_stale_time_sent', 'max_prefix_discard_extra_paths', 'max_prefix_exceed_discard_paths', 'max_prefix_limit', 'max_prefix_restart_time', 'max_prefix_threshold_percent', 'neighbor_default_originate', 'neighbor_long_lived_graceful_restart_capable', 'neighbor_long_lived_graceful_restart_time_remaining', 'neighbor_preserved_forwarding_state', 'neighbor_preserved_long_lived_forwarding_state', 'neighbor_version', 'number_of_best_externalpaths', 'number_of_bestpaths', 'orf_entries_received', 'orr_group_index', 'orr_group_name', 'outstanding_version', 'outstanding_version_max', 'prefixes_accepted', 'prefixes_advertised', 'prefixes_be_advertised', 'prefixes_denied', 'prefixes_denied_no_policy', 'prefixes_denied_non_cumulative', 'prefixes_denied_orf_policy', 'prefixes_denied_policy', 'prefixes_denied_rt_permit', 'prefixes_suppressed', 'prefixes_synced', 'prefixes_withdrawn', 'prefixes_withdrawn_not_found', 'refresh_acked_version', 'refresh_target_version', 'refresh_version', 'remove_private_as_entire_aspath_from_inbound_updates', 'remove_private_as_entire_aspath_from_updates', 'remove_private_as_from_inbound_updates', 'remove_private_as_from_updates', 'restart_time', 'rib_purge_timeout_value', 'route_policy_default_originate', 'route_policy_in', 'route_policy_out', 'route_policy_prefix_orf', 'route_refreshes_received', 'route_refreshes_sent', 'selective_multipath_eligible', 'sent_community_to_neighbor', 'sent_extended_community_to_neighbor', 'sent_gshut_community_to_neighbor', 'stale_path_timeout', 'synced_acked_version', 'update_group_number', 'use_max_prefix_warning_only', 'vpn_update_gen_enabled', 'vpn_update_gen_trigger_enabled', 'weight'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, ['entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "extended-community-standby"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, ['entry'], name, value)


                                    class NeighborAfPerformanceStatistics(Entity):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                            self.yang_name = "neighbor-af-performance-statistics"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.processed_messages = YLeaf(YType.uint32, "processed-messages")

                                            self.sent_messages = YLeaf(YType.uint32, "sent-messages")

                                            self.split_horizon_update_blocked = YLeaf(YType.uint32, "split-horizon-update-blocked")

                                            self.split_horizon_update_transmit = YLeaf(YType.uint32, "split-horizon-update-transmit")

                                            self.split_horizon_withdraw_blocked = YLeaf(YType.uint32, "split-horizon-withdraw-blocked")

                                            self.split_horizon_withdraw_transmit = YLeaf(YType.uint32, "split-horizon-withdraw-transmit")

                                            self.sub_group_pending_message_count = YLeaf(YType.uint32, "sub-group-pending-message-count")
                                            self._segment_path = lambda: "neighbor-af-performance-statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, ['processed_messages', 'sent_messages', 'split_horizon_update_blocked', 'split_horizon_update_transmit', 'split_horizon_withdraw_blocked', 'split_horizon_withdraw_transmit', 'sub_group_pending_message_count'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.gshut_active = YLeaf(YType.boolean, "gshut-active")

                                        self.gshut_exists = YLeaf(YType.boolean, "gshut-exists")

                                        self.gshut_local_active = YLeaf(YType.boolean, "gshut-local-active")

                                        self.gshut_locpref = YLeaf(YType.uint32, "gshut-locpref")

                                        self.gshut_locpref_set = YLeaf(YType.boolean, "gshut-locpref-set")

                                        self.gshut_prepends = YLeaf(YType.uint8, "gshut-prepends")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, ['gshut_active', 'gshut_exists', 'gshut_local_active', 'gshut_locpref', 'gshut_locpref_set', 'gshut_prepends'], name, value)


                                class MessageStatistics(Entity):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                        self.yang_name = "message-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"keepalive" : ("keepalive", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive), "notification" : ("notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification), "open" : ("open", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open), "route-refresh" : ("route_refresh", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh), "total" : ("total", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total), "update" : ("update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update)}
                                        self._child_list_classes = {}

                                        self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self._children_name_map["keepalive"] = "keepalive"
                                        self._children_yang_names.add("keepalive")

                                        self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self._children_name_map["notification"] = "notification"
                                        self._children_yang_names.add("notification")

                                        self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self._children_name_map["open"] = "open"
                                        self._children_yang_names.add("open")

                                        self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self._children_name_map["route_refresh"] = "route-refresh"
                                        self._children_yang_names.add("route-refresh")

                                        self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self._children_name_map["total"] = "total"
                                        self._children_yang_names.add("total")

                                        self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self
                                        self._children_name_map["update"] = "update"
                                        self._children_yang_names.add("update")
                                        self._segment_path = lambda: "message-statistics"


                                    class Keepalive(Entity):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                            self.yang_name = "keepalive"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "keepalive"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Notification(Entity):
                                        """
                                        Notification
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                            self.yang_name = "notification"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "notification"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Open(Entity):
                                        """
                                        Open
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                            self.yang_name = "open"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "open"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class RouteRefresh(Entity):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                            self.yang_name = "route-refresh"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "route-refresh"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Total(Entity):
                                        """
                                        Total
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                            self.yang_name = "total"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "total"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                    class Update(Entity):
                                        """
                                        Update
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                            self.yang_name = "update"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"rx" : ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx), "tx" : ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)}
                                            self._child_list_classes = {}

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._children_yang_names.add("rx")

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"
                                            self._children_yang_names.add("tx")
                                            self._segment_path = lambda: "update"


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "rx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"last-time-spec" : ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec)}
                                                self._child_list_classes = {}

                                                self.count = YLeaf(YType.uint32, "count")

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._children_yang_names.add("last-time-spec")
                                                self._segment_path = lambda: "tx"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, ['count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                                    self._segment_path = lambda: "last-time-spec"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.active_collision = YLeaf(YType.uint32, "active-collision")

                                        self.actives = YLeaf(YType.uint32, "actives")

                                        self.control_to_read_thread_trigger = YLeaf(YType.uint32, "control-to-read-thread-trigger")

                                        self.control_to_write_thread_trigger = YLeaf(YType.uint32, "control-to-write-thread-trigger")

                                        self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                        self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                        self.failed_post_actives = YLeaf(YType.uint32, "failed-post-actives")

                                        self.high_throttled_read = YLeaf(YType.uint32, "high-throttled-read")

                                        self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                        self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                        self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                        self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                        self.last_nsr_scoped_sync = YLeaf(YType.uint32, "last-nsr-scoped-sync")

                                        self.last_sent_seq_no = YLeaf(YType.uint32, "last-sent-seq-no")

                                        self.low_throttled_read = YLeaf(YType.uint32, "low-throttled-read")

                                        self.maximum_read_size = YLeaf(YType.uint32, "maximum-read-size")

                                        self.nbr_fd = YLeaf(YType.int32, "nbr-fd")

                                        self.nbr_flags = YLeaf(YType.uint32, "nbr-flags")

                                        self.network_status = YLeaf(YType.uint32, "network-status")

                                        self.nsr_oper_down_count = YLeaf(YType.uint32, "nsr-oper-down-count")

                                        self.passive_collision = YLeaf(YType.uint32, "passive-collision")

                                        self.passives = YLeaf(YType.uint32, "passives")

                                        self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                        self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                        self.read_throttles = YLeaf(YType.uint32, "read-throttles")

                                        self.rejected_passives = YLeaf(YType.uint32, "rejected-passives")

                                        self.reset_flags = YLeaf(YType.uint32, "reset-flags")

                                        self.reset_retries = YLeaf(YType.uint8, "reset-retries")

                                        self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                        self.sync_flags = YLeaf(YType.uint32, "sync-flags")

                                        self.time_since_last_throttled_read = YLeaf(YType.uint32, "time-since-last-throttled-read")

                                        self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                        self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                        self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                        self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                        self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                        self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                        self._segment_path = lambda: "performance-statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, ['active_collision', 'actives', 'control_to_read_thread_trigger', 'control_to_write_thread_trigger', 'data_bytes_read', 'data_bytes_written', 'failed_post_actives', 'high_throttled_read', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'last_nsr_scoped_sync', 'last_sent_seq_no', 'low_throttled_read', 'maximum_read_size', 'nbr_fd', 'nbr_flags', 'network_status', 'nsr_oper_down_count', 'passive_collision', 'passives', 'read_calls_count', 'read_messages_count', 'read_throttles', 'rejected_passives', 'reset_flags', 'reset_retries', 'subgroup_list_time', 'sync_flags', 'time_since_last_throttled_read', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                                class ReceivedNotificationInfo(Entity):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                        self.yang_name = "received-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "received-notification-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "received-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, ['entry'], name, value)


                                class SendNotificationInfo(Entity):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                        self.yang_name = "send-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData)}

                                        self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                        self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                        self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "send-notification-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "send-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "last-notification-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, ['entry'], name, value)


                                class TcpInitSyncDoneTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-done-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-done-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, ['nanoseconds', 'seconds'], name, value)


                                class TcpInitSyncTimeSpec(Entity):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "tcp-init-sync-time-spec"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, ['nanoseconds', 'seconds'], name, value)


                        class NextHopVrf(Entity):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf, self).__init__()

                                self.yang_name = "next-hop-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.last_notification_processing_time = YLeaf(YType.uint32, "last-notification-processing-time")

                                self.last_notificationication_time = YLeaf(YType.uint32, "last-notificationication-time")

                                self.max_notification_bestpath_changes = YLeaf(YType.uint32, "max-notification-bestpath-changes")

                                self.max_notification_bestpath_deletes = YLeaf(YType.uint32, "max-notification-bestpath-deletes")

                                self.max_proc_notification_time = YLeaf(YType.uint32, "max-proc-notification-time")

                                self.maximum_processing_time = YLeaf(YType.uint32, "maximum-processing-time")

                                self.total_processing_time = YLeaf(YType.uint32, "total-processing-time")
                                self._segment_path = lambda: "next-hop-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf, ['last_notification_processing_time', 'last_notificationication_time', 'max_notification_bestpath_changes', 'max_notification_bestpath_deletes', 'max_proc_notification_time', 'maximum_processing_time', 'total_processing_time'], name, value)


                        class Postits(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits, self).__init__()

                                self.yang_name = "postits"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"postit" : ("postit", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit)}

                                self.postit = YList(self)
                                self._segment_path = lambda: "postits"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits, [], name, value)


                            class Postit(Entity):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit, self).__init__()

                                    self.yang_name = "postit"
                                    self.yang_parent_name = "postits"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbors-address" : ("neighbors_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress)}
                                    self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf), "postit-info" : ("postit_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.connect_state = YLeaf(YType.uint32, "connect-state")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.start_time = YLeaf(YType.uint32, "start-time")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self._children_name_map["neighbors_address"] = "neighbors-address"
                                    self._children_yang_names.add("neighbors-address")

                                    self.neighbor_af = YList(self)
                                    self.postit_info = YList(self)
                                    self._segment_path = lambda: "postit" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit, ['neighbor_address', 'connect_state', 'nsr_state', 'start_time', 'vrf_name'], name, value)


                                class NeighborAf(Entity):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf, self).__init__()

                                        self.yang_name = "neighbor-af"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.boolean, "entry")
                                        self._segment_path = lambda: "neighbor-af"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf, ['entry'], name, value)


                                class NeighborsAddress(Entity):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress, self).__init__()

                                        self.yang_name = "neighbors-address"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "neighbors-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class PostitInfo(Entity):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\:  str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo, self).__init__()

                                        self.yang_name = "postit-info"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"postit-notification" : ("postit_notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification)}
                                        self._child_list_classes = {}

                                        self.peer_id = YLeaf(YType.uint32, "peer-id")

                                        self.postit_af_name = YLeaf(YType.enumeration, "postit-af-name")

                                        self.postit_direction = YLeaf(YType.uint8, "postit-direction")

                                        self.postit_flags = YLeaf(YType.uint8, "postit-flags")

                                        self.postit_id = YLeaf(YType.uint32, "postit-id")

                                        self.postit_policy = YLeaf(YType.str, "postit-policy")

                                        self.postit_reset = YLeaf(YType.enumeration, "postit-reset")

                                        self.postit_subtype = YLeaf(YType.uint32, "postit-subtype")

                                        self.postit_ts = YLeaf(YType.uint64, "postit-ts")

                                        self.postit_type = YLeaf(YType.uint32, "postit-type")

                                        self.postit_notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self._children_name_map["postit_notification"] = "postit-notification"
                                        self._children_yang_names.add("postit-notification")
                                        self._segment_path = lambda: "postit-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo, ['peer_id', 'postit_af_name', 'postit_direction', 'postit_flags', 'postit_id', 'postit_policy', 'postit_reset', 'postit_subtype', 'postit_ts', 'postit_type'], name, value)


                                    class PostitNotification(Entity):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                            self.yang_name = "postit-notification"
                                            self.yang_parent_name = "postit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"last-notification-data" : ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData)}

                                            self.notification_error_code = YLeaf(YType.uint8, "notification-error-code")

                                            self.notification_error_subcode = YLeaf(YType.uint8, "notification-error-subcode")

                                            self.time_since_last_notification = YLeaf(YType.uint32, "time-since-last-notification")

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "postit-notification"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, ['notification_error_code', 'notification_error_subcode', 'time_since_last_notification'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "postit-notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint8, "entry")
                                                self._segment_path = lambda: "last-notification-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, ['entry'], name, value)


                        class ProcessInfo(Entity):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo, self).__init__()

                                self.yang_name = "process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_), "performance-statistics" : ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf)}
                                self._child_list_classes = {}

                                self.process_instance = YLeaf(YType.uint8, "process-instance")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.vrf_totals = YLeaf(YType.boolean, "vrf-totals")

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"
                                self._children_yang_names.add("global")

                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._children_yang_names.add("performance-statistics")

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._children_yang_names.add("vrf")
                                self._segment_path = lambda: "process-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo, ['process_instance', 'vrf_name', 'vrf_totals'], name, value)


                            class Global_(Entity):
                                """
                                Global information
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize>`
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: large_community_entry_count
                                
                                	Number of large community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_memory
                                
                                	Memory (in bytes) used by large community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize>`
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount>`
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize>`
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\:  str
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"bmp-pool-alloc-count" : ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount), "bmp-pool-free-count" : ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount), "bmp-pool-size" : ("bmp_pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize), "msg-log-pool-alloc-count" : ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount), "msg-log-pool-free-count" : ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount), "msg-log-pool-size" : ("msg_log_pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize), "pool-alloc-count" : ("pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount), "pool-free-count" : ("pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount), "pool-size" : ("pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize)}

                                    self.as_path_entries_memory = YLeaf(YType.uint32, "as-path-entries-memory")

                                    self.as_path_entry_count = YLeaf(YType.uint32, "as-path-entry-count")

                                    self.attr_set_entry_count = YLeaf(YType.uint32, "attr-set-entry-count")

                                    self.attr_set_memory = YLeaf(YType.uint32, "attr-set-memory")

                                    self.community_entry_count = YLeaf(YType.uint32, "community-entry-count")

                                    self.community_memory = YLeaf(YType.uint32, "community-memory")

                                    self.established_neighbors_count_total = YLeaf(YType.uint32, "established-neighbors-count-total")

                                    self.extended_community_entry_count = YLeaf(YType.uint32, "extended-community-entry-count")

                                    self.extended_community_memory = YLeaf(YType.uint32, "extended-community-memory")

                                    self.large_community_entry_count = YLeaf(YType.uint32, "large-community-entry-count")

                                    self.large_community_memory = YLeaf(YType.uint32, "large-community-memory")

                                    self.lindex_entry_count = YLeaf(YType.uint32, "lindex-entry-count")

                                    self.lindex_memory = YLeaf(YType.uint32, "lindex-memory")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.lsattr_entry_count = YLeaf(YType.uint32, "lsattr-entry-count")

                                    self.lsattr_memory = YLeaf(YType.uint32, "lsattr-memory")

                                    self.neighbors_count_total = YLeaf(YType.uint32, "neighbors-count-total")

                                    self.nexthop_count = YLeaf(YType.uint32, "nexthop-count")

                                    self.nexthop_memory = YLeaf(YType.uint32, "nexthop-memory")

                                    self.path_attribute_memory = YLeaf(YType.uint32, "path-attribute-memory")

                                    self.path_attributes_entry_count = YLeaf(YType.uint32, "path-attributes-entry-count")

                                    self.pe_distinguisher_label_entry_count = YLeaf(YType.uint32, "pe-distinguisher-label-entry-count")

                                    self.pe_distinguisher_label_memory = YLeaf(YType.uint32, "pe-distinguisher-label-memory")

                                    self.ppmp_entry_count = YLeaf(YType.uint32, "ppmp-entry-count")

                                    self.ppmp_memory = YLeaf(YType.uint32, "ppmp-memory")

                                    self.process_instance_node = YLeaf(YType.str, "process-instance-node")

                                    self.pta_entry_count = YLeaf(YType.uint32, "pta-entry-count")

                                    self.pta_memory = YLeaf(YType.uint32, "pta-memory")

                                    self.restart_count = YLeaf(YType.uint32, "restart-count")

                                    self.ribrnh_entry_count = YLeaf(YType.uint32, "ribrnh-entry-count")

                                    self.ribrnh_memory = YLeaf(YType.uint32, "ribrnh-memory")

                                    self.route_reflector_memory = YLeaf(YType.uint32, "route-reflector-memory")

                                    self.route_reflectors = YLeaf(YType.uint32, "route-reflectors")

                                    self.sn_num_non_dflt_vrf_nbrs = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs")

                                    self.sn_num_non_dflt_vrf_nbrs_estab = YLeaf(YType.uint32, "sn-num-non-dflt-vrf-nbrs-estab")

                                    self.total_vrf_count = YLeaf(YType.uint32, "total-vrf-count")

                                    self.tunnel_encap_entry_count = YLeaf(YType.uint32, "tunnel-encap-entry-count")

                                    self.tunnel_encap_memory = YLeaf(YType.uint32, "tunnel-encap-memory")

                                    self.bmp_pool_alloc_count = YList(self)
                                    self.bmp_pool_free_count = YList(self)
                                    self.bmp_pool_size = YList(self)
                                    self.msg_log_pool_alloc_count = YList(self)
                                    self.msg_log_pool_free_count = YList(self)
                                    self.msg_log_pool_size = YList(self)
                                    self.pool_alloc_count = YList(self)
                                    self.pool_free_count = YList(self)
                                    self.pool_size = YList(self)
                                    self._segment_path = lambda: "global"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_, ['as_path_entries_memory', 'as_path_entry_count', 'attr_set_entry_count', 'attr_set_memory', 'community_entry_count', 'community_memory', 'established_neighbors_count_total', 'extended_community_entry_count', 'extended_community_memory', 'large_community_entry_count', 'large_community_memory', 'lindex_entry_count', 'lindex_memory', 'local_as', 'lsattr_entry_count', 'lsattr_memory', 'neighbors_count_total', 'nexthop_count', 'nexthop_memory', 'path_attribute_memory', 'path_attributes_entry_count', 'pe_distinguisher_label_entry_count', 'pe_distinguisher_label_memory', 'ppmp_entry_count', 'ppmp_memory', 'process_instance_node', 'pta_entry_count', 'pta_memory', 'restart_count', 'ribrnh_entry_count', 'ribrnh_memory', 'route_reflector_memory', 'route_reflectors', 'sn_num_non_dflt_vrf_nbrs', 'sn_num_non_dflt_vrf_nbrs_estab', 'total_vrf_count', 'tunnel_encap_entry_count', 'tunnel_encap_memory'], name, value)


                                class BmpPoolAllocCount(Entity):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount, self).__init__()

                                        self.yang_name = "bmp-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount, ['entry'], name, value)


                                class BmpPoolFreeCount(Entity):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount, self).__init__()

                                        self.yang_name = "bmp-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount, ['entry'], name, value)


                                class BmpPoolSize(Entity):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize, self).__init__()

                                        self.yang_name = "bmp-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "bmp-pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize, ['entry'], name, value)


                                class MsgLogPoolAllocCount(Entity):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount, self).__init__()

                                        self.yang_name = "msg-log-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount, ['entry'], name, value)


                                class MsgLogPoolFreeCount(Entity):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount, self).__init__()

                                        self.yang_name = "msg-log-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount, ['entry'], name, value)


                                class MsgLogPoolSize(Entity):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize, self).__init__()

                                        self.yang_name = "msg-log-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "msg-log-pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize, ['entry'], name, value)


                                class PoolAllocCount(Entity):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount, self).__init__()

                                        self.yang_name = "pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-alloc-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount, ['entry'], name, value)


                                class PoolFreeCount(Entity):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount, self).__init__()

                                        self.yang_name = "pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-free-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount, ['entry'], name, value)


                                class PoolSize(Entity):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize, self).__init__()

                                        self.yang_name = "pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "pool-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize, ['entry'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"global" : ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_), "vrf" : ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf)}
                                    self._child_list_classes = {}

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"
                                    self._children_yang_names.add("global")

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._children_yang_names.add("vrf")
                                    self._segment_path = lambda: "performance-statistics"


                                class Global_(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\:  bool
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:   :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\:  bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\:  bool
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ds-npl" : ("ds_npl", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl), "ipv4rib-server" : ("ipv4rib_server", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer), "ipv6rib-server" : ("ipv6rib_server", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer), "lsd-connection" : ("lsd_connection", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection), "te-connection" : ("te_connection", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection)}
                                        self._child_list_classes = {"active-nsr-mode-enter-time" : ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime), "active-nsrfo-time" : ("active_nsrfo_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime), "issu-milestone" : ("issu_milestone", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone), "postit-count-info" : ("postit_count_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo), "standby-nsr-mode-enter-time" : ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime)}

                                        self.active_nsr_state = YLeaf(YType.uint32, "active-nsr-state")

                                        self.active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "active-nsrtcp-phase-two-enter-time")

                                        self.brib_api_input_bytes = YLeaf(YType.uint32, "brib-api-input-bytes")

                                        self.brib_api_input_messages = YLeaf(YType.uint32, "brib-api-input-messages")

                                        self.brib_api_input_prefixes_received = YLeaf(YType.uint32, "brib-api-input-prefixes-received")

                                        self.brib_api_input_processing_time = YLeaf(YType.uint32, "brib-api-input-processing-time")

                                        self.brib_api_input_withdrawn_prefixes = YLeaf(YType.uint32, "brib-api-input-withdrawn-prefixes")

                                        self.brib_api_output_bytes_generated = YLeaf(YType.uint32, "brib-api-output-bytes-generated")

                                        self.brib_api_output_bytes_sent = YLeaf(YType.uint32, "brib-api-output-bytes-sent")

                                        self.brib_api_output_calls = YLeaf(YType.uint32, "brib-api-output-calls")

                                        self.brib_api_output_generation_time = YLeaf(YType.uint32, "brib-api-output-generation-time")

                                        self.brib_api_output_messages_sent = YLeaf(YType.uint32, "brib-api-output-messages-sent")

                                        self.brib_api_output_prefixes_advertised = YLeaf(YType.uint32, "brib-api-output-prefixes-advertised")

                                        self.brib_api_output_prefixes_withdrawn = YLeaf(YType.uint32, "brib-api-output-prefixes-withdrawn")

                                        self.brib_api_output_sending_time = YLeaf(YType.uint32, "brib-api-output-sending-time")

                                        self.configuration_items_processed = YLeaf(YType.uint32, "configuration-items-processed")

                                        self.configuration_processing_time = YLeaf(YType.uint32, "configuration-processing-time")

                                        self.current_clock_time = YLeaf(YType.uint64, "current-clock-time")

                                        self.edm_processing_time = YLeaf(YType.uint32, "edm-processing-time")

                                        self.edm_requests_count = YLeaf(YType.uint32, "edm-requests-count")

                                        self.in_event_attach_calls = YLeaf(YType.uint32, "in-event-attach-calls")

                                        self.in_out_event_attach_calls = YLeaf(YType.uint32, "in-out-event-attach-calls")

                                        self.initial_sync_sessions_added = YLeaf(YType.boolean, "initial-sync-sessions-added")

                                        self.instance_node_role = YLeaf(YType.boolean, "instance-node-role")

                                        self.io_handler_tm = YLeaf(YType.uint64, "io-handler-tm")

                                        self.io_timer_id = YLeaf(YType.uint32, "io-timer-id")

                                        self.io_tree_timer_expiry = YLeaf(YType.uint64, "io-tree-timer-expiry")

                                        self.io_tree_timer_left = YLeaf(YType.uint64, "io-tree-timer-left")

                                        self.nsr_last_reset_reason = YLeaf(YType.uint8, "nsr-last-reset-reason")

                                        self.out_event_attach_calls = YLeaf(YType.uint32, "out-event-attach-calls")

                                        self.proc_scoped_sync_state = YLeaf(YType.enumeration, "proc-scoped-sync-state")

                                        self.qad_ac_ks_failure = YLeaf(YType.uint32, "qad-ac-ks-failure")

                                        self.qad_ac_ks_received = YLeaf(YType.uint32, "qad-ac-ks-received")

                                        self.qad_init_drops = YLeaf(YType.uint32, "qad-init-drops")

                                        self.qad_messages_received = YLeaf(YType.uint32, "qad-messages-received")

                                        self.qad_messages_sent = YLeaf(YType.uint32, "qad-messages-sent")

                                        self.qad_processed = YLeaf(YType.uint32, "qad-processed")

                                        self.qad_recv_drops = YLeaf(YType.uint32, "qad-recv-drops")

                                        self.qad_resumes = YLeaf(YType.uint32, "qad-resumes")

                                        self.qad_send_drops = YLeaf(YType.uint32, "qad-send-drops")

                                        self.qad_send_failure = YLeaf(YType.uint32, "qad-send-failure")

                                        self.qad_suspends = YLeaf(YType.uint32, "qad-suspends")

                                        self.qad_timeout_received = YLeaf(YType.uint32, "qad-timeout-received")

                                        self.qad_timeout_recvd = YLeaf(YType.uint32, "qad-timeout-recvd")

                                        self.qadack_sent = YLeaf(YType.uint32, "qadack-sent")

                                        self.qadoos_drops = YLeaf(YType.uint32, "qadoos-drops")

                                        self.redcon_nsr_ready = YLeaf(YType.boolean, "redcon-nsr-ready")

                                        self.redcon_state_time = YLeaf(YType.uint32, "redcon-state-time")

                                        self.sec_active_nsr_state = YLeaf(YType.uint32, "sec-active-nsr-state")

                                        self.sec_active_nsrtcp_phase_two_enter_time = YLeaf(YType.uint32, "sec-active-nsrtcp-phase-two-enter-time")

                                        self.tep2p_auto_tunnel_enabled = YLeaf(YType.boolean, "tep2p-auto-tunnel-enabled")

                                        self.total_neighbors_with_pending_postits = YLeaf(YType.uint32, "total-neighbors-with-pending-postits")

                                        self.total_outstanding_postits = YLeaf(YType.uint32, "total-outstanding-postits")

                                        self.updgen_handler_tm = YLeaf(YType.uint64, "updgen-handler-tm")

                                        self.updgen_timer_id = YLeaf(YType.uint32, "updgen-timer-id")

                                        self.updgen_tree_timer_expiry = YLeaf(YType.uint64, "updgen-tree-timer-expiry")

                                        self.updgen_tree_timer_left = YLeaf(YType.uint64, "updgen-tree-timer-left")

                                        self.ds_npl = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                        self.ds_npl.parent = self
                                        self._children_name_map["ds_npl"] = "ds-npl"
                                        self._children_yang_names.add("ds-npl")

                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                        self.ipv4rib_server.parent = self
                                        self._children_name_map["ipv4rib_server"] = "ipv4rib-server"
                                        self._children_yang_names.add("ipv4rib-server")

                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                        self.ipv6rib_server.parent = self
                                        self._children_name_map["ipv6rib_server"] = "ipv6rib-server"
                                        self._children_yang_names.add("ipv6rib-server")

                                        self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self._children_name_map["lsd_connection"] = "lsd-connection"
                                        self._children_yang_names.add("lsd-connection")

                                        self.te_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                        self.te_connection.parent = self
                                        self._children_name_map["te_connection"] = "te-connection"
                                        self._children_yang_names.add("te-connection")

                                        self.active_nsr_mode_enter_time = YList(self)
                                        self.active_nsrfo_time = YList(self)
                                        self.issu_milestone = YList(self)
                                        self.postit_count_info = YList(self)
                                        self.standby_nsr_mode_enter_time = YList(self)
                                        self._segment_path = lambda: "global"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_, ['active_nsr_state', 'active_nsrtcp_phase_two_enter_time', 'brib_api_input_bytes', 'brib_api_input_messages', 'brib_api_input_prefixes_received', 'brib_api_input_processing_time', 'brib_api_input_withdrawn_prefixes', 'brib_api_output_bytes_generated', 'brib_api_output_bytes_sent', 'brib_api_output_calls', 'brib_api_output_generation_time', 'brib_api_output_messages_sent', 'brib_api_output_prefixes_advertised', 'brib_api_output_prefixes_withdrawn', 'brib_api_output_sending_time', 'configuration_items_processed', 'configuration_processing_time', 'current_clock_time', 'edm_processing_time', 'edm_requests_count', 'in_event_attach_calls', 'in_out_event_attach_calls', 'initial_sync_sessions_added', 'instance_node_role', 'io_handler_tm', 'io_timer_id', 'io_tree_timer_expiry', 'io_tree_timer_left', 'nsr_last_reset_reason', 'out_event_attach_calls', 'proc_scoped_sync_state', 'qad_ac_ks_failure', 'qad_ac_ks_received', 'qad_init_drops', 'qad_messages_received', 'qad_messages_sent', 'qad_processed', 'qad_recv_drops', 'qad_resumes', 'qad_send_drops', 'qad_send_failure', 'qad_suspends', 'qad_timeout_received', 'qad_timeout_recvd', 'qadack_sent', 'qadoos_drops', 'redcon_nsr_ready', 'redcon_state_time', 'sec_active_nsr_state', 'sec_active_nsrtcp_phase_two_enter_time', 'tep2p_auto_tunnel_enabled', 'total_neighbors_with_pending_postits', 'total_outstanding_postits', 'updgen_handler_tm', 'updgen_timer_id', 'updgen_tree_timer_expiry', 'updgen_tree_timer_left'], name, value)


                                    class ActiveNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, self).__init__()

                                            self.yang_name = "active-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "active-nsr-mode-enter-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime, ['entry'], name, value)


                                    class ActiveNsrfoTime(Entity):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, self).__init__()

                                            self.yang_name = "active-nsrfo-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "active-nsrfo-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime, ['entry'], name, value)


                                    class DsNpl(Entity):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:   :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:   :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\:  str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\:  bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\:  str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, self).__init__()

                                            self.yang_name = "ds-npl"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"npl-endpoint" : ("npl_endpoint", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint), "npl-priority-statistic" : ("npl_priority_statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic)}

                                            self.dir_service_conn_state = YLeaf(YType.enumeration, "dir-service-conn-state")

                                            self.dsissu_status_flag = YLeaf(YType.uint32, "dsissu-status-flag")

                                            self.issu_mgr_conn_state = YLeaf(YType.enumeration, "issu-mgr-conn-state")

                                            self.issu_phase = YLeaf(YType.str, "issu-phase")

                                            self.issu_type_ng = YLeaf(YType.boolean, "issu-type-ng")

                                            self.issuha_option = YLeaf(YType.str, "issuha-option")

                                            self.local_ds_handle = YLeaf(YType.uint64, "local-ds-handle")

                                            self.service_name = YLeaf(YType.str, "service-name")

                                            self.npl_endpoint = YList(self)
                                            self.npl_priority_statistic = YList(self)
                                            self._segment_path = lambda: "ds-npl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl, ['dir_service_conn_state', 'dsissu_status_flag', 'issu_mgr_conn_state', 'issu_phase', 'issu_type_ng', 'issuha_option', 'local_ds_handle', 'service_name'], name, value)


                                        class NplEndpoint(Entity):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\:  str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\:  str
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, self).__init__()

                                                self.yang_name = "npl-endpoint"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"endpoint" : ("endpoint", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint)}

                                                self.endpoint_active_flag = YLeaf(YType.boolean, "endpoint-active-flag")

                                                self.endpoint_handle = YLeaf(YType.uint64, "endpoint-handle")

                                                self.endpoint_issu_role = YLeaf(YType.str, "endpoint-issu-role")

                                                self.endpoint_name = YLeaf(YType.str, "endpoint-name")

                                                self.endpoint_stale_flag = YLeaf(YType.boolean, "endpoint-stale-flag")

                                                self.expected_sequence_num = YLeaf(YType.uint32, "expected-sequence-num")

                                                self.msg_size = YLeaf(YType.uint32, "msg-size")

                                                self.node_id = YLeaf(YType.str, "node-id")

                                                self.sync_group_name = YLeaf(YType.str, "sync-group-name")

                                                self.wheel_id = YLeaf(YType.uint32, "wheel-id")

                                                self.endpoint = YList(self)
                                                self._segment_path = lambda: "npl-endpoint"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint, ['endpoint_active_flag', 'endpoint_handle', 'endpoint_issu_role', 'endpoint_name', 'endpoint_stale_flag', 'expected_sequence_num', 'msg_size', 'node_id', 'sync_group_name', 'wheel_id'], name, value)


                                            class Endpoint(Entity):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                    self.yang_name = "endpoint"
                                                    self.yang_parent_name = "npl-endpoint"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint8, "entry")
                                                    self._segment_path = lambda: "endpoint"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint, ['entry'], name, value)


                                        class NplPriorityStatistic(Entity):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, self).__init__()

                                                self.yang_name = "npl-priority-statistic"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"num-recv" : ("num_recv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv), "num-recv-drop" : ("num_recv_drop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop), "num-sent" : ("num_sent", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent), "num-sent-drop" : ("num_sent_drop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop)}

                                                self.num_recv = YList(self)
                                                self.num_recv_drop = YList(self)
                                                self.num_sent = YList(self)
                                                self.num_sent_drop = YList(self)
                                                self._segment_path = lambda: "npl-priority-statistic"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic, [], name, value)


                                            class NumRecv(Entity):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                    self.yang_name = "num-recv"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "num-recv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv, ['entry'], name, value)


                                            class NumRecvDrop(Entity):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                    self.yang_name = "num-recv-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray)}

                                                    self.nsr_pl_recv_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-recv-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                                class NsrPlRecvDropArray(Entity):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-recv-drop-array"
                                                        self.yang_parent_name = "num-recv-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                                            class NumSent(Entity):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                    self.yang_name = "num-sent"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "num-sent"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent, ['entry'], name, value)


                                            class NumSentDrop(Entity):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                    self.yang_name = "num-sent-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray)}

                                                    self.nsr_pl_send_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-sent-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                                class NsrPlSendDropArray(Entity):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-06-26'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-send-drop-array"
                                                        self.yang_parent_name = "num-sent-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "nsr-pl-send-drop-array"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                                    class Ipv4RibServer(Entity):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, self).__init__()

                                            self.yang_name = "ipv4rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                            self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                            self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                            self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                            self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                            self._children_yang_names.add("first-rib-connection-down-timestamp")

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                            self._children_yang_names.add("first-rib-connection-up-timestamp")

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._children_yang_names.add("last-rib-connection-down-timestamp")

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                            self._children_yang_names.add("last-rib-connection-up-timestamp")
                                            self._segment_path = lambda: "ipv4rib-server"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class Ipv6RibServer(Entity):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, self).__init__()

                                            self.yang_name = "ipv6rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-rib-connection-down-timestamp" : ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp), "first-rib-connection-up-timestamp" : ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp), "last-rib-connection-down-timestamp" : ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp), "last-rib-connection-up-timestamp" : ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.is_rib_connection_up = YLeaf(YType.boolean, "is-rib-connection-up")

                                            self.last_rib_connection_down_age = YLeaf(YType.uint32, "last-rib-connection-down-age")

                                            self.last_rib_connection_up_age = YLeaf(YType.uint32, "last-rib-connection-up-age")

                                            self.rib_connection_down_count = YLeaf(YType.uint32, "rib-connection-down-count")

                                            self.rib_connection_up_count = YLeaf(YType.uint32, "rib-connection-up-count")

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"
                                            self._children_yang_names.add("first-rib-connection-down-timestamp")

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"
                                            self._children_yang_names.add("first-rib-connection-up-timestamp")

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._children_yang_names.add("last-rib-connection-down-timestamp")

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"
                                            self._children_yang_names.add("last-rib-connection-up-timestamp")
                                            self._segment_path = lambda: "ipv6rib-server"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer, ['is_rib_connection_up', 'last_rib_connection_down_age', 'last_rib_connection_up_age', 'rib_connection_down_count', 'rib_connection_up_count'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class IssuMilestone(Entity):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\:  str
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, self).__init__()

                                            self.yang_name = "issu-milestone"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.milestone_met_timestamp = YLeaf(YType.uint32, "milestone-met-timestamp")

                                            self.milestone_name = YLeaf(YType.str, "milestone-name")

                                            self.milestone_start_timestamp = YLeaf(YType.uint32, "milestone-start-timestamp")
                                            self._segment_path = lambda: "issu-milestone"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone, ['milestone_met_timestamp', 'milestone_name', 'milestone_start_timestamp'], name, value)


                                    class LsdConnection(Entity):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, self).__init__()

                                            self.yang_name = "lsd-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                            self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                            self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                            self._children_yang_names.add("first-connection-down-timestamp")

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                            self._children_yang_names.add("first-connection-up-timestamp")

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._children_yang_names.add("last-connection-down-timestamp")

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                            self._children_yang_names.add("last-connection-up-timestamp")
                                            self._segment_path = lambda: "lsd-connection"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                    class PostitCountInfo(Entity):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, self).__init__()

                                            self.yang_name = "postit-count-info"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-address" : ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress)}
                                            self._child_list_classes = {}

                                            self.postit_count = YLeaf(YType.uint32, "postit-count")

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._children_yang_names.add("neighbor-address")
                                            self._segment_path = lambda: "postit-count-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo, ['postit_count', 'vrf_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "postit-count-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress)}
                                                self._child_list_classes = {}

                                                self.afi = YLeaf(YType.enumeration, "afi")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                                self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                                self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                                self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                                self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                                self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                                self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                                self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                                self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                                self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                                self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                                self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                                self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                                self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                                self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                                self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                                self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                                self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                                self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                                self._children_yang_names.add("ipv4-sr-policy-address")

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._children_yang_names.add("ipv6-sr-policy-address")

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                                self._children_yang_names.add("l2vpn-mspw-address")

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                                self._children_yang_names.add("l2vpn-vpls-address")
                                                self._segment_path = lambda: "neighbor-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                            class L2VpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-mspw-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                            class L2VpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-06-26'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                                    self._segment_path = lambda: "l2vpn-vpls-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                    class StandbyNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, self).__init__()

                                            self.yang_name = "standby-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "standby-nsr-mode-enter-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime, ['entry'], name, value)


                                    class TeConnection(Entity):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, self).__init__()

                                            self.yang_name = "te-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"first-connection-down-timestamp" : ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp), "first-connection-up-timestamp" : ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp), "last-connection-down-timestamp" : ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp), "last-connection-up-timestamp" : ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp)}
                                            self._child_list_classes = {}

                                            self.connection_down_count = YLeaf(YType.uint32, "connection-down-count")

                                            self.connection_up_count = YLeaf(YType.uint32, "connection-up-count")

                                            self.is_connection_up = YLeaf(YType.boolean, "is-connection-up")

                                            self.last_connection_down_age = YLeaf(YType.uint32, "last-connection-down-age")

                                            self.last_connection_up_age = YLeaf(YType.uint32, "last-connection-up-age")

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"
                                            self._children_yang_names.add("first-connection-down-timestamp")

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"
                                            self._children_yang_names.add("first-connection-up-timestamp")

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._children_yang_names.add("last-connection-down-timestamp")

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"
                                            self._children_yang_names.add("last-connection-up-timestamp")
                                            self._segment_path = lambda: "te-connection"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection, ['connection_down_count', 'connection_up_count', 'is_connection_up', 'last_connection_down_age', 'last_connection_up_age'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "first-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-down-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp, ['nanoseconds', 'seconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")
                                                self._segment_path = lambda: "last-connection-up-timestamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.data_bytes_read = YLeaf(YType.uint32, "data-bytes-read")

                                        self.data_bytes_written = YLeaf(YType.uint32, "data-bytes-written")

                                        self.high_throttled_read_count = YLeaf(YType.uint32, "high-throttled-read-count")

                                        self.inbound_update_messages = YLeaf(YType.uint32, "inbound-update-messages")

                                        self.inbound_update_messages_time = YLeaf(YType.uint32, "inbound-update-messages-time")

                                        self.io_read_time = YLeaf(YType.uint32, "io-read-time")

                                        self.io_write_time = YLeaf(YType.uint32, "io-write-time")

                                        self.low_throttled_read_count = YLeaf(YType.uint32, "low-throttled-read-count")

                                        self.lpts_calls = YLeaf(YType.uint32, "lpts-calls")

                                        self.lpts_set_up_time = YLeaf(YType.uint32, "lpts-set-up-time")

                                        self.read_calls_count = YLeaf(YType.uint32, "read-calls-count")

                                        self.read_messages_count = YLeaf(YType.uint32, "read-messages-count")

                                        self.read_throttles_count = YLeaf(YType.uint32, "read-throttles-count")

                                        self.subgroup_list_time = YLeaf(YType.uint32, "subgroup-list-time")

                                        self.write_calls_count = YLeaf(YType.uint32, "write-calls-count")

                                        self.write_queue_calls_count = YLeaf(YType.uint32, "write-queue-calls-count")

                                        self.write_queue_messages_count = YLeaf(YType.uint32, "write-queue-messages-count")

                                        self.write_queue_time = YLeaf(YType.uint32, "write-queue-time")

                                        self.write_subgroup_calls_count = YLeaf(YType.uint32, "write-subgroup-calls-count")

                                        self.write_subgroup_messages_count = YLeaf(YType.uint32, "write-subgroup-messages-count")
                                        self._segment_path = lambda: "vrf"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf, ['data_bytes_read', 'data_bytes_written', 'high_throttled_read_count', 'inbound_update_messages', 'inbound_update_messages_time', 'io_read_time', 'io_write_time', 'low_throttled_read_count', 'lpts_calls', 'lpts_set_up_time', 'read_calls_count', 'read_messages_count', 'read_throttles_count', 'subgroup_list_time', 'write_calls_count', 'write_queue_calls_count', 'write_queue_messages_count', 'write_queue_time', 'write_subgroup_calls_count', 'write_subgroup_messages_count'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.established_neighbors_count = YLeaf(YType.uint32, "established-neighbors-count")

                                    self.neighbors_count = YLeaf(YType.uint32, "neighbors-count")

                                    self.network_count = YLeaf(YType.uint32, "network-count")

                                    self.notifications_received = YLeaf(YType.uint32, "notifications-received")

                                    self.notifications_sent = YLeaf(YType.uint32, "notifications-sent")

                                    self.path_count = YLeaf(YType.uint32, "path-count")

                                    self.update_messages_received = YLeaf(YType.uint32, "update-messages-received")

                                    self.update_messages_sent = YLeaf(YType.uint32, "update-messages-sent")
                                    self._segment_path = lambda: "vrf"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf, ['established_neighbors_count', 'neighbors_count', 'network_count', 'notifications_received', 'notifications_sent', 'path_count', 'update_messages_received', 'update_messages_sent'], name, value)


                        class Sessions(Entity):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"session" : ("session", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session)}

                                self.session = YList(self)
                                self._segment_path = lambda: "sessions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions, [], name, value)


                            class Session(Entity):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\:  bool
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "sessions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"connection-local-address" : ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress), "connection-remote-address" : ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress)}
                                    self._child_list_classes = {}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.connection_state = YLeaf(YType.enumeration, "connection-state")

                                    self.description = YLeaf(YType.str, "description")

                                    self.is_local_address_configured = YLeaf(YType.boolean, "is-local-address-configured")

                                    self.local_as = YLeaf(YType.uint32, "local-as")

                                    self.messages_queued_in = YLeaf(YType.uint32, "messages-queued-in")

                                    self.messages_queued_out = YLeaf(YType.uint32, "messages-queued-out")

                                    self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                    self.nsr_state = YLeaf(YType.enumeration, "nsr-state")

                                    self.postit_pending = YLeaf(YType.boolean, "postit-pending")

                                    self.remote_as = YLeaf(YType.uint32, "remote-as")

                                    self.speaker_id = YLeaf(YType.uint8, "speaker-id")

                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"
                                    self._children_yang_names.add("connection-local-address")

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._children_yang_names.add("connection-remote-address")
                                    self._segment_path = lambda: "session" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session, ['neighbor_address', 'connection_state', 'description', 'is_local_address_configured', 'local_as', 'messages_queued_in', 'messages_queued_out', 'nsr_enabled', 'nsr_state', 'postit_pending', 'remote_as', 'speaker_id', 'vrf_name'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "connection-remote-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundErrorNeighbors(Entity):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors, self).__init__()

                                self.yang_name = "update-inbound-error-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"update-inbound-error-neighbor" : ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor)}

                                self.update_inbound_error_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors, [], name, value)


                            class UpdateInboundErrorNeighbor(Entity):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\:  bool
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-error-neighbor"
                                    self.yang_parent_name = "update-inbound-error-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"first-update-error-handling-reset-timestamp" : ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp), "first-update-malformed-timestamp" : ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp), "first-update-memory-allocation-fail-timestamp" : ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp), "last-error-handling-reset-timestamp" : ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp), "last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp), "last-update-memory-allocation-fail-timestamp" : ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)}
                                    self._child_list_classes = {"establishment-action-count" : ("establishment_action_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount), "update-error-message" : ("update_error_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.establishment_total_update_message_count = YLeaf(YType.uint32, "establishment-total-update-message-count")

                                    self.last_error_handling_reset_age = YLeaf(YType.uint32, "last-error-handling-reset-age")

                                    self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                    self.last_update_memory_allocation_fail_age = YLeaf(YType.uint32, "last-update-memory-allocation-fail-age")

                                    self.total_update_message_count = YLeaf(YType.uint32, "total-update-message-count")

                                    self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                    self.update_error_handling_avoid_reset = YLeaf(YType.boolean, "update-error-handling-avoid-reset")

                                    self.update_error_handling_reset_count = YLeaf(YType.uint32, "update-error-handling-reset-count")

                                    self.update_error_message_list_count = YLeaf(YType.uint32, "update-error-message-list-count")

                                    self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                    self.update_memory_allocation_fail_count = YLeaf(YType.uint32, "update-memory-allocation-fail-count")

                                    self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"
                                    self._children_yang_names.add("first-update-error-handling-reset-timestamp")

                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"
                                    self._children_yang_names.add("first-update-malformed-timestamp")

                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"
                                    self._children_yang_names.add("first-update-memory-allocation-fail-timestamp")

                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"
                                    self._children_yang_names.add("last-error-handling-reset-timestamp")

                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                    self._children_yang_names.add("last-update-malformed-timestamp")

                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                    self._children_yang_names.add("last-update-memory-allocation-fail-timestamp")

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                    self._children_yang_names.add("update-neighbor-address")

                                    self.establishment_action_count = YList(self)
                                    self.update_error_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', 'establishment_total_update_message_count', 'last_error_handling_reset_age', 'last_update_malformed_age', 'last_update_memory_allocation_fail_age', 'total_update_message_count', 'update_attribute_discard_count', 'update_error_handling_avoid_reset', 'update_error_handling_reset_count', 'update_error_message_list_count', 'update_malformed_message_count', 'update_memory_allocation_fail_count', 'update_vrf_name'], name, value)


                                class EstablishmentActionCount(Entity):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                        self.yang_name = "establishment-action-count"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "establishment-action-count"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, ['entry'], name, value)


                                class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "first-update-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-error-handling-reset-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class FirstUpdateMalformedTimestamp(Entity):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "first-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-malformed-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastErrorHandlingResetTimestamp(Entity):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "last-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-error-handling-reset-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateMalformedTimestamp(Entity):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "last-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-malformed-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateErrorMessage(Entity):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                        self.yang_name = "update-error-message"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-message-reset-data" : ("update_message_reset_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData), "update-message-timestamp" : ("update_message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)}
                                        self._child_list_classes = {"update-error-element" : ("update_error_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement), "update-message-data" : ("update_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)}

                                        self.update_attribute_discard_count = YLeaf(YType.uint32, "update-attribute-discard-count")

                                        self.update_error_final_action = YLeaf(YType.enumeration, "update-error-final-action")

                                        self.update_error_nlri_address_family = YLeaf(YType.enumeration, "update-error-nlri-address-family")

                                        self.update_error_nlri_string = YLeaf(YType.str, "update-error-nlri-string")

                                        self.update_error_nlri_string_truncated = YLeaf(YType.boolean, "update-error-nlri-string-truncated")

                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self._children_name_map["update_message_reset_data"] = "update-message-reset-data"
                                        self._children_yang_names.add("update-message-reset-data")

                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self
                                        self._children_name_map["update_message_timestamp"] = "update-message-timestamp"
                                        self._children_yang_names.add("update-message-timestamp")

                                        self.update_error_element = YList(self)
                                        self.update_message_data = YList(self)
                                        self._segment_path = lambda: "update-error-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, ['update_attribute_discard_count', 'update_error_final_action', 'update_error_nlri_address_family', 'update_error_nlri_string', 'update_error_nlri_string_truncated'], name, value)


                                    class UpdateErrorElement(Entity):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:   :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                            self.yang_name = "update-error-element"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                            self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                            self.update_attribute_length = YLeaf(YType.uint16, "update-attribute-length")

                                            self.update_error_action = YLeaf(YType.enumeration, "update-error-action")

                                            self.update_error_data = YLeaf(YType.str, "update-error-data")

                                            self.update_error_data_length = YLeaf(YType.uint16, "update-error-data-length")
                                            self._segment_path = lambda: "update-error-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, ['update_attribute_code', 'update_attribute_flags', 'update_attribute_length', 'update_error_action', 'update_error_data', 'update_error_data_length'], name, value)


                                    class UpdateMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                            self.yang_name = "update-message-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "update-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, ['entry'], name, value)


                                    class UpdateMessageResetData(Entity):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:   :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                            self.yang_name = "update-message-reset-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_error_reset_notification_code = YLeaf(YType.uint8, "update-error-reset-notification-code")

                                            self.update_error_reset_notification_data = YLeaf(YType.str, "update-error-reset-notification-data")

                                            self.update_error_reset_notification_data_length = YLeaf(YType.uint16, "update-error-reset-notification-data-length")

                                            self.update_error_reset_notification_sub_code = YLeaf(YType.uint16, "update-error-reset-notification-sub-code")

                                            self.update_error_reset_reason = YLeaf(YType.enumeration, "update-error-reset-reason")
                                            self._segment_path = lambda: "update-message-reset-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, ['update_error_reset_notification_code', 'update_error_reset_notification_data', 'update_error_reset_notification_data_length', 'update_error_reset_notification_sub_code', 'update_error_reset_reason'], name, value)


                                    class UpdateMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                            self.yang_name = "update-message-timestamp"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "update-message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundErrorVrf(Entity):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf, self).__init__()

                                self.yang_name = "update-inbound-error-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"last-update-malformed-timestamp" : ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp)}
                                self._child_list_classes = {}

                                self.last_update_malformed_age = YLeaf(YType.uint32, "last-update-malformed-age")

                                self.update_malformed_message_count = YLeaf(YType.uint32, "update-malformed-message-count")

                                self.update_malformed_neighbor_count = YLeaf(YType.uint32, "update-malformed-neighbor-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._children_yang_names.add("last-update-malformed-timestamp")
                                self._segment_path = lambda: "update-inbound-error-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf, ['last_update_malformed_age', 'update_malformed_message_count', 'update_malformed_neighbor_count', 'update_vrf_name'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-malformed-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, ['nanoseconds', 'seconds'], name, value)


                        class UpdateInboundFilterNeighbors(Entity):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"update-inbound-filter-neighbor" : ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor)}

                                self.update_inbound_filter_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors, [], name, value)


                            class UpdateInboundFilterNeighbor(Entity):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-filter-neighbor"
                                    self.yang_parent_name = "update-inbound-filter-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"first-update-filtered-timestamp" : ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp), "last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp), "update-neighbor-address" : ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)}
                                    self._child_list_classes = {"update-attribute-filter-attributes" : ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes), "update-filter-message" : ("update_filter_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage)}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.configured_update_filter_message_buffer_count = YLeaf(YType.uint32, "configured-update-filter-message-buffer-count")

                                    self.establishment_total_filter_update_message_count = YLeaf(YType.uint32, "establishment-total-filter-update-message-count")

                                    self.establishment_update_filtered_message_count = YLeaf(YType.uint32, "establishment-update-filtered-message-count")

                                    self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                    self.message_update_attribute_filtering_enabled = YLeaf(YType.boolean, "message-update-attribute-filtering-enabled")

                                    self.operational_update_attribute_filtering_enabled = YLeaf(YType.boolean, "operational-update-attribute-filtering-enabled")

                                    self.operational_update_filter_message_buffer_count = YLeaf(YType.uint32, "operational-update-filter-message-buffer-count")

                                    self.total_filter_update_message_count = YLeaf(YType.uint32, "total-filter-update-message-count")

                                    self.update_attribute_filter_group_name = YLeaf(YType.str, "update-attribute-filter-group-name")

                                    self.update_filter_logging_enabled = YLeaf(YType.boolean, "update-filter-logging-enabled")

                                    self.update_filter_message_buffer_circular = YLeaf(YType.boolean, "update-filter-message-buffer-circular")

                                    self.update_filter_message_list_count = YLeaf(YType.uint32, "update-filter-message-list-count")

                                    self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                    self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"
                                    self._children_yang_names.add("first-update-filtered-timestamp")

                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                    self._children_yang_names.add("last-update-filtered-timestamp")

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"
                                    self._children_yang_names.add("update-neighbor-address")

                                    self.update_attribute_filter_attributes = YList(self)
                                    self.update_filter_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', 'configured_update_filter_message_buffer_count', 'establishment_total_filter_update_message_count', 'establishment_update_filtered_message_count', 'last_update_filtered_age', 'message_update_attribute_filtering_enabled', 'operational_update_attribute_filtering_enabled', 'operational_update_filter_message_buffer_count', 'total_filter_update_message_count', 'update_attribute_filter_group_name', 'update_filter_logging_enabled', 'update_filter_message_buffer_circular', 'update_filter_message_list_count', 'update_filtered_message_count', 'update_vrf_name'], name, value)


                                class FirstUpdateFilteredTimestamp(Entity):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "first-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "first-update-filtered-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class LastUpdateFilteredTimestamp(Entity):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "last-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "last-update-filtered-timestamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateAttributeFilterAttributes(Entity):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                        self.yang_name = "update-attribute-filter-attributes"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"last-update-filter-match-timestamp" : ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp)}
                                        self._child_list_classes = {}

                                        self.establishment_update_filter_match_count = YLeaf(YType.uint32, "establishment-update-filter-match-count")

                                        self.last_update_filter_match_age = YLeaf(YType.uint32, "last-update-filter-match-age")

                                        self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")

                                        self.update_filter_match_count = YLeaf(YType.uint32, "update-filter-match-count")

                                        self.update_internal_attribute_code = YLeaf(YType.uint32, "update-internal-attribute-code")

                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                        self._children_yang_names.add("last-update-filter-match-timestamp")
                                        self._segment_path = lambda: "update-attribute-filter-attributes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, ['establishment_update_filter_match_count', 'last_update_filter_match_age', 'update_filter_action', 'update_filter_match_count', 'update_internal_attribute_code'], name, value)


                                    class LastUpdateFilterMatchTimestamp(Entity):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                            self.yang_name = "last-update-filter-match-timestamp"
                                            self.yang_parent_name = "update-attribute-filter-attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "last-update-filter-match-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateFilterMessage(Entity):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                        self.yang_name = "update-filter-message"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-filter-message-timestamp" : ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)}
                                        self._child_list_classes = {"update-filter-element" : ("update_filter_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement), "update-filter-message-data" : ("update_filter_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)}

                                        self.update_filter_final_action = YLeaf(YType.enumeration, "update-filter-final-action")

                                        self.update_filter_nlri_address_family = YLeaf(YType.enumeration, "update-filter-nlri-address-family")

                                        self.update_filter_nlri_string = YLeaf(YType.str, "update-filter-nlri-string")

                                        self.update_filter_nlri_string_truncated = YLeaf(YType.boolean, "update-filter-nlri-string-truncated")

                                        self.update_filtered_attribute_count = YLeaf(YType.uint32, "update-filtered-attribute-count")

                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"
                                        self._children_yang_names.add("update-filter-message-timestamp")

                                        self.update_filter_element = YList(self)
                                        self.update_filter_message_data = YList(self)
                                        self._segment_path = lambda: "update-filter-message"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, ['update_filter_final_action', 'update_filter_nlri_address_family', 'update_filter_nlri_string', 'update_filter_nlri_string_truncated', 'update_filtered_attribute_count'], name, value)


                                    class UpdateFilterElement(Entity):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                            self.yang_name = "update-filter-element"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.update_attribute_code = YLeaf(YType.uint8, "update-attribute-code")

                                            self.update_attribute_flags = YLeaf(YType.uint8, "update-attribute-flags")

                                            self.update_filter_action = YLeaf(YType.enumeration, "update-filter-action")
                                            self._segment_path = lambda: "update-filter-element"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, ['update_attribute_code', 'update_attribute_flags', 'update_filter_action'], name, value)


                                    class UpdateFilterMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                            self.yang_name = "update-filter-message-data"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint8, "entry")
                                            self._segment_path = lambda: "update-filter-message-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, ['entry'], name, value)


                                    class UpdateFilterMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                            self.yang_name = "update-filter-message-timestamp"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                            self.seconds = YLeaf(YType.uint32, "seconds")
                                            self._segment_path = lambda: "update-filter-message-timestamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, ['nanoseconds', 'seconds'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ipv4-sr-policy-address" : ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress), "ipv6-sr-policy-address" : ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress), "l2vpn-mspw-address" : ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress), "l2vpn-vpls-address" : ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress)}
                                        self._child_list_classes = {}

                                        self.afi = YLeaf(YType.enumeration, "afi")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv4_flowspec_address = YLeaf(YType.str, "ipv4-flowspec-address")

                                        self.ipv4_label_address = YLeaf(YType.str, "ipv4-label-address")

                                        self.ipv4_mcast_address = YLeaf(YType.str, "ipv4-mcast-address")

                                        self.ipv4_mdt_address = YLeaf(YType.str, "ipv4-mdt-address")

                                        self.ipv4_tunnel_address = YLeaf(YType.str, "ipv4-tunnel-address")

                                        self.ipv4mvpn_address = YLeaf(YType.str, "ipv4mvpn-address")

                                        self.ipv4vpn_address = YLeaf(YType.str, "ipv4vpn-address")

                                        self.ipv4vpn_flowspec_address = YLeaf(YType.str, "ipv4vpn-flowspec-address")

                                        self.ipv4vpna_mcastddress = YLeaf(YType.str, "ipv4vpna-mcastddress")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        self.ipv6_flowspec_address = YLeaf(YType.str, "ipv6-flowspec-address")

                                        self.ipv6_label_address = YLeaf(YType.str, "ipv6-label-address")

                                        self.ipv6_mcast_address = YLeaf(YType.str, "ipv6-mcast-address")

                                        self.ipv6mvpn_address = YLeaf(YType.str, "ipv6mvpn-address")

                                        self.ipv6vpn_address = YLeaf(YType.str, "ipv6vpn-address")

                                        self.ipv6vpn_flowspec_address = YLeaf(YType.str, "ipv6vpn-flowspec-address")

                                        self.ipv6vpn_mcast_address = YLeaf(YType.str, "ipv6vpn-mcast-address")

                                        self.l2vpn_evpn_address = YLeaf(YType.str, "l2vpn-evpn-address")

                                        self.ls_ls_address = YLeaf(YType.str, "ls-ls-address")

                                        self.rt_constraint_address = YLeaf(YType.str, "rt-constraint-address")

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"
                                        self._children_yang_names.add("ipv4-sr-policy-address")

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._children_yang_names.add("ipv6-sr-policy-address")

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"
                                        self._children_yang_names.add("l2vpn-mspw-address")

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"
                                        self._children_yang_names.add("l2vpn-vpls-address")
                                        self._segment_path = lambda: "update-neighbor-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, ['afi', 'ipv4_address', 'ipv4_flowspec_address', 'ipv4_label_address', 'ipv4_mcast_address', 'ipv4_mdt_address', 'ipv4_tunnel_address', 'ipv4mvpn_address', 'ipv4vpn_address', 'ipv4vpn_flowspec_address', 'ipv4vpna_mcastddress', 'ipv6_address', 'ipv6_flowspec_address', 'ipv6_label_address', 'ipv6_mcast_address', 'ipv6mvpn_address', 'ipv6vpn_address', 'ipv6vpn_flowspec_address', 'ipv6vpn_mcast_address', 'l2vpn_evpn_address', 'ls_ls_address', 'rt_constraint_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv4_srpolicy_address = YLeaf(YType.str, "ipv4-srpolicy-address")
                                            self._segment_path = lambda: "ipv4-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, ['ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.ipv6_srpolicy_address = YLeaf(YType.str, "ipv6-srpolicy-address")
                                            self._segment_path = lambda: "ipv6-sr-policy-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, ['ipv6_srpolicy_address'], name, value)


                                    class L2VpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-mspw-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress, ['l2vpn_address'], name, value)


                                    class L2VpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.l2vpn_address = YLeaf(YType.str, "l2vpn-address")
                                            self._segment_path = lambda: "l2vpn-vpls-address"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnVplsAddress, ['l2vpn_address'], name, value)


                        class UpdateInboundFilterVrf(Entity):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf, self).__init__()

                                self.yang_name = "update-inbound-filter-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"last-update-filtered-timestamp" : ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp)}
                                self._child_list_classes = {}

                                self.last_update_filtered_age = YLeaf(YType.uint32, "last-update-filtered-age")

                                self.update_filtered_message_count = YLeaf(YType.uint32, "update-filtered-message-count")

                                self.update_filtered_neighbor_count = YLeaf(YType.uint32, "update-filtered-neighbor-count")

                                self.update_vrf_name = YLeaf(YType.str, "update-vrf-name")

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._children_yang_names.add("last-update-filtered-timestamp")
                                self._segment_path = lambda: "update-inbound-filter-vrf"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf, ['last_update_filtered_age', 'update_filtered_message_count', 'update_filtered_neighbor_count', 'update_vrf_name'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                                    self.seconds = YLeaf(YType.uint32, "seconds")
                                    self._segment_path = lambda: "last-update-filtered-timestamp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, ['nanoseconds', 'seconds'], name, value)

    def clone_ptr(self):
        self._top_entity = Bgp()
        return self._top_entity

